(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 10.4' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     80826,       2124]
NotebookOptionsPosition[     78348,       2018]
NotebookOutlinePosition[     78738,       2035]
CellTagsIndexPosition[     78695,       2032]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Initialization", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.621868657974337*^9}],

Cell["\<\
linestyle = \
{{Thickness[.01],RGBColor[0,0,0]},{Thickness[.01],RGBColor[0,0,0]}};
labelstyle = {Black,20};
axes3D[range_]:= \
Graphics3D[{Thickness[.005],Black,Line[{{-range,0,0},{range,0,0}}],Thickness[\
0.005],Black,Line[{{0,-range,0},{0,range,0}}],Thickness[0.005],Black,Line[{{0,\
0,-range},{0,0,range}}]}];
SetOptions[Plot3D,PlotRange\[Rule]{{-1,1},{-1,1},{-1,1}},Mesh\[Rule]True, \
Boxed\[Rule]True,BoxRatios\[Rule]{1,1,1},Axes\[Rule]True,Ticks\[Rule]\
Automatic,BoxStyle\[Rule]Thickness[.005],LabelStyle\[Rule]labelstyle,\
BaseStyle\[Rule]20,ImageSize\[Rule]400, \
ColorFunction\[Rule]\"GrayTones\",ClippingStyle\[Rule]None];
SetOptions[ParametricPlot3D,PlotRange\[Rule]{{-1,1},{-1,1},{-1,1}},Mesh\[Rule]\
True, Boxed\[Rule]True,BoxRatios\[Rule]{1,1,1},Axes\[Rule]True,Ticks\[Rule]\
Automatic,BoxStyle\[Rule]Thickness[.005],LabelStyle\[Rule]labelstyle,\
BaseStyle\[Rule]20,ImageSize\[Rule]400, ColorFunction\[Rule]\"GrayTones\"];
SetOptions[ContourPlot3D,PlotRange\[Rule]{{-1,1},{-1,1},{-1,1}},Mesh\[Rule]\
True, Boxed\[Rule]True,BoxRatios\[Rule]{1,1,1},Axes\[Rule]True,Ticks\[Rule]\
Automatic,BoxStyle\[Rule]Thickness[.005],LabelStyle\[Rule]labelstyle,\
BaseStyle\[Rule]20,ImageSize\[Rule]400, ColorOutput\[Rule]GrayLevel];
SetOptions[Manipulate,LabelStyle\[Rule]labelstyle];
SetOptions[Manipulator,LabelStyle\[Rule]labelstyle];
$TextStyle = {FontSize\[Rule]14, FontFamily\[Rule]\"TimesRoman\", FontWeight\
\[Rule] \"Bold\"};
SetOptions[$FrontEnd, DynamicEvaluationTimeout\[Rule]300];\
\>", "Input",
 PageWidth->WindowWidth,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.603389644118922*^9, 3.603389675194922*^9}, 
   3.603389718395277*^9, {3.603389764272524*^9, 3.603389883256543*^9}, {
   3.603501995190625*^9, 3.603501999801301*^9}, {3.603502560791518*^9, 
   3.6035025996978693`*^9}, {3.603502778111023*^9, 3.6035027969238358`*^9}, {
   3.604524179752186*^9, 3.6045242118354797`*^9}, {3.61116208315841*^9, 
   3.611162092830179*^9}, {3.6138099231496897`*^9, 3.6138099482334137`*^9}, {
   3.621868646792555*^9, 3.621868657974621*^9}, {3.627817957244691*^9, 
   3.627818002520535*^9}, 3.627910839534174*^9, {3.630889422404436*^9, 
   3.630889424591185*^9}, {3.630889462119503*^9, 3.630889489107106*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["16.  Minimal Surfaces", "Section"],

Cell[TextData[{
 "The field of minimal surfaces is an active and growing ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["one", "1"], TraditionalForm]]],
 ".  A minimal surface is defined as having zero mean ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["curvature", "2"], TraditionalForm]]],
 ".  The plane is the first and simplest of the family of minimal surfaces, \
with the catenoid and helicoid being the earliest non-trivial examples found. \
 This chapter presents only some of the more commonly known minimal surfaces \
rather than attempting to be exhaustive."
}], "Text",
 CellChangeTimes->{{3.6062480856781893`*^9, 3.606248147395299*^9}}],

Cell[CellGroupData[{

Cell["16.0 Plotting Information for This Chapter", "Subsection"],

Cell["\<\
The plots of this chapter require the 3-D graphics functions Plot3D, \
ParametricPlot3D, and ContourPlot3D.  The attributes of the plots can be \
changed by modifying the SetOptions command in the initialization cell.  Due \
to the length of time required to compute many of these surfaces, the \
function Manipulate is only wrapped around only a few of the minimal surface \
plots.  The projection used here is the perspective one described at the \
beginning of Chapter 12.  The surface representation is as described at the \
beginning of Chapter 13.  The enclosing box shown with the figures of this \
chapter has limits of -1 to +1 for all three axes, unless noted otherwise.\
\>", "Text",
 CellChangeTimes->{{3.604512959734674*^9, 3.604512962725597*^9}, {
  3.6045758776312313`*^9, 3.604575956159526*^9}, {3.6062482085488873`*^9, 
  3.606248230120851*^9}, {3.6323204513866043`*^9, 3.632320459496344*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["16.1  Elementary Minimal Surfaces", "Subsection"],

Cell[CellGroupData[{

Cell["16.1.1  Catenoid ", "Subsubsection",
 CellChangeTimes->{{3.604523913160812*^9, 3.6045239186145277`*^9}, {
   3.613809972731576*^9, 3.6138099837044497`*^9}, {3.613813231851737*^9, 
   3.613813247910184*^9}, 3.621715990367146*^9}],

Cell[TextData[{
 "Note: this is also seen as 13.7.13.\n\nParametrically, the catenoid is \
given by \n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = c\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = c\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = \[PlusMinus]c\[CenterDot]arccosh(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")\n\t\t\t \nThe catenoid is the only surface of revolution which is also a \
\"minimal surface.\"  In the following, the top (",
 StyleBox["z",
  FontSlant->"Italic"],
 " > 0) and bottom (",
 StyleBox["z",
  FontSlant->"Italic"],
 " < 0) halves are constructed separately and then combined in the final \
plot.    "
}], "Text",
 CellChangeTimes->{{3.6062482689452047`*^9, 3.606248268947785*^9}, {
  3.613811409088841*^9, 3.613811441961646*^9}, {3.6138132346390133`*^9, 
  3.613813237297811*^9}, {3.630889689166589*^9, 3.630889689740074*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "mp", ",", " ", "np", ",", " ", "p1", ",", " ", "p2", ",", " ", "minu", 
       ",", " ", "maxu"}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "41"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "41"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"minu", " ", "=", 
       RowBox[{"-", "10"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"maxu", " ", "=", " ", "10"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", "*", "u", "*", 
           RowBox[{"Cos", "[", "v", "]"}]}], ",", 
          RowBox[{"a", "*", "u", "*", 
           RowBox[{"Sin", "[", "v", "]"}]}], ",", 
          RowBox[{"c", "*", 
           RowBox[{"Sign", "[", "u", "]"}], 
           RowBox[{"ArcCosh", "[", 
            RowBox[{"Abs", "[", "u", "]"}], "]"}]}]}], "}"}], ",", " ", "\n", 
        "      ", 
        RowBox[{"{", 
         RowBox[{"u", ",", " ", "minu", ",", " ", "maxu"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"v", ",", " ", "0", ",", " ", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", " ", "np"}], "}"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "a"}], "*", "maxu"}], ",", 
           RowBox[{"a", "*", "maxu"}]}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", " ", 
           RowBox[{"-", "5"}], ",", " ", "1"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<16.1.1\>\""}]}], "]"}]}]}], "\n",
     "  ", "]"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "0.3"}], "}"}], ",", " ", "0.1", ",", " ", "1.0", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "0.7"}], "}"}], ",", " ", "0.1", ",", " ", "1.0", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "c"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.603672988639448*^9, 
   3.6036730116673307`*^9}, {3.603673064651318*^9, 3.603673089464676*^9}, {
   3.603718490787071*^9, 3.6037187286960773`*^9}, {3.603718760439679*^9, 
   3.6037188102518253`*^9}, {3.603718908852*^9, 3.6037189171412973`*^9}, {
   3.603718949927916*^9, 3.603719007376978*^9}, {3.603719083157634*^9, 
   3.603719094000058*^9}, {3.6045239599336653`*^9, 3.604523976198807*^9}, {
   3.604524011208948*^9, 3.60452401318851*^9}, {3.611150010993154*^9, 
   3.611150033483059*^9}, {3.613811447968876*^9, 3.613811468417835*^9}, {
   3.627818040518065*^9, 3.627818113217414*^9}, {3.630889629554117*^9, 
   3.630889701067025*^9}, {3.630889743972158*^9, 3.630889750556347*^9}, {
   3.6308897847052727`*^9, 3.6308897855049047`*^9}, {3.630889822705015*^9, 
   3.630889866843506*^9}, {3.630889899543372*^9, 3.630889900331822*^9}, {
   3.630889931770577*^9, 3.630889972806951*^9}, {3.6308900192958193`*^9, 
   3.630890020481923*^9}, 3.6308900700554256`*^9, 3.6308901939844303`*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.3, $CellContext`c$$ = 0.7, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.3}, 0.1, 1.}, {{
       Hold[$CellContext`c$$], 0.7}, 0.1, 1.}}, Typeset`size$$ = {
    500., {238., 253.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$2440$$ = 
    0, $CellContext`c$2441$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.3, $CellContext`c$$ = 0.7}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$2440$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2441$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`p1$, \
$CellContext`p2$, $CellContext`minu$, $CellContext`maxu$}, $CellContext`mp$ = 
         41; $CellContext`np$ = 
         41; $CellContext`minu$ = -10; $CellContext`maxu$ = 10; 
        ParametricPlot3D[{$CellContext`a$$ $CellContext`u 
           Cos[$CellContext`v], $CellContext`a$$ $CellContext`u 
           Sin[$CellContext`v], $CellContext`c$$ Sign[$CellContext`u] ArcCosh[
             
             Abs[$CellContext`u]]}, {$CellContext`u, $CellContext`minu$, \
$CellContext`maxu$}, {$CellContext`v, 0, 2 Pi}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          PlotRange -> {(-$CellContext`a$$) $CellContext`maxu$, \
$CellContext`a$$ $CellContext`maxu$}, ViewPoint -> {4, -5, 1}, PlotLabel -> 
          "16.1.1"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.3}, 0.1, 1., Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.7}, 0.1, 1., Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {321., 328.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6045240769964533`*^9, {3.604524223862053*^9, 3.604524229426817*^9}, {
   3.60457420805719*^9, 3.604574227415435*^9}, 3.6138100053240128`*^9, {
   3.613810136878686*^9, 3.6138101435785217`*^9}, {3.613811471795171*^9, 
   3.613811483551547*^9}, 3.61381325924783*^9, {3.6278180917773247`*^9, 
   3.627818130450849*^9}, 3.630889526222899*^9, 3.6308897132332487`*^9, {
   3.630889751389516*^9, 3.630889786531652*^9}, {3.6308898433848753`*^9, 
   3.630889901102078*^9}, 3.6308899822451477`*^9, {3.6308900245315437`*^9, 
   3.630890112605907*^9}, {3.6308901847550373`*^9, 3.630890194747243*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["16.1.2  Right Helicoid ", "Subsubsection",
 CellChangeTimes->{{3.604524371393752*^9, 3.6045243774661493`*^9}, {
   3.6138100287443113`*^9, 3.613810043317309*^9}, {3.613813279475301*^9, 
   3.61381328862297*^9}, 3.621715998014296*^9}],

Cell[TextData[{
 "Note that this is also seen as 12.7.14.\n\n",
 "The equation of the right helicoid is given by ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "[arctan(",
 StyleBox["y",
  FontSlant->"Italic"],
 "/",
 StyleBox["x",
  FontSlant->"Italic"],
 ") + 2",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[Pi]].  Parametrically,\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["u",
  FontSlant->"Italic"],
 "\[CenterDot]cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 "),\n\ty = ",
 StyleBox["u",
  FontSlant->"Italic"],
 "\[CenterDot]sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), \n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["v",
  FontSlant->"Italic"],
 ".  \n \nSurfaces generated with min(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") < 0 and max(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") > 0 appear as twisted ribbons.  Surfaces generated with min(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") > 0 and max(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") > 0 or with min(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") < 0 and max(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") < 0 appear as spiral staircases.  In the limit as min(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") = max(",
 StyleBox["u",
  FontSlant->"Italic"],
 "), the surface degenerates to a simple 3-D space curve.  In the following, \
2",
 StyleBox["n",
  FontSlant->"Italic"],
 " is the number of full twists of the helicoid for -1 \[LessSlantEqual] ",
 StyleBox["z",
  FontSlant->"Italic"],
 " \[LessSlantEqual] 1."
}], "Text",
 CellChangeTimes->{{3.604524458153337*^9, 3.604524520737163*^9}, {
  3.606248315873701*^9, 3.606248333818815*^9}, {3.613813281989297*^9, 
  3.613813285385785*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", " ", "np", ",", "c"}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "6"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "21"}], ";", "\[IndentingNewLine]", 
      RowBox[{"c", " ", "=", " ", "1"}], ";", "\n", "     ", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"n", " ", "\[Pi]", " ", "v"}], "]"}]}], ",", 
          RowBox[{"u", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"n", " ", "\[Pi]", " ", "v"}], "]"}]}], ",", 
          RowBox[{"c", " ", "v"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "minu", ",", "maxu"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"PlotRange", " ", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", " ", 
        RowBox[{"BoxRatios", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", 
           RowBox[{"-", "5"}], ",", "1"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<16.1.2\>\""}]}], "]"}]}]}], "\n",
     " ", "]"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "5", ",", "1"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"minu", ",", 
       RowBox[{"-", "0.4"}]}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"maxu", ",", "0.4"}], "}"}], ",", "minu", ",", "1"}], "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"n", ",", "minu", ",", "maxu"}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.603672988639448*^9, 
   3.6036730116673307`*^9}, {3.603673064651318*^9, 3.603673089464676*^9}, {
   3.603718490787071*^9, 3.6037187286960773`*^9}, {3.603718760439679*^9, 
   3.6037188102518253`*^9}, {3.603718908852*^9, 3.6037189171412973`*^9}, {
   3.603718949927916*^9, 3.603719007376978*^9}, {3.603719083157634*^9, 
   3.603719094000058*^9}, {3.603719254270371*^9, 3.603719454193747*^9}, {
   3.603719497531605*^9, 3.603719499868704*^9}, 3.603719550332416*^9, 
   3.60371958093377*^9, {3.6037197522096777`*^9, 3.603719754626832*^9}, {
   3.60371980669869*^9, 3.603719914115428*^9}, {3.603720009875557*^9, 
   3.603720015223247*^9}, {3.603720261701483*^9, 3.603720271512823*^9}, {
   3.603720385502399*^9, 3.603720393863626*^9}, {3.6037204368140297`*^9, 
   3.603720442964096*^9}, {3.603720477464559*^9, 3.603720499965723*^9}, {
   3.60372055936495*^9, 3.603720559925486*^9}, {3.6037206947671824`*^9, 
   3.60372069874082*^9}, {3.60460283839788*^9, 3.604602848927968*^9}, {
   3.611150055685001*^9, 3.6111500595335073`*^9}, 3.611152822309643*^9, {
   3.613811556585297*^9, 3.6138115673931217`*^9}, {3.627818142132002*^9, 
   3.6278181598419313`*^9}, {3.630890253083992*^9, 3.63089025497008*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`maxu$$ = 
    0.4, $CellContext`minu$$ = -0.4, $CellContext`n$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`n$$], 1, 5, 1}, {{
       Hold[$CellContext`minu$$], -0.4}, -1, 1}, {{
       Hold[$CellContext`maxu$$], 0.4}, 
      Dynamic[$CellContext`minu$$], 1}}, Typeset`size$$ = {
    500., {235., 250.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`n$1864$$ = 
    0, $CellContext`minu$1865$$ = 0, $CellContext`maxu$1866$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`maxu$$ = 
        0.4, $CellContext`minu$$ = -0.4, $CellContext`n$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$1864$$, 0], 
        Hold[$CellContext`minu$$, $CellContext`minu$1865$$, 0], 
        Hold[$CellContext`maxu$$, $CellContext`maxu$1866$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`c$}, \
$CellContext`mp$ = 6; $CellContext`np$ = 21; $CellContext`c$ = 1; 
        ParametricPlot3D[{$CellContext`u 
           Cos[$CellContext`n$$ Pi $CellContext`v], $CellContext`u 
           Sin[$CellContext`n$$ 
             Pi $CellContext`v], $CellContext`c$ $CellContext`v}, \
{$CellContext`u, $CellContext`minu$$, $CellContext`maxu$$}, {$CellContext`v, \
-1, 1}, PlotRange -> {{-1, 1}, {-1, 1}, {-1, 1}}, BoxRatios -> {1, 1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {4, -5, 1}, PlotLabel -> "16.1.2"]], 
      "Specifications" :> {{$CellContext`n$$, 1, 5, 
         1}, {{$CellContext`minu$$, -0.4}, -1, 
         1}, {{$CellContext`maxu$$, 0.4}, 
         Dynamic[$CellContext`minu$$], 1}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`n$$, $CellContext`minu$$, \
$CellContext`maxu$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {339., 346.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604524394558321*^9, 3.604524402782394*^9}, 
   3.613810058115299*^9, {3.613810201010729*^9, 3.6138102074272623`*^9}, 
   3.6138115806699877`*^9, {3.627818164731757*^9, 3.6278181734527493`*^9}, {
   3.630890237656904*^9, 3.630890256311083*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["16.2  Complex Minimal Surfaces", "Subsection"],

Cell[CellGroupData[{

Cell["16.2.1  Enneper's Surface", "Subsubsection"],

Cell[TextData[{
 "Enneper's surface is given parametrically by:\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["r",
  FontSlant->"Italic"],
 " cos(\[CurlyPhi]) - ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox[
     StyleBox["r",
      FontSlant->"Italic"], "3"], "3"], TraditionalForm]]],
 "cos(3\[CurlyPhi])\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   FractionBox["r", "3"], TraditionalForm]]],
 "[3 sin(\[CurlyPhi]) + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["r",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 "sin(3\[CurlyPhi])]\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "2"], TraditionalForm]]],
 Cell[BoxData[
  StyleBox[
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"2", "\[CurlyPhi]"}], ")"}], " "}], "Text"]]],
 "\n\nwhere\n\t\n\t0 \[LessEqual] ",
 StyleBox["r",
  FontSlant->"Italic"],
 " \[LessEqual] ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\t(",
 StyleBox["a",
  FontSlant->"Italic"],
 " is arbitrary)\n\t-\[Pi] \[LessEqual] \[CurlyPhi] \[LessEqual] \[Pi]"
}], "Text",
 CellChangeTimes->{{3.604524627576645*^9, 3.6045246321658993`*^9}, {
  3.6045247326908293`*^9, 3.6045247745704517`*^9}, {3.604525058203216*^9, 
  3.6045250728918858`*^9}, {3.6138103472831697`*^9, 3.613810347594067*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", " ", "np", ",", " ", "a"}], "}"}], ",", " ", 
     "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "36"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "51"}], ";", "\[IndentingNewLine]", 
      RowBox[{"a", " ", "=", " ", "2"}], ";", "\n", "     ", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"r", " ", 
            RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", "^", "3"}], "/", "3"}], ")"}], 
            RowBox[{"Cos", "[", 
             RowBox[{"3", " ", "\[CurlyPhi]"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"r", "/", "3"}], ")"}]}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "+", 
             RowBox[{
              RowBox[{"r", "^", "2"}], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"3", " ", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"r", "^", "2"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "\[CurlyPhi]"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "0", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[CurlyPhi]", ",", 
          RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", 
           RowBox[{"-", "4"}], ",", "2"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<16.2.1\>\""}]}], "]"}]}]}], "\n",
     "  ", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.603672988639448*^9, 
   3.6036730116673307`*^9}, {3.603673064651318*^9, 3.603673089464676*^9}, {
   3.603718490787071*^9, 3.6037187286960773`*^9}, {3.603718760439679*^9, 
   3.6037188102518253`*^9}, {3.603718908852*^9, 3.6037189171412973`*^9}, {
   3.603718949927916*^9, 3.603719007376978*^9}, {3.603719083157634*^9, 
   3.603719094000058*^9}, {3.603719254270371*^9, 3.603719454193747*^9}, {
   3.603719497531605*^9, 3.603719499868704*^9}, 3.603719550332416*^9, 
   3.60371958093377*^9, {3.6037197522096777`*^9, 3.603719754626832*^9}, {
   3.60371980669869*^9, 3.603719914115428*^9}, {3.603720009875557*^9, 
   3.603720015223247*^9}, {3.603720261701483*^9, 3.603720271512823*^9}, {
   3.603720385502399*^9, 3.603720393863626*^9}, {3.6037204368140297`*^9, 
   3.603720442964096*^9}, {3.603720477464559*^9, 3.603720499965723*^9}, {
   3.60372055936495*^9, 3.603720559925486*^9}, {3.6037206947671824`*^9, 
   3.60372069874082*^9}, {3.604524928114356*^9, 3.604524954382243*^9}, {
   3.6045250836582203`*^9, 3.604525099301528*^9}, {3.604525151740287*^9, 
   3.604525169793234*^9}, {3.611150076294736*^9, 3.6111500937082167`*^9}, {
   3.613810269824121*^9, 3.6138102869225693`*^9}, 3.6138113085071507`*^9, {
   3.621716010480255*^9, 3.621716030178825*^9}, {3.627820215116344*^9, 
   3.627820235458703*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {259., 274.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp, $CellContext`np, $CellContext`a}, \
$CellContext`mp = 36; $CellContext`np = 51; $CellContext`a = 2; 
        ParametricPlot3D[{$CellContext`r 
            Cos[$CellContext`\[CurlyPhi]] - ($CellContext`r^3/3) 
           Cos[3 $CellContext`\[CurlyPhi]], (-($CellContext`r/3)) (
            3 Sin[$CellContext`\[CurlyPhi]] + $CellContext`r^2 
             Sin[3 $CellContext`\[CurlyPhi]]), $CellContext`r^2 
           Cos[2 $CellContext`\[CurlyPhi]]}, {$CellContext`r, 
           0, $CellContext`a}, {$CellContext`\[CurlyPhi], -Pi, Pi}, 
          PlotPoints -> {$CellContext`mp, $CellContext`np}, 
          PlotRange -> {{-4, 4}, {-4, 4}, {-4, 4}}, ViewPoint -> {4, -4, 2}, 
          PlotLabel -> "16.2.1"]], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {297., 304.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.604525201088805*^9, 3.613810297386104*^9, 
  3.6138113132211637`*^9, 3.6278202909193373`*^9, 3.630943453697253*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["16.2.2  Costa's Surface", "Subsubsection"],

Cell["\<\
This algorithm for plotting Costa's surface was taken from the MathWorld \
website.  The plot will take several seconds to complete.  \
\>", "Text",
 CellChangeTimes->{
  3.604574368425406*^9, {3.604575215732648*^9, 3.60457522458492*^9}, {
   3.613810456864011*^9, 3.6138104568663387`*^9}, {3.6309442790343122`*^9, 
   3.630944286681551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"g", ",", "e1", ",", "Costa", ",", "\[Epsilon]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g", "=", 
       RowBox[{"WeierstrassInvariants", "[", 
        RowBox[{"{", 
         RowBox[{"0.5", ",", 
          RowBox[{"\[ImaginaryI]", "/", "2"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"e1", "=", 
       RowBox[{"WeierstrassP", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "g"}], "]"}]}], ";", "\n", "     ", 
      RowBox[{
       RowBox[{"Costa", "[", 
        RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
       RowBox[{"Module", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"wz1", "=", 
            RowBox[{"WeierstrassZeta", "[", 
             RowBox[{
              RowBox[{"u", "+", 
               RowBox[{"\[ImaginaryI]", " ", "v"}]}], ",", "g"}], "]"}]}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"wz2", "=", 
            RowBox[{"WeierstrassZeta", "[", 
             RowBox[{
              RowBox[{"u", "+", 
               RowBox[{"\[ImaginaryI]", " ", "v"}], "-", 
               RowBox[{"1", "/", "2"}]}], ",", "g"}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"wz3", "=", 
            RowBox[{"WeierstrassZeta", "[", 
             RowBox[{
              RowBox[{"u", "+", 
               RowBox[{"\[ImaginaryI]", " ", "v"}], "-", 
               RowBox[{"\[ImaginaryI]", "/", "2"}]}], ",", "g"}], "]"}]}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"wp", "=", 
            RowBox[{"WeierstrassP", "[", 
             RowBox[{
              RowBox[{"u", "+", 
               RowBox[{"\[ImaginaryI]", " ", "v"}]}], ",", "g"}], "]"}]}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"Re", "[", 
             RowBox[{
              RowBox[{"-", "wz1"}], "+", 
              RowBox[{"\[Pi]", " ", "u"}], "+", 
              RowBox[{
               RowBox[{"\[Pi]", "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "e1"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"\[Pi]", "/", 
                RowBox[{"(", 
                 RowBox[{"2", "e1"}], ")"}]}], 
               RowBox[{"(", 
                RowBox[{"wz2", "-", "wz3"}], ")"}]}]}], "]"}], "/", "2"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Re", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "\[ImaginaryI]"}], " ", "wz1"}], "+", 
              RowBox[{"\[Pi]", " ", "v"}], "+", 
              RowBox[{
               RowBox[{"\[Pi]", "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "e1"}], ")"}]}], "-", 
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"\[Pi]", "/", 
                RowBox[{"(", 
                 RowBox[{"2", "e1"}], ")"}]}], 
               RowBox[{"(", 
                RowBox[{"wz2", "-", "wz3"}], ")"}]}]}], "]"}], "/", "2"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{"2", "\[Pi]"}], "]"}], "/", "4"}], ")"}], 
            RowBox[{"Log", "[", 
             RowBox[{"Abs", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"wp", "-", "e1"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"wp", "+", "e1"}], ")"}]}], "]"}], "]"}]}]}], 
          "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]", "]"}]}], ";",
       "\n", "     ", 
      RowBox[{"\[Epsilon]", "=", 
       RowBox[{"10.", "^", 
        RowBox[{"(", 
         RowBox[{"-", "6"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"Costa", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "\[Epsilon]", ",", 
          RowBox[{"1", "-", "\[Epsilon]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", "\[Epsilon]", ",", 
          RowBox[{"1", "-", "\[Epsilon]"}]}], "}"}], ",", 
        RowBox[{"PlotRange", " ", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"BoxRatios", " ", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "3"}], "}"}]}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"50", ",", "120"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", 
           RowBox[{"-", "3"}], ",", "3"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<16.2.2\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.6045252827040052`*^9, 3.60452534271*^9}, {
   3.604525380298201*^9, 3.604525384516548*^9}, {3.604525463772418*^9, 
   3.6045254886906*^9}, 3.604525604469183*^9, {3.6045256741133204`*^9, 
   3.604525680525185*^9}, {3.60452571789889*^9, 3.604525726267469*^9}, {
   3.60457439859793*^9, 3.604574412499317*^9}, {3.604574459112471*^9, 
   3.604574463363195*^9}, {3.604574495430434*^9, 3.604574496260269*^9}, {
   3.604574583153948*^9, 3.604574589913443*^9}, {3.6045749773775387`*^9, 
   3.604574992183858*^9}, {3.6045750316374407`*^9, 3.604575106732627*^9}, 
   3.604575162081069*^9, {3.611150114912344*^9, 3.611150138247924*^9}, {
   3.6217160465556087`*^9, 3.6217160557559834`*^9}, {3.6278203088864*^9, 
   3.627820338611611*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {242., 258.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`g, $CellContext`e1, $CellContext`Costa, \
$CellContext`\[Epsilon]}, $CellContext`g = 
         WeierstrassInvariants[{0.5, I/2}]; $CellContext`e1 = 
         WeierstrassP[1/2, $CellContext`g]; $CellContext`Costa[
           Pattern[$CellContext`u, 
            Blank[]], 
           Pattern[$CellContext`v, 
            Blank[]]] := 
         Module[{$CellContext`wz1 = 
            WeierstrassZeta[$CellContext`u + 
              I $CellContext`v, $CellContext`g], $CellContext`wz2 = 
            WeierstrassZeta[$CellContext`u + I $CellContext`v - 1/
              2, $CellContext`g], $CellContext`wz3 = 
            WeierstrassZeta[$CellContext`u + I $CellContext`v - I/
              2, $CellContext`g], $CellContext`wp = 
            WeierstrassP[$CellContext`u + 
              I $CellContext`v, $CellContext`g]}, {
           Re[-$CellContext`wz1 + Pi $CellContext`u + 
              Pi^2/(4 $CellContext`e1) + (Pi/(
                2 $CellContext`e1)) ($CellContext`wz2 - $CellContext`wz3)]/2, 
            Re[(-I) $CellContext`wz1 + Pi $CellContext`v + 
              Pi^2/(4 $CellContext`e1) - 
              I (Pi/(2 $CellContext`e1)) ($CellContext`wz2 - \
$CellContext`wz3)]/2, (Sqrt[2 Pi]/4) Log[
              
              Abs[($CellContext`wp - $CellContext`e1)/($CellContext`wp + \
$CellContext`e1)]]}]; $CellContext`\[Epsilon] = 10.^(-6); ParametricPlot3D[
          $CellContext`Costa[$CellContext`u, $CellContext`v], \
{$CellContext`u, $CellContext`\[Epsilon], 
           1 - $CellContext`\[Epsilon]}, {$CellContext`v, $CellContext`\
\[Epsilon], 1 - $CellContext`\[Epsilon]}, 
          PlotRange -> {{-4, 4}, {-4, 4}, {-3, 3}}, BoxRatios -> {4, 4, 3}, 
          PlotPoints -> {50, 120}, ViewPoint -> {4, -3, 3}, PlotLabel -> 
          "16.2.2"]], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {280., 288.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604525617962533*^9, 3.604525682328418*^9, 3.604525728199997*^9, 
   3.6045744999434233`*^9, 3.6045749974351482`*^9, 3.604575039869074*^9, {
   3.604575093664419*^9, 3.60457510867548*^9}, 3.604575206230999*^9, 
   3.61381034060254*^9, 3.627820341565611*^9, 3.6278203971338453`*^9, 
   3.6309435496899557`*^9, 3.630944787058971*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["16.2.3  Hennenberg's Surface", "Subsubsection"],

Cell[TextData[{
 "Hennenberg's surface is given parametrically by\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 2 sinh(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 ") - 2 sinh(3",
 StyleBox["u",
  FontSlant->"Italic"],
 ")cos(3",
 StyleBox["v",
  FontSlant->"Italic"],
 ")/3\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 2 sinh(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 ") + 2 sinh(3",
 StyleBox["u",
  FontSlant->"Italic"],
 ")sin(3",
 StyleBox["v",
  FontSlant->"Italic"],
 ")/3\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = 2 cosh(2",
 StyleBox["u",
  FontSlant->"Italic"],
 ") cos(2",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t\nwhere \n\n\t0 \[LessEqual] ",
 StyleBox["u",
  FontSlant->"Italic"],
 " \[LessEqual] ",
 StyleBox["a",
  FontSlant->"Italic"],
 "  (",
 StyleBox["a",
  FontSlant->"Italic"],
 " is arbitrary)\n\t-\[Pi] \[LessEqual] ",
 StyleBox["v",
  FontSlant->"Italic"],
 " \[LessEqual] \[Pi] "
}], "Text",
 CellChangeTimes->{{3.61381048819632*^9, 3.613810539495208*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", "np", ",", " ", "a"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "35"}], ";", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "100"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"a", " ", "=", " ", "0.95"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"Sinh", "[", "u", "]"}], 
            RowBox[{"Cos", "[", "v", "]"}]}], " ", "-", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "/", "3"}], ")"}], 
            RowBox[{"Sinh", "[", 
             RowBox[{"3", "u"}], "]"}], 
            RowBox[{"Cos", "[", 
             RowBox[{"3", "v"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"Sinh", "[", "u", "]"}], 
            RowBox[{"Sin", "[", "v", "]"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "/", "3"}], ")"}], 
            RowBox[{"Sinh", "[", 
             RowBox[{"3", "u"}], "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"3", "v"}], "]"}]}]}], ",", 
          RowBox[{"2", 
           RowBox[{"Cosh", "[", 
            RowBox[{"2", "u"}], "]"}], 
           RowBox[{"Cos", "[", 
            RowBox[{"2", "v"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "0.0", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"PlotRange", " ", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "7"}], ",", "7"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", "4", ",", "2"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<16.2.3\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604575355833387*^9, 3.60457541660782*^9}, {
  3.6111501574345417`*^9, 3.611150161420039*^9}, {3.613810559537003*^9, 
  3.613810576811933*^9}, {3.613811266404249*^9, 3.613811275778907*^9}, {
  3.621716071055274*^9, 3.621716078642898*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {251., 267.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp, $CellContext`np, $CellContext`a}, \
$CellContext`mp = 35; $CellContext`np = 100; $CellContext`a = 0.95; 
        ParametricPlot3D[{
          2 Sinh[$CellContext`u] Cos[$CellContext`v] - (2/3) 
           Sinh[3 $CellContext`u] Cos[3 $CellContext`v], 
           2 Sinh[$CellContext`u] Sin[$CellContext`v] + (2/3) 
            Sinh[3 $CellContext`u] Sin[3 $CellContext`v], 2 
           Cosh[2 $CellContext`u] Cos[2 $CellContext`v]}, {$CellContext`u, 
           0., $CellContext`a}, {$CellContext`v, -Pi, Pi}, 
          PlotPoints -> {$CellContext`mp, $CellContext`np}, 
          PlotRange -> {{-7, 7}, {-7, 7}, {-7, 7}}, ViewPoint -> {4, 4, 2}, 
          PlotLabel -> "16.2.3"]], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {289., 297.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604575428802752*^9, 3.6138105823313828`*^9, 3.613811279838022*^9, 
   3.627820454384626*^9, {3.630943724161034*^9, 3.630943748983724*^9}, 
   3.630944975036663*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["16.2.4  Scherk's First Surface", "Subsubsection"],

Cell[TextData[{
 "Scherk's first surface is given explicitly by \n\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ln[cos(",
 StyleBox["x",
  FontSlant->"Italic"],
 ")/cos(",
 StyleBox["y",
  FontSlant->"Italic"],
 ")] \n\t\nor implicitly by\n\n\t",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   StyleBox["z",
    FontSlant->"Italic"]]]],
 " cos(",
 StyleBox["y",
  FontSlant->"Italic"],
 ") - cos(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") = 0.  "
}], "Text",
 CellChangeTimes->{{3.604575463843528*^9, 3.60457548598869*^9}, {
  3.604577026249275*^9, 3.604577071370425*^9}, {3.6046010804355803`*^9, 
  3.604601097391548*^9}, {3.604602732811776*^9, 3.604602763096904*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 51;
    np = 51;
    Plot3D[Log[Cos[x]/Cos[y]],{x,-2\[Pi],2\[Pi]}, {y,-2\[Pi],2\[Pi]}, \
PlotPoints\[Rule]{mp,np},PlotRange\[Rule]{{-2\[Pi],2\[Pi]},{-2\[Pi],2\[Pi]},{-\
4,4}},
 BoxRatios\[Rule]{2\[Pi],2\[Pi],4}, ViewPoint\[Rule]{2,-3,2},PlotLabel\[Rule]\
\"16.2.4\"] 
  ],
  TrackedSymbols\[Rule]{}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.6045755349845057`*^9, 3.604575568148388*^9}, {
   3.604575601453744*^9, 3.6045756311841803`*^9}, {3.604575669050002*^9, 
   3.604575745548574*^9}, {3.604576337378994*^9, 3.60457638012784*^9}, 
   3.6045767074031153`*^9, {3.604576915811018*^9, 3.604576992521652*^9}, {
   3.611150168493938*^9, 3.6111501716796207`*^9}, {3.621716090928731*^9, 
   3.621716100377534*^9}, {3.627820492821773*^9, 3.627820513670162*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {239., 254.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp, $CellContext`np}, $CellContext`mp = 
         51; $CellContext`np = 51; Plot3D[
          Log[
          Cos[$CellContext`x]/Cos[$CellContext`y]], {$CellContext`x, (-2) Pi, 
           2 Pi}, {$CellContext`y, (-2) Pi, 2 Pi}, 
          PlotPoints -> {$CellContext`mp, $CellContext`np}, 
          PlotRange -> {{(-2) Pi, 2 Pi}, {(-2) Pi, 2 Pi}, {-4, 4}}, 
          BoxRatios -> {2 Pi, 2 Pi, 4}, ViewPoint -> {2, -3, 2}, PlotLabel -> 
          "16.2.4"]], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {277., 284.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604576392621168*^9, 3.6045767159121637`*^9, {3.604576981237052*^9, 
   3.604576997624981*^9}, 3.613810610336484*^9, 3.627820522110899*^9, 
   3.6309437952206993`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["16.2.5  Scherk's Second Surface", "Subsubsection"],

Cell[TextData[{
 "Scherk's Second Surface is given parametrically by:\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = Re{2[ln(1 + ",
 StyleBox["r",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[CurlyPhi]"], 
   TraditionalForm]]],
 ") - ln(1 - ",
 StyleBox["r",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[CurlyPhi]"], 
   TraditionalForm]]],
 ")]}\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = Re[4\[ImaginaryI] ta",
 Cell[BoxData[
  SuperscriptBox["n", 
   RowBox[{"-", "1"}]]]],
 "(",
 StyleBox["r",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", "i\[CurlyPhi]"], TraditionalForm]]],
 ")]\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " =",
 " Re{2\[ImaginaryI][-ln(1 - ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["r",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"2", "\[ImaginaryI]\[CurlyPhi]"}]], TraditionalForm]]],
 ") + ln(1 + ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        StyleBox["r",
         FontSlant->"Italic"], "2"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", "\[ImaginaryI]\[CurlyPhi]"}]]}], ")"}], "]"}], "}"}], 
   TraditionalForm]]],
 "\n\t\t\nwhere\n\t\t \n\t0 \[LessEqual] \[CurlyPhi] < 2\[Pi]\n\t0 < ",
 StyleBox["r",
  FontSlant->"Italic"],
 " < 1\t\t"
}], "Text",
 CellChangeTimes->{{3.604601368200123*^9, 3.604601420670932*^9}, {
  3.604601460226293*^9, 3.604601460226385*^9}, {3.604601496799552*^9, 
  3.604601496799652*^9}, {3.6046015301030483`*^9, 3.6046015436193457`*^9}, {
  3.6046027201130857`*^9, 3.6046027216743717`*^9}, {3.60624841996165*^9, 
  3.606248433010268}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 51;
    np = 51;
    ParametricPlot3D[
{Re[2*(-Log[1 - E^(I*\[CurlyPhi])*r] + Log[1 + E^(I*\[CurlyPhi])*r])], 
  Re[4*I*ArcTan[E^(I*\[CurlyPhi])*r]], 
  Re[2*I*(-Log[1 - E^(2*I*\[CurlyPhi])*r^2] + Log[1 + \
E^(2*I*\[CurlyPhi])*r^2])]},
{\[CurlyPhi], 0, 2\[Pi]}, {r, .01, .99}, \
PlotRange\[Rule]{{-3,3},{-3,3},{-3,3}}, PlotPoints\[Rule]{mp,np},ViewPoint\
\[Rule]{4, -5, 4},PlotLabel\[Rule]\"16.2.5\"]
  ],
  TrackedSymbols\[Rule]{}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604601590896553*^9, 3.6046017084144163`*^9}, {
   3.6046017873441687`*^9, 3.6046017963873367`*^9}, {3.611150179279751*^9, 
   3.611150182642248*^9}, 3.6138106737729483`*^9, 3.613810775323306*^9, {
   3.61381081407318*^9, 3.613810837884479*^9}, {3.621716123140123*^9, 
   3.621716131690406*^9}, {3.6278205471093473`*^9, 3.627820563857634*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {283., 298.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp, $CellContext`np}, $CellContext`mp = 
         51; $CellContext`np = 51; ParametricPlot3D[{
           Re[
           2 (-Log[1 - E^(I $CellContext`\[CurlyPhi]) $CellContext`r] + 
             Log[1 + E^(I $CellContext`\[CurlyPhi]) $CellContext`r])], 
           Re[4 I ArcTan[E^(I $CellContext`\[CurlyPhi]) $CellContext`r]], 
           Re[
           2 I (-Log[1 - E^(2 I $CellContext`\[CurlyPhi]) $CellContext`r^2] + 
             Log[1 + E^(2 
                  I $CellContext`\[CurlyPhi]) $CellContext`r^2])]}, \
{$CellContext`\[CurlyPhi], 0, 2 Pi}, {$CellContext`r, 0.01, 0.99}, 
          PlotRange -> {{-3, 3}, {-3, 3}, {-3, 3}}, 
          PlotPoints -> {$CellContext`mp, $CellContext`np}, 
          ViewPoint -> {4, -5, 4}, PlotLabel -> "16.2.5"]], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {321., 328.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6138108220339193`*^9, 3.613810839454834*^9}, 
   3.627820569050231*^9, 3.6309438423866377`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["16.2.6  Catalan's Surface", "Subsubsection"],

Cell[TextData[{
 "Catalan's Surface is given parametrically by:\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["u",
  FontSlant->"Italic"],
 " - sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") cosh(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 1 - cosh(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") cosh(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = - 4 sin(",
 Cell[BoxData[
  FormBox[
   FractionBox[
    StyleBox["u",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 ") sinh(",
 Cell[BoxData[
  FormBox[
   FractionBox[
    StyleBox["v",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 ")\n\t\nwhere\n\n\t0 \[LessEqual] ",
 StyleBox["u",
  FontSlant->"Italic"],
 " \[LessEqual] 2",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[Pi]\t(",
 StyleBox["n",
  FontSlant->"Italic"],
 " gives the number of periodic repetitions in the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " direction)\n\t-",
 StyleBox["a",
  FontSlant->"Italic"],
 " \[LessEqual] ",
 StyleBox["v",
  FontSlant->"Italic"],
 " \[LessEqual] ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\t(",
 StyleBox["a",
  FontSlant->"Italic"],
 " is arbitrary)"
}], "Text",
 CellChangeTimes->{
  3.604601893813922*^9, {3.604602121277014*^9, 3.604602124278624*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", "np", ",", "n", ",", " ", "a"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "50"}], ";", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "50"}], ";", "\[IndentingNewLine]", 
      RowBox[{"n", " ", "=", " ", "2"}], ";", "\[IndentingNewLine]", 
      RowBox[{"a", " ", "=", " ", "2"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", " ", "-", " ", 
           RowBox[{
            RowBox[{"Sin", "[", "u", "]"}], 
            RowBox[{"Cosh", "[", "v", "]"}]}]}], ",", 
          RowBox[{"1", " ", "-", " ", 
           RowBox[{
            RowBox[{"Cos", "[", "u", "]"}], 
            RowBox[{"Cosh", "[", "v", "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"u", "/", "2"}], "]"}], 
           RowBox[{"Sinh", "[", 
            RowBox[{"v", "/", "2"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "0", ",", 
          RowBox[{"2", " ", "n", " ", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"-", "a"}], ",", "a"}], "}"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "15"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"BoxRatios", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"3", ",", 
           RowBox[{"-", "7"}], ",", "2"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<16.2.6\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.6046019215851603`*^9, 3.6046019337216787`*^9}, {
  3.604601985706029*^9, 3.604602036522839*^9}, {3.6111502122460814`*^9, 
  3.611150216158667*^9}, {3.6138111539064713`*^9, 3.6138111920259247`*^9}, {
  3.621716140479795*^9, 3.621716148143249*^9}, {3.627820583859002*^9, 
  3.6278205856965923`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {267., 283.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp, $CellContext`np, $CellContext`n, \
$CellContext`a}, $CellContext`mp = 50; $CellContext`np = 50; $CellContext`n = 
         2; $CellContext`a = 2; 
        ParametricPlot3D[{$CellContext`u - Sin[$CellContext`u] 
           Cosh[$CellContext`v], 1 - Cos[$CellContext`u] 
           Cosh[$CellContext`v], (-4) Sin[$CellContext`u/2] 
           Sinh[$CellContext`v/2]}, {$CellContext`u, 0, 2 $CellContext`n 
           Pi}, {$CellContext`v, -$CellContext`a, $CellContext`a}, 
          PlotRange -> {{-5, 15}, {-10, 10}, {-10, 10}}, 
          BoxRatios -> {1, 1, 1}, 
          PlotPoints -> {$CellContext`mp, $CellContext`np}, 
          ViewPoint -> {3, -7, 2}, PlotLabel -> "16.2.6"]], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {305., 313.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604602065585476*^9, {3.6138110282704067`*^9, 3.613811051369001*^9}, {
   3.613811204793639*^9, 3.613811207297666*^9}, 3.6278205875976543`*^9, 
   3.63094387956639*^9, 3.630945003131009*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["16.2.7  Richmond's Surface", "Subsubsection"],

Cell[TextData[{
 "Richmond's Surface (of degree 1) is given parametrically by:\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = -cos(\[CurlyPhi])/(2",
 StyleBox["r",
  FontSlant->"Italic"],
 ") - ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox[
     StyleBox["r",
      FontSlant->"Italic"], "3"], "6"], TraditionalForm]]],
 "cos(3\[CurlyPhi])\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = -sin(\[CurlyPhi])/(2",
 StyleBox["r",
  FontSlant->"Italic"],
 ") - ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox[
     StyleBox["r",
      FontSlant->"Italic"], "3"], "6"], TraditionalForm]]],
 "sin(3\[CurlyPhi])\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["r",
     FontSlant->"Italic"], " "}], TraditionalForm]]],
 "cos(\[CurlyPhi])\n\t\nwhere\n\n\t0 \[LessEqual] \[CurlyPhi] \[LessEqual] 2\
\[Pi]\n\t",
 StyleBox["a",
  FontSlant->"Italic"],
 " \[LessEqual] ",
 StyleBox["r",
  FontSlant->"Italic"],
 " \[LessEqual] ",
 StyleBox["b",
  FontSlant->"Italic"],
 "\t(",
 StyleBox["a, b",
  FontSlant->"Italic"],
 " are arbitrary but positive)"
}], "Text",
 CellChangeTimes->{{3.6046021549796467`*^9, 3.6046021597670794`*^9}, 
   3.6046022313223667`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", "np", ",", " ", "a", ",", " ", "b"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "20"}], ";", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "60"}], ";", "\[IndentingNewLine]", 
      RowBox[{"a", " ", "=", " ", "0.3"}], ";", "\[IndentingNewLine]", 
      RowBox[{"b", " ", "=", " ", "1.0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"2", " ", "r"}], ")"}]}], " ", "-", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", "^", "3"}], "/", "6"}], ")"}], 
            RowBox[{"Cos", "[", 
             RowBox[{"3", " ", "\[CurlyPhi]"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"2", " ", "r"}], ")"}]}], " ", "-", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", "^", "3"}], "/", "6"}], ")"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"3", "\[CurlyPhi]"}], "]"}]}]}], ",", " ", 
          RowBox[{"r", " ", 
           RowBox[{"Cos", "[", " ", "\[CurlyPhi]", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "a", ",", "b"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[CurlyPhi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"BoxRatios", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"7", ",", "7", ",", "3"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<16.2.7\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604602249326058*^9, 3.6046022946640882`*^9}, {
  3.60460232642276*^9, 3.604602327469118*^9}, {3.6111502236086817`*^9, 
  3.611150226821134*^9}, {3.613811092766227*^9, 3.613811132315419*^9}, {
  3.621716162505763*^9, 3.621716169642943*^9}, {3.627820600870515*^9, 
  3.6278206036203747`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {232., 247.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp, $CellContext`np, $CellContext`a, \
$CellContext`b}, $CellContext`mp = 20; $CellContext`np = 60; $CellContext`a = 
         0.3; $CellContext`b = 1.; 
        ParametricPlot3D[{(-Cos[$CellContext`\[CurlyPhi]])/(
            2 $CellContext`r) - ($CellContext`r^3/6) 
           Cos[3 $CellContext`\[CurlyPhi]], (-Sin[$CellContext`\[CurlyPhi]])/(
            2 $CellContext`r) - ($CellContext`r^3/6) 
           Sin[3 $CellContext`\[CurlyPhi]], $CellContext`r 
           Cos[$CellContext`\[CurlyPhi]]}, {$CellContext`r, $CellContext`a, \
$CellContext`b}, {$CellContext`\[CurlyPhi], 0, 2 Pi}, 
          PlotRange -> {{-1, 1}, {-1, 1}, {-1, 1}}, BoxRatios -> {1, 1, 1}, 
          PlotPoints -> {$CellContext`mp, $CellContext`np}, 
          ViewPoint -> {7, 7, 3}, PlotLabel -> "16.2.7"]], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {270., 277.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.6046023346760683`*^9, 3.613811063070656*^9, 
  3.613811135674643*^9, 3.627820611581654*^9, 3.6309439158144827`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["16.2.8  Bour's Surface", "Subsubsection"],

Cell[TextData[{
 "Bour's Surface (of degree 3) is given parametrically by:\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "2"], TraditionalForm]]],
 "cos(2\[CurlyPhi]) - ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "4"], TraditionalForm]]],
 "cos(4\[CurlyPhi])/4\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "2"], TraditionalForm]]],
 "sin(2\[CurlyPhi]) + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "4"], TraditionalForm]]],
 "sin(4\[CurlyPhi])/4\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = 2",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "3"], TraditionalForm]]],
 "cos(3\[CurlyPhi])/3\n\t\nwhere\n\n\t0 \[LessEqual] \[CurlyPhi] \[LessEqual] \
2\[Pi]\n\t0 \[LessEqual] ",
 StyleBox["r",
  FontSlant->"Italic"],
 " \[LessEqual] ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\t(",
 StyleBox["a",
  FontSlant->"Italic"],
 " is arbitrary)"
}], "Text",
 CellChangeTimes->{
  3.604602368336341*^9, {3.6046024414985332`*^9, 3.604602497351651*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", "np", ",", " ", "a"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "20"}], ";", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", "100"}], ";", "\[IndentingNewLine]", 
      RowBox[{"a", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"r", "^", "2"}], "*", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"2", "\[CurlyPhi]"}], "]"}], "/", "2"}]}], " ", "-", 
           " ", 
           RowBox[{
            RowBox[{"r", "^", "4"}], "*", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"4", "\[CurlyPhi]"}], "]"}], "/", "4"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"r", "^", "2"}]}], "*", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"2", "\[CurlyPhi]"}], "]"}], "/", "2"}]}], " ", "-", 
           " ", 
           RowBox[{
            RowBox[{"r", "^", "4"}], "*", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"4", "\[CurlyPhi]"}], "]"}], "/", "4"}]}]}], ",", " ", 
          RowBox[{"2", "*", 
           RowBox[{"r", "^", "3"}], "*", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"3", "\[CurlyPhi]"}], "]"}], "/", "3"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "0", ",", "a"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[CurlyPhi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"6", ",", 
           RowBox[{"-", "6"}], ",", "3"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<16.2.8\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.60460253427665*^9, 3.604602576520214*^9}, {
  3.604602613050761*^9, 3.604602622926013*^9}, {3.6046026679947433`*^9, 
  3.6046026822134037`*^9}, {3.6111502372958813`*^9, 3.611150242933823*^9}, {
  3.613811694031703*^9, 3.6138117360941477`*^9}, {3.621716176179357*^9, 
  3.621716182655918*^9}, {3.627820622459013*^9, 3.6278206250841217`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {244., 259.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp, $CellContext`np, $CellContext`a}, \
$CellContext`mp = 20; $CellContext`np = 100; $CellContext`a = 1; 
        ParametricPlot3D[{$CellContext`r^2 (Cos[2 $CellContext`\[CurlyPhi]]/
             2) - $CellContext`r^4 (Cos[4 $CellContext`\[CurlyPhi]]/
            4), (-$CellContext`r^2) (Sin[2 $CellContext`\[CurlyPhi]]/
             2) - $CellContext`r^4 (Sin[4 $CellContext`\[CurlyPhi]]/4), 
           2 $CellContext`r^3 (Cos[3 $CellContext`\[CurlyPhi]]/
            3)}, {$CellContext`r, 
           0, $CellContext`a}, {$CellContext`\[CurlyPhi], 0, 2 Pi}, 
          PlotPoints -> {$CellContext`mp, $CellContext`np}, 
          ViewPoint -> {6, -6, 3}, PlotLabel -> "16.2.8"]], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {282., 289.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6046026434465857`*^9, 3.604602687976911*^9, {3.61381167456334*^9, 
   3.61381175830626*^9}, 3.6217161887786217`*^9, 3.627820629315133*^9, 
   3.6309439395487347`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["REFERENCES", "Subsection",
 CellChangeTimes->{{3.606248595012486*^9, 3.606248621655993*^9}}],

Cell[TextData[{
 "1. Hoffman, D.A., ed., ",
 StyleBox["Global Theory Of Minimal Surfaces: Proceedings Of The Clay \
Mathematics Institute 2001 Summer School",
  FontSlant->"Italic"],
 ", Mathematical Sciences Research Institute, Berkeley, California (Clay \
Mathematics Proceedings, V.2), American Mathematical Society, 2005.\n\n2. \
Gray, A., ",
 StyleBox["Modern Differential Geometry of Curves and Surfaces with \
Mathematica, 2nd Ed.",
  FontSlant->"Italic"],
 ", CRC Press, 1999.\n\n3. \
http://mathworld.wolfram.com/CostaMinimalSurface.html\n"
}], "Text",
 CellChangeTimes->{{3.606248595012486*^9, 3.606248631974264*^9}, 
   3.606323470213402*^9, 3.630944120933207*^9, {3.630944226383009*^9, 
   3.63094425555689*^9}}]
}, Closed]]
}, Open  ]]
},
WindowSize->{955, 888},
WindowMargins->{{122, Automatic}, {Automatic, 0}},
Magnification:>1.25 Inherited,
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 25, \
2016)",
StyleDefinitions->"myStyles.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 125, 2, 37, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1614, 39, 2280, 38, 753, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3931, 82, 40, 0, 51, "Section"],
Cell[3974, 84, 651, 14, 111, "Text"],
Cell[CellGroupData[{
Cell[4650, 102, 64, 0, 57, "Subsection"],
Cell[4717, 104, 920, 13, 195, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[5674, 122, 55, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[5754, 126, 234, 3, 66, "Subsubsection"],
Cell[5991, 131, 1087, 38, 488, "Text"],
Cell[CellGroupData[{
Cell[7103, 173, 4126, 85, 760, "Input"],
Cell[11232, 260, 3386, 64, 1306, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[14667, 330, 239, 3, 50, "Subsubsection"],
Cell[14909, 335, 1808, 76, 582, "Text"],
Cell[CellGroupData[{
Cell[16742, 415, 4374, 94, 718, "Input"],
Cell[21119, 511, 3139, 61, 1376, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[24319, 579, 52, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[24396, 583, 50, 0, 53, "Subsubsection"],
Cell[24449, 585, 1369, 52, 426, "Text"],
Cell[CellGroupData[{
Cell[25843, 641, 4399, 93, 437, "Input"],
Cell[30245, 736, 2219, 41, 970, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[32513, 783, 48, 0, 40, "Subsubsection"],
Cell[32564, 785, 352, 7, 95, "Text"],
Cell[CellGroupData[{
Cell[32941, 796, 6262, 152, 883, "Input"],
Cell[39206, 950, 3493, 67, 918, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[42748, 1023, 53, 0, 40, "Subsubsection"],
Cell[42804, 1025, 1104, 54, 391, "Text"],
Cell[CellGroupData[{
Cell[43933, 1083, 2932, 73, 471, "Input"],
Cell[46868, 1158, 2244, 43, 946, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[49161, 1207, 55, 0, 40, "Subsubsection"],
Cell[49219, 1209, 685, 25, 283, "Text"],
Cell[CellGroupData[{
Cell[49929, 1238, 826, 20, 343, "Input"],
Cell[50758, 1260, 2018, 40, 907, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[52825, 1306, 56, 0, 40, "Subsubsection"],
Cell[52884, 1308, 1854, 67, 403, "Text"],
Cell[CellGroupData[{
Cell[54763, 1379, 887, 22, 437, "Input"],
Cell[55653, 1403, 2254, 44, 1045, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[57956, 1453, 50, 0, 40, "Subsubsection"],
Cell[58009, 1455, 1343, 64, 401, "Text"],
Cell[CellGroupData[{
Cell[59377, 1523, 2782, 67, 471, "Input"],
Cell[62162, 1592, 2277, 44, 996, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[64488, 1642, 51, 0, 40, "Subsubsection"],
Cell[64542, 1644, 1244, 52, 431, "Text"],
Cell[CellGroupData[{
Cell[65811, 1700, 3164, 77, 471, "Input"],
Cell[68978, 1779, 2302, 43, 885, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[71329, 1828, 47, 0, 40, "Subsubsection"],
Cell[71379, 1830, 1080, 43, 396, "Text"],
Cell[CellGroupData[{
Cell[72484, 1877, 2699, 66, 437, "Input"],
Cell[75186, 1945, 2248, 43, 922, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[77495, 1995, 98, 1, 46, "Subsection"],
Cell[77596, 1998, 724, 16, 318, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature rxDroyOBevKKoAgSRQ2vvvAv *)
