(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 10.4' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[    111415,       2590]
NotebookOptionsPosition[    105684,       2368]
NotebookOutlinePosition[    106073,       2385]
CellTagsIndexPosition[    106030,       2382]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Initialization", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.621868694661923*^9}],

Cell["\<\
labelstyle = {Black,20};
SetOptions[Graphics3D,BoxRatios\[Rule]Automatic,PlotRange\[Rule]All,Boxed\
\[Rule]False,BaseStyle\[Rule]20,ImageSize\[Rule]400,Lighting\[Rule]{{\"\
Ambient\",Gray}}];
$TextStyle = {FontSize\[Rule]14, FontFamily\[Rule]\"TimesRoman\", FontWeight \
\[Rule]\"Bold\"};
<<PolyhedronOperations`;
SetOptions[Manipulate,LabelStyle\[Rule]labelstyle];
SetOptions[Manipulator,LabelStyle\[Rule]labelstyle];\
\>", "Input",
 PageWidth->WindowWidth,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.604603001173614*^9, 3.604603091675377*^9}, 
   3.604603133287093*^9, 3.604603363151657*^9, {3.6046035057874327`*^9, 
   3.604603521108993*^9}, {3.6046036004787893`*^9, 3.604603602299912*^9}, {
   3.6111622067463427`*^9, 3.611162207330868*^9}, {3.613811896243239*^9, 
   3.613811910940624*^9}, {3.613812651978958*^9, 3.6138126556585197`*^9}, 
   3.613813699629877*^9, {3.621716338431095*^9, 3.621716339129075*^9}, {
   3.621716379431327*^9, 3.621716380091798*^9}, {3.6217168559962587`*^9, 
   3.6217168826075706`*^9}, {3.621868684918017*^9, 3.621868694662095*^9}, {
   3.627820826571007*^9, 3.627820869706932*^9}, {3.6278209734228354`*^9, 
   3.6278209747213297`*^9}, {3.627910865314147*^9, 3.627910868195696*^9}, {
   3.630975896276683*^9, 3.630975925827259*^9}, {3.6309805417613993`*^9, 
   3.630980542259878*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["17.  Regular and Semi-Regular Solids with Edges", "Section"],

Cell[TextData[{
 "This chapter illustrates polyhedra, which are formed by joined, regular \
polygons.  If all the polygons are regular and identical, the polyhedron is \
termed a regular polyhedron or regular solid.  The known polyhedra are \
numerous (see, for instance, the comprehensive survey of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Williams", "1"], TraditionalForm]]],
 "); and only the simpler and more common ones are presented here."
}], "Text",
 CellChangeTimes->{{3.6062492567871113`*^9, 3.6062492646498213`*^9}, {
  3.606249568141387*^9, 3.606249579957243*^9}}],

Cell[CellGroupData[{

Cell["17.0 Plotting Information for This Chapter", "Subsection"],

Cell[TextData[{
 "This chapter uses some of the built-in 3-D graphic forms of ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "from PolyhedronData.  It also uses the built-in package \
PolyhedronOperations.  Other 3-D forms are displayed with the Graphics3D \
function.  By evaluating the initialization cell, the aspect ratios are set \
to show any figure in its true aspect.  All plotted figures are rotatable in \
3-D.  Viewpoints have been set at large distances so that the perspective is \
approximately the isometric one.   Simple gray shading of the surface has \
been provided in the initialization cell, but this can be changed to produce \
complex and colorful renditions."
}], "Text",
 CellChangeTimes->{{3.6046037501705923`*^9, 3.604603855400174*^9}, {
  3.604604635092478*^9, 3.604604650300445*^9}, {3.613814002378791*^9, 
  3.613814078790081*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["17.1 Platonic Solids", "Subsection"],

Cell["\<\
There are five Platonic solids: tetrahedron, hexahedron (cube), octahedron, \
dodecahedron, and icosahedron.  They are also called the regular solids or \
regular polyhedra.  They are defined as being convex polyhedra having all \
faces equal, with each face being a convex regular polygon.\
\>", "Text",
 CellChangeTimes->{{3.6046046735992413`*^9, 3.6046046772206182`*^9}, 
   3.606249348744815*^9}],

Cell[CellGroupData[{

Cell["17.1.1  Tetrahedron (n = 4)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<Tetrahedron\>\"", ",", "\"\<Faces\>\""}], "]"}]}], "}"}],
      ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "10", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.1.1\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604297651444*^9, 3.604604306683023*^9}, {
   3.611150298001685*^9, 3.611150306755328*^9}, 3.611162249587317*^9, 
   3.613813532327467*^9, {3.621716898546526*^9, 3.621716936761323*^9}, {
   3.6278207958728247`*^9, 3.6278208189468403`*^9}, {3.627820909916889*^9, 
   3.627820920085129*^9}, {3.627820952295828*^9, 3.627820955622258*^9}, {
   3.630945550965173*^9, 3.630945575005652*^9}, {3.630945656228428*^9, 
   3.630945659815399*^9}, {3.630945752493226*^9, 3.6309457670648746`*^9}, 
   3.630973800141547*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {211., 226.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["Tetrahedron", "Faces"]}, ViewPoint -> {30, 10, -5}, 
        PlotLabel -> "17.1.1", LabelStyle -> {Black, 20}], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {249., 256.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604604006082637*^9, 3.604604067494088*^9, {3.6046040995839157`*^9, 
   3.604604134670286*^9}, 3.604604307890798*^9, 3.6138119699652863`*^9, 
   3.6138133621381493`*^9, {3.613813522282955*^9, 3.613813533282275*^9}, 
   3.613813713912677*^9, 3.6217163479959908`*^9, {3.62171686647622*^9, 
   3.621716890343293*^9}, {3.621716929275359*^9, 3.621716938001298*^9}, 
   3.627820748972046*^9, 3.627820812396488*^9, 3.627820921047708*^9, 
   3.630945206788533*^9, 3.6309455759594173`*^9, 3.6309456614946613`*^9, {
   3.630945758294415*^9, 3.630945768861249*^9}, 3.630973529902883*^9, 
   3.630973800927161*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.1.2  Hexahedron (Cube) (n = 6)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<Cube\>\"", ",", "\"\<Faces\>\""}], "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "10", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.1.2\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.611150318845565*^9, 
   3.611150324157001*^9}, 3.611162249640419*^9, {3.621725222157462*^9, 
   3.6217252420938883`*^9}, {3.627820995536701*^9, 3.627821006445504*^9}, {
   3.630973656054175*^9, 3.6309736804278727`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {244., 259.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["Cube", "Faces"]}, ViewPoint -> {30, 10, -5}, 
        PlotLabel -> "17.1.2", LabelStyle -> {Black, 20}], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {282., 289.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604604243542603*^9, 3.604604257795231*^9}, 
   3.6046043242529716`*^9, 3.613813392368742*^9, 3.613813719759995*^9, 
   3.621725247927217*^9, 3.627821008457272*^9, 3.630945221358842*^9, {
   3.630973662001383*^9, 3.630973680955912*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.1.3  Octahedron (n = 8)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<Octahedron\>\"", ",", "\"\<Faces\>\""}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "10", ",", 
        RowBox[{"-", "3"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.1.3\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.6111503349065847`*^9, 3.611150337806985*^9}, 3.61116224968928*^9, {
   3.613813446027481*^9, 3.6138134465755863`*^9}, {3.6217252751316147`*^9, 
   3.621725282431891*^9}, {3.6278210181475763`*^9, 3.627821023445434*^9}, {
   3.630973705131675*^9, 3.630973775429369*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {230., 245.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["Octahedron", "Faces"]}, ViewPoint -> {30, 10, -3}, 
        PlotLabel -> "17.1.3", LabelStyle -> {Black, 20}], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {268., 275.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604604388114738*^9, 3.604604418938697*^9, 3.61381340329873*^9, {
   3.613813448434452*^9, 3.613813470268351*^9}, 3.61381354784905*^9, 
   3.613813725244495*^9, 3.6217252845262003`*^9, 3.627821024401498*^9, {
   3.630973717366755*^9, 3.630973776732733*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.1.4  Dodecahedron (n = 12)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<Dodecahedron\>\"", ",", "\"\<Faces\>\""}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "5", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.1.4\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.611150344944022*^9, 
   3.611150348119772*^9}, 3.611162249739296*^9, 3.613813575752985*^9, {
   3.613813666741399*^9, 3.613813690942346*^9}, {3.6217252996926937`*^9, 
   3.62172531288186*^9}, {3.627821039932926*^9, 3.627821046034371*^9}, {
   3.630973831868977*^9, 3.630973860429347*^9}, 3.630973943067415*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {232., 248.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["Dodecahedron", "Faces"]}, ViewPoint -> {30, 5, -5}, 
        PlotLabel -> "17.1.4", LabelStyle -> {Black, 20}], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {270., 278.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604604477371027*^9, 3.613813411796102*^9, 3.613813576701056*^9, 
   3.61381364083327*^9, 3.6138136844493093`*^9, 3.6138137308629017`*^9, 
   3.6217253145495872`*^9, 3.6278210478454647`*^9, {3.630973842523774*^9, 
   3.63097386086545*^9}, 3.630973943729888*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.1.5  Icosahedron (n = 20)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<Icosahedron\>\"", ",", "\"\<Faces\>\""}], "]"}]}], "}"}],
      ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "5", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.1.5\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.611150356794758*^9, 
   3.611150360594171*^9}, 3.611162249791422*^9, {3.62172532199439*^9, 
   3.6217253301821003`*^9}, {3.627821059484969*^9, 3.62782106699685*^9}, {
   3.630973890569313*^9, 3.630973917640374*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {301., 317.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["Icosahedron", "Faces"]}, ViewPoint -> {30, 5, -5}, 
        PlotLabel -> "17.1.5", LabelStyle -> {Black, 20}], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {339., 347.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604604606052408*^9, 3.613813503545789*^9, 3.613813735746704*^9, 
   3.621725334016863*^9, {3.6278210675676737`*^9, 3.6278210736572237`*^9}, {
   3.630973881846732*^9, 3.6309739182753963`*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2 Archimedean Solids", "Subsection"],

Cell["\<\
There are 13 Archimedean solids.  They are defined as convex polyhedra whose \
faces are two or more types of regular polygons.  The function PolyhedronData \
plots these polyhedra, plus many more not shown here.  For a list of all \
polyhedra in the package, execute the command \
\[OpenCurlyDoubleQuote]PolyhedronData[]\[CloseCurlyDoubleQuote]. \
\>", "Text",
 CellChangeTimes->{{3.6046056291063766`*^9, 3.604605679907649*^9}, {
   3.604605800161408*^9, 3.604605884656563*^9}, {3.604605950145009*^9, 
   3.60460597311607*^9}, 3.632415049608644*^9}],

Cell[CellGroupData[{

Cell["17.2.1  Cuboctahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<Cuboctahedron\>\"", ",", "\"\<Faces\>\""}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "10", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.1\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, {3.6111503724196043`*^9, 3.6111503756444902`*^9}, 
   3.611162249841296*^9, 3.6138137890042667`*^9, {3.621725353207171*^9, 
   3.621725361256865*^9}, {3.627821104572295*^9, 3.627821110845407*^9}, {
   3.630974037344656*^9, 3.6309740672552853`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {187., 202.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["Cuboctahedron", "Faces"]}, ViewPoint -> {30, 10, -5},
         PlotLabel -> "17.2.1", LabelStyle -> {Black, 20}], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {225., 232.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604604801607726*^9, {3.613813776990965*^9, 3.613813789811386*^9}, 
   3.621725363188918*^9, 3.627821112274095*^9, {3.630974063941523*^9, 
   3.630974067767659*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.2  Great rhombicosidodecahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<GreatRhombicosidodecahedron\>\"", ",", "\"\<Faces\>\""}],
         "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "5", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.2\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.61115038815851*^9, 
   3.611150392407099*^9}, 3.611162249890316*^9, 3.613813799387764*^9, {
   3.621725369719816*^9, 3.621725377395872*^9}, {3.627821126597556*^9, 
   3.627821132670352*^9}, {3.6309740949195747`*^9, 3.6309741327915087`*^9}, {
   3.6309742245062933`*^9, 3.630974231806177*^9}, 3.630974325957652*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {264., 280.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["GreatRhombicosidodecahedron", "Faces"]}, 
        ViewPoint -> {30, 5, -5}, PlotLabel -> "17.2.2", 
        LabelStyle -> {Black, 20}], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {302., 310.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604604946869142*^9, 3.6138138004757442`*^9, 3.6217253792835207`*^9, 
   3.627821133560872*^9, 3.630974134674285*^9, {3.6309742269842052`*^9, 
   3.630974232439419*^9}, 3.630974334003599*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.3  Great rhombicuboctahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<GreatRhombicuboctahedron\>\"", ",", "\"\<Faces\>\""}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "10", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.3\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.611150399682744*^9, 3.611150403019883*^9}, 
   3.611162249941036*^9, 3.6138138086539383`*^9, {3.621725388094956*^9, 
   3.6217253950958633`*^9}, {3.627821145133622*^9, 3.627821151482667*^9}, {
   3.630974273334854*^9, 3.630974316643731*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {244., 259.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["GreatRhombicuboctahedron", "Faces"]}, 
        ViewPoint -> {30, 10, -5}, PlotLabel -> "17.2.3", 
        LabelStyle -> {Black, 20}], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {282., 289.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.6046050132612123`*^9, 3.6138138099410686`*^9, 
  3.621725397177225*^9, 3.627821152972662*^9, 3.630974317153661*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.4  Icosidodecahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<Icosidodecahedron\>\"", ",", "\"\<Faces\>\""}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "5", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.4\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.6046050636273317`*^9, 3.604605071848833*^9}, {
   3.611150409506919*^9, 3.611150413745015*^9}, 3.6111622499894543`*^9, 
   3.61381382400419*^9, {3.621725408431073*^9, 3.621725417258952*^9}, {
   3.62782116370966*^9, 3.6278211691077747`*^9}, {3.630974375471797*^9, 
   3.630974404005549*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {232., 248.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["Icosidodecahedron", "Faces"]}, 
        ViewPoint -> {30, 5, -5}, PlotLabel -> "17.2.4", 
        LabelStyle -> {Black, 20}], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {270., 278.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6046050749745207`*^9, {3.613813819988798*^9, 3.613813824647853*^9}, 
   3.621725419227601*^9, 3.627821172709188*^9, {3.630974397261796*^9, 
   3.630974404512415*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.5  Small rhombicosidodecahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<SmallRhombicosidodecahedron\>\"", ",", "\"\<Faces\>\""}],
         "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "5", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.5\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.6046050636273317`*^9, 3.604605071848833*^9}, {
   3.604605162660084*^9, 3.604605169160696*^9}, {3.611150420619751*^9, 
   3.611150424020212*^9}, 3.611162250041134*^9, 3.613813832090845*^9, {
   3.6217254259326763`*^9, 3.6217254328965816`*^9}, {3.6278211830080967`*^9, 
   3.6278211880828753`*^9}, {3.630974432260315*^9, 3.630974461394854*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {264., 280.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["SmallRhombicosidodecahedron", "Faces"]}, 
        ViewPoint -> {30, 5, -5}, PlotLabel -> "17.2.5", 
        LabelStyle -> {Black, 20}], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {302., 310.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.604605180015424*^9, 3.61381383328869*^9, 
  3.621725434389388*^9, 3.627821189402549*^9, 3.6309744757686167`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.6  Small rhombicuboctahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<SmallRhombicuboctahedron\>\"", ",", "\"\<Faces\>\""}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "10", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.6\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.6046050636273317`*^9, 3.604605071848833*^9}, {
   3.604605162660084*^9, 3.604605169160696*^9}, {3.604605223894012*^9, 
   3.6046052260072403`*^9}, {3.611150433545227*^9, 3.611150437470036*^9}, 
   3.611162250090208*^9, 3.613813840616809*^9, {3.6217254436830378`*^9, 
   3.621725451433723*^9}, {3.627821198695223*^9, 3.627821204347939*^9}, {
   3.630974503285027*^9, 3.630974531457941*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {244., 259.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["SmallRhombicuboctahedron", "Faces"]}, 
        ViewPoint -> {30, 10, -5}, PlotLabel -> "17.2.6", 
        LabelStyle -> {Black, 20}], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {282., 289.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604605236082008*^9, 3.6138138417569838`*^9, 3.6217254530968246`*^9, 
   3.627821205195101*^9, {3.630974528251198*^9, 3.630974531897237*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.7  Snub cube", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<SnubCube\>\"", ",", "\"\<Faces\>\""}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "10", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.7\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.6046050636273317`*^9, 3.604605071848833*^9}, {
   3.604605162660084*^9, 3.604605169160696*^9}, {3.604605223894012*^9, 
   3.6046052260072403`*^9}, {3.604605276430531*^9, 3.604605279185697*^9}, {
   3.611150444682125*^9, 3.611150448982904*^9}, 3.6111622501393967`*^9, 
   3.613813851091632*^9, {3.62172546248164*^9, 3.621725469633132*^9}, {
   3.627821216186318*^9, 3.62782122173454*^9}, {3.630974554997408*^9, 
   3.6309745808579082`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {244., 259.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["SnubCube", "Faces"]}, ViewPoint -> {30, 10, -5}, 
        PlotLabel -> "17.2.7", LabelStyle -> {Black, 20}], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {282., 289.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604605281112302*^9, 3.613813852187451*^9, 3.621725471423596*^9, 
   3.627821222439598*^9, {3.6309745705226107`*^9, 3.630974581395467*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.8  Snub dodecahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<SnubDodecahedron\>\"", ",", "\"\<Faces\>\""}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "5", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.8\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.6046050636273317`*^9, 3.604605071848833*^9}, {
   3.604605162660084*^9, 3.604605169160696*^9}, {3.604605223894012*^9, 
   3.6046052260072403`*^9}, {3.604605276430531*^9, 3.604605279185697*^9}, {
   3.604605320542161*^9, 3.604605323757965*^9}, {3.611150456982232*^9, 
   3.611150460532693*^9}, 3.6111622501902037`*^9, 3.613813859017108*^9, {
   3.6217254817953*^9, 3.621725489833213*^9}, {3.627821232473502*^9, 
   3.627821239770258*^9}, {3.6309746146731377`*^9, 3.630974636983656*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {262., 277.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["SnubDodecahedron", "Faces"]}, 
        ViewPoint -> {30, 5, -5}, PlotLabel -> "17.2.8", 
        LabelStyle -> {Black, 20}], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {300., 307.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604605328453165*^9, 3.6138138605063477`*^9, 3.621725491513513*^9, 
   3.627821241604537*^9, {3.630974633046522*^9, 3.63097463754764*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.9  Truncated cube", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<TruncatedCube\>\"", ",", "\"\<Faces\>\""}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "10", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.9\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.6046050636273317`*^9, 3.604605071848833*^9}, {
   3.604605162660084*^9, 3.604605169160696*^9}, {3.604605223894012*^9, 
   3.6046052260072403`*^9}, {3.604605276430531*^9, 3.604605279185697*^9}, {
   3.604605320542161*^9, 3.604605323757965*^9}, {3.604605369468788*^9, 
   3.604605372773912*^9}, {3.6111504681197853`*^9, 3.611150472107835*^9}, 
   3.611162250258627*^9, 3.613813881853835*^9, {3.621725499108073*^9, 
   3.621725506658052*^9}, {3.627821249834923*^9, 3.627821255071598*^9}, {
   3.630974664198518*^9, 3.630974685133854*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {244., 259.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["TruncatedCube", "Faces"]}, ViewPoint -> {30, 10, -5},
         PlotLabel -> "17.2.9", LabelStyle -> {Black, 20}], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {282., 289.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6046053761000957`*^9, 3.613813883021824*^9, 3.62172550813074*^9, 
   3.627821255804387*^9, {3.6309746810428*^9, 3.630974685630794*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.10  Truncated dodecahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<TruncatedDodecahedron\>\"", ",", "\"\<Faces\>\""}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "5", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.10\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.6046050636273317`*^9, 3.604605071848833*^9}, {
   3.604605162660084*^9, 3.604605169160696*^9}, {3.604605223894012*^9, 
   3.6046052260072403`*^9}, {3.604605276430531*^9, 3.604605279185697*^9}, {
   3.604605320542161*^9, 3.604605323757965*^9}, {3.604605369468788*^9, 
   3.604605372773912*^9}, {3.6046054210606318`*^9, 3.604605424096634*^9}, {
   3.611150478832409*^9, 3.611150481257678*^9}, 3.611162250308784*^9, 
   3.613813889490879*^9, {3.621725516932548*^9, 3.621725525484243*^9}, {
   3.627821264022019*^9, 3.6278212705954027`*^9}, {3.6309747168471937`*^9, 
   3.6309747475728703`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {232., 248.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["TruncatedDodecahedron", "Faces"]}, 
        ViewPoint -> {30, 5, -5}, PlotLabel -> "17.2.10", 
        LabelStyle -> {Black, 20}], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {270., 278.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604605428731248*^9, 3.6138138905680723`*^9, 3.6217255274957*^9, 
   3.627821271871043*^9, {3.6309747363446693`*^9, 3.630974748053603*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.11  Truncated icosahedron", "Subsubsection"],

Cell["This shape commonly appears in a soccer ball.", "Text",
 CellChangeTimes->{{3.6309748260015793`*^9, 3.63097485069985*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<TruncatedIcosahedron\>\"", ",", "\"\<Faces\>\""}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "5", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.11\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.6046050636273317`*^9, 3.604605071848833*^9}, {
   3.604605162660084*^9, 3.604605169160696*^9}, {3.604605223894012*^9, 
   3.6046052260072403`*^9}, {3.604605276430531*^9, 3.604605279185697*^9}, {
   3.604605320542161*^9, 3.604605323757965*^9}, {3.604605369468788*^9, 
   3.604605372773912*^9}, {3.6046054210606318`*^9, 3.604605424096634*^9}, {
   3.604605472406302*^9, 3.6046054734383163`*^9}, {3.6111504893574867`*^9, 
   3.611150492008026*^9}, 3.611162250356687*^9, 3.613813898841868*^9, {
   3.6217255380333557`*^9, 3.6217255447094507`*^9}, {3.627821283296854*^9, 
   3.627821289720245*^9}, {3.630974772048695*^9, 3.63097479522019*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {255., 271.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["TruncatedIcosahedron", "Faces"]}, 
        ViewPoint -> {30, 5, -5}, PlotLabel -> "17.2.11", 
        LabelStyle -> {Black, 20}], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {293., 301.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604605478865643*^9, 3.613813900055018*^9, 3.621725546398157*^9, 
   3.627821291977545*^9, {3.6309747912770767`*^9, 3.630974795764968*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.12  Truncated octahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<TruncatedOctahedron\>\"", ",", "\"\<Faces\>\""}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "10", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.12\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.6046050636273317`*^9, 3.604605071848833*^9}, {
   3.604605162660084*^9, 3.604605169160696*^9}, {3.604605223894012*^9, 
   3.6046052260072403`*^9}, {3.604605276430531*^9, 3.604605279185697*^9}, {
   3.604605320542161*^9, 3.604605323757965*^9}, {3.604605369468788*^9, 
   3.604605372773912*^9}, {3.6046054210606318`*^9, 3.604605424096634*^9}, {
   3.604605472406302*^9, 3.6046054734383163`*^9}, {3.604605524110127*^9, 
   3.604605525671805*^9}, {3.611150499132791*^9, 3.611150503070344*^9}, 
   3.6111622504061337`*^9, 3.613813907304528*^9, {3.621725561206953*^9, 
   3.621725567797165*^9}, {3.627821305559667*^9, 3.627821312407844*^9}, {
   3.630974882311884*^9, 3.630974910583611*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {232., 248.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["TruncatedOctahedron", "Faces"]}, 
        ViewPoint -> {30, 10, -5}, PlotLabel -> "17.2.12", 
        LabelStyle -> {Black, 20}], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {270., 278.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6046055288362503`*^9, 3.613813908507146*^9, 3.621725570252701*^9, 
   3.6278213139651413`*^9, {3.63097490725709*^9, 3.630974911087255*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.2.13  Truncated tetrahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<TruncatedTetrahedron\>\"", ",", "\"\<Faces\>\""}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "10", ",", 
        RowBox[{"-", "5"}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<17.2.13\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604603985913224*^9, 3.604604004913702*^9}, {
   3.604604057043828*^9, 3.604604091799432*^9}, {3.6046041224212217`*^9, 
   3.604604133897036*^9}, {3.604604237587907*^9, 3.604604256653976*^9}, {
   3.604604314919256*^9, 3.6046043226350393`*^9}, {3.6046043848827763`*^9, 
   3.604604387130878*^9}, {3.604604417192971*^9, 3.6046044178438272`*^9}, {
   3.604604471283451*^9, 3.60460447274326*^9}, {3.604604544722673*^9, 
   3.604604568840214*^9}, 3.604604605033667*^9, {3.604604793818935*^9, 
   3.604604796325605*^9}, 3.604604942577779*^9, {3.604605007366103*^9, 
   3.604605009984948*^9}, {3.6046050636273317`*^9, 3.604605071848833*^9}, {
   3.604605162660084*^9, 3.604605169160696*^9}, {3.604605223894012*^9, 
   3.6046052260072403`*^9}, {3.604605276430531*^9, 3.604605279185697*^9}, {
   3.604605320542161*^9, 3.604605323757965*^9}, {3.604605369468788*^9, 
   3.604605372773912*^9}, {3.6046054210606318`*^9, 3.604605424096634*^9}, {
   3.604605472406302*^9, 3.6046054734383163`*^9}, {3.604605524110127*^9, 
   3.604605525671805*^9}, {3.60460556435249*^9, 3.604605565485303*^9}, {
   3.611150511020199*^9, 3.6111505134701653`*^9}, 3.61116225045621*^9, 
   3.613813917641905*^9, {3.621725579995997*^9, 3.62172558841008*^9}, {
   3.6278213257332687`*^9, 3.627821333183888*^9}, {3.630974936311968*^9, 
   3.630974954822722*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {208., 223.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics3D[{
         EdgeForm[Thick], 
         PolyhedronData["TruncatedTetrahedron", "Faces"]}, 
        ViewPoint -> {30, 10, -5}, PlotLabel -> "17.2.13", 
        LabelStyle -> {Black, 20}], "Specifications" :> {}, 
      "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {246., 253.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.60460556901622*^9, 3.6138139188069563`*^9, 3.6217255901164093`*^9, 
   3.627821334025165*^9, {3.630974951658197*^9, 3.6309749553051863`*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.3 Duals of Platonic Solids", "Subsection"],

Cell[TextData[{
 "A dual of a polyhedron is made by placing a vertex at the center of the \
sides of the polyhedron and placing polygons at the vertices of the \
polyhedron.  The resulting polyhedron is the ",
 StyleBox["dual",
  FontSlant->"Italic"],
 " of the first.  For Platonic solids, the duals are another Platonic solid.  \
The combination of the original Platonic solid and its dual gives just three \
unique cases as shown here.  The edges of the original solids are outlined, \
unless they are hidden by the join.  For the join, one of the figures must be \
scaled to produce a cleanly defined joined figure."
}], "Text",
 CellChangeTimes->{{3.604684249252645*^9, 3.6046842728532*^9}, {
  3.604684318765964*^9, 3.604684334179047*^9}, {3.613814321380884*^9, 
  3.613814327429185*^9}}],

Cell[CellGroupData[{

Cell["17.3.1  Dual of Tetrahedron ", "Subsubsection"],

Cell["The dual of a tetrahedron is another, identical tetrahedron.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
 Module[{figure,g,h},
  figure = {EdgeForm[Thick],PolyhedronData[\"Tetrahedron\",\"Faces\"]};
  g = Graphics3D[figure];
  h = Graphics3D[Rotate[figure,\[Pi],{1,0,0}]];
  Show[g,h,ViewPoint\[Rule]{40,50,20},PlotLabel\[Rule]\"17.3.1\",LabelStyle\
\[Rule]{Black,20}]
 ]
 ,TrackedSymbols\[Rule]{}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604615648799541*^9, 3.6046157558881683`*^9}, {
   3.604616141041625*^9, 3.604616167981743*^9}, {3.6046163148522*^9, 
   3.6046163256271*^9}, {3.6046165457781267`*^9, 3.6046165552825727`*^9}, {
   3.604616594727247*^9, 3.604616603837138*^9}, {3.604616652528594*^9, 
   3.604616658725453*^9}, {3.604616746522297*^9, 3.604616782666191*^9}, {
   3.604616933292152*^9, 3.604616941964341*^9}, {3.604616978764566*^9, 
   3.60461704679115*^9}, {3.6046170880373793`*^9, 3.6046170880427437`*^9}, {
   3.60461713607283*^9, 3.604617143281604*^9}, 3.604617519280344*^9, {
   3.604617659700705*^9, 3.604617681275128*^9}, {3.60461810520875*^9, 
   3.604618113080958*^9}, {3.6046819828582563`*^9, 3.604682057159107*^9}, {
   3.604682087649344*^9, 3.604682099716146*^9}, {3.604682135426692*^9, 
   3.604682209786515*^9}, {3.604682305424712*^9, 3.604682308336749*^9}, {
   3.6046824091925592`*^9, 3.6046824119033337`*^9}, {3.604682450098324*^9, 
   3.604682457769347*^9}, 3.604682516417946*^9, {3.604682651240501*^9, 
   3.6046826583570223`*^9}, {3.6046829326000977`*^9, 3.604682958776762*^9}, {
   3.604683008728921*^9, 3.604683034522788*^9}, {3.604683065109365*^9, 
   3.604683068002652*^9}, {3.604683254597282*^9, 3.604683297187317*^9}, {
   3.60468333081599*^9, 3.6046833815502443`*^9}, {3.611150525871047*^9, 
   3.6111505299067383`*^9}, {3.6217256115192347`*^9, 3.621725618647046*^9}, {
   3.627821376248303*^9, 3.627821397581688*^9}, 3.630975141366555*^9, {
   3.6309751807967043`*^9, 3.630975184685132*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {309., 325.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`figure, $CellContext`g, $CellContext`h}, \
$CellContext`figure = {
           EdgeForm[Thick], 
           PolyhedronData["Tetrahedron", "Faces"]}; $CellContext`g = 
         Graphics3D[$CellContext`figure]; $CellContext`h = Graphics3D[
           Rotate[$CellContext`figure, Pi, {1, 0, 0}]]; 
        Show[$CellContext`g, $CellContext`h, ViewPoint -> {40, 50, 20}, 
          PlotLabel -> "17.3.1", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {347., 355.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.6046833014617977`*^9, 3.604683383691348*^9, 
  3.613814101966975*^9, 3.621725621713249*^9, 3.627821401175495*^9, 
  3.630975212072241*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.3.2  Dual of Hexahedron", "Subsubsection"],

Cell["The dual of a hexahedron is an octahedron.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
 Module[{figure1,figure2,g,h},
  figure1 = {EdgeForm[Thick],PolyhedronData[\"Cube\",\"Faces\"]};
  figure2 = {EdgeForm[Thick],PolyhedronData[\"Octahedron\",\"Faces\"]};
  g = Graphics3D[figure1];
  h = Graphics3D[Scale[figure2,Sqrt[2]]];
  Show[g,h,ViewPoint\[Rule]{40,50,20},PlotLabel\[Rule]\"17.3.2\",LabelStyle\
\[Rule]{Black,20}]
 ],
 TrackedSymbols\[Rule]{}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604615648799541*^9, 3.6046157558881683`*^9}, {
   3.604616141041625*^9, 3.604616167981743*^9}, {3.6046163148522*^9, 
   3.6046163256271*^9}, {3.6046165457781267`*^9, 3.6046165552825727`*^9}, {
   3.604616594727247*^9, 3.604616603837138*^9}, {3.604616652528594*^9, 
   3.604616658725453*^9}, {3.604616746522297*^9, 3.604616782666191*^9}, {
   3.604616933292152*^9, 3.604616941964341*^9}, {3.604616978764566*^9, 
   3.60461704679115*^9}, {3.6046170880373793`*^9, 3.6046170880427437`*^9}, {
   3.60461713607283*^9, 3.604617143281604*^9}, 3.604617519280344*^9, {
   3.604617659700705*^9, 3.604617681275128*^9}, {3.60461810520875*^9, 
   3.604618113080958*^9}, {3.6046819828582563`*^9, 3.604682057159107*^9}, {
   3.604682087649344*^9, 3.604682099716146*^9}, {3.604682135426692*^9, 
   3.604682209786515*^9}, {3.604682305424712*^9, 3.604682308336749*^9}, {
   3.6046824091925592`*^9, 3.6046824119033337`*^9}, {3.604682450098324*^9, 
   3.604682457769347*^9}, 3.604682516417946*^9, {3.604682651240501*^9, 
   3.6046826583570223`*^9}, {3.6046829326000977`*^9, 3.604682958776762*^9}, {
   3.604683008728921*^9, 3.604683034522788*^9}, {3.604683065109365*^9, 
   3.604683068002652*^9}, {3.604683254597282*^9, 3.604683297187317*^9}, {
   3.60468333081599*^9, 3.6046833815502443`*^9}, {3.604683517093029*^9, 
   3.6046835685256042`*^9}, 3.6046836401215363`*^9, 3.604683746704536*^9, {
   3.604683850418989*^9, 3.604683903178809*^9}, {3.611150539131564*^9, 
   3.611150544592495*^9}, {3.6217256600832987`*^9, 3.6217256673585167`*^9}, {
   3.627821410181806*^9, 3.627821424634012*^9}, {3.630975248000503*^9, 
   3.630975264111147*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {254., 269.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`figure1, $CellContext`figure2, $CellContext`g, \
$CellContext`h}, $CellContext`figure1 = {
           EdgeForm[Thick], 
           PolyhedronData["Cube", "Faces"]}; $CellContext`figure2 = {
           EdgeForm[Thick], 
           PolyhedronData["Octahedron", "Faces"]}; $CellContext`g = 
         Graphics3D[$CellContext`figure1]; $CellContext`h = Graphics3D[
           Scale[$CellContext`figure2, 
            Sqrt[2]]]; 
        Show[$CellContext`g, $CellContext`h, ViewPoint -> {40, 50, 20}, 
          PlotLabel -> "17.3.2", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {292., 299.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604683654766884*^9, 3.604683750401029*^9, {3.604683888469558*^9, 
   3.604683904867249*^9}, 3.613814128266762*^9, 3.621725669415017*^9, 
   3.627821426248496*^9, 3.630975276719743*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.3.3  Dual of Dodecahedron", "Subsubsection"],

Cell["The dual of a dodecahedron is an icosahedron.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
 Module[{figure1,figure2,g,h},
  figure1 = {EdgeForm[Thick],PolyhedronData[\"Dodecahedron\",\"Faces\"]};
  figure2 = {EdgeForm[Thick],PolyhedronData[\"Icosahedron\",\"Faces\"]};
  g = Graphics3D[figure1];
  h = Graphics3D[Scale[figure2,GoldenRatio]];
  Show[g,h,ViewPoint\[Rule]{40,50,20},PlotLabel\[Rule]\"17.3.3\",LabelStyle\
\[Rule]{Black,20}]
 ],
 TrackedSymbols\[Rule]{}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604615648799541*^9, 3.6046157558881683`*^9}, {
   3.604616141041625*^9, 3.604616167981743*^9}, {3.6046163148522*^9, 
   3.6046163256271*^9}, {3.6046165457781267`*^9, 3.6046165552825727`*^9}, {
   3.604616594727247*^9, 3.604616603837138*^9}, {3.604616652528594*^9, 
   3.604616658725453*^9}, {3.604616746522297*^9, 3.604616782666191*^9}, {
   3.604616933292152*^9, 3.604616941964341*^9}, {3.604616978764566*^9, 
   3.60461704679115*^9}, {3.6046170880373793`*^9, 3.6046170880427437`*^9}, {
   3.60461713607283*^9, 3.604617143281604*^9}, 3.604617519280344*^9, {
   3.604617659700705*^9, 3.604617681275128*^9}, {3.60461810520875*^9, 
   3.604618113080958*^9}, {3.6046819828582563`*^9, 3.604682057159107*^9}, {
   3.604682087649344*^9, 3.604682099716146*^9}, {3.604682135426692*^9, 
   3.604682209786515*^9}, {3.604682305424712*^9, 3.604682308336749*^9}, {
   3.6046824091925592`*^9, 3.6046824119033337`*^9}, {3.604682450098324*^9, 
   3.604682457769347*^9}, 3.604682516417946*^9, {3.604682651240501*^9, 
   3.6046826583570223`*^9}, {3.6046829326000977`*^9, 3.604682958776762*^9}, {
   3.604683008728921*^9, 3.604683034522788*^9}, {3.604683065109365*^9, 
   3.604683068002652*^9}, {3.604683254597282*^9, 3.604683297187317*^9}, {
   3.60468333081599*^9, 3.6046833815502443`*^9}, {3.604683517093029*^9, 
   3.6046835685256042`*^9}, 3.6046836401215363`*^9, 3.604683746704536*^9, {
   3.604683850418989*^9, 3.604683903178809*^9}, {3.60468394261172*^9, 
   3.604683992413457*^9}, {3.604684053604334*^9, 3.60468411861586*^9}, {
   3.604684197633358*^9, 3.604684200380575*^9}, {3.611150551044415*^9, 
   3.611150557817247*^9}, {3.6217256912711763`*^9, 3.621725697682104*^9}, {
   3.6278214396480503`*^9, 3.627821449456667*^9}, {3.630975312173421*^9, 
   3.630975324799355*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {}, 
    Typeset`size$$ = {500., {277., 293.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`figure1, $CellContext`figure2, $CellContext`g, \
$CellContext`h}, $CellContext`figure1 = {
           EdgeForm[Thick], 
           PolyhedronData["Dodecahedron", "Faces"]}; $CellContext`figure2 = {
           EdgeForm[Thick], 
           PolyhedronData["Icosahedron", "Faces"]}; $CellContext`g = 
         Graphics3D[$CellContext`figure1]; $CellContext`h = Graphics3D[
           Scale[$CellContext`figure2, GoldenRatio]]; 
        Show[$CellContext`g, $CellContext`h, ViewPoint -> {40, 50, 20}, 
          PlotLabel -> "17.3.3", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {}, "Options" :> {TrackedSymbols -> {}}, 
      "DefaultOptions" :> {LabelStyle -> $CellContext`labelstyle}],
     ImageSizeCache->{555., {315., 323.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604683968868607*^9, 3.6046839931483097`*^9}, {
   3.604684057501968*^9, 3.60468408542629*^9}, 3.604684120431807*^9, 
   3.604684201909052*^9, 3.613814147231954*^9, {3.621725699893491*^9, 
   3.621725709327002*^9}, 3.627821452087178*^9, 3.630975337434104*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.4 Stellated (Star) Polyhedra", "Subsection"],

Cell[TextData[{
 "A stellated polyhedron is formed by placing a vertex over the center of \
each polygon side and connecting this vertex to all the corners of the \
polygon.  ",
 "Although any convex polyhedra can be stellated, this section presents only \
the stellated Platonic solids.  ",
 "Let ",
 StyleBox["a",
  FontSlant->"Italic"],
 " be the ratio of the distance to the star vertices over the distance to the \
regular vertices, both measured from the center of the figure."
}], "Text"],

Cell[CellGroupData[{

Cell["17.4.1  Stellated tetrahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "g", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g", " ", "=", " ", 
       RowBox[{"Stellate", "[", 
        RowBox[{
         RowBox[{"PolyhedronData", "[", 
          RowBox[{"\"\<Tetrahedron\>\"", ",", "\"\<Image\>\""}], "]"}], ",", 
         "a"}], "]"}]}], ";", "\[IndentingNewLine]", " ", 
      RowBox[{"Show", "[", 
       RowBox[{"g", ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"9", ",", "24", ",", "16"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<17.4.1\>\""}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "2"}], "}"}], ",", "1", ",", "4", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "a", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604680677832404*^9, 3.604680725004891*^9}, {
  3.604680973651292*^9, 3.604681039102713*^9}, {3.6046811443035707`*^9, 
  3.6046811444364977`*^9}, {3.611150569120161*^9, 3.611150571696476*^9}, {
  3.621725730197185*^9, 3.621725736809944*^9}, {3.627821471197481*^9, 
  3.627821503319137*^9}, {3.630975683363162*^9, 3.630975744578006*^9}, {
  3.630975787952861*^9, 3.630975790952648*^9}, {3.630979976101419*^9, 
  3.630979984182723*^9}, {3.6309800304593887`*^9, 3.630980074528438*^9}, {
  3.630980134474712*^9, 3.630980159521179*^9}, {3.630980377315834*^9, 
  3.6309803912444277`*^9}, {3.6309804523267*^9, 3.630980474223198*^9}, {
  3.630980616613133*^9, 3.630980694449494*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 2, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 2}, 1, 4}}, Typeset`size$$ = {
    500., {315., 330.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$10101$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 2}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$10101$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`g$}, $CellContext`g$ = 
         PolyhedronOperations`Stellate[
           PolyhedronData["Tetrahedron", "Image"], $CellContext`a$$]; 
        Show[$CellContext`g$, ViewPoint -> {9, 24, 16}, PlotLabel -> "17.4.1",
           LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a$$, 2}, 1, 4, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {376., 383.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.630980669552717*^9, 3.630980696886402*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.4.2  Stellated cube", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "g", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g", " ", "=", " ", 
       RowBox[{"Stellate", "[", 
        RowBox[{
         RowBox[{"PolyhedronData", "[", 
          RowBox[{"\"\<Cube\>\"", ",", "\"\<Image\>\""}], "]"}], ",", "a"}], 
        "]"}]}], ";", "\n", "  ", 
      RowBox[{"Show", "[", 
       RowBox[{"g", ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"9", ",", "24", ",", "16"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<17.4.2\>\""}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "3"}], "}"}], ",", "1", ",", "4", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "a", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604680677832404*^9, 3.604680725004891*^9}, {
  3.604680973651292*^9, 3.604681039102713*^9}, {3.6046810776248007`*^9, 
  3.604681078432375*^9}, {3.6046811177203217`*^9, 3.604681132005156*^9}, {
  3.611150584635359*^9, 3.61115058885738*^9}, {3.621725764322235*^9, 
  3.621725770260229*^9}, {3.627821516697074*^9, 3.627821521908011*^9}, {
  3.6309804973371363`*^9, 3.6309805166487427`*^9}, {3.630980568963151*^9, 
  3.630980605811517*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 3}, 1, 4}}, Typeset`size$$ = {
    500., {304., 320.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$10301$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$10301$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`g$}, $CellContext`g$ = 
         PolyhedronOperations`Stellate[
           PolyhedronData["Cube", "Image"], $CellContext`a$$]; 
        Show[$CellContext`g$, ViewPoint -> {9, 24, 16}, PlotLabel -> "17.4.2",
           LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a$$, 3}, 1, 4, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {365., 372.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6046810876549253`*^9, {3.60468111870967*^9, 3.6046811346986713`*^9}, 
   3.613814418377191*^9, 3.621725771555203*^9, 3.627821522870575*^9, 
   3.630980517996643*^9, {3.6309805568464518`*^9, 3.630980586934408*^9}, 
   3.630980707350191*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.4.3  Stellated octahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "g", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g", " ", "=", " ", 
       RowBox[{"Stellate", "[", 
        RowBox[{
         RowBox[{"PolyhedronData", "[", 
          RowBox[{"\"\<Octahedron\>\"", ",", "\"\<Image\>\""}], "]"}], ",", 
         "a"}], "]"}]}], ";", "\n", "     ", 
      RowBox[{"Show", "[", 
       RowBox[{"g", ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"9", ",", "24", ",", "16"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<17.4.3\>\""}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "3"}], "}"}], ",", "1", ",", "4", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "a", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604680677832404*^9, 3.604680725004891*^9}, {
  3.604680973651292*^9, 3.604681039102713*^9}, {3.6046810776248007`*^9, 
  3.604681078432375*^9}, {3.6046811177203217`*^9, 3.604681132005156*^9}, {
  3.604681202488162*^9, 3.604681229139606*^9}, {3.611150597696392*^9, 
  3.6111506018964157`*^9}, {3.621725797247686*^9, 3.6217258035225267`*^9}, {
  3.6278215406221857`*^9, 3.627821558370265*^9}, {3.6309807458538923`*^9, 
  3.6309807578274727`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 3}, 1, 4}}, Typeset`size$$ = {
    500., {304., 320.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$11222$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$11222$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`g$}, $CellContext`g$ = 
         PolyhedronOperations`Stellate[
           PolyhedronData["Octahedron", "Image"], $CellContext`a$$]; 
        Show[$CellContext`g$, ViewPoint -> {9, 24, 16}, PlotLabel -> "17.4.3",
           LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a$$, 3}, 1, 4, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {365., 372.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.60468121400935*^9, 3.604681229882082*^9}, 
   3.613814430179864*^9, 3.621725805532035*^9, 3.6278215604320908`*^9, {
   3.630980762081285*^9, 3.630980771730933*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.4.4  Stellated dodecahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "g", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g", " ", "=", " ", 
       RowBox[{"Stellate", "[", 
        RowBox[{
         RowBox[{"PolyhedronData", "[", 
          RowBox[{"\"\<Dodecahedron\>\"", ",", "\"\<Image\>\""}], "]"}], ",", 
         "a"}], "]"}]}], ";", "\n", "  ", 
      RowBox[{"Show", "[", 
       RowBox[{"g", ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"9", ",", "24", ",", "16"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<17.4.4\>\""}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "2"}], "}"}], ",", "1", ",", "4", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "a", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604680677832404*^9, 3.604680725004891*^9}, {
  3.604680973651292*^9, 3.604681039102713*^9}, {3.6046810776248007`*^9, 
  3.604681078432375*^9}, {3.6046811177203217`*^9, 3.604681132005156*^9}, {
  3.604681202488162*^9, 3.604681229139606*^9}, {3.6046812674802237`*^9, 
  3.604681268962936*^9}, {3.6046813429378*^9, 3.604681344382248*^9}, {
  3.61115060823456*^9, 3.6111506111217012`*^9}, {3.621725823035385*^9, 
  3.621725834060727*^9}, {3.627821570423834*^9, 3.627821577120401*^9}, {
  3.630980789827173*^9, 3.6309808193398457`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 2, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 2}, 1, 4}}, Typeset`size$$ = {
    500., {323., 338.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$12383$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 2}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$12383$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`g$}, $CellContext`g$ = 
         PolyhedronOperations`Stellate[
           PolyhedronData["Dodecahedron", "Image"], $CellContext`a$$]; 
        Show[$CellContext`g$, ViewPoint -> {9, 24, 16}, PlotLabel -> "17.4.4",
           LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a$$, 2}, 1, 4, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {384., 391.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604681272323085*^9, 3.604681344969095*^9, 3.6138144387595863`*^9, 
   3.6217258409651413`*^9, 3.627821580194463*^9, {3.630980805509056*^9, 
   3.630980819948647*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["17.4.5  Stellated icosahedron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "g", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g", " ", "=", " ", 
       RowBox[{"Stellate", "[", 
        RowBox[{
         RowBox[{"PolyhedronData", "[", 
          RowBox[{"\"\<Icosahedron\>\"", ",", "\"\<Image\>\""}], "]"}], ",", 
         "a"}], "]"}]}], ";", "\n", "     ", 
      RowBox[{"Show", "[", 
       RowBox[{"g", ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"9", ",", "10", ",", "16"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<17.4.5\>\""}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "2"}], "}"}], ",", "1", ",", "4", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "a", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604680677832404*^9, 3.604680725004891*^9}, {
  3.604680973651292*^9, 3.604681039102713*^9}, {3.6046810776248007`*^9, 
  3.604681078432375*^9}, {3.6046811177203217`*^9, 3.604681132005156*^9}, {
  3.604681202488162*^9, 3.604681229139606*^9}, {3.6046812674802237`*^9, 
  3.604681268962936*^9}, {3.604681305718711*^9, 3.60468132813757*^9}, {
  3.611150618359336*^9, 3.6111506215967207`*^9}, {3.621725847923018*^9, 
  3.621725857035473*^9}, {3.627821588970108*^9, 3.627821605195281*^9}, {
  3.6309808315399237`*^9, 3.630980888400877*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 2, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 2}, 1, 4}}, Typeset`size$$ = {
    500., {291., 306.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$13904$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 2}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$13904$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`g$}, $CellContext`g$ = 
         PolyhedronOperations`Stellate[
           PolyhedronData["Icosahedron", "Image"], $CellContext`a$$]; 
        Show[$CellContext`g$, ViewPoint -> {9, 10, 16}, PlotLabel -> "17.4.5",
           LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a$$, 2}, 1, 4, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {352., 359.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604681317211892*^9, 3.604681328725268*^9}, 
   3.613814448260515*^9, 3.621725859508342*^9, 3.627821606915504*^9, {
   3.63098084742136*^9, 3.630980899856943*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["REFERENCE", "Subsection",
 CellChangeTimes->{{3.606249447814328*^9, 3.606249488384821*^9}}],

Cell[TextData[{
 "1. Williams, R.,",
 StyleBox[" The Geometrical Foundation of Natural Structure",
  FontSlant->"Italic"],
 ", Dover, New York, 1979."
}], "Text",
 CellChangeTimes->{{3.606249447814328*^9, 3.606249492931181*^9}}]
}, Closed]]
}, Open  ]]
},
WindowSize->{886, 890},
WindowMargins->{{19, Automatic}, {Automatic, 4}},
Magnification:>1.25 Inherited,
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 25, \
2016)",
StyleDefinitions->"myStyles.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 125, 2, 37, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1614, 39, 1386, 25, 278, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3037, 69, 66, 0, 51, "Section"],
Cell[3106, 71, 583, 11, 110, "Text"],
Cell[CellGroupData[{
Cell[3714, 86, 64, 0, 57, "Subsection"],
Cell[3781, 88, 868, 15, 408, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[4686, 108, 42, 0, 46, "Subsection"],
Cell[4731, 110, 410, 7, 165, "Text"],
Cell[CellGroupData[{
Cell[5166, 121, 52, 0, 66, "Subsubsection"],
Cell[CellGroupData[{
Cell[5243, 125, 1480, 31, 288, "Input"],
Cell[6726, 158, 2142, 40, 1025, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[8917, 204, 58, 0, 50, "Subsubsection"],
Cell[CellGroupData[{
Cell[9000, 208, 1273, 27, 288, "Input"],
Cell[10276, 237, 1767, 34, 1152, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[12092, 277, 51, 0, 50, "Subsubsection"],
Cell[CellGroupData[{
Cell[12168, 281, 1438, 30, 288, "Input"],
Cell[13609, 313, 1796, 35, 1097, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[15454, 354, 54, 0, 50, "Subsubsection"],
Cell[CellGroupData[{
Cell[15533, 358, 1527, 31, 288, "Input"],
Cell[17063, 391, 1801, 35, 1108, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[18913, 432, 53, 0, 50, "Subsubsection"],
Cell[CellGroupData[{
Cell[18991, 436, 1502, 31, 288, "Input"],
Cell[20496, 469, 1732, 34, 1377, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[22289, 510, 45, 0, 46, "Subsection"],
Cell[22337, 512, 560, 9, 106, "Text"],
Cell[CellGroupData[{
Cell[22922, 525, 46, 0, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[22993, 529, 1586, 32, 288, "Input"],
Cell[24582, 563, 1707, 34, 931, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[26338, 603, 61, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[26424, 607, 1692, 33, 331, "Input"],
Cell[28119, 642, 1755, 35, 1233, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[29923, 683, 58, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[30006, 687, 1667, 33, 331, "Input"],
Cell[31676, 722, 1675, 33, 1152, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[33400, 761, 50, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[33475, 765, 1707, 34, 331, "Input"],
Cell[35185, 801, 1721, 35, 1108, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[36955, 842, 61, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[37041, 846, 1771, 34, 331, "Input"],
Cell[38815, 882, 1674, 33, 1233, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[40538, 921, 58, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[40621, 925, 1815, 35, 331, "Input"],
Cell[42439, 962, 1703, 34, 1152, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[44191, 1002, 42, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[44258, 1006, 1846, 36, 288, "Input"],
Cell[46107, 1044, 1676, 33, 1152, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[47832, 1083, 50, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[47907, 1087, 1900, 36, 331, "Input"],
Cell[49810, 1125, 1691, 34, 1222, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[51550, 1165, 47, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[51622, 1169, 1948, 37, 288, "Input"],
Cell[53573, 1208, 1678, 33, 1152, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[55300, 1247, 56, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[55381, 1251, 2014, 38, 331, "Input"],
Cell[57398, 1291, 1698, 34, 1108, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[59145, 1331, 55, 0, 32, "Subsubsection"],
Cell[59203, 1333, 128, 1, 71, "Text"],
Cell[CellGroupData[{
Cell[59356, 1338, 2060, 38, 331, "Input"],
Cell[61419, 1378, 1697, 34, 1197, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[63165, 1418, 54, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[63244, 1422, 2107, 39, 331, "Input"],
Cell[65354, 1463, 1698, 34, 1108, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[67101, 1503, 55, 0, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[67181, 1507, 2157, 40, 331, "Input"],
Cell[69341, 1549, 1701, 34, 1012, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[71103, 1590, 51, 0, 46, "Subsection"],
Cell[71157, 1592, 794, 14, 303, "Text"],
Cell[CellGroupData[{
Cell[71976, 1610, 53, 0, 66, "Subsubsection"],
Cell[72032, 1612, 76, 0, 71, "Text"],
Cell[CellGroupData[{
Cell[72133, 1616, 1876, 33, 428, "Input"],
Cell[74012, 1651, 1956, 38, 1408, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[76017, 1695, 51, 0, 50, "Subsubsection"],
Cell[76071, 1697, 58, 0, 71, "Text"],
Cell[CellGroupData[{
Cell[76154, 1701, 2070, 36, 468, "Input"],
Cell[78227, 1739, 2135, 42, 1191, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[80411, 1787, 53, 0, 50, "Subsubsection"],
Cell[80467, 1789, 61, 0, 71, "Text"],
Cell[CellGroupData[{
Cell[80553, 1793, 2227, 38, 468, "Input"],
Cell[82783, 1833, 2207, 41, 1283, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[85051, 1881, 53, 0, 46, "Subsection"],
Cell[85107, 1883, 495, 11, 170, "Text"],
Cell[CellGroupData[{
Cell[85627, 1898, 54, 0, 53, "Subsubsection"],
Cell[CellGroupData[{
Cell[85706, 1902, 1891, 40, 300, "Input"],
Cell[87600, 1944, 1956, 39, 1216, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[89605, 1989, 47, 0, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[89677, 1993, 1629, 37, 300, "Input"],
Cell[91309, 2032, 2147, 43, 1182, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[93505, 2081, 53, 0, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[93583, 2085, 1669, 37, 333, "Input"],
Cell[95255, 2124, 2076, 41, 1182, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[97380, 2171, 55, 0, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[97460, 2175, 1756, 38, 333, "Input"],
Cell[99219, 2215, 2082, 42, 1241, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[101350, 2263, 54, 0, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[101429, 2267, 1760, 38, 333, "Input"],
Cell[103192, 2307, 2075, 41, 1141, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[105328, 2355, 97, 1, 46, "Subsection"],
Cell[105428, 2358, 228, 6, 408, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature dwpPlF2rTotY5DwalWD48jV6 *)
