(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 10.4' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[    395373,       9423]
NotebookOptionsPosition[    388978,       9198]
NotebookOutlinePosition[    389461,       9219]
CellTagsIndexPosition[    389418,       9216]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["1. Introduction", "Section"],

Cell[CellGroupData[{

Cell["1.0 Plotting Information for This Chapter", "Subsection"],

Cell["\<\
Although this chapter is intended to be primarily a textual introduction to \
the actual presentation of curves and surfaces in the subsequent chapters, it \
does contain a few evaluatable cells to illustrate particular mathematical \
properties.  These cells are indicated by the presence of the \
\[OpenCurlyDoubleQuote]\[DoubleLongRightArrow]\[CloseCurlyDoubleQuote] symbol \
at the far left.  This indicates that the cell can be opened to find a \
Manipulate function which illustrates the given property.  If readers have \
the Wolfram Research CDF Player installed and read this chapter in the CDF \
Player, then they can use the capability of the CDF Player to manipulate \
parameters interactively.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.1 Concept of a Curve", "Subsection"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 " be the Euclidean space of dimension ",
 StyleBox["n",
  FontSlant->"Italic"],
 ".  (According to this definition, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "1"], TraditionalForm]]],
 " is a line, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "2"], TraditionalForm]]],
 " is a plane, and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 " is a volume.)  A curve in ",
 StyleBox["n",
  FontSlant->"Italic"],
 "-space is defined as the set of points which result when a mapping from ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "1"], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["E", "n"], " "}], TraditionalForm]]],
 "is performed.  In this reference work, only curves in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "2"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 " will be considered.  Let ",
 StyleBox["t",
  FontSlant->"Italic"],
 " represent the independent variable in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "1"], TraditionalForm]]],
 ".  An ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "2"], TraditionalForm]]],
 " curve is then given by\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 "), ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["g",
  FontSlant->"Italic"],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ")\n\nand an ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 " curve by\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 "), ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["g",
  FontSlant->"Italic"],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 "), ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["h",
  FontSlant->"Italic"],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ")\n\nwhere ",
 StyleBox["f",
  FontSlant->"Italic"],
 ", ",
 StyleBox["g",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["h",
  FontSlant->"Italic"],
 " mean \"function of.\"  The domain of ",
 StyleBox["t",
  FontSlant->"Italic"],
 " is usually (0, 2\[Pi]), (-\[Infinity], \[Infinity]), or (0, \[Infinity]).  \
These are the parametric representations of a curve.  However, in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "2"], TraditionalForm]]],
 " curves are commonly expressed as\n\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ")\n\nor as\n\n\t",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = 0\n\nwhich are the explicit and implicit forms, respectively.  The \
explicit form is readily reducible from the parametric form when ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["t",
  FontSlant->"Italic"],
 " in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "2"], TraditionalForm]]],
 " and when ",
 StyleBox["x",
  FontSlant->"Italic"],
 " =",
 StyleBox[" f",
  FontSlant->"Italic"],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["t ",
  FontSlant->"Italic"],
 "and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["g",
  FontSlant->"Italic"],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["t ",
  FontSlant->"Italic"],
 "in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 ".  The implicit form of a curve will often comprise more points than a \
corresponding explicit form.  For example ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 " - ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 0 has two ranges in ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", one positive and one negative, while the explicit form derived from \
solving the above equation gives ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SqrtBox["x"], TraditionalForm]]],
 " for which the range of ",
 StyleBox["y",
  FontSlant->"Italic"],
 " is positive only.\n\nGenerally, the definition of a curve imposes a ",
 StyleBox["smoothness ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["criterion",
     FontSlant->"Italic"], "1"], TraditionalForm]]],
 ", meaning that the trace of the curve has no abrupt changes of direction \
(continuous first derivative).  However, for purposes of this reference work, \
a broader definition of curve is proposed.  Here, a curve may be composed of \
smooth branches, each satisfying the above definition, provided that the \
intervals over which the curve branches are distinctly defined and are \
contiguous.  This definition will encompass forms such as polygons or \
sawtooth functions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 Concept of a Surface", "Subsection"],

Cell[TextData[{
 "This reference work defines surfaces as existing only in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 ".  Therefore a surface is defined as the mapping from ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "2"], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 " according to\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["s",
  FontSlant->"Italic"],
 ", ",
 StyleBox["t",
  FontSlant->"Italic"],
 "), \n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["g",
  FontSlant->"Italic"],
 "(",
 StyleBox["s",
  FontSlant->"Italic"],
 ", ",
 StyleBox["t",
  FontSlant->"Italic"],
 "), \n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["h",
  FontSlant->"Italic"],
 "(",
 StyleBox["s",
  FontSlant->"Italic"],
 ",",
 StyleBox[" t",
  FontSlant->"Italic"],
 ").\n\nAs for curves, the conversion from this parametric form to more \
common forms\n\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ")\n\nor\n\n\t",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") = 0\n\nmay not be possible in some cases.  Again, a ",
 StyleBox["smoothness ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["criterion",
     FontSlant->"Italic"], "1"], TraditionalForm]]],
 " is desirable; but the generalized definition of surface requires that this \
smoothness criterion only be satisfied piecewise for all distinct mappings of \
the (",
 StyleBox["s",
  FontSlant->"Italic"],
 ", ",
 StyleBox["t",
  FontSlant->"Italic"],
 ") plane over which the surface is defined.  These generalized surfaces are \
termed manifolds.  Cubes are examples of surfaces which can be defined in \
this deterministic manner."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3 Coordinate Systems", "Subsection"],

Cell[TextData[{
 "The number of available coordinate systems for representing curves is large \
and even larger for surfaces.  However, to maintain uniformity of \
presentation throughout this volume, only the following will be used:\n\n\t\t\
2-D                                           3-D\n           Cartesian, \
polar\t   \tCartesian, cylindrical, spherical\n\nThe term parametric is often \
used as though it were a coordinate system, but it is really a representation \
of coordinates in terms of an additional independent parameter which is not \
itself a coordinate of the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["E",
     FontSlant->"Italic"], "3"], TraditionalForm]]],
 " space in which the curve or surface exists."
}], "Text"],

Cell[CellGroupData[{

Cell["1.3.1 Cartesian Coordinates", "Subsubsection"],

Cell[TextData[{
 "The Cartesian coordinates system is illustrated in Figure 1 for two \
dimensions.  This is the most natural, but not always the most convenient, \
system of coordinates for curves in two dimensions.  Coordinates of a point \
",
 StyleBox["p",
  FontSlant->"Italic"],
 " are measured linearly along two axes which intersect with a right angle at \
the origin (0, 0).  The Cartesian system is also called the rectangular \
coordinates system.  For three dimensions, an additional axis, orthogonal to \
the other two, is placed as shown in Figure 2."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"1.5", ",", "2.0"}], "}"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2.0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<X\>\"", ",", "\"\<Y\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", "None"}], "}"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", " ", 
     RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", "16"}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<Figure 1.1.\\nThe Cartesian coordinate system\\nfor two \
dimensions.\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "14"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "2.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1.5", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0"}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
     "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"x", ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", "2.1"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"y", ",", 
        RowBox[{"{", 
         RowBox[{"1.6", ",", "1.0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"p", ",", 
        RowBox[{"{", 
         RowBox[{"1.6", ",", "2.1"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[0.03], AbsoluteThickness[1.6], 
      PointBox[{{1.5, 2.}, {1.5, 2.}}]}, {}}, {}}, {
    {Thickness[Large], Dashing[{Small, Small}], 
     LineBox[{{0, 2.}, {1.5, 2.}}]}, 
    {Thickness[Large], Dashing[{Small, Small}], 
     LineBox[{{1.5, 0}, {1.5, 2.}}]}}, {InsetBox["x", {0.75, 2.1}], 
    InsetBox["y", {1.6, 1.}], InsetBox["p", {1.6, 2.1}]}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"X\"", TraditionalForm], 
    FormBox["\"Y\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Thickness[Large],
  BaseStyle->16,
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->{
    GrayLevel[0], 14},
  Method->{},
  PlotLabel->FormBox[
   "\"Figure 1.1.\\nThe Cartesian coordinate system\\nfor two dimensions.\"", 
    TraditionalForm],
  PlotRange->{{0, 2.}, {0, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{None, None}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ListPointPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"1.5", ",", "2.0", ",", "2.5"}], "}"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2.0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3.0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"PointSize", "[", "0.03", "]"}]}], "}"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<X\>\"", ",", "\"\<Y\>\"", ",", "\"\<Z\>\""}], "}"}]}], 
     ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", "None", ",", "None"}], "}"}]}], ",", " ", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2.0", ",", "2.5", ",", "3.0"}], "}"}]}], ",", 
     RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", " ", 
     RowBox[{"BaseStyle", "\[Rule]", "16"}], ",", 
     RowBox[{"BoxStyle", "\[Rule]", "Thick"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1000", ",", 
        RowBox[{"-", "2000"}], ",", "400"}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<Figure 1.2.\\nThe Cartesian coordinate system\\nfor three \
dimensions.\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "14"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "2.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "0.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1.5", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "0.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "2.5"}], "}"}]}], "}"}], "]"}]}], 
       "}"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"x", ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", "1.5", ",", "0.0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"y", ",", 
        RowBox[{"{", 
         RowBox[{"1.8", ",", "1.0", ",", "0.0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"z", ",", 
        RowBox[{"{", 
         RowBox[{"1.6", ",", "2.1", ",", "1.5"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"p", ",", 
        RowBox[{"{", 
         RowBox[{"1.6", ",", "2.1", ",", "2.6"}], "}"}]}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}], "Input"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0], PointSize[0.03], Point3DBox[{{1.5, 2., 2.5}}]}, {
    {Thickness[Large], Dashing[{Small, Small}], 
     Line3DBox[{{0, 2., 0.}, {1.5, 2., 0.}}]}, 
    {Thickness[Large], Dashing[{Small, Small}], 
     Line3DBox[{{1.5, 0., 0.}, {1.5, 2., 0.}}]}, 
    {Thickness[Large], Dashing[{Small, Small}], 
     Line3DBox[{{1.5, 2., 0.}, {1.5, 2., 2.5}}]}}, {Text3DBox[
     FormBox["x", StandardForm], {0.75, 1.5, 0.}], Text3DBox[
     FormBox["y", StandardForm], {1.8, 1., 0.}], Text3DBox[
     FormBox["z", StandardForm], {1.6, 2.1, 1.5}], Text3DBox[
     FormBox["p", StandardForm], {1.6, 2.1, 2.6}]}},
  Axes->True,
  AxesLabel->{
    FormBox["\"X\"", TraditionalForm], 
    FormBox["\"Y\"", TraditionalForm], 
    FormBox["\"Z\"", TraditionalForm]},
  AxesStyle->Thickness[Large],
  BaseStyle->16,
  BoxRatios->{2., 2.5, 3.},
  BoxStyle->Thickness[Large],
  FaceGridsStyle->Automatic,
  LabelStyle->{
    GrayLevel[0], 14},
  PlotLabel->FormBox[
   "\"Figure 1.2.\\nThe Cartesian coordinate system\\nfor three \
dimensions.\"", TraditionalForm],
  PlotRange->{{0, 2.}, {0, 2.5}, {0, 3.}},
  PlotRangePadding->{{Automatic, Automatic}, {Automatic, Automatic}, {
    Automatic, Automatic}},
  Ticks->{None, None, None},
  ViewPoint->{1000, -2000, 400}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3.2 Polar Coordinates", "Subsubsection"],

Cell[TextData[{
 "Polar coordinates (",
 StyleBox["r",
  FontSlant->"Italic"],
 ", \[Theta]) are defined for two dimensions and are a desirable alternative \
to Cartesian ones when the curve is point symmetric and exists only over a \
limited domain and range of the variables ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".  As illustrated in Figure 3, the coordinate ",
 StyleBox["r",
  FontSlant->"Italic"],
 " is the distance of the point ",
 StyleBox["p",
  FontSlant->"Italic"],
 " from the origin and the coordinate \[Theta] is the counterclockwise angle \
which the line from the origin to ",
 StyleBox["p",
  FontSlant->"Italic"],
 " makes with the horizontal line through the origin to the right.  \
Counterclockwise rotations are measured in positive \[Theta], while clockwise \
rotations are measured in negative \[Theta], relative to this line.  \
Transformations from polar to Cartesian, and vice-versa, are made according \
to: \n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["r",
  FontSlant->"Italic"],
 " cos(\[Theta]),  \n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["r",
  FontSlant->"Italic"],
 " sin(\[Theta])\nand \n\t",
 StyleBox["r",
  FontSlant->"Italic"],
 " =",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"x", " "}], "2"], "+", " ", 
       SuperscriptBox["y", "2"]}], ")"}], 
     RowBox[{"1", "/", "2"}]]}], TraditionalForm]]],
 ", \n\t\[Theta] = arctan(",
 StyleBox["y",
  FontSlant->"Italic"],
 "/",
 StyleBox["x",
  FontSlant->"Italic"],
 ").\n"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"1.5", ",", "2.0"}], "}"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2.0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<X\>\"", ",", "\"\<Y\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", "None"}], "}"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", " ", 
     RowBox[{"BaseStyle", "\[Rule]", "16"}], ",", 
     RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<Figure 1.3.\\nThe polar coordinate system\\nfor two \
dimensions.\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "14"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", "Thick", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.0", ",", "0.0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.5", ",", "2.0"}], "}"}]}], "}"}], "]"}]}], "}"}], "}"}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"r", ",", 
        RowBox[{"{", 
         RowBox[{"0.75", ",", "1.2"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"p", ",", 
        RowBox[{"{", 
         RowBox[{"1.6", ",", "2.1"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "p2", ",", "p3"}], "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[0.03], AbsoluteThickness[1.6], 
      PointBox[{{1.5, 2.}, {1.5, 2.}}]}, {}}, {}}, 
   {Thickness[Large], Dashing[{Small, Small}], 
    LineBox[{{0., 0.}, {1.5, 2.}}]}, {InsetBox["r", {0.75, 1.2}], 
    InsetBox["p", {1.6, 2.1}]}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"X\"", TraditionalForm], 
    FormBox["\"Y\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Thickness[Large],
  BaseStyle->16,
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->{
    GrayLevel[0], 14},
  Method->{},
  PlotLabel->FormBox[
   "\"Figure 1.3.\\nThe polar coordinate system\\nfor two dimensions.\"", 
    TraditionalForm],
  PlotRange->{{0, 2.}, {0, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{None, None}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3.3 Cylindrical Coordinates", "Subsubsection"],

Cell[TextData[{
 "Cylindrical coordinates are used in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 ".  They combine the (",
 StyleBox["r",
  FontSlant->"Italic"],
 ", \[Theta]) polar coordinates of two dimensions with the third coordinate \
",
 StyleBox["z",
  FontSlant->"Italic"],
 " measured perpendicularly from the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-",
 StyleBox["y",
  FontSlant->"Italic"],
 " plane at (",
 StyleBox["r",
  FontSlant->"Italic"],
 ", \[Theta]) to the point ",
 StyleBox["p",
  FontSlant->"Italic"],
 " at (",
 StyleBox["r",
  FontSlant->"Italic"],
 ", \[Theta], ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") as in Figure 4.  The normal convention is for ",
 StyleBox["z",
  FontSlant->"Italic"],
 " to be positive upward.  Transformation from cylindrical to Cartesian \
coordinates involves only the polar-to-Cartesian transformations given above \
because the ",
 StyleBox["z",
  FontSlant->"Italic"],
 " coordinate is unchanged.  Cylindrical coordinates are often appropriate \
when surfaces are axially symmetric about the ",
 StyleBox["z",
  FontSlant->"Italic"],
 " axis; for example, in representing the form ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "2"], TraditionalForm]]],
 " = ",
 StyleBox["z",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ListPointPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"1.5", ",", "2.0", ",", "2.0"}], "}"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Black", "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.7"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", "None", ",", "None"}], "}"}]}], ",", " ", 
     RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", "Automatic"}], ",", " ", 
     RowBox[{"BaseStyle", "\[Rule]", "16"}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<Figure 1.4.\\nThe cylindrical coordinate system\\nfor three \
dimensions.\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "14"}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"100", ",", 
        RowBox[{"-", "60"}], ",", "50"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p2", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "0.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "r", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p3", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "2.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "z", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p4", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "2.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "p", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p5", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2.0", ",", "0.0", ",", "0.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "X", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p6", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.0", ",", "2.0", ",", "0.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "Y", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p7", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "2.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "Z", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p8", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"r", ",", 
        RowBox[{"{", 
         RowBox[{"0.8", ",", "1.0", ",", "0.1"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"z", ",", 
        RowBox[{"{", 
         RowBox[{"1.6", ",", "2.1", ",", "1.0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"p", ",", 
        RowBox[{"{", 
         RowBox[{"1.6", ",", "2.1", ",", "2.1"}], "}"}]}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p9", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"X", ",", 
        RowBox[{"{", 
         RowBox[{"2.0", ",", "0.0", ",", "0.0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"Y", ",", 
        RowBox[{"{", 
         RowBox[{"0.0", ",", "2.1", ",", "0.0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"Z", ",", 
        RowBox[{"{", 
         RowBox[{"0.0", ",", "0.0", ",", "2.1"}], "}"}]}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p10", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"1.5", ",", "2.0", ",", "2.0"}], "}"}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
  "p1", ",", "p2", ",", "p3", ",", "p4", ",", "p5", ",", "p6", ",", "p7", ",",
    "p8", ",", "p9", ",", "p10"}], "]"}]}], "Input"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0], Point3DBox[{{1.5, 2., 2.}}]}, 
   {Thickness[Large], Dashing[{Small, Small}], 
    Line3DBox[{{0., 0., 0.}, {1.5, 2., 0.}}]}, 
   {Thickness[Large], Dashing[{Small, Small}], 
    Line3DBox[{{1.5, 2., 0.}, {1.5, 2., 2.}}]}, 
   {Thickness[Large], Dashing[{Small, Small}], 
    Line3DBox[{{0., 0., 0.}, {1.5, 2., 2.}}]}, 
   {Thickness[Large], Line3DBox[{{0., 0., 0.}, {2., 0., 0.}}]}, 
   {Thickness[Large], Line3DBox[{{0., 0., 0.}, {0., 2., 0.}}]}, 
   {Thickness[Large], Line3DBox[{{0., 0., 0.}, {0., 0., 2.}}]}, {Text3DBox[
     FormBox["r", StandardForm], {0.8, 1., 0.1}], Text3DBox[
     FormBox["z", StandardForm], {1.6, 2.1, 1.}], Text3DBox[
     FormBox["p", StandardForm], {1.6, 2.1, 2.1}]}, {Text3DBox[
     FormBox["X", StandardForm], {2., 0., 0.}], Text3DBox[
     FormBox["Y", StandardForm], {0., 2.1, 0.}], Text3DBox[
     FormBox["Z", StandardForm], {0., 0., 2.1}]}, 
   {PointSize[0.05], Point3DBox[{1.5, 2., 2.}]}},
  Axes->False,
  AxesLabel->{None, None, None},
  BaseStyle->16,
  BoxRatios->Automatic,
  Boxed->False,
  FaceGridsStyle->Automatic,
  LabelStyle->{
    GrayLevel[0], 14},
  PlotLabel->FormBox[
   "\"Figure 1.4.\\nThe cylindrical coordinate system\\nfor three dimensions.\
\"", TraditionalForm],
  PlotRange->{{-0.1, 1.7}, {-0.1, 2.2}, {-0.1, 2.2}},
  PlotRangePadding->{{Automatic, Automatic}, {Automatic, Automatic}, {
    Automatic, Automatic}},
  Ticks->{None, None, None},
  ViewPoint->{100, -60, 50}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3.4 Spherical Coordinates", "Subsubsection"],

Cell[TextData[{
 "As illustrated in Figure 5, let a point in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 " lie at a radial distance ",
 StyleBox["r",
  FontSlant->"Italic"],
 " along a vector from the origin.  Project this vector to the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-",
 StyleBox["y",
  FontSlant->"Italic"],
 " plane and let the angle between the vector and its projection be \
\[CurlyPhi].  Now measure the angle \[Theta] of the projected line in the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-",
 StyleBox["y",
  FontSlant->"Italic"],
 " plane as for polar coordinates.  Then (",
 StyleBox["r",
  FontSlant->"Italic"],
 ", \[Theta], \[CurlyPhi]) are the spherical coordinates of ",
 StyleBox["p",
  FontSlant->"Italic"],
 ".  The transformations from spherical to Cartesian coordinates, and \
vice-versa, are given by\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["r",
  FontSlant->"Italic"],
 " cos\[Theta] sin\[CurlyPhi],  \n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["r",
  FontSlant->"Italic"],
 " sin\[Theta] sin\[CurlyPhi],  \n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["r",
  FontSlant->"Italic"],
 " cos\[CurlyPhi]\nand\n\t",
 StyleBox["r",
  FontSlant->"Italic"],
 " =",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"x", " "}], "2"], "+", " ", 
       SuperscriptBox["y", "2"]}], ")"}], 
     RowBox[{"1", "/", "2"}]]}], TraditionalForm]]],
 ", \n\t\[Theta] = arctan(",
 StyleBox["y",
  FontSlant->"Italic"],
 "/",
 StyleBox["x",
  FontSlant->"Italic"],
 "), \n\t\[CurlyPhi] = arctan[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"x", " "}], "2"], "+", " ", 
      SuperscriptBox["y", "2"]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 "/",
 StyleBox["z",
  FontSlant->"Italic"],
 "].\n\nSpherical coordinates are often appropriate for surfaces having point \
symmetry about the origin.  The usual coordinates of geography, which refer \
to points on the earth by latitude and longitude, are a spherical system.",
 "\n"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"ListPointPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"1.5", ",", "2.0", ",", "2.0"}], "}"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Black", "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.7"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", "None", ",", "None"}], "}"}]}], ",", " ", 
     RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"BoxRatios", "\[Rule]", "Automatic"}], ",", " ", 
     RowBox[{"BaseStyle", "\[Rule]", "16"}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<Figure 1.5.\\nThe spherical coordinate system\\nfor three \
dimensions.\>\""}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "14"}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"100", ",", 
        RowBox[{"-", "60"}], ",", "50"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p2", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "0.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "r", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p3", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "2.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "z", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p4", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1.5", ",", "2.0", ",", "2.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "p", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p5", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2.0", ",", "0.0", ",", "0.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "X", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p6", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.0", ",", "2.0", ",", "0.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "Y", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p7", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.0", ",", "0.0", ",", "2.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "}"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "Z", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p8", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"r", ",", 
        RowBox[{"{", 
         RowBox[{"0.6", ",", "1.0", ",", "1.0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"p", ",", 
        RowBox[{"{", 
         RowBox[{"1.6", ",", "2.1", ",", "2.1"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\[Phi]", ",", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.1", ",", "0.3"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\[Theta]", ",", 
        RowBox[{"{", 
         RowBox[{"0.6", ",", "0.0", ",", "0.1"}], "}"}]}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p9", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Text", "[", 
       RowBox[{"X", ",", 
        RowBox[{"{", 
         RowBox[{"2.0", ",", "0.0", ",", "0.0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"Y", ",", 
        RowBox[{"{", 
         RowBox[{"0.0", ",", "2.1", ",", "0.0"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"Z", ",", 
        RowBox[{"{", 
         RowBox[{"0.0", ",", "0.0", ",", "2.1"}], "}"}]}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p10", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"1.5", ",", "2.0", ",", "2.0"}], "}"}], "]"}]}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
  "p1", ",", "p2", ",", "p3", ",", "p4", ",", "p5", ",", "p6", ",", "p7", ",",
    "p8", ",", "p9", ",", "p10"}], "]"}]}], "Input"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0], Point3DBox[{{1.5, 2., 2.}}]}, 
   {Thickness[Large], Dashing[{Small, Small}], 
    Line3DBox[{{0., 0., 0.}, {1.5, 2., 0.}}]}, 
   {Thickness[Large], Dashing[{Small, Small}], 
    Line3DBox[{{1.5, 2., 0.}, {1.5, 2., 2.}}]}, 
   {Thickness[Large], Dashing[{Small, Small}], 
    Line3DBox[{{0., 0., 0.}, {1.5, 2., 2.}}]}, 
   {Thickness[Large], Line3DBox[{{0., 0., 0.}, {2., 0., 0.}}]}, 
   {Thickness[Large], Line3DBox[{{0., 0., 0.}, {0., 2., 0.}}]}, 
   {Thickness[Large], Line3DBox[{{0., 0., 0.}, {0., 0., 2.}}]}, {Text3DBox[
     FormBox["r", StandardForm], {0.6, 1., 1.}], Text3DBox[
     FormBox["p", StandardForm], {1.6, 2.1, 2.1}], Text3DBox[
     FormBox["\[Phi]", StandardForm], {0.1, 0.1, 0.3}], Text3DBox[
     FormBox["\[Theta]", StandardForm], {0.6, 0., 0.1}]}, {Text3DBox[
     FormBox["X", StandardForm], {2., 0., 0.}], Text3DBox[
     FormBox["Y", StandardForm], {0., 2.1, 0.}], Text3DBox[
     FormBox["Z", StandardForm], {0., 0., 2.1}]}, 
   {PointSize[0.05], Point3DBox[{1.5, 2., 2.}]}},
  Axes->False,
  AxesLabel->{None, None, None},
  BaseStyle->16,
  BoxRatios->Automatic,
  Boxed->False,
  FaceGridsStyle->Automatic,
  LabelStyle->{
    GrayLevel[0], 14},
  PlotLabel->FormBox[
   "\"Figure 1.5.\\nThe spherical coordinate system\\nfor three \
dimensions.\"", TraditionalForm],
  PlotRange->{{-0.1, 1.7}, {-0.1, 2.2}, {-0.1, 2.2}},
  PlotRangePadding->{{Automatic, Automatic}, {Automatic, Automatic}, {
    Automatic, Automatic}},
  Ticks->{None, None, None},
  ViewPoint->{100, -60, 50}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4 Qualitative Properties of Curves and Surfaces", "Subsection"],

Cell["\<\
Curves and surfaces exhibit a wide variety of forms.Particular attributes of \
form are derivable from the equations themselves, and many texts treat these \
in rigorous detail.The purpose here is not to duplicate such explicit and \
analytical treatment but rather to present the properties of curves and \
surfaces in a qualitative manner to which their visible forms are naturally \
and easily related.  Understanding these properties enables one to choose the \
appropriate curve for a given purpose (for example, data fitting) or to \
modify, when necessary, an equation given in this volume into one more \
suitable for a given purpose.\
\>", "Text"],

Cell[CellGroupData[{

Cell["1.4.1 Derivative", "Subsubsection"],

Cell[TextData[{
 "A fundamental quantity associated with a curve, or function, is the \
derivative.The derivative exists at all continuous points of the curve \
(except singular points as described in Section 1.4.7).  Although the \
definition of derivative can be made with analytical ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["rigor", "1"], TraditionalForm]]],
 ", in graphical terms the derivative at any point is the slope of the \
tangent line at that point and is written as ",
 StyleBox["dy",
  FontSlant->"Italic"],
 "/",
 StyleBox["dx",
  FontSlant->"Italic"],
 " for two-dimensional curves.  For three-dimensional curves, the tangent \
line is along the trajectory of the curve, and three such derivatives are \
possible using the three pairs of (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") coordinates.Closely associated with the derivative is a curve' s normal \
which is the line perpendicular to the tangent.  In two dimensions the normal \
is a single line, but in three dimensions the normal sweeps out a plane \
perpendicular to the tangent of the curve.  As for curves, the derivative of \
a surface is a fundamental quantity.  The derivative at any continuous point \
of a surface relates to the tangent plane of the surface at that point.  For \
this plane, three partial derivatives exist, written as ",
 StyleBox["dy",
  FontSlant->"Italic"],
 "/",
 StyleBox["dz",
  FontSlant->"Italic"],
 ", ",
 StyleBox["dz",
  FontSlant->"Italic"],
 "/",
 StyleBox["dx",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["dx",
  FontSlant->"Italic"],
 "/",
 StyleBox["dy",
  FontSlant->"Italic"],
 " (or their inverses), which are the slopes of the lines formed at the \
intersection of the tangent plane with the ",
 StyleBox["y",
  FontSlant->"Italic"],
 "-",
 StyleBox["z",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 "-",
 StyleBox["x",
  FontSlant->"Italic"],
 ", and",
 StyleBox[" x",
  FontSlant->"Italic"],
 "-",
 StyleBox["y",
  FontSlant->"Italic"],
 " planes, respectively.  The normal ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "p"], TraditionalForm]]],
 " to the surface at a point is the vector orthogonal to the surface there.  \
It is defined at all points for which the surface is smooth by the partial \
derivatives\n                    \n                    ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "p"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    RowBox[{"[", 
     RowBox[{
      RowBox[{"(", GridBox[{
         {
          FractionBox["\[Delta]y", "\[Delta]s"], 
          FractionBox["\[Delta]y", "\[Delta]t"]},
         {
          FractionBox["\[Delta]z", "\[Delta]s"], 
          FractionBox["\[Delta]z", "\[Delta]t"]}
        }], ")"}], ",", 
      RowBox[{"(", GridBox[{
         {
          FractionBox["\[Delta]z", "\[Delta]s"], 
          FractionBox["\[Delta]z", "\[Delta]t"]},
         {
          FractionBox["\[Delta]x", "\[Delta]s"], 
          FractionBox["\[Delta]x", "\[Delta]t"]}
        }], ")"}], ",", 
      RowBox[{"(", GridBox[{
         {
          FractionBox["\[Delta]x", "\[Delta]s"], 
          FractionBox["\[Delta]x", "\[Delta]t"]},
         {
          FractionBox["\[Delta]y", "\[Delta]s"], 
          FractionBox["\[Delta]y", "\[Delta]t"]}
        }], ")"}]}], "]"}], "p"], TraditionalForm]]],
 "\n                    \nusing the parametric representation equations.  If \
the surface can be expressed in the implicit form ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") = 0, then simply\n                    \n                    ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "p"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    RowBox[{"[", 
     RowBox[{
      FractionBox["\[Delta]f", "\[Delta]x"], ",", 
      FractionBox["\[Delta]f", "\[Delta]y"], ",", 
      FractionBox["\[Delta]f", "\[Delta]z"]}], "]"}], "p"], TraditionalForm]]],
 "\n                    \nThe above definitions give the (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") components of the normal vector, and it is customary to normalize them to \
(",
 StyleBox["x",
  FontSlant->"Italic"],
 "', ",
 StyleBox["y",
  FontSlant->"Italic"],
 "', ",
 StyleBox["z",
  FontSlant->"Italic"],
 "') by dividing them with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", "+", " ", 
      SuperscriptBox["y", "2"], " ", "+", " ", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 " so that ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"x", "'"}], "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"y", "'"}], "2"], TraditionalForm]]],
 " +",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox[
     RowBox[{"z", "'"}], "2"]}], TraditionalForm]]],
 " = 1.  The following cell embodies the above equation for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["n", "p"], " "}], TraditionalForm]]],
 "using the implicit form of the surface for an ellipsoid; the normal  is \
computed instantaneously as the position on the surface of the ellipsoid is \
changed."
}], "Text"],

Cell[CellGroupData[{

Cell["\[DoubleLongRightArrow]Show the normal to a surface.", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"p1", " ", "=", " ", 
    RowBox[{"Plot3D", "[", 
     RowBox[{
      RowBox[{"4", "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "/", "4"}], " ", "-", " ", 
         RowBox[{
          RowBox[{"y", "^", "2"}], "/", "9"}]}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", " ", 
        RowBox[{"-", "4"}], ",", " ", "4"}], "}"}], ",", " ", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{"y", ",", " ", 
        RowBox[{"-", "4"}], ",", " ", "4"}], "}"}], ",", " ", 
      RowBox[{"PlotRange", " ", "->", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "3"}], ",", " ", "3"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", " ", "4"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "5"}], "}"}]}], "}"}]}], ",", " ", "\n", 
      "    ", 
      RowBox[{"AxesLabel", " ", "->", " ", 
       RowBox[{"{", 
        RowBox[{"X", ",", " ", "Y", ",", " ", "Z"}], "}"}]}], ",", " ", 
      RowBox[{"BoxRatios", " ", "->", " ", 
       RowBox[{"{", 
        RowBox[{"6", ",", " ", "8", ",", " ", "5"}], "}"}]}], ",", " ", "\n", 
      "    ", 
      RowBox[{
      "PlotLabel", " ", "->", " ", "\"\<normal to an ellipsoid\>\""}]}], 
     "]"}]}], ";"}], " "}], "\n", 
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"implicit", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "2"}], "/", "4"}], " ", "+", " ", 
      RowBox[{
       RowBox[{"y", "^", "2"}], "/", "9"}], " ", "+", " ", 
      RowBox[{
       RowBox[{"z", "^", "2"}], "/", "16"}]}]}], ";", " ", "\n", "   ", 
    RowBox[{"fx", " ", "=", " ", 
     RowBox[{"D", "[", 
      RowBox[{"implicit", ",", " ", "x"}], "]"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"fy", " ", "=", " ", 
     RowBox[{"D", "[", 
      RowBox[{"implicit", ",", " ", "y"}], "]"}]}], ";", " ", "\n", "   ", 
    RowBox[{"fz", " ", "=", " ", 
     RowBox[{"D", "[", 
      RowBox[{"implicit", ",", " ", "z"}], "]"}]}], ";", " ", "\n", "   ", 
    RowBox[{"z0", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"4", "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{
          RowBox[{"x0", "^", "2"}], "/", "4"}], " ", "-", " ", 
         RowBox[{
          RowBox[{"y0", "^", "2"}], "/", "9"}]}], "]"}]}], "]"}]}], ";", " ", 
    "\n", "   ", 
    RowBox[{"coord", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"x0", ",", " ", "y0", ",", " ", "z0"}], "}"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"normal", " ", "=", " ", 
     RowBox[{"Normalize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fx", ",", " ", "fy", ",", " ", "fz"}], "}"}], " ", "/.", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", " ", "->", " ", "x0"}], ",", " ", 
         RowBox[{"y", " ", "->", " ", "y0"}], ",", " ", 
         RowBox[{"z", " ", "->", " ", "z0"}]}], "}"}]}], "]"}]}], ";", " ", 
    "\n", "   ", 
    RowBox[{"coordplus", " ", "=", " ", 
     RowBox[{"coord", " ", "+", " ", "normal"}]}], ";", " ", "\n", "   ", 
    RowBox[{"p2", " ", "=", " ", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Large", "]"}], ",", " ", "\n", "      ", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"x0", ",", " ", "y0", ",", " ", "z0"}], "}"}], "]"}]}], 
       "}"}], "]"}]}], ";", " ", "\n", "   ", 
    RowBox[{"p3", " ", "=", " ", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", " ", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{"coord", ",", " ", "coordplus"}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";", " ", "\n", "   ", 
    RowBox[{"Show", "[", 
     RowBox[{"p1", ",", " ", "p2", ",", " ", "p3"}], "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{"-", "2"}], ",", " ", "2"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{"-", "3"}], ",", " ", "3"}], "}"}]}], "\[IndentingNewLine]", 
  "]"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`x0$$ = 
    0.9500000000000002, $CellContext`y0$$ = -1.45, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`x0$$], 0}, -2, 2}, {{
       Hold[$CellContext`y0$$], 0}, -3, 3}}, Typeset`size$$ = {
    476., {161., 167.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`x0$4633$$ = 
    0, $CellContext`y0$4634$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`x0$$ = 0, $CellContext`y0$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`x0$$, $CellContext`x0$4633$$, 0], 
        Hold[$CellContext`y0$$, $CellContext`y0$4634$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`implicit = $CellContext`x^2/
          4 + $CellContext`y^2/9 + $CellContext`z^2/16; $CellContext`fx = 
        D[$CellContext`implicit, $CellContext`x]; $CellContext`fy = 
        D[$CellContext`implicit, $CellContext`y]; $CellContext`fz = 
        D[$CellContext`implicit, $CellContext`z]; $CellContext`z0 = 
        N[4 Sqrt[
           1 - $CellContext`x0$$^2/4 - $CellContext`y0$$^2/
            9]]; $CellContext`coord = {$CellContext`x0$$, $CellContext`y0$$, \
$CellContext`z0}; $CellContext`normal = Normalize[
          
          ReplaceAll[{$CellContext`fx, $CellContext`fy, $CellContext`fz}, \
{$CellContext`x -> $CellContext`x0$$, $CellContext`y -> $CellContext`y0$$, \
$CellContext`z -> $CellContext`z0}]]; $CellContext`coordplus = \
$CellContext`coord + $CellContext`normal; $CellContext`p2 = Graphics3D[{
           PointSize[Large], 
           
           Point[{$CellContext`x0$$, $CellContext`y0$$, $CellContext`z0}]}]; \
$CellContext`p3 = Graphics3D[{Thick, 
           Line[{$CellContext`coord, $CellContext`coordplus}]}]; 
       Show[$CellContext`p1, $CellContext`p2, $CellContext`p3]), 
      "Specifications" :> {{{$CellContext`x0$$, 0}, -2, 
         2}, {{$CellContext`y0$$, 0}, -3, 3}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{531., {226., 233.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.2 Symmetry", "Subsubsection"],

Cell[TextData[{
 "For curves in two dimensions, if\n                    \n                    \
",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(-",
 StyleBox["x",
  FontSlant->"Italic"],
 ")\n                    \nholds, then the curve is symmetric about the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " axis.  The curve is antisymmetric about the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " axis when\n                    \n                    ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") = -",
 StyleBox["f",
  FontSlant->"Italic"],
 "(-",
 StyleBox["x",
  FontSlant->"Italic"],
 ").\n                    \nA simple example is powers of ",
 StyleBox["x",
  FontSlant->"Italic"],
 ": ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "n"], TraditionalForm]]],
 ".  If ",
 StyleBox["n",
  FontSlant->"Italic"],
 " is even, the curve is symmetric; if ",
 StyleBox["n",
  FontSlant->"Italic"],
 " is odd, it is antisymmetric.  Antisymmetry is also referred to as \
\"symmetric with respect to the origin\" or point symmetry about (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = (0, 0).  For surfaces, three kinds of symmetry exist : point, axial, \
and plane.  A surface has point symmetry when\n                    \n         \
           ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = -",
 StyleBox["f",
  FontSlant->"Italic"],
 "(-",
 StyleBox["x",
  FontSlant->"Italic"],
 ", -",
 StyleBox["y",
  FontSlant->"Italic"],
 ").\n                    \nSimple examples of point symmetry are spheres or \
ellipsoids.  A surface has axial symmetry when\n                    \n        \
             ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(-",
 StyleBox["x",
  FontSlant->"Italic"],
 ", -",
 StyleBox["y",
  FontSlant->"Italic"],
 ").\n                    \nAn example of axial symmetry is a paraboloid.  \
Finally, a surface has plane symmetry about the (",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") plane when\n                    \n                    ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(-",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ").\n                    \nSimilarly, symmetry about the (x, z) plane \
implies\n                    \n                    ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", -",
 StyleBox["y",
  FontSlant->"Italic"],
 ").\n                    \nFinally, symmetry about the (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") plane is represented by\n                    \n                    ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = -",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ").\n                    \nExamples of plane symmetry include ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["x",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 " and ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "x"], TraditionalForm]]],
 "cos(",
 StyleBox["y",
  FontSlant->"Italic"],
 ")."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.3 Extent", "Subsubsection"],

Cell[TextData[{
 "The extent of a curve is defined by the range (",
 StyleBox["y",
  FontSlant->"Italic"],
 " variation) and domain (",
 StyleBox["x",
  FontSlant->"Italic"],
 " variation) of the curve.  The extent is unbounded if both ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " values can extend to infinity (for example, ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 ").The extent is semibounded if either ",
 StyleBox["y",
  FontSlant->"Italic"],
 " or ",
 StyleBox["x",
  FontSlant->"Italic"],
 " has a bound less than infinity.  The transcendental equation ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") is such a curve because the range is limited between negative and \
positive unity.  A curve is fully bounded if both ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " bounds are less than infinity.  A circle is a simple example of this type \
of extent.\n\nFor surfaces the concept of extent can be applied in three \
dimensions where domain applies to ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " while range applies to ",
 StyleBox["z",
  FontSlant->"Italic"],
 ".  Surfaces formed by revolution of a curve in the (",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") or (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") plane about the ",
 StyleBox["z",
  FontSlant->"Italic"],
 " axis will possess the same extent property that the two-dimensional curve \
had.  For example, an ellipse in the (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") plane gives an ellipsoid as the surface of revolution--both have the \
fully bounded property.  Similarly, any surface formed by continuous \
translation of a two-dimensional curve (for example, a parabolic sheet) will \
have the same extent property as the original curve."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.4 Asymptotes", "Subsubsection"],

Cell[TextData[{
 "The y asymptotes of a curve are defined by\n                    \n          \
         ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["y", "a"]}], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["lim", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"\[PlusMinus]", "\[Infinity]"}]}]], TraditionalForm]]],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ").\n                    \nAlthough this definition includes asymptotes at \
infinity, only those with | ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "a"], TraditionalForm]]],
 "| < \[Infinity] are of interest.  Asymptotic values are often crucial in \
choosing and applying functions.  Physically, an equation may or may not \
properly describe real phenomena, depending on its asymptotic behavior.  Note \
that, even though a curve may be semi-bounded, its asymptote may not be \
determinable.  An example of a semi-bounded function with a y asymptote is ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"-", "x"}]], TraditionalForm]]],
 " while one without an asymptote is ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["x",
  FontSlant->"Italic"],
 ").  \n\nThe ",
 StyleBox["x",
  FontSlant->"Italic"],
 " asymptotes of a curve may be defined in a similar manner with\n\n          \
         ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["x", "a"]}], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["lim", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"\[PlusMinus]", "\[Infinity]"}]}]], TraditionalForm]]],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["y",
  FontSlant->"Italic"],
 ")\n\nwhen the function is inverted to give ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["y",
  FontSlant->"Italic"],
 ").  An example of a curve with a finite x asymptote is ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", "-", " ", 
      SuperscriptBox["x", "2"]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 " whose asymptote lies at ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = +",
 StyleBox["c",
  FontSlant->"Italic"],
 " or ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = -",
 StyleBox["c",
  FontSlant->"Italic"],
 ".  \n\nIn addition, curves may have asymptotes that are any arbitrary lines \
in the plane, not simply horizontal or vertical lines; and the limiting \
requirements are similar to the forms given above for horizontal or vertical \
asymptotes.  For instance, the equation ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["x",
  FontSlant->"Italic"],
 " + 1/",
 StyleBox["x",
  FontSlant->"Italic"],
 " has ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["x",
  FontSlant->"Italic"],
 " as its asymptote."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.5 Periodicity", "Subsubsection"],

Cell[TextData[{
 "A curve is defined as periodic on ",
 StyleBox["x",
  FontSlant->"Italic"],
 " with period ",
 StyleBox["X",
  FontSlant->"Italic"],
 " if\n                    \n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 " + ",
 StyleBox["nX",
  FontSlant->"Italic"],
 ")\n                    \nis constant for all integers ",
 StyleBox["n",
  FontSlant->"Italic"],
 ".  The transcendental function ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["ax",
  FontSlant->"Italic"],
 ") is an example of a periodic curve.  A polar coordinate curve can also be \
defined as periodic with period \[Alpha] in terms of angle \[Theta] if\n      \
              \n\t",
 StyleBox["r",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(\[Theta] + ",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[Alpha])\n                    \nis constant for all integers n.  An \
example of such a periodic curve is ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = cos(4\[Theta]) which exhibits 8 \"petals\" evenly spaced around the \
origin.  Surfaces are periodic on x and y with periods ",
 StyleBox["X",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Y",
  FontSlant->"Italic"],
 ", respectively, if\n                    \n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 " + ",
 StyleBox["nX",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 " + ",
 StyleBox["mY",
  FontSlant->"Italic"],
 ")\n                    \nis constant for all integers ",
 StyleBox["n",
  FontSlant->"Italic"],
 " and ",
 StyleBox["m",
  FontSlant->"Italic"],
 ".  A surface also may be periodic in only ",
 StyleBox["x",
  FontSlant->"Italic"],
 " or only ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".  A cylindrical-coordinate surface may be periodic with period ",
 StyleBox["a",
  FontSlant->"Italic"],
 " in terms of the angle \[Theta] if\n                    \n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(r, \[Theta] + ",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[Alpha])\n                    \nis constant for all integers",
 StyleBox[" n",
  FontSlant->"Italic"],
 ".  Another type of periodicity expressible in cylindrical coordinates is in \
the radial direction with period ",
 StyleBox["R",
  FontSlant->"Italic"],
 ", when\n                    \n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["r",
  FontSlant->"Italic"],
 " + ",
 StyleBox["nR",
  FontSlant->"Italic"],
 ", \[Theta])\n                    \nis constant for all integers ",
 StyleBox["n",
  FontSlant->"Italic"],
 ".  An example of such periodicity is given by ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = cos(2\[Pi]",
 StyleBox["r",
  FontSlant->"Italic"],
 ") cos(\[Theta]), which has a period of ",
 StyleBox["R",
  FontSlant->"Italic"],
 " = 1."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.6 Continuity", "Subsubsection"],

Cell[TextData[{
 "A curve is continuous at a point ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 ", provided it is defined at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 ", when\n                    \n\t",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "+"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["lim", 
    RowBox[{"x", "\[Rule]", 
     SubsuperscriptBox["x", "0", "+"]}]], TraditionalForm]]],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ")\n                    \nand\n                    \n\t",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "-"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["lim", 
    RowBox[{"x", "\[Rule]", 
     SubsuperscriptBox["x", "0", "-"]}]], TraditionalForm]]],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ").\n                    \nare finite and equal.  Here \"+\" and \"-\" refer \
to approaching ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 " from the right and left, respectively.  Discontinuities may be finite or \
infinite: the former implies ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "+"], TraditionalForm]]],
 " \[NotEqual]  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "-"], TraditionalForm]]],
 " even though they are both finite while the latter implies one or both \
limits are infinite.  For surfaces, the paths to a point ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "0"], TraditionalForm]]],
 " = (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "0"], TraditionalForm]]],
 ") are infinite in number; and continuity exists only if the surface is \
defined at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "0"], TraditionalForm]]],
 " and\n                    \n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["lim", 
    RowBox[{"p", "\[Rule]", 
     SubscriptBox["p", "0"]}]], TraditionalForm]]],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ") \n                    \nis constant for all possible paths.  When the \
curve or surface is undefined at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "0"], TraditionalForm]]],
 " and the above relations hold, it is said to be discontinuous, but with a \
removable discontinuity.  For any points at which the above relations do not \
hold, the curve or surface is discontinuous, with an essential discontinuity \
at such points.  The curve ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["x",
  FontSlant->"Italic"],
 ")/",
 StyleBox["x",
  FontSlant->"Italic"],
 " has a removable discontinuity and is therefore continuous in appearance \
while ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 1/",
 StyleBox["x",
  FontSlant->"Italic"],
 " has an essential discontinuity at ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 0 and is therefore discontinuous in appearance.  Curves and surfaces are \
differentiable (meaning the derivative exists) everywhere that they are \
either continuous or have removable discontinuities."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.7 Singular Points", "Subsubsection"],

Cell[TextData[{
 "Curves and surfaces may contain singular points.  Writing the function for \
a two-dimensional curve as\n                    \n\t",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = 0,\n                    \nthe derivative \[Delta]",
 StyleBox["y",
  FontSlant->"Italic"],
 "/\[Delta]",
 StyleBox["x",
  FontSlant->"Italic"],
 " can be written as\n                    \n\t",
 Cell[BoxData[
  FormBox[
   FractionBox["\[Delta]y", "\[Delta]x"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    FractionBox[
     RowBox[{"g", "(", 
      RowBox[{"x", ",", "y"}], ")"}], 
     RowBox[{"h", "(", 
      RowBox[{"x", ",", "y"}], ")"}]],
    FontSlant->"Italic"], TraditionalForm]]],
 "\n                    \nwhere ",
 StyleBox["g",
  FontSlant->"Italic"],
 " and ",
 StyleBox["h",
  FontSlant->"Italic"],
 " are functions of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".  If, for a given point ",
 StyleBox["p",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 "), the functions ",
 StyleBox["g",
  FontSlant->"Italic"],
 " and ",
 StyleBox["h",
  FontSlant->"Italic"],
 " both vanish, the derivative becomes the indeterminate form 0/0; and ",
 StyleBox["p",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") is then a singular point of the curve.  Singular points imply that two or \
more branches of the curve meet or cross.  If two branches are involved, it \
is a double point; if three are involved, it is a triple point; etc.  \
Singularities at triple or higher points are not as commonly encountered as \
those at double points.  Double-point singularities for two-dimensional \
curves are classified as follows: \n\n1) Isolated points (also known as \
acnodes or conjugate points) are where a single point is disjoint from the \
remainder of the curve.  In this case, the derivative is imaginary.  \n\n2) \
Node points (also known as crunodes) are where the two derivatives are real \
and unequal, such that the curve crosses itself.  \n\n3) Cusp points (also \
known as spinodes) are where the derivatives of two arcs on either side are \
unequal while the curve joins at this point.  A cusp of the first kind \
involves second derivatives of opposite sign, and a cusp of the second kind \
involves second derivatives of the same sign.  \n\n4) Double cusp points \
(also known as tacnodes or osculation points) are where the derivatives of \
two arcs become equal while the two arcs of the curve are continuous along \
both directions away from such points.  Double cusps may also be of the first \
or second kind, as for single cusps.\n\nCurves having one or more nodes will \
exhibit loops which enclose areas.  Curves having osculations may also \
exhibit loops, on one or both sides of the osculation point.\n\nThe concept \
of singular points is extendable to surfaces.  Many surfaces are the result \
of the revolution of a two-dimensional curve about some line; such surfaces \
retain the singular points of the curve, except that each such point on the \
curve, unless on the axis of revolution, becomes a circular ring of singular \
points centered on the axis of revolution.  Singular points appear on more \
complicated surfaces also, but an analysis of the possibilities is beyond the \
scope of this volume."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.8 Critical Points", "Subsubsection"],

Cell[TextData[{
 "Points of a curve ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") at which the derivative ",
 StyleBox["dy",
  FontSlant->"Italic"],
 "/",
 StyleBox["dx",
  FontSlant->"Italic"],
 " = 0 are termed critical points, of which there are three types: \n\n1) \
Maximum points are where the curve is concave downward and thus the second \
derivative ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", "2"], TraditionalForm]]],
 StyleBox["y",
  FontSlant->"Italic"],
 "/",
 Cell[BoxData[
  FormBox["d", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " > 0.\n          \n2) Minimum points are where the curve is concave upward \
and thus the second derivative ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", "2"], TraditionalForm]]],
 StyleBox["y",
  FontSlant->"Italic"],
 "/",
 Cell[BoxData[
  FormBox["d", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " < 0.\n       \n3) Inflection points are where ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", "2"], TraditionalForm]]],
 StyleBox["y",
  FontSlant->"Italic"],
 "/",
 Cell[BoxData[
  FormBox["d", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " = 0 and the curve changes its direction of concavity.  \n\nFor surfaces ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 "), the critical points lie at ",
 StyleBox["dz",
  FontSlant->"Italic"],
 "/",
 StyleBox["dx",
  FontSlant->"Italic"],
 " = ",
 StyleBox["dz",
  FontSlant->"Italic"],
 "/",
 StyleBox["dy",
  FontSlant->"Italic"],
 " = 0.  Maximum and minimum points of surfaces are defined similar to those \
of curves, except both second derivatives must together be greater than zero \
or less than zero.  In the case that they are of opposite sign, the critical \
point is termed a saddle.  Such critical points are ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["nondegenerate", "2"], TraditionalForm]]],
 " and are isolated from other critical points.  More complicated types of \
degenerate critical points occur for surfaces.  Points can be classified as \
degenerate or nondegenerate, depending on whether the determinant of\n    \n\t\
",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[Delta]", "2"], "z"}], 
        SuperscriptBox["\[Delta]x", "2"]], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[Delta]", "2"], "z"}], "\[Delta]x\[Delta]y"]},
      {
       FractionBox[
        RowBox[{
         SuperscriptBox["\[Delta]", "2"], "z"}], "\[Delta]x\[Delta]y"], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[Delta]", "2"], "z"}], 
        SuperscriptBox["\[Delta]y", "2"]]}
     }], ")"}], TraditionalForm]]],
 "    \n    \nvanishes or not, respectively.  For instance, the surface ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 " has a single nondegenerate critical point while ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 " has two continuous lines of degenerate critical points, intersecting at \
(0, 0)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.9 Zeroes", "Subsubsection"],

Cell[TextData[{
 "The zeroes of a two-dimensional function ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") occur where ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") = 0 and are isolated points on the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis.  (For polynomial functions, the zeroes are often referred to as the \
roots.)  Similarly, the zeroes of a three-dimensional function ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") occur where ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = 0; but the loci of these points form one or more distinct, continuous \
curves in the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-",
 StyleBox["y ",
  FontSlant->"Italic"],
 "plane.The zeroes of certain functions are important in characterizing their \
oscillatory behavior; for example, the function sin(",
 StyleBox["x",
  FontSlant->"Italic"],
 ").The zeroes of other functions may be unique points of interest in \
physical applications.  Not all functions, as defined, have zeroes; for \
example, the function ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") = 2 - cos(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") has unity as its lower bound.  However, such a function can be translated \
in one or the other y directions to produce a function having zeroes in \
addition to all the qualitative properties of the original function.  The \
definition of the exact zeroes of a function is often difficult and often \
must be accomplished by numerical methods on a computer.  Zeroes of many \
functions are tabulated in standard references such as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Abramowitz", "3"], TraditionalForm]]],
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.10 Integrability", "Subsubsection"],

Cell[TextData[{
 "The function ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") defined over the interval [",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"],
 "] has the integral\n    \n\t",
 StyleBox["I",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Integral]", "a", "b"], TraditionalForm]]],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") ",
 StyleBox["dx.",
  FontSlant->"Italic"],
 "\n    \nThe integral exists if ",
 StyleBox["I",
  FontSlant->"Italic"],
 " converges to a single, bounded value for a given interval; and the \
function is said to be integrable.  Note that the integral ",
 StyleBox["I",
  FontSlant->"Italic"],
 " may exist under two abnormal circumstances: \n\n1) Either ",
 StyleBox["a",
  FontSlant->"Italic"],
 " or ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", or both, extend to infinity.\n\n2) The function y has an infinite \
discontinuity at one or both endpoints or at one or more points interior to [",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"],
 "].\n\nUnder either of these circumstances, the integral is an improper \
integral.  Proving the existence of the integral of a given function is not \
always straightforward, and a discussion is beyond the scope of this volume.  \
Transient functions always have an integral on the interval [0, \[Infinity]] \
and are often given as solutions to physical problems in which the response \
of a medium to a given input or disturbance is sought.  Such responses must \
possess an integral if the input was finite and measurable.  Examples of such \
functions are ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"-", 
     StyleBox["ax",
      FontSlant->"Italic"]}]], TraditionalForm]]],
 "sin(",
 StyleBox["bx",
  FontSlant->"Italic"],
 ") or ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 1/(1 + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 ").  Surfaces given by ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") are integrable when\n\n\t",
 StyleBox["I",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Integral]", "a", "b"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Integral]", "c", "d"], TraditionalForm]]],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") ",
 StyleBox["dx dy",
  FontSlant->"Italic"],
 "\n\nexists.  Improper integrals of surfaces are defined in the same manner \
as those of two-dimensional curves.  Transient responses exist for three \
dimensions and are integrable also.  A curve property which has an important \
consequence for integration is that of even and odd functions.  Even \
functions have ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(-",
 StyleBox["x",
  FontSlant->"Italic"],
 "), and for such curves\n\n\t",
 StyleBox["I",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", 
    SubsuperscriptBox["\[Integral]", "0", "a"]}], TraditionalForm]]],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") ",
 StyleBox["dx",
  FontSlant->"Italic"],
 "\n\nif the one-sided ",
 StyleBox["I",
  FontSlant->"Italic"],
 " exists over[0, ",
 StyleBox["a",
  FontSlant->"Italic"],
 "].  For odd functions ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(-",
 StyleBox["x",
  FontSlant->"Italic"],
 "), and ",
 StyleBox["I",
  FontSlant->"Italic"],
 " = 0 over any interval[-",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["a",
  FontSlant->"Italic"],
 "].  This concept can be easily extended to surfaces."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.11 Multiple Values", "Subsubsection"],

Cell[TextData[{
 "A curve is multivalued if, for a given (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 "), it has two or more distinct values.  A simple example is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 " = ",
 StyleBox["x",
  FontSlant->"Italic"],
 ".  Multivalued functions are not integrable in the normal sense although \
one or more particular branches of the curve may have well-defined integrals. \
 While a curve may be multivalued in its Cartesian-form equation, the polar \
form of the equation may be single-valued, in the sense that only one value \
of r exists for each value of angle \[Theta].  Compare, for example, \n\n\t",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", "+", " ", 
      SuperscriptBox["y", "2"]}], ")"}], "3"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", "-", " ", 
      SuperscriptBox["y", "2"]}], ")"}], "2"], TraditionalForm]]],
 "\n\nwhich is the equation of a quadrifolium, with its polar equation\n\n\t\
",
 StyleBox["r",
  FontSlant->"Italic"],
 " = cos(2\[Theta]).\n\nIntegrability is affected by the choice of coordinate \
system; this example shows that, when an integral is not defined due to a \
function being multivalued, it may be well defined when the transformation to \
polar coordinates is made and the integral evaluated along the polar angle \
\[Theta].  Similarly, surfaces may be single-valued or multivalued depending \
upon whether ",
 StyleBox["z",
  FontSlant->"Italic"],
 " takes on one or more values for a given (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") point."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4.12 Curvature", "Subsubsection"],

Cell[TextData[{
 "Given that a unit of length along the curve path is \[Delta]",
 StyleBox["s",
  FontSlant->"Italic"],
 " and that the tangent line changes its direction over \[Delta]",
 StyleBox["s",
  FontSlant->"Italic"],
 " by an angle \[Delta]\[Theta] where \[Theta] is the angle of the tangent \
with the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis, then the principal curvature is given by\n\n\t",
 StyleBox["c",
  FontSlant->"Italic"],
 " = \[LeftBracketingBar]",
 Cell[BoxData[
  FormBox[
   FractionBox["\[Delta]\[Theta]", "\[Delta]s"], TraditionalForm]]],
 "\[RightBracketingBar].\n\nThe radius of curvature is simply the inverse of \
the curvature, or \[Rho] = 1/",
 StyleBox["c",
  FontSlant->"Italic"],
 ".  At a point of inflection of a curve, ",
 StyleBox["c",
  FontSlant->"Italic"],
 " = 0 and \[Rho] = \[Infinity].  Conversely, at a cusp of a curve, ",
 StyleBox["c",
  FontSlant->"Italic"],
 " = \[Infinity] and \[Rho] = 0.\n\nThe curvature can be expressed in terms \
of the derivatives of the curve also.  If the curve is expressed implicitly \
as ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = 0 and if ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "x"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "y"], TraditionalForm]]],
 " are the first partial derivatives and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", 
    StyleBox["xx",
     FontSlant->"Italic"]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", 
    StyleBox["yy",
     FontSlant->"Italic"]], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", 
    StyleBox["xy",
     FontSlant->"Italic"]], TraditionalForm]]],
 " are the second partial derivatives, then\n\n\t",
 StyleBox["c",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{
      SubscriptBox["f", 
       StyleBox["xx",
        FontSlant->"Italic"]], 
      SuperscriptBox[
       SubscriptBox["f", "y"], "2"]}], " ", "-", " ", 
     RowBox[{"2", 
      SubscriptBox["f", 
       StyleBox["xy",
        FontSlant->"Italic"]], 
      SubscriptBox["f", "x"], 
      SubscriptBox["f", "y"]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["f", 
       StyleBox["yy",
        FontSlant->"Italic"]], 
      SuperscriptBox[
       SubscriptBox["f", "x"], "2"]}]}], 
    SuperscriptBox[
     RowBox[{"(", GridBox[{
        {
         RowBox[{
          SuperscriptBox[
           SubscriptBox["f", "x"], "2"], " ", "+"}], 
         SuperscriptBox[
          SubscriptBox["f", "y"], "2"]}
       }], ")"}], 
     RowBox[{"3", "/", "2"}]]], TraditionalForm]]],
 ".\n\nFor curves defined parametrically as {",
 StyleBox["x",
  FontSlant->"Italic"],
 "(\[Theta]), ",
 StyleBox["y",
  FontSlant->"Italic"],
 "(\[Theta])}, letting ",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["d",
  FontSlant->"Italic"],
 "[",
 StyleBox["x",
  FontSlant->"Italic"],
 "(\[Theta])]/",
 StyleBox["d",
  FontSlant->"Italic"],
 "\[Theta], ",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["d",
  FontSlant->"Italic"],
 "[",
 StyleBox["y",
  FontSlant->"Italic"],
 "(\[Theta])/",
 StyleBox["d",
  FontSlant->"Italic"],
 "\[Theta], ",
 StyleBox["x",
  FontSlant->"Italic"],
 "'' = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["d", "2"], "["}], TraditionalForm]]],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 "(\[Theta])]/",
 StyleBox["d",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Theta]", "2"], TraditionalForm]]],
 ", and ",
 StyleBox["y",
  FontSlant->"Italic"],
 "'' = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", "2"], TraditionalForm]]],
 "[",
 StyleBox["y",
  FontSlant->"Italic"],
 "(\[Theta])]/",
 StyleBox["d",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Theta]", "2"], TraditionalForm]]],
 ", one obtains the curvature as \n\n\t",
 StyleBox["c",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"x", "'"}], 
      RowBox[{"y", "''"}]}], " ", "-", " ", 
     RowBox[{
      RowBox[{"y", "'"}], 
      RowBox[{"x", "''"}]}]}], 
    SuperscriptBox[
     RowBox[{"(", GridBox[{
        {
         RowBox[{
          SuperscriptBox[
           RowBox[{"x", "'"}], "2"], " ", "+", " "}], 
         SuperscriptBox[
          RowBox[{"y", "'"}], "2"]}
       }], ")"}], 
     RowBox[{"3", "/", "2"}]]], TraditionalForm]]],
 ".\n\nWhen the curve is expressed in polar coordinates ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(\[Theta]) and the derivatives ",
 StyleBox["dr",
  FontSlant->"Italic"],
 "/",
 StyleBox["d",
  FontSlant->"Italic"],
 "\[Theta] and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", "2"], TraditionalForm]]],
 StyleBox["r",
  FontSlant->"Italic"],
 "/",
 StyleBox["d",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Theta]", "2"], TraditionalForm]]],
 " are given by ",
 StyleBox["r",
  FontSlant->"Italic"],
 "' and ",
 StyleBox["r",
  FontSlant->"Italic"],
 "'' respectively, then the curvature is\n\n\t",
 StyleBox["c",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     SuperscriptBox["r", "2"], " ", "+", " ", 
     RowBox[{"2", 
      SuperscriptBox[
       RowBox[{"r", "'"}], "2"]}], " ", "-", " ", 
     RowBox[{"r", " ", 
      RowBox[{"r", "''"}]}]}], 
    SuperscriptBox[
     RowBox[{"(", GridBox[{
        {
         RowBox[{
          SuperscriptBox["r", "2"], " ", "+", " "}], 
         SuperscriptBox[
          RowBox[{"r", "'"}], "2"]}
       }], ")"}], 
     RowBox[{"3", "/", "2"}]]], TraditionalForm]]],
 ".\n\nThe radius of curvature at lobes of polar curves is of interest in \
order to define the \"tightness\" of the lobes.  At the peak of the lobe, ",
 StyleBox["r",
  FontSlant->"Italic"],
 "' = 0 and \[Rho] = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "2"], TraditionalForm]]],
 "/(",
 StyleBox["r",
  FontSlant->"Italic"],
 " - ",
 StyleBox["r",
  FontSlant->"Italic"],
 "'').  This reduces to \[Rho] = ",
 StyleBox["r",
  FontSlant->"Italic"],
 " in the case of a circle, for which ",
 StyleBox["r",
  FontSlant->"Italic"],
 "'' = 0.\n\nFor surfaces, the geometry underlying the concept of curvature \
is more complex.  Curvature of a surface at a point ",
 StyleBox["p",
  FontSlant->"Italic"],
 " is normally given as the Gaussian curvature\n\n\t",
 StyleBox["K",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Kappa]", "1"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Kappa]", "2"], TraditionalForm]]],
 "\n\nwhere the \[Kappa]\[CloseCurlyQuote]s are the principal curvatures, \
with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Kappa]", "1"], "being", " ", "the", " ", "minimum"}], 
   TraditionalForm]]],
 " curvature at ",
 StyleBox["p",
  FontSlant->"Italic"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Kappa]", "2"], TraditionalForm]]],
 " being the maximum curvature at ",
 StyleBox["p",
  FontSlant->"Italic"],
 ".   These curvatures are determined by the two-dimensional curvature of the \
intersections of the surface with all possible planes containing ",
 StyleBox["p",
  FontSlant->"Italic"],
 ".  If ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Kappa]", "1"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"and", " ", 
    SubscriptBox["\[Kappa]", "2"]}], TraditionalForm]]],
 " are both of the same sign, the point ",
 StyleBox["p",
  FontSlant->"Italic"],
 " is an elliptic point and the surface is dome-like at ",
 StyleBox["p",
  FontSlant->"Italic"],
 ".  If ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Kappa]", "1"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"and", " ", 
    SubscriptBox["\[Kappa]", "2"]}], TraditionalForm]]],
 "have opposite signs, the point ",
 StyleBox["p",
  FontSlant->"Italic"],
 " is a hyperbolic point and the surface is saddle-like at ",
 StyleBox["p",
  FontSlant->"Italic"],
 ".  If either ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Kappa]", "1"], TraditionalForm]]],
 "or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Kappa]", "2"], TraditionalForm]]],
 " is zero, the point ",
 StyleBox["p",
  FontSlant->"Italic"],
 " is a parabolic point.  A line separating positive and negative ",
 StyleBox["K",
  FontSlant->"Italic"],
 " regions is a parabolic line.\n\nIf a surface is defined explicitly as ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 "), then the Gaussian curvature can be calculated as\n\n\t",
 StyleBox["K",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{
      SubscriptBox["z", "xx"], " ", 
      SubscriptBox["z", 
       StyleBox["yy",
        FontSlant->"Italic"]]}], " ", "-", " ", 
     SubsuperscriptBox["z", 
      StyleBox["xy",
       FontSlant->"Italic"], "2"]}], 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      SubsuperscriptBox["z", "x", "2"], 
      SubsuperscriptBox["z", "y", "2"]}]}]], TraditionalForm]]],
 "\n\nwhere\n\n \t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "x"], TraditionalForm]]],
 " = \[Delta]",
 StyleBox["z",
  FontSlant->"Italic"],
 "/\[Delta]",
 StyleBox["x",
  FontSlant->"Italic"],
 ",\n  \t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "y"], TraditionalForm]]],
 " = \[Delta]",
 StyleBox["z",
  FontSlant->"Italic"],
 "/\[Delta]",
 StyleBox["y",
  FontSlant->"Italic"],
 ",\n  \t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", 
    StyleBox["xx",
     FontSlant->"Italic"]], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Delta]", "2"], TraditionalForm]]],
 StyleBox["z",
  FontSlant->"Italic"],
 "/\[Delta]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 ",\n  \t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", 
    StyleBox["yy",
     FontSlant->"Italic"]], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Delta]", "2"], TraditionalForm]]],
 StyleBox["z",
  FontSlant->"Italic"],
 "/\[Delta]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 ",\n  \t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", 
    StyleBox["xy",
     FontSlant->"Italic"]], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Delta]", "2"], TraditionalForm]]],
 StyleBox["z",
  FontSlant->"Italic"],
 "/\[Delta]",
 StyleBox["x",
  FontSlant->"Italic"],
 "\[Delta]",
 StyleBox["y",
  FontSlant->"Italic"],
 "."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5 Classification of Curves and Surfaces", "Subsection"],

Cell["Figure 6. Classification of Curves and Surfaces", "Text"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzs/el7bGWdP/72dc7vwbmu8+T8BzIoOKGiaLbS7diSDY6oaWntxgJFJFtx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    "], {{0, 1012}, {3016, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> ColorProfileData[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIj
UNAApJaBycDRxcmVCagqN6+kKMjdSSEiMkqB/QIDBwM3gzCDMYN1YnJxgWNA
gA9IdV5+XioDBvh2jQFkIMNlXZBZmPJ4AVdyQVEJkP4DxEYpqcXJDAyMBkB2
dnlJAVCccQ6QLZKUDWZvALGLQoKcgewjQDZfOoR9BcROgrCfgNhFQE8A2V9A
6tPBbCYOsDkQtgyIXZJaAbKXwTm/oLIoMz2jRMHIwMBAwTElPylVIbiyuCQ1
t1jBMy85v6ggvyixJDUFqBbiPjAQhCgEhZiGoaWlhSaJ/iYIQPEAYX0OBIcv
o9gZhBgCJJcWlUGZjEzGhPkIM+ZIMDD4L2VgYPmDEDPpZWBYoMPAwD8VIaZm
yMAgoM/AsG8OAIg4XPo=
      "], "RGB", "XYZ"], Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{579.4806249999999, Automatic},
  ImageSizeRaw->{3016, 1012},
  PlotRange->{{0, 3016}, {0, 1012}}]], "Output",
 TextAlignment->Center],

Cell[TextData[{
 "The family of two-dimensional and three-dimensional curves can be \
illustrated as in Figure 6.  This particular schematic reflects the \
organization of this reference work, and every curve which can be traced by a \
given mathematical equation or given set of mathematical rules can be placed \
in one of the categories shown.  There is a top-level dichotomy between \
determinate and random curves.  A determinate curve is one for which the \
functional relationship between x and y is known everywhere from the equation \
or set of rules.  No realization is required to produce the curve, for it is \
contained wholly within its defining equations or rules.  On the other hand, \
a random curve will have a random factor or term in its mathematical \
definition such that an actual realization is required to produce the curve, \
which will differ from any other realization.  For example, ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") + ",
 StyleBox["w",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") where ",
 StyleBox["w",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") is a random variable on ",
 StyleBox["x",
  FontSlant->"Italic"],
 ", defines a random curve.  At the second level in Figure 6, the distinction \
is made between algebraic, transcendental, integral, and non-differentiable \
curves as described below."
}], "Text"],

Cell[CellGroupData[{

Cell["1.5.1 Algebraic Curves", "Subsubsection"],

Cell[TextData[{
 "A polynomial is defined as a summation of terms composed of integer powers \
of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".  An algebraic curve is one whose implicit function \n\n\t",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = 0\n\nis a polynomial in ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " (after rationalization as described below, if necessary).  Because a curve \
is often defined in the explicit form\n\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 "),\n\nthere is a need to distinguish rational and irrational functions of \
",
 StyleBox["x",
  FontSlant->"Italic"],
 ".  A rational function of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " is a quotient of two polynomials in ",
 StyleBox["x",
  FontSlant->"Italic"],
 ", both having only integer powers.  An irrational function of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " is a quotient of two polynomials, one or both of which has a term (or \
terms) with power ",
 StyleBox["p",
  FontSlant->"Italic"],
 "/",
 StyleBox["q",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["p",
  FontSlant->"Italic"],
 " and ",
 StyleBox["q",
  FontSlant->"Italic"],
 " are integers.  Irrational functions can be rationalized, but the curves \
will not be identical before and after rationalization.  In general, the \
rationalized form has more branches; for example, consider ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SqrtBox["x"], TraditionalForm]]],
 " which is rationalized to ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 " = ",
 StyleBox["x",
  FontSlant->"Italic"],
 ".  The former curve has only one branch (for positive ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") if a strict definition of the radical is used whereas the latter has two \
branches, for ",
 StyleBox["y",
  FontSlant->"Italic"],
 " < 0 and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " > 0.  In this reference work, the rationalized curve will be presented \
graphically in all cases, even though the equation is printed in its \
irrational form for simplicity.\n     \nBesides simple polynomials, rational \
functions are often grouped into sets convenient for certain mathematical \
applications.  Examples of such polynomial sets are Chebychev polynomials, \
Laguerre polynomials, and Bernoulli polynomials.  Most polynomial sets have \
the property of orthogonality, meaning that for any two functions ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "2"], TraditionalForm]]],
 " of the set,\n\n\t \[Integral] ",
 StyleBox["w",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ")",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", "x", ")"}], 
    SubscriptBox["f", "2"]}], TraditionalForm]]],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") ",
 StyleBox["dx",
  FontSlant->"Italic"],
 " = 0\n\nover the defined domain of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " for the particular set, where ",
 StyleBox["w",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") is a weighting function.  This property ensures that the different curves \
within the set make distinct contributions to the set."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5.2 Transcendental Curves", "Subsubsection"],

Cell[TextData[{
 "The transcendental curves cannot be expressed as finite polynomials in ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".  These are curves containing one or more of the following forms: \
exponential (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "x"], TraditionalForm]]],
 "), logarithmic (log ",
 StyleBox["x",
  FontSlant->"Italic"],
 "), or trigonometric (sin ",
 StyleBox["x",
  FontSlant->"Italic"],
 ", cos ",
 StyleBox["x",
  FontSlant->"Italic"],
 ").  The hyperbolic functions are often mentioned as part of this group, but \
they are not really distinct because they are forms composed of exponential \
functions.  Any curve expressed as a mixture of transcendentals and \
polynomials is considered to be transcendental.  All of the primary \
transcendental functions can, in fact, be expressed as infinite polynomial \
series:\n\n\t",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "x"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   UnderoverscriptBox["\[CapitalSigma]", 
    RowBox[{"n", " ", "=", " ", "0"}], "\[Infinity]"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["x", "n"], 
    RowBox[{"n", "!"}]], TraditionalForm]]],
 "\t(-\[Infinity] < ",
 StyleBox["x",
  FontSlant->"Italic"],
 " < \[Infinity]),\t\t\t              \n\n\tcos ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = \t ",
 Cell[BoxData[
  FormBox[
   UnderoverscriptBox["\[CapitalSigma]", 
    RowBox[{"n", " ", "=", " ", "0"}], "\[Infinity]"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], 
     SuperscriptBox["x", 
      RowBox[{"2", "n"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "n"}], ")"}], "!"}]], TraditionalForm]]],
 "\t(-\[Infinity] < ",
 StyleBox["x",
  FontSlant->"Italic"],
 " < \[Infinity]),                  \n\n\tsin ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = \t ",
 Cell[BoxData[
  FormBox[
   UnderoverscriptBox["\[CapitalSigma]", 
    RowBox[{"n", " ", "=", " ", "0"}], "\[Infinity]"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], 
     SuperscriptBox["x", 
      RowBox[{
       RowBox[{"2", "n"}], "+", "1"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "n"}], " ", "+", " ", "1"}], ")"}], "!"}]], 
   TraditionalForm]]],
 "     (-\[Infinity] < ",
 StyleBox["x",
  FontSlant->"Italic"],
 " < \[Infinity]),                \n\n \tlog ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox["2", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   UnderoverscriptBox["\[CapitalSigma]", 
    RowBox[{"n", " ", "=", " ", "0"}], "\[Infinity]"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{
     RowBox[{"2", "n"}], " ", "-", " ", "1"}]], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"x", "-", "1"}], 
      RowBox[{"x", "+", "1"}]], ")"}], 
    RowBox[{
     RowBox[{"2", "n"}], "+", "1"}]], TraditionalForm]]],
 "\t(",
 StyleBox["x",
  FontSlant->"Italic"],
 " > 0).\n"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5.3 Integral Curves", "Subsubsection"],

Cell[TextData[{
 "Certain continuous curves not expressible in algebraic or transcendental \
forms are familiar mathematical tools.  These curves are equal to the \
integral of algebraic or transcendental curves by definition; examples \
include Bessel functions, Airy integrals, Fresnel integrals, and the error \
function.  The integral curve is given by \n\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "[",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"],
 "] = ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Integral]", "a", "b"], TraditionalForm]]],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") ",
 StyleBox["dx",
  FontSlant->"Italic"],
 "\n\nwhere the lower limit of integration a is usually a fixed point such as \
-\[Infinity]  or 0.  Like transcendental curves, these integral curves also \
have expansions in terms of power series or polynomial series, often making \
evaluation rather straightforward on computers."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5.4 Piecewise Continuous Functions", "Subsubsection"],

Cell[TextData[{
 "Members of the previous classes of curves (algebraic, transcendental, and \
integral) all have the property that (except at a few points, called singular \
points) the curve is smooth and differentiable.  In the spirit of a broad \
definition of curve, a class of non-differentiable curves appears in Figure \
6.  These curves have discontinuity of the first derivative as a basic \
attribute and are quite often composed of straight-line segments.  Such \
curves include the simple polygonal forms as well as the intricate \"regular \
fractal\" curves of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Mandelbrot", "4"], TraditionalForm]]],
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5.5 Classification of Surfaces", "Subsubsection"],

Cell[TextData[{
 "In general, surfaces may follow the same classification scheme as curves \
(Figure 6).  Many commonly-used surfaces are either rotations of \
two-dimensional curves about an axis, thus giving axial, or possibly point, \
symmetry.  In this case the independent variable ",
 StyleBox["x",
  FontSlant->"Italic"],
 " of the two-dimensional curve's equation can be replaced with the radial \
variable ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", "+", " ", 
      SuperscriptBox["y", "2"]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 " to form the equation of the surface.  Other commonly used surfaces are \
merely a continuous translation of a given two-dimensional curve along a \
straight line.  Such surfaces will actually have only one independent \
variable if a coordinate system having one axis coincident with the straight \
line is chosen.\n\t\nIf the two independent variables of the explicit \
equation of the surface, ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") are separable in the sense that\n\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["y",
  FontSlant->"Italic"],
 "),\n\nthen the surface is orthogonal.  In such a case, the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " dependence may fall in one of the classes of Figure 6 while the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " dependence falls in another.  Orthogonal surfaces require fewer operations \
to evaluate over a grid of the domain of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " because the defining equation only needs to be evaluated once along the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " direction and once along the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " direction, with all other points evaluated by simple multiplication of the \
",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " factors appropriate to each point on the (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") plane. "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6 Basic Curve and Surface Operations", "Subsection"],

Cell["\<\
There are many simple operations which can be applied to curves and surfaces \
in order to change them.  Knowledge of these operations enables one to adapt \
a given curve or surface to a particular need and to thus extend the curves \
and surfaces given in this reference work to a larger set of mathematical \
forms.  Only a few of the most common operations are presented here.  Of \
these, two (translation and rotation) are homomorphic operations, which means \
that the form of the curve is preserved, with merely its position or \
orientation in space being changed.\
\>", "Text"],

Cell[CellGroupData[{

Cell["1.6.1 Translation", "Subsubsection"],

Cell[TextData[{
 "If one or more of the coordinates (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") of a point is changed according to\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["x",
  FontSlant->"Italic"],
 " + ",
 StyleBox["a,",
  FontSlant->"Italic"],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["y",
  FontSlant->"Italic"],
 " + ",
 StyleBox["b,",
  FontSlant->"Italic"],
 "\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["z",
  FontSlant->"Italic"],
 " + ",
 StyleBox["c,",
  FontSlant->"Italic"],
 "\n\nthe curve or surface undergoes a translation of amount (",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", ",
 StyleBox["c",
  FontSlant->"Italic"],
 ") along the (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") axes, respectively."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6.2 Rotation", "Subsubsection"],

Cell[TextData[{
 "In polar coordinates, if the angle \[Theta] is changed by a positive amount \
\[Alpha] thus\n\n\t\[Theta]' = \[Theta] + \[Alpha],\n\nthe curve undergoes a \
counter-clockwise rotation of \[Alpha] degrees.  This is convenient for polar \
coordinates, but the rotation can also be expressed in Cartesian coordinates \
as\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["x",
  FontSlant->"Italic"],
 " cos (\[Alpha]) + ",
 StyleBox["y",
  FontSlant->"Italic"],
 " sin (\[Alpha]),\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = -",
 StyleBox["x",
  FontSlant->"Italic"],
 " sin (\[Alpha]) + ",
 StyleBox["y",
  FontSlant->"Italic"],
 " cos (\[Alpha]).\n\nIn three dimensions, a surface can be rotated about any \
of the three axes by using these equations on the coordinate pairs (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 "), (",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 "), or (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") depending on whether the rotation is about the ",
 StyleBox["z",
  FontSlant->"Italic"],
 ", ",
 StyleBox["x",
  FontSlant->"Italic"],
 ", or ",
 StyleBox["y",
  FontSlant->"Italic"],
 " axis, respectively."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6.3 Linear Scaling", "Subsubsection"],

Cell[TextData[{
 "The relations for linear scaling are\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["ax,",
  FontSlant->"Italic"],
 " \n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["by,",
  FontSlant->"Italic"],
 " \n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["cz.",
  FontSlant->"Italic"],
 "\n\nThese stretch the curve or surface by the factors ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["c",
  FontSlant->"Italic"],
 " along the respective axes.  When using polar, cylindrical, or spherical \
coordinates, a similar relation\n\n\t",
 StyleBox["r",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["dr",
  FontSlant->"Italic"],
 "\n\nstretches or compresses the curve or surface along the radial \
coordinate by the factor ",
 StyleBox["d",
  FontSlant->"Italic"],
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6.4 Reflection", "Subsubsection"],

Cell[TextData[{
 "A two-dimensional curve has a reflection about the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis caused by letting\n\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = -",
 StyleBox["y",
  FontSlant->"Italic"],
 "\n\nor about the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " axis by letting\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = -",
 StyleBox["x",
  FontSlant->"Italic"],
 "\n\nor through the origin by applying both these equations.  In three \
dimensions, a curve or surface is reflected across the (",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 "), (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 "), or (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") planes when\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = -",
 StyleBox["x,",
  FontSlant->"Italic"],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = -",
 StyleBox["y,",
  FontSlant->"Italic"],
 "\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 "' = -",
 StyleBox["z,",
  FontSlant->"Italic"],
 "\n\nrespectively.  It can be reflected through the origin when one sets\n\n\
\t",
 StyleBox["r",
  FontSlant->"Italic"],
 "' = -",
 StyleBox["r",
  FontSlant->"Italic"],
 "\n\nin spherical coordinates and mirrored through the ",
 StyleBox["z",
  FontSlant->"Italic"],
 " axis when the same operation is made on ",
 StyleBox["r",
  FontSlant->"Italic"],
 " for cylindrical coordinates.  The application to two-dimensional polar \
coordinates follows from the cylindrical case."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6.5 Rotational Scaling", "Subsubsection"],

Cell[TextData[{
 "For two dimensions, let\n\n\t\[Theta]' = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "\[Theta]\n\nfor the polar angle; the polar curve is then stretched or \
compressed along the angular direction by a factor ",
 StyleBox["c",
  FontSlant->"Italic"],
 " in a rotational scaling.  The same operation can be applied to \[Theta] \
for cylindrical coordinates in three dimensions or to both \[Theta] and \
\[CurlyPhi] for spherical coordinates in three dimensions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6.6 Radial Translation", "Subsubsection"],

Cell[TextData[{
 "In two dimensions with polar coordinates, if the radial coordinate is \
translated according to\n\n\t",
 StyleBox["r",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["r",
  FontSlant->"Italic"],
 " + ",
 StyleBox["a",
  FontSlant->"Italic"],
 ",\n\nthen the entire curve moves outward by the amount ",
 StyleBox["a",
  FontSlant->"Italic"],
 " from the origin.  Note that this operation is not homomorphic like \
Cartesian translation because the curve is stretched in the angular direction \
while undergoing the radial translation.  This operation can be performed on \
the radial coordinate of either cylindrical or spherical coordinate systems \
in three dimensions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6.7 Weighting", "Subsubsection"],

Cell[TextData[{
 "In a two-dimensional Cartesian system, let\n\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' =",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox[
     RowBox[{"\[LeftBracketingBar]", "x", "\[RightBracketingBar]"}], "a"]}], 
   TraditionalForm]]],
 " ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".\n\nThis operation performs a weighting on the curve by the factor ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"\[LeftBracketingBar]", "x", "\[RightBracketingBar]"}], "a"], 
   TraditionalForm]]],
 ", a symmetric operator.  If ",
 StyleBox["a",
  FontSlant->"Italic"],
 " > 0, the curve is stretched in the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " direction by a factor which increases with ",
 StyleBox["x",
  FontSlant->"Italic"],
 "; but if ",
 StyleBox["a",
  FontSlant->"Italic"],
 " < 0, the curve is compressed by a factor which decreases with ",
 StyleBox["x",
  FontSlant->"Italic"],
 ".  Similar treatments can be performed on surfaces in three dimensions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6.8 Nonlinear Scaling", "Subsubsection"],

Cell[TextData[{
 "If in two dimensions the nonlinear scaling\n\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "a"], TraditionalForm]]],
 "\n\nis performed, the curve is progressively scaled upward or downward in \
absolute value, according to whether ",
 StyleBox["a",
  FontSlant->"Italic"],
 " > 1 or ",
 StyleBox["a",
  FontSlant->"Italic"],
 " < 1, respectively.  Note that, if ",
 StyleBox["y",
  FontSlant->"Italic"],
 " < 0 and ",
 StyleBox["a",
  FontSlant->"Italic"],
 " = 2, 4, 6, ..., then the scaled curve will flip to the opposite side of \
the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis.  Similar scalings can be made in three dimensions using any of the \
appropriate coordinate systems."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6.9 Shear", "Subsubsection"],

Cell[TextData[{
 "A curve undergoes simple shear when either all its ",
 StyleBox["x",
  FontSlant->"Italic"],
 " coordinates or all its ",
 StyleBox["y",
  FontSlant->"Italic"],
 " coordinates remain constant while the other set is increased in proportion \
to ",
 StyleBox["x",
  FontSlant->"Italic"],
 " or ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", respectively.  The general transformations for simple shearing of a \
two-dimensional curve are\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["x",
  FontSlant->"Italic"],
 " + ",
 StyleBox["ay",
  FontSlant->"Italic"],
 ",\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["bx",
  FontSlant->"Italic"],
 " + ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".\n\nThe transformations for simple ",
 StyleBox["x",
  FontSlant->"Italic"],
 " shear are\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["x",
  FontSlant->"Italic"],
 " + ",
 StyleBox["ay,",
  FontSlant->"Italic"],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".\n\nand for simple ",
 StyleBox["y",
  FontSlant->"Italic"],
 " shear are\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["x",
  FontSlant->"Italic"],
 ",\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["bx",
  FontSlant->"Italic"],
 " + ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".\n\nSurfaces may be simply sheared along one or two axes with similar \
transformations.  Another special case of shear is termed pure shear, and the \
transformations for a two-dimensional curve are given by\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["kx,",
  FontSlant->"Italic"],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["k", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 StyleBox["y.",
  FontSlant->"Italic"],
 "\n\nFor surfaces, pure shear will only apply to two of the three coordinate \
directions, with the remaining one having no change.  Pure shear is a special \
case of linear scaling under this circumstance."
}], "Text"],

Cell[CellGroupData[{

Cell["\[DoubleLongRightArrow]Show simple shear. ", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Show", " ", "simple", " ", "shear", " ", "applied", " ", "to", " ", "a", 
    " ", 
    RowBox[{"circle", "."}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x", " ", "=", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", "\[Pi]", " ", "t"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"y", " ", "=", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", "\[Pi]", " ", "t"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ParametricPlot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", " ", "+", " ", 
            RowBox[{"a", " ", "y"}]}], ",", 
           RowBox[{
            RowBox[{"b", " ", "x"}], " ", "+", " ", "y"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
         RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
         RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
         RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "0", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "0", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0., $CellContext`b$$ = 0., 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0, 1}, {
      Hold[$CellContext`b$$], 0, 1}}, Typeset`size$$ = {500., {242., 258.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`a$5233$$ = 0, $CellContext`b$5234$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0, $CellContext`b$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$5233$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$5234$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`x$, $CellContext`y$}, $CellContext`x$ = 
         Cos[(2 Pi) $CellContext`t]; $CellContext`y$ = 
         Sin[(2 Pi) $CellContext`t]; 
        ParametricPlot[{$CellContext`x$ + $CellContext`a$$ $CellContext`y$, \
$CellContext`b$$ $CellContext`x$ + $CellContext`y$}, {$CellContext`t, 0, 1}, 
          PlotRange -> {{-2, 2}, {-2, 2}}, PlotStyle -> {Thick, Black}, 
          AxesStyle -> Thick, Ticks -> None, AspectRatio -> 1]], 
      "Specifications" :> {{$CellContext`a$$, 0, 1, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 0, 1, Appearance -> "Labeled"}}, 
      "Options" :> {TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {322., 329.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\[DoubleLongRightArrow]Show pure shear.", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Show", " ", "pure", " ", "shear", " ", "for", " ", "a", " ", 
    RowBox[{"circle", "."}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x", " ", "=", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", "\[Pi]", " ", "t"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"y", " ", "=", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", "\[Pi]", " ", "t"}], "]"}]}], ";", 
       RowBox[{"ParametricPlot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"k", "*", "x"}], " ", ",", 
           RowBox[{"y", "/", "k"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
         RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
         RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"k", ",", "1"}], "}"}], ",", "0.5", ",", "2", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", "k", "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`k$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`k$$], 1}, 0.5, 2}}, Typeset`size$$ = {
    500., {242., 258.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`k$10273$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`k$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`k$$, $CellContext`k$10273$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`x$, $CellContext`y$}, $CellContext`x$ = 
         Cos[(2 Pi) $CellContext`t]; $CellContext`y$ = 
         Sin[(2 Pi) $CellContext`t]; 
        ParametricPlot[{$CellContext`k$$ $CellContext`x$, \
$CellContext`y$/$CellContext`k$$}, {$CellContext`t, 0, 1}, 
          PlotStyle -> {Thick, Black}, PlotRange -> {{-2, 2}, {-2, 2}}, 
          AxesStyle -> Thick, Ticks -> None, AspectRatio -> 1]], 
      "Specifications" :> {{{$CellContext`k$$, 1}, 0.5, 2, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`k$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {301., 308.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6.10 Matrix Method for Transformation", "Subsubsection"],

Cell[TextData[{
 "The foregoing transformations can all be expressed in matrix form, which is \
often convenient for computer algorithms.  This is especially true when \
several transformations are concatenated together, for the matrices can then \
be simply multiplied together to obtain a single transformation matrix.  \
Given a pair of coordinates (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 "), a matrix transformation to obtain the new coordinates (",
 StyleBox["x",
  FontSlant->"Italic"],
 "', ",
 StyleBox["y",
  FontSlant->"Italic"],
 "') is written as\n\n\t(",
 StyleBox["x",
  FontSlant->"Italic"],
 "'  ",
 StyleBox["y",
  FontSlant->"Italic"],
 "') = (",
 StyleBox["x",
  FontSlant->"Italic"],
 "  ",
 StyleBox["y",
  FontSlant->"Italic"],
 ")",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"a", "b"},
      {"c", "d"}
     }], ")"}], TraditionalForm]]],
 "\n\nor explicitly\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["ax",
  FontSlant->"Italic"],
 " + ",
 StyleBox["cy,",
  FontSlant->"Italic"],
 "\n\ty' = ",
 StyleBox["bx",
  FontSlant->"Italic"],
 " + ",
 StyleBox["dy.",
  FontSlant->"Italic"],
 "\n\nAccording to this definition, Table 1 lists several of the \
two-dimensional ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-",
 StyleBox["y",
  FontSlant->"Italic"],
 " transformations discussed previously with their corresponding matrix. "
}], "Text"],

Cell[TextData[{
 "\n",
 StyleBox["Table 1: 2-D Transformations\nOperation\t\tMatrix\t\t\tNotes\n",
  FontWeight->"Bold"],
 "Rotation\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {
       RowBox[{"cos", " ", "\[Alpha]"}], 
       RowBox[{"sin", " ", "\[Alpha]"}]},
      {
       RowBox[{
        RowBox[{"-", "sin"}], " ", "\[Alpha]"}], 
       RowBox[{"cos", " ", "\[Alpha]"}]}
     }], ")"}], TraditionalForm]]],
 "         \[Alpha] is the counterclockwise angle in the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-",
 StyleBox["y",
  FontSlant->"Italic"],
 " plane\nLinear scaling\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"a", "0"},
      {"0", "b"}
     }], ")"}], TraditionalForm]]],
 "\nReflection\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {
       RowBox[{"\[PlusMinus]", "1"}], "0"},
      {"0", 
       RowBox[{"\[PlusMinus]", "1"}]}
     }], ")"}], TraditionalForm]]],
 "\t\tUse + or - according to the desired reflection.\nWeighting\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", "0"},
      {"0", 
       SuperscriptBox["x", "a"]}
     }], ")"}], TraditionalForm]]],
 "\nNonlinear scaling\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", "0"},
      {"0", 
       SuperscriptBox["y", "a"]}
     }], ")"}], TraditionalForm]]],
 "\t\t\nSimple shear \t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", "a"},
      {"b", "1"}
     }], ")"}], TraditionalForm]]],
 "\t\t\tEither ",
 StyleBox["a",
  FontSlant->"Italic"],
 " or ",
 StyleBox["b",
  FontSlant->"Italic"],
 " is zero, for ",
 StyleBox["x",
  FontSlant->"Italic"],
 " or ",
 StyleBox["y",
  FontSlant->"Italic"],
 " shear, respectively.\nRotational scaling\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", "0"},
      {"0", "a"}
     }], ")"}], TraditionalForm]]],
 "\t\t\tUse with (",
 StyleBox["r",
  FontSlant->"Italic"],
 ", \[Theta]) coordinates."
}], "Text"],

Cell[TextData[{
 "\n",
 "Translations cannot be treated with the above matrix definition.  An \
extension is required to produce what is commonly referred to as the \
homogeneous coordinate representation in computer graphics programming.  In \
its simplest form, an additional coordinate of unity is appended to the (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") pair to give (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", 1).  A translation by ",
 StyleBox["u",
  FontSlant->"Italic"],
 " and ",
 StyleBox["v",
  FontSlant->"Italic"],
 " in the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " directions is then written using a 3-by-3 matrix\n\n\t(",
 StyleBox["x",
  FontSlant->"Italic"],
 "'  ",
 StyleBox["y",
  FontSlant->"Italic"],
 "'  1) = (",
 StyleBox["x",
  FontSlant->"Italic"],
 "  ",
 StyleBox["y",
  FontSlant->"Italic"],
 "  1)",
 Cell[BoxData[
  RowBox[{"(", GridBox[{
     {"1", "0", "0"},
     {"0", "1", "0"},
     {
      StyleBox["u",
       FontSlant->"Italic"], 
      StyleBox["v",
       FontSlant->"Italic"], "1"}
    }], ")"}]],
  CellChangeTimes->{{3.599008559804677*^9, 3.599008599732798*^9}}],
 "\n\nwhere explicitly, \n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["x",
  FontSlant->"Italic"],
 " + ",
 StyleBox["u",
  FontSlant->"Italic"],
 ",\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["y",
  FontSlant->"Italic"],
 " + ",
 StyleBox["v",
  FontSlant->"Italic"],
 ",\n\t1 = 1.\n\nWith this representation, a radial translation by ",
 StyleBox["s",
  FontSlant->"Italic"],
 " units of a curve given in (",
 StyleBox["r",
  FontSlant->"Italic"],
 ", \[Theta]) coordinates is effected by\n\n\t(",
 StyleBox["r",
  FontSlant->"Italic"],
 "'  \[Theta]'  1) = (",
 StyleBox["r",
  FontSlant->"Italic"],
 "  \[Theta]  1)",
 Cell[BoxData[
  RowBox[{"(", GridBox[{
     {"1", "0", "0"},
     {"0", "1", "0"},
     {
      StyleBox["s",
       FontSlant->"Italic"], "0", "1"}
    }], ")"}]],
  CellChangeTimes->{{3.599008559804677*^9, 3.599008599732798*^9}}],
 "\n\nsuch that ",
 StyleBox["r",
  FontSlant->"Italic"],
 "' = ",
 StyleBox["r",
  FontSlant->"Italic"],
 " + ",
 StyleBox["s",
  FontSlant->"Italic"],
 " and \[Theta] is unchanged.  In three dimensions similar transformations \
exist, as shown in Table 2, mostly being simple extensions of those given in \
Table 1.\n"
}], "Text"],

Cell[TextData[{
 "\n",
 StyleBox["Table 2: 3-D Transformations\nOperation\t\tMatrix\t\t\t\tNotes\n",
  FontWeight->"Bold"],
 "Rotation\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {
       RowBox[{"c\[Beta]", "\[CenterDot]", "c\[Gamma]"}], 
       RowBox[{
        RowBox[{
        "s\[Alpha]", "\[CenterDot]", "s\[Beta]", "\[CenterDot]", 
         "c\[Gamma]"}], " ", "+", " ", 
        RowBox[{"c\[Alpha]", "\[CenterDot]", "s\[Gamma]", " "}]}], 
       RowBox[{
        RowBox[{
         RowBox[{"-", "c\[Alpha]"}], "\[CenterDot]", "s\[Beta]", 
         "\[CenterDot]", "c\[Gamma]"}], " ", "+", " ", 
        RowBox[{"s\[Alpha]", "\[CenterDot]", "s\[Gamma]"}]}]},
      {
       RowBox[{
        RowBox[{"-", "c\[Beta]"}], "\[CenterDot]", "s\[Gamma]"}], 
       RowBox[{
        RowBox[{"c\[Alpha]", "\[CenterDot]", "c\[Gamma]"}], " ", "-", 
        RowBox[{
        "s\[Alpha]", "\[CenterDot]", "s\[Beta]", "\[CenterDot]", "s\[Gamma]", 
         " "}]}], 
       RowBox[{
        RowBox[{"s\[Alpha]", "\[CenterDot]", "c\[Gamma]"}], " ", "+", " ", 
        RowBox[{
        "c\[Alpha]", "\[CenterDot]", "s\[Beta]", "\[CenterDot]", 
         "s\[Gamma]"}]}]},
      {"s\[Beta]", 
       RowBox[{
        RowBox[{"-", "s\[Alpha]"}], "\[CenterDot]", "c\[Beta]"}], 
       RowBox[{"c\[Alpha]", "\[CenterDot]", "c\[Beta]"}]}
     }], ")"}], TraditionalForm]]],
 "         \t",
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"\[Alpha]", ",", "\[Beta]", ",", 
       RowBox[{
       "\[Gamma]", " ", "are", " ", "the", " ", "counterclockwise"}]}]},
     {
      RowBox[{"rotations", " ", "about", " ", "each", " ", "positive", " ", 
       RowBox[{"axis", "."}]}]}
    }], TraditionalForm]]],
 " \nLinear scaling\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"a", 
       RowBox[{"0", " "}], "0"},
      {"0", 
       RowBox[{"b", " "}], "0"},
      {"0", "0", "c"}
     }], ")"}], TraditionalForm]]],
 "\nReflection\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {
       RowBox[{"\[PlusMinus]", "1"}], 
       RowBox[{"0", " "}], "0"},
      {"0", 
       RowBox[{"\[PlusMinus]", "1", " "}], "0"},
      {"0", "0", 
       RowBox[{"\[PlusMinus]", "1"}]}
     }], ")"}], TraditionalForm]]],
 "\t\tUse + or - according to the desired reflection.\nWeighting\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", "0", "0"},
      {"0", 
       RowBox[{"1", " "}], "0"},
      {"0", "0", 
       StyleBox[
        RowBox[{
         SuperscriptBox["x", "a"], 
         SuperscriptBox["y", "a"]}],
        FontSlant->"Italic"]}
     }], ")"}], TraditionalForm]]],
 "\nNonlinear scaling\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", "0", "0"},
      {"0", 
       RowBox[{"1", " "}], "0"},
      {"0", "0", 
       SuperscriptBox["z", "a"]}
     }], ")"}], TraditionalForm]]],
 "\t\t\nSimple shear \t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", 
       RowBox[{"0", " "}], "0"},
      {"0", 
       RowBox[{"1", " "}], "0"},
      {"a", "0", "1"}
     }], ")"}], TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", 
       RowBox[{"0", " "}], "0"},
      {"a", 
       RowBox[{"1", " "}], "0"},
      {"0", "0", "1"}
     }], ")"}], TraditionalForm]]],
 "\t",
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{
       RowBox[{"Gives", " ", "simple", " ", "x", " ", "shear"}], ",", 
       RowBox[{
       "depending", " ", "on", " ", "whether", " ", "done", " ", "along", " ",
         "y", " ", "or", " ", "z"}]}]},
     {
      RowBox[{
       RowBox[{"direction", ".", "  ", "Similar"}], " ", "expressions", " ", 
       "hold", " ", "for", " ", "simple", " ", "y", " ", "or", " ", "z", " ", 
       
       RowBox[{"shear", "."}]}]}
    }], TraditionalForm]]],
 "\nRotational scaling\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", 
       RowBox[{"0", " "}], "0"},
      {"0", 
       RowBox[{"a", " "}], "0"},
      {"0", "0", "b"}
     }], ")"}], TraditionalForm]]],
 "\t\t\tUse with (",
 StyleBox["r",
  FontSlant->"Italic"],
 ", \[Theta], \[Phi]) coordinates.\n\
______________________________________________________________________________\
__________________\nc\[Alpha], c\[Beta], c\[Gamma] = cos \[Alpha] , cos \
\[Beta] , cos \[Gamma]\ns\[Alpha], s\[Beta], s\[Gamma] = sin \[Alpha] , sin \
\[Beta] , sin \[Gamma]"
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.7 Method of Presentation", "Subsection"],

Cell["\<\
This reference work is basically intended to be illustrative; therefore all \
functions, whether curves or surfaces, presented in this work will have an \
accompanying plot showing the form of the function.  Curves and surfaces and \
their plots are numbered for easy reference and grouped according to type.  \
Wherever popular names exist for certain curves or surfaces, they are placed \
with the equations themselves.  Only basic explanatory information is \
provided with each curve, as needed. The interested reader can consult \
textbooks, or world-wide web resources for further information on specific \
functions.\
\>", "Text"],

Cell[CellGroupData[{

Cell["1.7.1 Equations", "Subsubsection"],

Cell[TextData[{
 "The equation of each algebraic or transcendental curve will be given in the \
explicit form ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") or ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(\[Theta]) wherever possible; similarly, surfaces will be given as ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") or ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(\[Theta], ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") or ",
 StyleBox["r",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(\[Theta], \[CurlyPhi]).  Whenever polar, cylindrical, or spherical \
coordinate forms are used, the equation is also written in Cartesian \
coordinates, if possible . Because some curves and surfaces are not amenable \
to explicit forms, the parametric equations will be used as the alternative.  \
In either case, whether explicit or parametric, the implicit functional form \
will also be given, if derivable.  The explicit or parametric form is usually \
the most direct means to evaluate the curve or surface on a computer while \
the implicit form enables one to determine the degree of the equation (if \
algebraic) and also easily determine the derivatives in some cases.  Notes \
pertinent to evaluation are given whenever they may help to understand the \
figures better.  For integral curves and surfaces, the equation will be given \
as the integral ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = \[Integral] ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") or ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = \[Integral] ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ").  Most of the integral forms have commonly used names (for example, \
\"Bessel functions\").  Other curves or surfaces in this reference work are \
expressed not by single equations but rather by some set of mathematical \
rules.  The method of presentation will vary in these cases, always with the \
objective of providing the reader with a means of easily constructing the \
curve or surface by machine computation. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.7.2 Plots", "Subsubsection"],

Cell[TextData[{
 "Readers of previous editions will notice that, in this edition, only one \
realization of an equation is given.  The plots of the curves and surfaces \
were enabled with the Mathematica\[RegisteredTrademark] Manipulate function.  \
All of the variable parameters were allowed to be manipulated, to within \
reasonable limits; and a representative choice for printing was made using \
one set of parameters.  A few curves or surfaces require such a long \
computation time that manipulation is not feasible within reasonable time.  \
In these cases, a note is given with the equation.  Some curves and surfaces \
have no variable parameters, and so a simple static plotting function was \
used.  Plots of two-dimensional curves are done on the (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") plane, with the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " axes being horizontal and vertical, respectively.  Three-dimensional \
curves and surfaces have the additional ",
 StyleBox["z",
  FontSlant->"Italic"],
 " axis and are plotted in a projection which satisfactorily illustrates the \
form of each function.  The implicit form of a curve often comprises more \
points than a corresponding explicit form.  For example ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 " - ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 0 has two ranges in ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", one positive and one negative, while the explicit form derived from \
solving the above equation gives ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SqrtBox["x"], TraditionalForm]]],
 " for which the range of ",
 StyleBox["y",
  FontSlant->"Italic"],
 " is positive only; in such cases both the positive and negative range of ",
 StyleBox["y",
  FontSlant->"Italic"],
 " are plotted.  All graphs, unless there are no parameters to manipulate, \
include the readout of the parameters so that the reader can see the exact \
realization of the function.  Many functions have a wide range of possible \
realizations, sometimes differing radically in appearance; and thus the \
single example shown may not adequately show the behavior of the function.  \
This should encourage readers to avail themselves of the Mathematica\
\[RegisteredTrademark] capabilities contained in the Computable Document \
Format (CDF) files which accompany this printed book.  To activate these \
files, access the Wolfram Research site (http://www.wolfram.com) and download \
the free CDF Player."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["REFERENCES", "Subsection"],

Cell["\<\
1.  Buck, R. C., Advanced Calculus, McGraw-Hill, New York, 1965, chap. 5.\
\[IndentingNewLine]
2.  Poston, T., and I. Stewart, Catastrophe Theory and Its Applications, \
Pitman, New York, 1978.\[IndentingNewLine]
3.  Abramowitz, M., Ed., Handbook of Mathematical Functions, With Formulas, \
Graphs, and Mathematical Tables, Dover, 1974.\[IndentingNewLine]
4.  Mandelbrot, B. B., The Fractal Geometry of Nature, W. H. Freeman, San \
Francisco, 1983.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1083, 923},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.25 Inherited,
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 25, \
2016)",
StyleDefinitions->"myStyles.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 34, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[1545, 39, 63, 0, 57, "Subsection"],
Cell[1611, 41, 730, 11, 132, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2378, 57, 44, 0, 57, "Subsection"],
Cell[2425, 59, 5118, 217, 693, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7580, 281, 46, 0, 57, "Subsection"],
Cell[7629, 283, 2095, 93, 419, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9761, 381, 44, 0, 57, "Subsection"],
Cell[9808, 383, 761, 15, 205, "Text"],
Cell[CellGroupData[{
Cell[10594, 402, 52, 0, 35, "Subsubsection"],
Cell[10649, 404, 577, 11, 109, "Text"],
Cell[CellGroupData[{
Cell[11251, 419, 2662, 80, 214, "Input"],
Cell[13916, 501, 1194, 33, 558, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15147, 539, 3685, 105, 280, "Input"],
Cell[18835, 646, 1304, 32, 558, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20188, 684, 48, 0, 35, "Subsubsection"],
Cell[20239, 686, 1665, 59, 329, "Text"],
Cell[CellGroupData[{
Cell[21929, 749, 2173, 65, 192, "Input"],
Cell[24105, 816, 1073, 31, 558, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25227, 853, 54, 0, 35, "Subsubsection"],
Cell[25284, 855, 1322, 50, 134, "Text"],
Cell[CellGroupData[{
Cell[26631, 909, 6322, 188, 412, "Input"],
Cell[32956, 1099, 1500, 34, 558, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34505, 1139, 52, 0, 35, "Subsubsection"],
Cell[34560, 1141, 2230, 83, 409, "Text"],
Cell[CellGroupData[{
Cell[36815, 1228, 6457, 192, 412, "Input"],
Cell[43275, 1422, 1571, 35, 558, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[44907, 1464, 71, 0, 57, "Subsection"],
Cell[44981, 1466, 666, 10, 132, "Text"],
Cell[CellGroupData[{
Cell[45672, 1480, 41, 0, 35, "Subsubsection"],
Cell[45716, 1482, 5510, 188, 610, "Text"],
Cell[CellGroupData[{
Cell[51251, 1674, 121, 1, 37, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[51375, 1677, 4441, 119, 404, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[55819, 1798, 2881, 57, 479, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[58749, 1861, 39, 0, 35, "Subsubsection"],
Cell[58791, 1863, 4376, 204, 753, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63204, 2072, 37, 0, 35, "Subsubsection"],
Cell[63244, 2074, 2142, 76, 252, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65423, 2155, 41, 0, 35, "Subsubsection"],
Cell[65467, 2157, 3032, 115, 481, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68536, 2277, 42, 0, 35, "Subsubsection"],
Cell[68581, 2279, 3044, 124, 607, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71662, 2408, 41, 0, 35, "Subsubsection"],
Cell[71706, 2410, 3389, 122, 515, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75132, 2537, 46, 0, 35, "Subsubsection"],
Cell[75181, 2539, 3549, 94, 834, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78767, 2638, 46, 0, 35, "Subsubsection"],
Cell[78816, 2640, 3654, 133, 508, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82507, 2778, 37, 0, 35, "Subsubsection"],
Cell[82547, 2780, 2052, 73, 228, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84636, 2858, 45, 0, 35, "Subsubsection"],
Cell[84684, 2860, 4223, 175, 679, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88944, 3040, 47, 0, 35, "Subsubsection"],
Cell[88994, 3042, 1838, 53, 379, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90869, 3100, 41, 0, 35, "Subsubsection"],
Cell[90913, 3102, 10778, 440, 1277, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[101740, 3548, 63, 0, 57, "Subsection"],
Cell[101806, 3550, 63, 0, 37, "Text"],
Cell[101872, 3552, 236499, 3883, 261, "Output"],
Cell[338374, 7437, 1462, 36, 227, "Text"],
Cell[CellGroupData[{
Cell[339861, 7477, 47, 0, 35, "Subsubsection"],
Cell[339911, 7479, 3619, 131, 640, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343567, 7615, 52, 0, 35, "Subsubsection"],
Cell[343622, 7617, 3317, 125, 423, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[346976, 7747, 46, 0, 35, "Subsubsection"],
Cell[347025, 7749, 1031, 31, 212, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[348093, 7785, 61, 0, 35, "Subsubsection"],
Cell[348157, 7787, 677, 13, 133, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[348871, 7805, 57, 0, 35, "Subsubsection"],
Cell[348931, 7807, 2470, 85, 377, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[351450, 7898, 60, 0, 57, "Subsection"],
Cell[351513, 7900, 597, 9, 132, "Text"],
Cell[CellGroupData[{
Cell[352135, 7913, 42, 0, 35, "Subsubsection"],
Cell[352180, 7915, 1038, 56, 180, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353255, 7976, 39, 0, 35, "Subsubsection"],
Cell[353297, 7978, 1319, 52, 299, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[354653, 8035, 45, 0, 35, "Subsubsection"],
Cell[354701, 8037, 902, 40, 299, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[355640, 8082, 41, 0, 35, "Subsubsection"],
Cell[355684, 8084, 1617, 71, 512, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[357338, 8160, 49, 0, 35, "Subsubsection"],
Cell[357390, 8162, 490, 11, 180, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[357917, 8178, 49, 0, 35, "Subsubsection"],
Cell[357969, 8180, 697, 19, 180, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[358703, 8204, 40, 0, 35, "Subsubsection"],
Cell[358746, 8206, 1027, 36, 182, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[359810, 8247, 48, 0, 35, "Subsubsection"],
Cell[359861, 8249, 778, 27, 182, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360676, 8281, 36, 0, 35, "Subsubsection"],
Cell[360715, 8283, 2111, 90, 585, "Text"],
Cell[CellGroupData[{
Cell[362851, 8377, 111, 1, 37, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[362965, 8380, 2312, 61, 302, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[365280, 8443, 2359, 45, 671, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[367676, 8493, 108, 1, 37, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[367787, 8496, 2035, 52, 280, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[369825, 8550, 2086, 41, 629, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[371960, 8597, 64, 0, 35, "Subsubsection"],
Cell[372027, 8599, 1453, 59, 369, "Text"],
Cell[373483, 8660, 1977, 84, 408, "Text"],
Cell[375463, 8746, 2494, 105, 596, "Text"],
Cell[377960, 8853, 4421, 149, 639, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[382430, 9008, 48, 0, 57, "Subsection"],
Cell[382481, 9010, 647, 10, 132, "Text"],
Cell[CellGroupData[{
Cell[383153, 9024, 40, 0, 35, "Subsubsection"],
Cell[383196, 9026, 2481, 82, 277, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[385714, 9113, 36, 0, 35, "Subsubsection"],
Cell[385753, 9115, 2641, 62, 375, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[388443, 9183, 32, 0, 57, "Subsection"],
Cell[388478, 9185, 472, 9, 180, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature av0sczrRERTRNBKgFeeuQpXm *)
