(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 10.4' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[    189647,       4355]
NotebookOptionsPosition[    183286,       4118]
NotebookOutlinePosition[    183676,       4135]
CellTagsIndexPosition[    183633,       4132]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Initialization", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.6218684695075083`*^9}],

Cell["\<\
labelstyle = {Black,20};
SetOptions[Graphics,AspectRatio\[Rule]Automatic,Prolog\[Rule]\
AbsoluteThickness[5],LabelStyle\[Rule]labelstyle,ImageSize\[Rule]400];
$TextStyle = {FontSize\[Rule]14, FontFamily\[Rule]\"TimesRoman\", FontWeight\
\[Rule]\"Bold\"};
SetOptions[Manipulate,LabelStyle\[Rule]labelstyle];
SetOptions[Manipulator,LabelStyle\[Rule]labelstyle];
SetOptions[GraphicsGrid,BaseStyle\[Rule]20,ImageSize\[Rule]400];\
\>", "Input",
 PageWidth->WindowWidth,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.6027944695779943`*^9, 3.6027945027795887`*^9}, 
   3.602811882906534*^9, {3.606065455476055*^9, 3.606065456217258*^9}, 
   3.6111612315036783`*^9, {3.611164501721537*^9, 3.6111645133060017`*^9}, {
   3.612311060978657*^9, 3.612311096233262*^9}, {3.612311363173711*^9, 
   3.6123113991974382`*^9}, {3.6123114584517727`*^9, 3.6123114598864202`*^9}, 
   3.612311939665269*^9, 3.621868469507723*^9, {3.627673401025465*^9, 
   3.627673430248672*^9}, {3.627677211428351*^9, 3.627677212106456*^9}, 
   3.627910705437169*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["11.  Polygons", "Section"],

Cell["\<\
The familiar shapes of two-dimensional geometry are shown in the first \
sections of this chapter.  Scale is entirely relative for these figures.  \
Later sections show how triangles, squares, and hexagons can be combined into \
more complicated shapes; these can serve as building blocks for even larger \
patterns, and some are capable of tiling the plane.  The final section treats \
closed curves which are not strictly polygons because they have arc-like \
edges rather than straight-line edges.\
\>", "Text",
 CellChangeTimes->{{3.605832532002833*^9, 3.60583258429993*^9}}],

Cell[CellGroupData[{

Cell["11.0  Plotting Information for This Chapter", "Subsection"],

Cell["\<\
The 2-D polygonal shapes of this chapter are plotted with the Graphics \
function.  In most cases, the line segments of the figure are created \
geometrically and then concatenated.  The function GraphicsGrid is used in \
some cases to assemble similar figures into a matrix, for instance, the \
regular polygons.  \
\>", "Text",
 CellChangeTimes->{{3.602794649592559*^9, 3.6027946767656116`*^9}, {
  3.6028654358528147`*^9, 3.602865445052395*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["11.1 Polygons With Equal Sides", "Subsection",
 CellChangeTimes->{{3.620954765578559*^9, 3.6209547742292633`*^9}}],

Cell[CellGroupData[{

Cell["11.1.1 Regular Polygons", "Subsubsection",
 CellChangeTimes->{{3.620954781912765*^9, 3.620954803691221*^9}, 
   3.620955671471904*^9}],

Cell["\<\

The regular polygons of sides 3 through 12 have the following names:

\t\t 3 -- equilateral triangle
\t\t 4 -- square
\t\t 5 -- pentagon
\t\t 6 -- hexagon
\t\t 7 -- heptagon
\t\t 8 -- octagon
\t\t 9 -- nonagon
\t\t10 -- decagon
\t\t11 -- undecagon
\t\t12 -- dodecagon
\t\t
The following cell will display one of the 10 regular polygons given above.\
\>", "Text",
 CellChangeTimes->{
  3.602810878801631*^9, {3.602811959269643*^9, 3.6028119836804247`*^9}, 
   3.6209548125307627`*^9, {3.621474508387265*^9, 3.621474509122118*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"regular", ",", "polygon"}], "}"}], ",", "\[IndentingNewLine]", 
     " ", 
     RowBox[{
      RowBox[{"regular", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", "\[Pi]", " ", 
              RowBox[{"n", "/", "m"}]}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", "\[Pi]", " ", 
              RowBox[{"n", "/", "m"}]}], "]"}]}], "}"}], "//", "N"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";", "    ", 
      RowBox[{"polygon", " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Line", "[", "regular", "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"ToString", "[", "m", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"BaseStyle", "\[Rule]", "24"}]}], "]"}]}], "}"}], "]"}]}],
       ";", "\[IndentingNewLine]", " ", 
      RowBox[{"Show", "[", 
       RowBox[{"polygon", ",", 
        RowBox[{"BaseStyle", "\[Rule]", 
         RowBox[{"{", "20", "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<11.1.1\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"m", ",", "3", ",", "12", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "m", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.60281013888273*^9, 3.602810272396291*^9}, {
   3.602810312984351*^9, 3.602810350820086*^9}, 3.602810506850326*^9, {
   3.602810553411846*^9, 3.6028105707107077`*^9}, {3.602810607589562*^9, 
   3.6028106563010902`*^9}, {3.602810733488454*^9, 3.60281080013334*^9}, {
   3.602810969816121*^9, 3.602810969964563*^9}, {3.611106241477502*^9, 
   3.611106279080036*^9}, {3.6123113355155773`*^9, 3.61231134791418*^9}, 
   3.612312839761278*^9, {3.612313307000589*^9, 3.6123133134251423`*^9}, {
   3.620955665022946*^9, 3.620955666810754*^9}, {3.621474588986495*^9, 
   3.621474680364727*^9}, {3.6214747752516327`*^9, 3.6214748570252047`*^9}, {
   3.6214748919046497`*^9, 3.621474948538409*^9}, {3.621475027116868*^9, 
   3.621475033401589*^9}, 3.621475074177987*^9, {3.627673259941072*^9, 
   3.627673283075872*^9}, {3.6276733443508387`*^9, 3.627673361750598*^9}, {
   3.627676129572071*^9, 3.627676129768464*^9}, {3.6276761764467278`*^9, 
   3.627676195406517*^9}, {3.6276762729370413`*^9, 3.627676279443013*^9}, {
   3.627676310318568*^9, 3.627676320354437*^9}, 3.627676479830596*^9, {
   3.627676517906369*^9, 3.627676531817086*^9}, {3.6306311266961327`*^9, 
   3.630631129894658*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`m$$ = 6, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`m$$], 3, 12, 1}}, Typeset`size$$ = {
    500., {227., 243.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`m$11462$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`m$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`m$$, $CellContext`m$11462$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`regular$, $CellContext`polygon$}, \
$CellContext`regular$ = Table[
           N[{
             Cos[2 Pi ($CellContext`n/$CellContext`m$$)], 
             Sin[2 Pi ($CellContext`n/$CellContext`m$$)]}], {$CellContext`n, 
            0, $CellContext`m$$}]; $CellContext`polygon$ = Graphics[{Thick, 
            Line[$CellContext`regular$], 
            Text[
             ToString[$CellContext`m$$], {0, 0}, BaseStyle -> 24]}]; 
        Show[$CellContext`polygon$, BaseStyle -> {20}, PlotLabel -> 
          "11.1.1"]], 
      "Specifications" :> {{$CellContext`m$$, 3, 12, 1, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`m$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {288., 295.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.602810367712973*^9, 3.6028105089914417`*^9, 3.602810578671239*^9, {
   3.60281062088767*^9, 3.602810658303596*^9}, {3.602810737884761*^9, 
   3.60281074605188*^9}, 3.602810891126259*^9, 3.6028118908857727`*^9, 
   3.612311105739808*^9, 3.612311349452518*^9, 3.6123114713631687`*^9, 
   3.612312841134142*^9, 3.612313314325317*^9, 3.6208477523211823`*^9, {
   3.621475011307631*^9, 3.621475034850979*^9}, 3.6214750758701468`*^9, 
   3.621507187151493*^9, {3.627673242858288*^9, 3.627673283951026*^9}, 
   3.627673354102067*^9, 3.627673438474248*^9, 3.627676131419218*^9, 
   3.6276761977393503`*^9, 3.627676280780344*^9, 3.627676322052774*^9, 
   3.627676532719056*^9, 3.630631102257628*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.1.2 Star Polygons", "Subsubsection",
 CellChangeTimes->{{3.6209549814318047`*^9, 3.6209549816175337`*^9}}],

Cell[TextData[{
 "\nFor a star polygon outline, set ",
 StyleBox["m",
  FontSlant->"Italic"],
 " to number of star points in the first cell below.  The value ",
 StyleBox["c",
  FontSlant->"Italic"],
 " (",
 StyleBox["c",
  FontSlant->"Italic"],
 " > 1) is the ratio of the distance, as measured from the center of the \
figure, of the outer points of the star to that of the inner points of the \
star. "
}], "Text",
 CellChangeTimes->{3.602811796793228*^9, 3.620954998780375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"star", ",", "polygon"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"star", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", "\[Pi]", " ", 
              RowBox[{"n", "/", "m"}]}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", "\[Pi]", " ", 
              RowBox[{"n", "/", "m"}]}], "]"}]}], "}"}], "//", "N"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"star", "=", 
         RowBox[{"Insert", "[", 
          RowBox[{"star", ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"c", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "n"}], "-", "1"}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{"2", "m"}], ")"}]}]}], "]"}]}], ",", 
              RowBox[{"c", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "n"}], "-", "1"}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{"2", "m"}], ")"}]}]}], "]"}]}]}], "}"}], "//", 
            "N"}], ",", 
           RowBox[{"2", "n"}]}], "]"}]}], "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "m"}], "}"}]}], "\[IndentingNewLine]", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"polygon", " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Line", "[", "star", "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"ToString", "[", "m", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"BaseStyle", "\[Rule]", "24"}]}], "]"}]}], "}"}], "]"}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", 
       RowBox[{"polygon", ",", 
        RowBox[{"BaseStyle", "\[Rule]", "20"}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<11.1.2\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "3"}], "}"}], ",", "1", ",", "4", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"m", ",", "3", ",", "12", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "m"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.602811003865759*^9, 3.6028110274407387`*^9}, {
   3.602811062691442*^9, 3.6028113372192507`*^9}, 3.6028113829461107`*^9, {
   3.602811424970463*^9, 3.602811442716343*^9}, 3.602811534021352*^9, {
   3.602811569529447*^9, 3.602811577078496*^9}, {3.602811647121656*^9, 
   3.602811659996578*^9}, {3.602811698685895*^9, 3.602811699150085*^9}, {
   3.602811761423365*^9, 3.602811779423318*^9}, {3.602811866224868*^9, 
   3.602811866623912*^9}, {3.6111062630595284`*^9, 3.611106270644372*^9}, {
   3.6123114958922863`*^9, 3.6123115038172827`*^9}, {3.61231285681317*^9, 
   3.612312857562092*^9}, {3.6123133268408823`*^9, 3.612313332839447*^9}, {
   3.6209556862345467`*^9, 3.620955687023148*^9}, {3.6214751275773706`*^9, 
   3.621475336230624*^9}, {3.621475444144661*^9, 3.621475559030455*^9}, {
   3.621475591095504*^9, 3.621475674044886*^9}, {3.621507249035264*^9, 
   3.6215072495167313`*^9}, {3.621507862673298*^9, 3.621507869144869*^9}, {
   3.6215079797849903`*^9, 3.621507982045862*^9}, {3.627676362969743*^9, 
   3.6276763736471167`*^9}, 3.627676462357421*^9, {3.627676560407424*^9, 
   3.6276766018934526`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 3, $CellContext`m$$ = 6, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 3}, 1, 4}, {
      Hold[$CellContext`m$$], 3, 12, 1}}, Typeset`size$$ = {
    500., {296., 312.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$11857$$ = 
    0, $CellContext`m$11858$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`c$$ = 3, $CellContext`m$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$11857$$, 0], 
        Hold[$CellContext`m$$, $CellContext`m$11858$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`star$, $CellContext`polygon$}, $CellContext`star$ = 
         Table[
           N[{
             Cos[2 Pi ($CellContext`n/$CellContext`m$$)], 
             Sin[2 Pi ($CellContext`n/$CellContext`m$$)]}], {$CellContext`n, 
            0, $CellContext`m$$}]; 
        Do[$CellContext`star$ = Insert[$CellContext`star$, 
            
            N[{$CellContext`c$$ 
              Cos[2 Pi ((2 $CellContext`n - 1)/(
                 2 $CellContext`m$$))], $CellContext`c$$ 
              Sin[2 Pi ((2 $CellContext`n - 1)/(2 $CellContext`m$$))]}], 
            2 $CellContext`n], {$CellContext`n, 
           1, $CellContext`m$$}]; $CellContext`polygon$ = Graphics[{Thick, 
            Line[$CellContext`star$], 
            Text[
             ToString[$CellContext`m$$], {0, 0}, BaseStyle -> 24]}]; 
        Show[$CellContext`polygon$, BaseStyle -> 20, PlotLabel -> "11.1.2"]], 
      "Specifications" :> {{{$CellContext`c$$, 3}, 1, 4, Appearance -> 
         "Labeled"}, {$CellContext`m$$, 3, 12, 1, Appearance -> "Labeled"}}, 
      "Options" :> {TrackedSymbols -> {$CellContext`c$$, $CellContext`m$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {380., 387.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6028113395251503`*^9, 3.60281166714141*^9, 3.602811704981151*^9, {
   3.602811867464731*^9, 3.602811896214272*^9}, 3.612311505486763*^9, 
   3.612312858403365*^9, 3.612313334892653*^9, 3.6209557023884153`*^9, 
   3.6214757009808617`*^9, {3.621507395214023*^9, 3.621507403064946*^9}, 
   3.621507870637677*^9, 3.621507983499668*^9, 3.627676375727439*^9, 
   3.627676463032835*^9, {3.627676581239684*^9, 3.627676602426893*^9}, 
   3.6306311499718723`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.2 Irregular Triangles", "Subsection",
 CellChangeTimes->{3.620955035330903*^9}],

Cell[CellGroupData[{

Cell["11.2.1  Right Triangle (one angle = 90\[Degree])", "Subsubsection",
 CellChangeTimes->{3.6060625639736347`*^9, 3.620955045768199*^9}],

Cell["Enter a base and height for a right triangle.", "Text",
 CellChangeTimes->{{3.602812024281274*^9, 3.6028120353185453`*^9}, {
  3.611106393026155*^9, 3.611106393251169*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{triangle},
    triangle = Line[{{0,0},{base,0},{0,height},{0,0}}];
    Show[Graphics[{Thick,triangle}],BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.2.\
1\"]
  ],
  {{base,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  {{height,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{base,height}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.6028120460571823`*^9, 3.6028120522324038`*^9}, {
   3.6060627079772863`*^9, 3.60606273918521*^9}, {3.611106293939681*^9, 
   3.611106300200778*^9}, {3.612311517374668*^9, 3.612311524585726*^9}, {
   3.6123121396030273`*^9, 3.61231219071424*^9}, 3.620955610158566*^9, {
   3.621555872013101*^9, 3.621555986001225*^9}, {3.627676632969446*^9, 
   3.627676668890324*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`base$$ = 0.5, $CellContext`height$$ = 0.5, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`base$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`height$$], 0.5}, 0.1, 1}}, Typeset`size$$ = {
    500., {259., 275.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`base$7503$$ = 
    0, $CellContext`height$7504$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`base$$ = 0.5, $CellContext`height$$ = 0.5},
       "ControllerVariables" :> {
        Hold[$CellContext`base$$, $CellContext`base$7503$$, 0], 
        Hold[$CellContext`height$$, $CellContext`height$7504$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`triangle$}, $CellContext`triangle$ = 
         Line[{{0, 0}, {$CellContext`base$$, 0}, {0, $CellContext`height$$}, {
            0, 0}}]; Show[
          Graphics[{Thick, $CellContext`triangle$}], BaseStyle -> 20, 
          PlotLabel -> "11.2.1"]], 
      "Specifications" :> {{{$CellContext`base$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`height$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`base$$, $CellContext`height$$}}, 
      "DefaultOptions" :> {LabelStyle -> 20}],
     ImageSizeCache->{555., {343., 350.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.62155598689141*^9, 3.627676679543284*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.2.2  Isosceles Triangle (two angles equal)", "Subsubsection",
 CellChangeTimes->{3.606062567239882*^9, 3.620955048280772*^9}],

Cell["Enter a base and height for the isosceles triangle.", "Text",
 CellChangeTimes->{{3.602812083933028*^9, 3.602812089193926*^9}, {
   3.611106362938414*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{triangle},
    triangle = Line[{{-base/2,0},{0,height},{base/2,0},{-base/2,0}}];
    Show[Graphics[{Thick,triangle}],BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.2.\
2\"]
  ],
  {{base,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  {{height,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{base,height}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.602812098469294*^9, {3.606062752929924*^9, 3.6060627679283123`*^9}, {
   3.611106314428812*^9, 3.6111063172773848`*^9}, 3.61231154113981*^9, {
   3.6123122214301443`*^9, 3.6123122510771646`*^9}, 3.620955617733589*^9, {
   3.6215560235249357`*^9, 3.621556042454754*^9}, {3.627676722642786*^9, 
   3.6276767528652287`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`base$$ = 0.5, $CellContext`height$$ = 0.5, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`base$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`height$$], 0.5}, 0.1, 1}}, Typeset`size$$ = {
    500., {259., 275.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`base$12132$$ = 
    0, $CellContext`height$12133$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`base$$ = 0.5, $CellContext`height$$ = 0.5},
       "ControllerVariables" :> {
        Hold[$CellContext`base$$, $CellContext`base$12132$$, 0], 
        Hold[$CellContext`height$$, $CellContext`height$12133$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`triangle$}, $CellContext`triangle$ = 
         Line[{{-$CellContext`base$$/2, 0}, {
            0, $CellContext`height$$}, {$CellContext`base$$/2, 
             0}, {-$CellContext`base$$/2, 0}}]; Show[
          Graphics[{Thick, $CellContext`triangle$}], BaseStyle -> 20, 
          PlotLabel -> "11.2.2"]], 
      "Specifications" :> {{{$CellContext`base$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`height$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`base$$, $CellContext`height$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {343., 350.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.602812099979452*^9, 3.612311545405898*^9, 
  3.612312255350733*^9, 3.6215560446394978`*^9, 3.627676758022904*^9, 
  3.630631239611562*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.2.3  Acute Triangle (all angles < 90\[Degree])", "Subsubsection",
 CellChangeTimes->{3.6060625696928043`*^9, 3.620955051005611*^9}],

Cell["\<\
Enter angle1 < 90\[Degree] and angle2 < 90\[Degree], but such that angle1 + \
angle2 > 90\[Degree].  Note that the third angle is given by 180\[Degree] - \
angle1 - angle2.  The base length is set to 1.\
\>", "Text",
 CellChangeTimes->{{3.602812142770701*^9, 3.6028121503696127`*^9}, {
  3.606063028591732*^9, 3.606063034508712*^9}, {3.611184602636956*^9, 
  3.611184634483334*^9}, {3.621556102350286*^9, 3.621556138423929*^9}, {
  3.621556988903537*^9, 3.62155699732834*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{base,angle3,rightside,xtop,ytop,triangle},
    angle3 = 180-angle1-angle2;
    base = 1;
    rightside = base Sin[angle2 Degree]/Sin[angle3 Degree];
    xtop = rightside Cos[angle1 Degree];
    ytop = rightside Sin[angle1 Degree];
    triangle = Line[{{0,0},{base,0},{xtop,ytop},{0,0}}];
    Show[Graphics[{Thick,triangle}],BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.2.\
3\"]
  ],
  {{angle1,70},90 - angle2,89,Appearance\[Rule]\"Labeled\"},
  {{angle2,50},90 - angle1,89,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{angle1,angle2}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.602812177932296*^9, {3.606062775491234*^9, 3.606062778066304*^9}, {
   3.606062813198813*^9, 3.60606282999444*^9}, {3.60606304349772*^9, 
   3.606063063082753*^9}, {3.6060631608348427`*^9, 3.606063163421767*^9}, {
   3.611106323954083*^9, 3.611106328889922*^9}, 3.612311553551531*^9, {
   3.612312267028803*^9, 3.6123122722522707`*^9}, 3.620955626707781*^9, {
   3.621556160263158*^9, 3.621556242824635*^9}, {3.621556344325514*^9, 
   3.621556390114484*^9}, {3.621556424339732*^9, 3.621556455063615*^9}, {
   3.621556685202388*^9, 3.621556694089696*^9}, {3.621556804027855*^9, 
   3.6215568063527393`*^9}, {3.621556855228334*^9, 3.621556858002841*^9}, {
   3.621556910816821*^9, 3.6215569338033667`*^9}, {3.627676777791726*^9, 
   3.6276768096024313`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`angle1$$ = 70, $CellContext`angle2$$ = 50, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`angle1$$], 70}, 
      Dynamic[90 - $CellContext`angle2$$], 89}, {{
       Hold[$CellContext`angle2$$], 50}, 
      Dynamic[90 - $CellContext`angle1$$], 89}}, Typeset`size$$ = {
    500., {219., 234.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`angle1$12364$$ = 
    0, $CellContext`angle2$12365$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`angle1$$ = 70, $CellContext`angle2$$ = 50},
       "ControllerVariables" :> {
        Hold[$CellContext`angle1$$, $CellContext`angle1$12364$$, 0], 
        Hold[$CellContext`angle2$$, $CellContext`angle2$12365$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`base$, $CellContext`angle3$, \
$CellContext`rightside$, $CellContext`xtop$, $CellContext`ytop$, \
$CellContext`triangle$}, $CellContext`angle3$ = 
         180 - $CellContext`angle1$$ - $CellContext`angle2$$; \
$CellContext`base$ = 
         1; $CellContext`rightside$ = $CellContext`base$ 
          Sin[$CellContext`angle2$$ Degree]/
          Sin[$CellContext`angle3$ 
           Degree]; $CellContext`xtop$ = $CellContext`rightside$ 
          Cos[$CellContext`angle1$$ 
            Degree]; $CellContext`ytop$ = $CellContext`rightside$ 
          Sin[$CellContext`angle1$$ Degree]; $CellContext`triangle$ = 
         Line[{{0, 
            0}, {$CellContext`base$, 
             0}, {$CellContext`xtop$, $CellContext`ytop$}, {0, 0}}]; Show[
          Graphics[{Thick, $CellContext`triangle$}], BaseStyle -> 20, 
          PlotLabel -> "11.2.3"]], 
      "Specifications" :> {{{$CellContext`angle1$$, 70}, 
         Dynamic[90 - $CellContext`angle2$$], 89, Appearance -> 
         "Labeled"}, {{$CellContext`angle2$$, 50}, 
         Dynamic[90 - $CellContext`angle1$$], 89, Appearance -> "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`angle1$$, $CellContext`angle2$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {302., 309.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.6028121787615643`*^9, 3.612311556835568*^9, 
  3.61231227461721*^9, 3.621556351634042*^9, 3.621556394316711*^9, 
  3.621556457021986*^9, 3.621556699022649*^9, 3.621556807633906*^9, 
  3.62155686363871*^9, 3.621556934549735*^9, 3.627676817435873*^9, 
  3.630631259268662*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.2.4  Obtuse Triangle (one angle > 90\[Degree])", "Subsubsection",
 CellChangeTimes->{3.606062571425371*^9, 3.620955053818163*^9}],

Cell["\<\
For the third angle to be > 90\[Degree],  angle1 + angle2 < 90\[Degree].  The \
base length is set to 1.\
\>", "Text",
 CellChangeTimes->{{3.606063098071096*^9, 3.606063104157382*^9}, {
  3.6111064248641043`*^9, 3.611106425088963*^9}, {3.611184646795513*^9, 
  3.611184650345533*^9}, {3.6215570081535463`*^9, 3.621557014603362*^9}, {
  3.621557118255794*^9, 3.621557168479074*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{base,angle3,rightside,xtop,ytop,triangle},
    angle3 = 180-angle1-angle2;
    base = 1;
    rightside = base Sin[angle2 Degree]/Sin[angle3 Degree];
    xtop = rightside Cos[angle1 Degree];
    ytop = rightside Sin[angle1 Degree];
    triangle = Line[{{0,0},{base,0},{xtop,ytop},{0,0}}];
    Show[Graphics[{Thick,triangle}],BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.2.\
4\"]
  ],
  {{angle1,20},1,90,Appearance\[Rule]\"Labeled\"},
  {{angle2,40},1,90 - angle1,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{angle1,angle2}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.6028122059466543`*^9, {3.606063083816638*^9, 3.606063086899585*^9}, {
   3.6060631189413223`*^9, 3.606063153837226*^9}, {3.611106402903062*^9, 
   3.611106407427812*^9}, 3.612311564176717*^9, {3.612312282791464*^9, 
   3.612312290114853*^9}, 3.620955635621413*^9, {3.621557025392482*^9, 
   3.621557053217338*^9}, {3.621557257468801*^9, 3.62155728759273*^9}, {
   3.6276768314549417`*^9, 3.6276768753526154`*^9}, {3.627677093226918*^9, 
   3.6276771238751707`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`angle1$$ = 20, $CellContext`angle2$$ = 40, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`angle1$$], 20}, 1, 90}, {{
       Hold[$CellContext`angle2$$], 40}, 1, 
      Dynamic[90 - $CellContext`angle1$$]}}, Typeset`size$$ = {
    500., {81., 96.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`angle1$12596$$ = 
    0, $CellContext`angle2$12597$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`angle1$$ = 20, $CellContext`angle2$$ = 40},
       "ControllerVariables" :> {
        Hold[$CellContext`angle1$$, $CellContext`angle1$12596$$, 0], 
        Hold[$CellContext`angle2$$, $CellContext`angle2$12597$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`base$, $CellContext`angle3$, \
$CellContext`rightside$, $CellContext`xtop$, $CellContext`ytop$, \
$CellContext`triangle$}, $CellContext`angle3$ = 
         180 - $CellContext`angle1$$ - $CellContext`angle2$$; \
$CellContext`base$ = 
         1; $CellContext`rightside$ = $CellContext`base$ 
          Sin[$CellContext`angle2$$ Degree]/
          Sin[$CellContext`angle3$ 
           Degree]; $CellContext`xtop$ = $CellContext`rightside$ 
          Cos[$CellContext`angle1$$ 
            Degree]; $CellContext`ytop$ = $CellContext`rightside$ 
          Sin[$CellContext`angle1$$ Degree]; $CellContext`triangle$ = 
         Line[{{0, 
            0}, {$CellContext`base$, 
             0}, {$CellContext`xtop$, $CellContext`ytop$}, {0, 0}}]; Show[
          Graphics[{Thick, $CellContext`triangle$}], BaseStyle -> 20, 
          PlotLabel -> "11.2.4"]], 
      "Specifications" :> {{{$CellContext`angle1$$, 20}, 1, 90, Appearance -> 
         "Labeled"}, {{$CellContext`angle2$$, 40}, 1, 
         Dynamic[90 - $CellContext`angle1$$], Appearance -> "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`angle1$$, $CellContext`angle2$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {164., 171.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.602812206711007*^9, 3.6123115657847137`*^9, 3.6123122917663937`*^9, {
   3.621557272059615*^9, 3.621557289027779*^9}, 3.627676884680264*^9, {
   3.627677115592126*^9, 3.627677126242255*^9}, 3.6276771766217957`*^9, 
   3.627677228174625*^9, 3.630631285562537*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.3 Irregular Quadrilaterals", "Subsection",
 CellChangeTimes->{3.6209550651182213`*^9}],

Cell[CellGroupData[{

Cell["\<\
11.3.1  Rectangle (opposite sides are equal and all angles = 90\[Degree])\
\>", "Subsubsection",
 CellChangeTimes->{3.620955067568345*^9}],

Cell["Vary the width and a height for the rectangle.", "Text",
 CellChangeTimes->{{3.61110646997661*^9, 3.61110647015152*^9}, {
  3.621557344742833*^9, 3.6215573498800793`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{rectangle},
    rectangle = Line[{{0,0},{width,0},{width,height},{0,height},{0,0}}];
    Show[Graphics[{Thick,rectangle}],BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.\
3.1\"]
  ],
  {{width,1},0.5,4,Appearance\[Rule]\"Labeled\"},
  {{height,0.5},0.5,1,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{width,height}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.602812360335401*^9, {3.6060632064531193`*^9, 3.6060632293245564`*^9}, {
   3.6111064761905518`*^9, 3.611106481078508*^9}, {3.61231160961416*^9, 
   3.612311631161148*^9}, {3.612311966889586*^9, 3.612312010688384*^9}, {
   3.612312301066481*^9, 3.6123123066525507`*^9}, 3.620955540458229*^9, {
   3.621557355930237*^9, 3.621557467918415*^9}, {3.6276773142402363`*^9, 
   3.627677360180551*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`height$$ = 0.5, $CellContext`width$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`width$$], 1}, 0.5, 4}, {{
       Hold[$CellContext`height$$], 0.5}, 0.5, 1}}, Typeset`size$$ = {
    500., {140., 155.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`width$12828$$ = 
    0, $CellContext`height$12829$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`height$$ = 0.5, $CellContext`width$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`width$$, $CellContext`width$12828$$, 0], 
        Hold[$CellContext`height$$, $CellContext`height$12829$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`rectangle$}, $CellContext`rectangle$ = 
         Line[{{0, 
            0}, {$CellContext`width$$, 
             0}, {$CellContext`width$$, $CellContext`height$$}, {
            0, $CellContext`height$$}, {0, 0}}]; Show[
          Graphics[{Thick, $CellContext`rectangle$}], BaseStyle -> 20, 
          PlotLabel -> "11.3.1"]], 
      "Specifications" :> {{{$CellContext`width$$, 1}, 0.5, 4, Appearance -> 
         "Labeled"}, {{$CellContext`height$$, 0.5}, 0.5, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`width$$, $CellContext`height$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {223., 230.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.602812361839643*^9, 3.612311635468911*^9, {3.612311944822217*^9, 
   3.612311974325285*^9}, {3.6123120046890907`*^9, 3.612312012870554*^9}, 
   3.612312307415196*^9, 3.6215574347461767`*^9, 3.621557469566573*^9, 
   3.627677362103861*^9, 3.630631394344441*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
11.3.2  Parallelogram (opposite sides are equal and 2 angles > 90\[Degree] \
and 2 angles < 90\[Degree])\
\>", "Subsubsection",
 CellChangeTimes->{{3.6028123200848846`*^9, 3.6028123387493973`*^9}, 
   3.620955069293047*^9}],

Cell["\<\
Vary the length of the two adjacent sides and one angle for lower left corner.\
\>", "Text",
 CellChangeTimes->{{3.611106498701782*^9, 3.611106498864216*^9}, {
  3.6215574960687027`*^9, 3.621557498043404*^9}, {3.621557807345203*^9, 
  3.6215578313201513`*^9}, {3.6215578720080214`*^9, 3.621557873395316*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{parallelogram},
    parallelogram = Line[{{0,0},{width,0},{width + oblique*Cos[angle \
Degree],oblique*Sin[angle Degree]},
{oblique*Cos[angle Degree],oblique*Sin[angle Degree]},{0,0}}];
    Show[Graphics[{Thick,parallelogram}],BaseStyle\[Rule]20,PlotLabel\[Rule]\"\
11.3.2\"]
  ],
  {{width,1},0.5,4,Appearance\[Rule]\"Labeled\"},
  {{oblique,0.5},0.5,1,Appearance\[Rule]\"Labeled\"},
  {{angle,70},5,90,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{width,oblique,angle}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.602812381435606*^9, {3.606063253967046*^9, 3.606063296588396*^9}, {
   3.611106502878271*^9, 3.611106507551859*^9}, {3.6123116569268312`*^9, 
   3.612311674224002*^9}, {3.6123123137539663`*^9, 3.612312317740213*^9}, 
   3.620955549508278*^9, {3.621557512381109*^9, 3.621557617144433*^9}, {
   3.621557882721113*^9, 3.6215578838832893`*^9}, {3.621557962596101*^9, 
   3.6215579907089*^9}, {3.621558040484153*^9, 3.6215580408714333`*^9}, {
   3.621558082263177*^9, 3.621558129309408*^9}, {3.6276773794431562`*^9, 
   3.6276774264887867`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`angle$$ = 70, $CellContext`oblique$$ = 
    0.5, $CellContext`width$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`width$$], 1}, 0.5, 4}, {{
       Hold[$CellContext`oblique$$], 0.5}, 0.5, 1}, {{
       Hold[$CellContext`angle$$], 70}, 5, 90}}, Typeset`size$$ = {
    500., {116., 131.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`width$13062$$ = 
    0, $CellContext`oblique$13063$$ = 0, $CellContext`angle$13064$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`angle$$ = 70, $CellContext`oblique$$ = 
        0.5, $CellContext`width$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`width$$, $CellContext`width$13062$$, 0], 
        Hold[$CellContext`oblique$$, $CellContext`oblique$13063$$, 0], 
        Hold[$CellContext`angle$$, $CellContext`angle$13064$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`parallelogram$}, $CellContext`parallelogram$ = 
         Line[{{0, 
            0}, {$CellContext`width$$, 
             0}, {$CellContext`width$$ + $CellContext`oblique$$ 
              Cos[$CellContext`angle$$ Degree], $CellContext`oblique$$ 
             Sin[$CellContext`angle$$ Degree]}, {$CellContext`oblique$$ 
             Cos[$CellContext`angle$$ Degree], $CellContext`oblique$$ 
             Sin[$CellContext`angle$$ Degree]}, {0, 0}}]; Show[
          Graphics[{Thick, $CellContext`parallelogram$}], BaseStyle -> 20, 
          PlotLabel -> "11.3.2"]], 
      "Specifications" :> {{{$CellContext`width$$, 1}, 0.5, 4, Appearance -> 
         "Labeled"}, {{$CellContext`oblique$$, 0.5}, 0.5, 1, Appearance -> 
         "Labeled"}, {{$CellContext`angle$$, 70}, 5, 90, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`width$$, $CellContext`oblique$$, \
$CellContext`angle$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {222., 229.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6028123827569027`*^9, 3.6123116755495377`*^9, 3.6123123183983917`*^9, {
   3.621557589095771*^9, 3.621557617718953*^9}, 3.6215581363247747`*^9, 
   3.62767743098518*^9, 3.630631415781598*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
11.3.3  Rhombus (all sides are equal and 2 angles > 90\[Degree] and 2 angles \
< 90\[Degree])\
\>", "Subsubsection",
 CellChangeTimes->{{3.602812402760581*^9, 3.602812418124507*^9}, 
   3.620955071718302*^9}],

Cell["Vary the acute angle < 90\[Degree]  The side length is set to 1.", \
"Text",
 CellChangeTimes->{{3.611106576742895*^9, 3.6111066089026127`*^9}, {
  3.611184682969492*^9, 3.611184687106969*^9}, {3.621558175722389*^9, 
  3.621558205259481*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{rhombus},
    side = 1.0;
    rhombus = Line[{{0,0},{side,0},
    {side + side*Cos[angle Degree],side*Sin[angle Degree]},
    {side*Cos[angle Degree],side*Sin[angle Degree]},{0,0}}];
    Show[Graphics[{Thick,rhombus}],BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.3.\
3\"]
  ],
  {{angle,30},5,85,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{angle}
]\
\>", "Input",
 CellChangeTimes->{
  3.602812435360921*^9, {3.611106514078405*^9, 3.61110652121445*^9}, {
   3.6123123274165154`*^9, 3.6123123443027363`*^9}, 3.620955558558268*^9, {
   3.621558216797721*^9, 3.621558358473114*^9}, {3.621558500613474*^9, 
   3.621558512650269*^9}, {3.627677439590865*^9, 3.627677473663599*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`angle$$ = 30, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`angle$$], 30}, 5, 85}}, Typeset`size$$ = {
    500., {84., 100.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`angle$13470$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`angle$$ = 30}, 
      "ControllerVariables" :> {
        Hold[$CellContext`angle$$, $CellContext`angle$13470$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`rhombus$}, $CellContext`side = 
         1.; $CellContext`rhombus$ = 
         Line[{{0, 
            0}, {$CellContext`side, 
             0}, {$CellContext`side + $CellContext`side 
              Cos[$CellContext`angle$$ Degree], $CellContext`side 
             Sin[$CellContext`angle$$ Degree]}, {$CellContext`side 
             Cos[$CellContext`angle$$ Degree], $CellContext`side 
             Sin[$CellContext`angle$$ Degree]}, {0, 0}}]; Show[
          Graphics[{Thick, $CellContext`rhombus$}], BaseStyle -> 20, 
          PlotLabel -> "11.3.3"]], 
      "Specifications" :> {{{$CellContext`angle$$, 30}, 5, 85, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`angle$$}},
       "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {145., 152.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.602812438090555*^9, 3.612312345790873*^9, 
  3.62155820960257*^9, 3.621558363542836*^9, 3.6276774776961527`*^9, 
  3.630631434616547*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
11.3.4  Trapezoid (two sides parallel, other two sides equal but nonparallel)\
\>", "Subsubsection",
 CellChangeTimes->{3.620955073455101*^9}],

Cell["\<\
Vary the base width, a side distance, and a base angle < 90\[Degree].  The \
top angle will be 180\[Degree] - angle. \
\>", "Text",
 CellChangeTimes->{{3.60281248664707*^9, 3.602812522136585*^9}, {
  3.6028125667479153`*^9, 3.6028125737489843`*^9}, {3.611184699281814*^9, 
  3.611184701146068*^9}, {3.621558406099684*^9, 3.621558433048292*^9}, {
  3.6215585744757557`*^9, 3.6215585823366537`*^9}, {3.621558784275012*^9, 
  3.6215587877373943`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{trapezoid},
    trapezoid = Line[{{0,0},{base,0},{base - side*Cos[angle \
Degree],side*Sin[angle Degree]},
    {side*Cos[angle Degree],side*Sin[angle Degree]},{0,0}}];
    Show[Graphics[{Thick,trapezoid}],BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.\
3.4\"]
  ],
  {{base,1},0.5,4,Appearance\[Rule]\"Labeled\"},
  {{side,0.5},0.5,1,Appearance\[Rule]\"Labeled\"},
  {{angle,70},5,90,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{base,side,angle}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.602812469373568*^9, 3.60281258826182*^9, {3.606063427448349*^9, 
   3.606063463852983*^9}, {3.611106546291301*^9, 3.611106550839682*^9}, {
   3.612312359118339*^9, 3.612312384415409*^9}, 3.6209555678956413`*^9, {
   3.62155845218736*^9, 3.6215584646235*^9}, {3.621558518386261*^9, 
   3.621558519400607*^9}, {3.621558593524006*^9, 3.621558656078013*^9}, {
   3.621558695552153*^9, 3.621558710962665*^9}, {3.6276774907284737`*^9, 
   3.627677517488492*^9}, {3.6276782973008747`*^9, 3.627678305630414*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`angle$$ = 70, $CellContext`base$$ = 
    1, $CellContext`side$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`base$$], 1}, 0.5, 4}, {{
       Hold[$CellContext`side$$], 0.5}, 0.5, 1}, {{
       Hold[$CellContext`angle$$], 70}, 5, 90}}, Typeset`size$$ = {
    500., {132., 148.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`base$13858$$ = 
    0, $CellContext`side$13859$$ = 0, $CellContext`angle$13860$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`angle$$ = 70, $CellContext`base$$ = 
        1, $CellContext`side$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`base$$, $CellContext`base$13858$$, 0], 
        Hold[$CellContext`side$$, $CellContext`side$13859$$, 0], 
        Hold[$CellContext`angle$$, $CellContext`angle$13860$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`trapezoid$}, $CellContext`trapezoid$ = 
         Line[{{0, 
            0}, {$CellContext`base$$, 
             0}, {$CellContext`base$$ - $CellContext`side$$ 
             Cos[$CellContext`angle$$ Degree], $CellContext`side$$ 
             Sin[$CellContext`angle$$ Degree]}, {$CellContext`side$$ 
             Cos[$CellContext`angle$$ Degree], $CellContext`side$$ 
             Sin[$CellContext`angle$$ Degree]}, {0, 0}}]; Show[
          Graphics[{Thick, $CellContext`trapezoid$}], BaseStyle -> 20, 
          PlotLabel -> "11.3.4"]], 
      "Specifications" :> {{{$CellContext`base$$, 1}, 0.5, 4, Appearance -> 
         "Labeled"}, {{$CellContext`side$$, 0.5}, 0.5, 1, Appearance -> 
         "Labeled"}, {{$CellContext`angle$$, 70}, 5, 90, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`base$$, 1., $CellContext`angle$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {238., 245.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.602812588853319*^9, 3.6123123849872103`*^9, 
  3.621558657921579*^9, 3.621558712231608*^9, 3.627677522867977*^9, 
  3.627678306639039*^9, 3.630631461643509*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.3.5  Deltoid (two pairs of equal and adjacent sides)", \
"Subsubsection",
 CellChangeTimes->{3.62095507591781*^9}],

Cell["\<\
Vary the two side lengths and the angle between the pair of sides with the \
first length.  A concave variation of the deltoid can be made by having the \
two top lines go downward rather than upward from the side points.\
\>", "Text",
 CellChangeTimes->{{3.611106638652585*^9, 3.6111066461400757`*^9}, {
  3.621614054184911*^9, 3.621614070109017*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "points", ",", "miny", ",", "maxy", ",", "meany", ",", "deltoid"}], 
      "}"}], ",", "\n", "    ", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"concave", " ", "\[Equal]", "False"}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"points", " ", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"side1", "*", 
              RowBox[{"Sin", "[", 
               RowBox[{"angle", "*", 
                RowBox[{"(", 
                 RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}], ",", " ", 
             "\n", "       ", 
             RowBox[{"side1", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"angle", "*", 
                RowBox[{"(", 
                 RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}]}], "}"}], ",",
            " ", "\n", "      ", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", 
             RowBox[{
              RowBox[{"side1", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{"angle", "*", 
                 RowBox[{"(", 
                  RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}], " ", "+", 
              " ", "\n", "        ", 
              RowBox[{"side2", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{"angle", "*", 
                 RowBox[{"(", 
                  RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}]}]}], "}"}], 
           ",", " ", "\n", "      ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"-", "side1"}], ")"}], "*", 
              RowBox[{"Sin", "[", 
               RowBox[{"angle", "*", 
                RowBox[{"(", 
                 RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}], ",", " ", 
             "\n", "       ", 
             RowBox[{"side1", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"angle", "*", 
                RowBox[{"(", 
                 RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}]}], "}"}], ",",
            " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}]}], "}"}]}], ",", " ", "\n", 
        "      ", 
        RowBox[{"points", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"side1", "*", 
              RowBox[{"Sin", "[", 
               RowBox[{"angle", "*", 
                RowBox[{"(", 
                 RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}], ",", " ", 
             "\n", "       ", 
             RowBox[{"side1", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"angle", "*", 
                RowBox[{"(", 
                 RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}]}], "}"}], ",",
            " ", "\n", "      ", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", 
             RowBox[{
              RowBox[{"side1", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{"angle", "*", 
                 RowBox[{"(", 
                  RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}], " ", "-", 
              " ", "\n", "        ", 
              RowBox[{"side2", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{"angle", "*", 
                 RowBox[{"(", 
                  RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}]}]}], "}"}], 
           ",", " ", "\n", "      ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"-", "side1"}], ")"}], "*", 
              RowBox[{"Sin", "[", 
               RowBox[{"angle", "*", 
                RowBox[{"(", 
                 RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}], ",", " ", 
             "\n", "       ", 
             RowBox[{"side1", "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"angle", "*", 
                RowBox[{"(", 
                 RowBox[{"Degree", "/", "2"}], ")"}]}], "]"}]}]}], "}"}], ",",
            " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", " ", "0"}], "}"}]}], "}"}]}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Center", " ", "the", " ", "figure", " ", "on", " ", "y"}], 
        " ", "=", " ", "0."}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"miny", " ", "=", " ", 
       RowBox[{"Min", "[", 
        RowBox[{"points", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"maxy", " ", "=", " ", 
       RowBox[{"Max", "[", 
        RowBox[{"points", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"meany", " ", "=", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"miny", " ", "+", " ", "maxy"}], ")"}], "/", "2"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"points", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}], " ", "=", " ", 
         RowBox[{
          RowBox[{"points", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], " ", "-", " ", "meany"}]}],
         ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"1", 
           RowBox[{"Length", "[", "points", "]"}]}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"deltoid", " ", "=", " ", 
       RowBox[{"Line", "[", "points", "]"}]}], ";", "\n", "    ", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "deltoid"}], "}"}], "]"}], "\n", "      ", 
        ",", 
        RowBox[{"BaseStyle", "\[Rule]", "20"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<11.3.5\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"side1", ",", "1.0"}], "}"}], ",", "0.2", ",", "1.0", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"side2", ",", "1.0"}], "}"}], ",", "side1", ",", "1.0", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"angle", ",", "80"}], "}"}], ",", "10", ",", "170", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"concave", ",", 
     RowBox[{"{", 
      RowBox[{"False", ",", "True"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"side1", ",", "side2", ",", "angle", ",", "concave"}], "}"}]}]}],
   "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{
  3.6028126828784323`*^9, {3.602812719816538*^9, 3.6028127666777973`*^9}, {
   3.602812850420208*^9, 3.602812859741375*^9}, {3.6028129220318747`*^9, 
   3.602812940780558*^9}, {3.602812986681506*^9, 3.6028130079804087`*^9}, {
   3.606063497040451*^9, 3.606063568688712*^9}, {3.611106664411785*^9, 
   3.6111066702092247`*^9}, {3.612312407061001*^9, 3.6123124492373343`*^9}, {
   3.612312532073915*^9, 3.612312623459197*^9}, 3.6123127253617897`*^9, 
   3.6123127813505297`*^9, 3.620955583223578*^9, {3.621612828168704*^9, 
   3.621612843965279*^9}, {3.621613438970002*^9, 3.621613712809175*^9}, {
   3.621613748260634*^9, 3.621613832259405*^9}, {3.6216139384124126`*^9, 
   3.621613970534861*^9}, {3.621614106548477*^9, 3.621614109498534*^9}, {
   3.6216141443736973`*^9, 3.621614150848495*^9}, {3.621614317714501*^9, 
   3.621614325325251*^9}, {3.6216143835382633`*^9, 3.621614392087473*^9}, 
   3.621639966326914*^9, {3.621640319074095*^9, 3.62164042884719*^9}, {
   3.621640559661487*^9, 3.621640600835492*^9}, 3.6216407485634317`*^9, {
   3.621640804960816*^9, 3.621640813449848*^9}, {3.621640862637974*^9, 
   3.6216408855379744`*^9}, {3.6216409638047733`*^9, 
   3.6216409700067387`*^9}, {3.621641155927661*^9, 3.6216411568382*^9}, {
   3.6216412705772457`*^9, 3.621641329239326*^9}, {3.6216413827903137`*^9, 
   3.621641409351429*^9}, {3.621641462640485*^9, 3.621641484164154*^9}, {
   3.621641533153091*^9, 3.621641542489614*^9}, {3.621641691378416*^9, 
   3.621641700127508*^9}, {3.621641741528892*^9, 3.6216417440661983`*^9}, {
   3.627677543602703*^9, 3.627677591504669*^9}, {3.627677651856139*^9, 
   3.627677656640867*^9}, {3.627677777667161*^9, 3.627677864630101*^9}, {
   3.627677911140173*^9, 3.6276781854284077`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`angle$$ = 80, $CellContext`concave$$ = 
    False, $CellContext`side1$$ = 1., $CellContext`side2$$ = 1., 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`side1$$], 1.}, 0.2, 1.}, {{
       Hold[$CellContext`side2$$], 1.}, 
      Dynamic[$CellContext`side1$$], 1.}, {{
       Hold[$CellContext`angle$$], 80}, 10, 170}, {
      Hold[$CellContext`concave$$], {False, True}}}, Typeset`size$$ = {
    500., {260., 275.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`side1$14104$$ = 
    0, $CellContext`side2$14105$$ = 0, $CellContext`angle$14106$$ = 
    0, $CellContext`concave$14107$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`angle$$ = 80, $CellContext`concave$$ = 
        False, $CellContext`side1$$ = 1., $CellContext`side2$$ = 1.}, 
      "ControllerVariables" :> {
        Hold[$CellContext`side1$$, $CellContext`side1$14104$$, 0], 
        Hold[$CellContext`side2$$, $CellContext`side2$14105$$, 0], 
        Hold[$CellContext`angle$$, $CellContext`angle$14106$$, 0], 
        Hold[$CellContext`concave$$, $CellContext`concave$14107$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`points$, $CellContext`miny$, $CellContext`maxy$, \
$CellContext`meany$, $CellContext`deltoid$}, 
        If[$CellContext`concave$$ == 
          False, $CellContext`points$ = {{0, 
            0}, {$CellContext`side1$$ 
             Sin[$CellContext`angle$$ (Degree/2)], $CellContext`side1$$ 
             Cos[$CellContext`angle$$ (Degree/2)]}, {
            0, $CellContext`side1$$ 
              Cos[$CellContext`angle$$ (Degree/2)] + $CellContext`side2$$ 
              Cos[$CellContext`angle$$ (Degree/2)]}, {(-$CellContext`side1$$) 
             Sin[$CellContext`angle$$ (Degree/2)], $CellContext`side1$$ 
             Cos[$CellContext`angle$$ (Degree/2)]}, {0, 
            0}}, $CellContext`points$ = {{0, 
            0}, {$CellContext`side1$$ 
             Sin[$CellContext`angle$$ (Degree/2)], $CellContext`side1$$ 
             Cos[$CellContext`angle$$ (Degree/2)]}, {
            0, $CellContext`side1$$ 
              Cos[$CellContext`angle$$ (Degree/2)] - $CellContext`side2$$ 
             Sin[$CellContext`angle$$ (Degree/2)]}, {(-$CellContext`side1$$) 
             Sin[$CellContext`angle$$ (Degree/2)], $CellContext`side1$$ 
             Cos[$CellContext`angle$$ (Degree/2)]}, {0, 
            0}}]; $CellContext`miny$ = Min[
           Part[$CellContext`points$, All, 2]]; $CellContext`maxy$ = Max[
           
           Part[$CellContext`points$, All, 
            2]]; $CellContext`meany$ = ($CellContext`miny$ + \
$CellContext`maxy$)/2; 
        Do[Part[$CellContext`points$, $CellContext`i, 2] = 
          Part[$CellContext`points$, $CellContext`i, 
             2] - $CellContext`meany$, {$CellContext`i, 1 
           Length[$CellContext`points$]}]; $CellContext`deltoid$ = 
         Line[$CellContext`points$]; Show[
          Graphics[{Thick, $CellContext`deltoid$}], BaseStyle -> 20, 
          PlotRange -> {{-1, 1}, {-1, 1}}, AspectRatio -> 1, PlotLabel -> 
          "11.3.5"]], 
      "Specifications" :> {{{$CellContext`side1$$, 1.}, 0.2, 1., Appearance -> 
         "Labeled"}, {{$CellContext`side2$$, 1.}, 
         Dynamic[$CellContext`side1$$], 1., Appearance -> 
         "Labeled"}, {{$CellContext`angle$$, 80}, 10, 170, Appearance -> 
         "Labeled"}, {$CellContext`concave$$, {False, True}}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`side1$$, $CellContext`side2$$, \
$CellContext`angle$$, $CellContext`concave$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {383., 390.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6123127268887987`*^9, 3.612312782989747*^9, 3.6216126389500628`*^9, 
   3.6216141655774393`*^9, 3.621614393104773*^9, 3.621639857751175*^9, {
   3.621640329438513*^9, 3.621640355838489*^9}, {3.6216404070381804`*^9, 
   3.621640429896751*^9}, 3.621640472625554*^9, 3.621640563078569*^9, 
   3.621640602651822*^9, 3.621640815048132*^9, {3.621640865830317*^9, 
   3.6216408869219427`*^9}, 3.621640977656475*^9, 3.6216411628243637`*^9, {
   3.621641311961231*^9, 3.6216413305780573`*^9}, {3.621641388260138*^9, 
   3.621641410187093*^9}, {3.6216414646325207`*^9, 3.6216415436156063`*^9}, 
   3.6216417017443132`*^9, 3.621641745550185*^9, 3.6276775959992037`*^9, 
   3.627677657815618*^9, 3.627677873539287*^9, 3.627678194895389*^9, 
   3.627678263531208*^9, 3.630631479811695*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.4 Polyiamonds", "Subsection",
 CellChangeTimes->{3.6209550879682817`*^9}],

Cell[CellGroupData[{

Cell["11.4.1 Triamonds (3 connected equilateral triangles)", "Subsubsection",
 CellChangeTimes->{3.602813267590926*^9, 3.620955090192728*^9}],

Cell["\<\
There is only one shape which the triamond can take, disregarding rotation \
and reflection.  The checkbox \[OpenCurlyDoubleQuote]up\
\[CloseCurlyDoubleQuote] allows one to flip the figure about the horizontal.\
\>", "Text",
 CellChangeTimes->{{3.627678344587777*^9, 3.627678371360956*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{t1,t2,over,triamond},
    t1 = Table[N[{Cos[2\[Pi](n+1/4)/3],Sin[2\[Pi](n+1/4)/3]}],{n,1,4}];
    t2 = Table[N[{Cos[2\[Pi](n-1/4)/3],Sin[2\[Pi](n-1/4)/3]-0.5}],{n,1,4}];
    over = Table[N[{Sqrt[3],0}],{n,1,4}];
    If[up == True,
      triamond = Map[Line,{t1,0.5*over + t2,-0.5*over + t2}],
      triamond = Map[Line,{t1,0.5*over + t2,over + t1}]
    ];
    Graphics[PrependTo[triamond,Directive[Thick]],PlotLabel\[Rule]\"11.4.1\"]
  ],
  {up,{False,True}},
  TrackedSymbols\[Rule]{up}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.602813314231163*^9, 3.6028133301912403`*^9}, {
   3.606063665070842*^9, 3.6060636901581593`*^9}, {3.611106687104644*^9, 
   3.61110669337978*^9}, 3.620955475533124*^9, {3.6216418383897667`*^9, 
   3.621641856550809*^9}, {3.621642064757814*^9, 3.621642102114428*^9}, {
   3.621643278109799*^9, 3.6216432838329067`*^9}, {3.62164341504673*^9, 
   3.6216434415590363`*^9}, {3.62164350542421*^9, 3.621643587397429*^9}, 
   3.6216436630007963`*^9, {3.621643712099792*^9, 3.621643730424987*^9}, {
   3.621643776251018*^9, 3.6216437836359386`*^9}, {3.621643979800767*^9, 
   3.621644004986835*^9}, 3.621644123116516*^9, {3.621644247552412*^9, 
   3.621644271463224*^9}, {3.621644328326528*^9, 3.621644336463497*^9}, {
   3.627678377549028*^9, 3.627678429136342*^9}, {3.6276789054002943`*^9, 
   3.627678910949239*^9}, {3.627678954136834*^9, 3.627678969572624*^9}, {
   3.627685968897951*^9, 3.6276859707012873`*^9}, {3.627686571226411*^9, 
   3.627686571526245*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`up$$ = False, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`up$$], {False, True}}}, Typeset`size$$ = {
    500., {128., 135.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`up$14349$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`up$$ = False}, 
      "ControllerVariables" :> {
        Hold[$CellContext`up$$, $CellContext`up$14349$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t1$, $CellContext`t2$, $CellContext`over$, \
$CellContext`triamond$}, $CellContext`t1$ = Table[
           N[{
             Cos[2 Pi ($CellContext`n + 1/4)/3], 
             Sin[2 Pi ($CellContext`n + 1/4)/3]}], {$CellContext`n, 1, 
            4}]; $CellContext`t2$ = Table[
           N[{
             Cos[2 Pi ($CellContext`n - 1/4)/3], 
             Sin[2 Pi ($CellContext`n - 1/4)/3] - 0.5}], {$CellContext`n, 1, 
            4}]; $CellContext`over$ = Table[
           N[{
             Sqrt[3], 0}], {$CellContext`n, 1, 4}]; 
        If[$CellContext`up$$ == True, $CellContext`triamond$ = 
          Map[Line, {$CellContext`t1$, 
             0.5 $CellContext`over$ + $CellContext`t2$, (-0.5) \
$CellContext`over$ + $CellContext`t2$}], $CellContext`triamond$ = 
          Map[Line, {$CellContext`t1$, 
             0.5 $CellContext`over$ + $CellContext`t2$, $CellContext`over$ + \
$CellContext`t1$}]]; Graphics[
          PrependTo[$CellContext`triamond$, 
           Directive[Thick]], PlotLabel -> "11.4.1"]], 
      "Specifications" :> {{$CellContext`up$$, {False, True}}}, 
      "Options" :> {TrackedSymbols -> {$CellContext`up$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {179., 186.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6028133322080727`*^9, 3.621558842128841*^9, {3.621643715291266*^9, 
   3.621643739297573*^9}, 3.621643787096879*^9, 3.621644125162324*^9, 
   3.621644273482552*^9, 3.6216443377566547`*^9, 3.627678336901181*^9, 
   3.627678433978344*^9, 3.627678913100874*^9, 3.627678971123501*^9, 
   3.6276859829179497`*^9, 3.627686573446315*^9, 3.630631625393104*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.4.2 Tetriamonds (4 connected equilateral triangles)", "Subsubsection",
 CellChangeTimes->{{3.602813255992255*^9, 3.602813269003304*^9}, 
   3.62095509178095*^9}],

Cell["There are 3 possible shapes for the tetriamond.  ", "Text",
 CellChangeTimes->{3.602813375882217*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{t1,t2,up,over,tetriamond,plot},
    Do[t1[i] = Table[N[{Cos[2\[Pi](n+1/4)/3] + \
6*Mod[(i-1),3],Sin[2\[Pi](n+1/4)/3]}],{n,1,4}],{i,1,3}];
    Do[t2[i] = Table[N[{Cos[2\[Pi](n-1/4)/3] + \
6*Mod[(i-1),3],Sin[2\[Pi](n-1/4)/3]-0.5}],{n,1,4}],{i,1,3}];
    up = Table[N[{0,1.5}],{n,1,4}];
    over = 0.5 Table[N[{Sqrt[3],0}],{n,1,4}];
    tetriamond[1] = Map[Line,{t1[1], over + t2[1], - over + t2[1], -2 over + \
t1[1]}];
    tetriamond[2] = Map[Line,{t1[2], over + t2[2], - over + t2[2], up + \
t2[2]}];
    tetriamond[3] = Map[Line,{t1[3], over + t2[3], - over + t2[3], over - up \
+ t1[3]}];
    Do[PrependTo[tetriamond[i],Directive[Thick]],{i,1,3}];
    If[all == True,
      plot = {tetriamond[1],tetriamond[2],tetriamond[3]}, 
      plot = tetriamond[instance]
    ];
    Graphics[plot,BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.4.2\"]
  ],
  {all,{False,True}},
  {instance,{1,2,3},ControlType\[Rule]SetterBar},
  TrackedSymbols\[Rule]{all,instance}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.602813390869729*^9, 3.6028133935292797`*^9}, {
   3.606063712331963*^9, 3.60606378315129*^9}, {3.611106704444119*^9, 
   3.611106707467078*^9}, {3.61231289244489*^9, 3.612312903755637*^9}, 
   3.6209554902584333`*^9, {3.6216421547277327`*^9, 3.621642173390593*^9}, {
   3.6216422041409388`*^9, 3.6216424375166187`*^9}, 3.621642498955158*^9, {
   3.6216425368297567`*^9, 3.62164254715491*^9}, {3.6216426243818493`*^9, 
   3.621642629530271*^9}, {3.621642682319268*^9, 3.621642723980715*^9}, {
   3.6216429009948893`*^9, 3.6216429089561987`*^9}, {3.621642989982362*^9, 
   3.621642990794433*^9}, {3.621643070884008*^9, 3.6216430736452303`*^9}, {
   3.6216431804457817`*^9, 3.62164320473431*^9}, {3.627679056527074*^9, 
   3.6276791010491323`*^9}, {3.627679143059813*^9, 3.627679227512999*^9}, {
   3.627679281311857*^9, 3.6276793447340307`*^9}, 3.6276793972979393`*^9, 
   3.627679433960582*^9, {3.627686155578376*^9, 3.627686231801792*^9}, {
   3.6276865610414133`*^9, 3.627686561389121*^9}, {3.627687605377385*^9, 
   3.6276876078635263`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`all$$ = True, $CellContext`instance$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`all$$], {False, True}}, {
      Hold[$CellContext`instance$$], {1, 2, 3}}}, Typeset`size$$ = {
    500., {86., 101.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`all$14558$$ = 
    False, $CellContext`instance$14559$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`all$$ = False, $CellContext`instance$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`all$$, $CellContext`all$14558$$, False], 
        Hold[$CellContext`instance$$, $CellContext`instance$14559$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t1$, $CellContext`t2$, $CellContext`up$, \
$CellContext`over$, $CellContext`tetriamond$, $CellContext`plot$}, 
        Do[$CellContext`t1$[$CellContext`i] = Table[
            
            N[{Cos[2 Pi ($CellContext`n + 1/4)/3] + 
              6 Mod[$CellContext`i - 1, 3], 
              Sin[2 Pi ($CellContext`n + 1/4)/3]}], {$CellContext`n, 1, 
             4}], {$CellContext`i, 1, 3}]; 
        Do[$CellContext`t2$[$CellContext`i] = Table[
            
            N[{Cos[2 Pi ($CellContext`n - 1/4)/3] + 
              6 Mod[$CellContext`i - 1, 3], 
              Sin[2 Pi ($CellContext`n - 1/4)/3] - 0.5}], {$CellContext`n, 1, 
             4}], {$CellContext`i, 1, 3}]; $CellContext`up$ = Table[
           N[{0, 1.5}], {$CellContext`n, 1, 4}]; $CellContext`over$ = 
         0.5 Table[
            N[{
              Sqrt[3], 0}], {$CellContext`n, 1, 4}]; $CellContext`tetriamond$[
          1] = Map[Line, {
            $CellContext`t1$[
            1], $CellContext`over$ + $CellContext`t2$[
             1], -$CellContext`over$ + $CellContext`t2$[
             1], (-2) $CellContext`over$ + $CellContext`t1$[
             1]}]; $CellContext`tetriamond$[2] = Map[Line, {
            $CellContext`t1$[
            2], $CellContext`over$ + $CellContext`t2$[
             2], -$CellContext`over$ + $CellContext`t2$[
             2], $CellContext`up$ + $CellContext`t2$[
             2]}]; $CellContext`tetriamond$[3] = Map[Line, {
            $CellContext`t1$[
            3], $CellContext`over$ + $CellContext`t2$[
             3], -$CellContext`over$ + $CellContext`t2$[
             3], $CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             3]}]; Do[
          PrependTo[
           $CellContext`tetriamond$[$CellContext`i], 
           Directive[Thick]], {$CellContext`i, 1, 3}]; 
        If[$CellContext`all$$ == True, $CellContext`plot$ = {
            $CellContext`tetriamond$[1], 
            $CellContext`tetriamond$[2], 
            $CellContext`tetriamond$[
            3]}, $CellContext`plot$ = \
$CellContext`tetriamond$[$CellContext`instance$$]]; 
        Graphics[$CellContext`plot$, BaseStyle -> 20, PlotLabel -> "11.4.2"]],
       "Specifications" :> {{$CellContext`all$$, {
         False, True}}, {$CellContext`instance$$, {1, 2, 3}, ControlType -> 
         SetterBar}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`all$$, $CellContext`instance$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {168., 175.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.602813394672653*^9, {3.612312885712928*^9, 3.612312905037155*^9}, 
   3.621558862282486*^9, 3.621642443262998*^9, 3.621642548090617*^9, 
   3.621642632980337*^9, {3.621642715892747*^9, 3.6216427257071333`*^9}, 
   3.6216429111029387`*^9, 3.621642959823348*^9, {3.621642993554962*^9, 
   3.6216430201858253`*^9}, 3.6216431471850357`*^9, {3.621643181552305*^9, 
   3.621643207728978*^9}, 3.627679256308988*^9, 3.627679404952916*^9, 
   3.627679443921628*^9, 3.627680957968732*^9, 3.627685990479823*^9, 
   3.627686090306774*^9, 3.627686166325697*^9, 3.627686233189644*^9, 
   3.627686581426611*^9, 3.627686642307316*^9, 3.630631650021496*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.4.3 Pentiamonds (5 connected equilateral triangles)", "Subsubsection",
 CellChangeTimes->{3.602813270103285*^9, 3.6209550938550463`*^9}],

Cell["There are 4 possible shapes for the pentiamond.  ", "Text",
 CellChangeTimes->{3.6028134418936777`*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{t1,t2,up,over,pentiamond,plot},
    Do[t1[i] = Table[N[{Cos[2\[Pi](n+1/4)/3] + 6 \
Mod[(i-1),4],Sin[2\[Pi](n+1/4)/3]}],{n,1,4}],{i,1,4}];
    Do[t2[i] = Table[N[{Cos[2\[Pi](n-1/4)/3] + 6 \
Mod[(i-1),4],Sin[2\[Pi](n-1/4)/3]-0.5}],{n,1,4}],{i,1,4}];
    up = Table[N[{0,1.5}],{n,1,4}];
    over = 0.5 Table[N[{Sqrt[3],0}],{n,1,4}];
    pentiamond[1] = Map[Line,{t1[1], over + t2[1], 2 over + t1[1], - over + \
t2[1], - 2 over + t1[1]}];
    pentiamond[2] = Map[Line,{t1[2], over + t2[2], 2 over + t1[2], - over + \
t2[2], - over - up + t1[2]}];
    pentiamond[3] = Map[Line,{t1[3], over + t2[3], 2 over + t1[3], - over + \
t2[3], up + t2[3]}];
    pentiamond[4] = Map[Line,{t1[4], over + t2[4], - over + t2[4], - over - \
up + t1[4], - up + t2[4]}];
    Do[PrependTo[pentiamond[i],Directive[Thick]],{i,1,4}];
    If[all == True, 
      plot = {pentiamond[1],pentiamond[2],pentiamond[3],pentiamond[4]}, 
      plot = pentiamond[instance]
    ];
    Graphics[plot,BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.4.3\"]
  ],
  {all,{False,True}},
  {instance,{1,2,3,4},ControlType\[Rule]SetterBar},
  TrackedSymbols\[Rule]{all,instance}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.602813429344171*^9, {3.606063815048395*^9, 3.60606387037184*^9}, {
   3.61110671750537*^9, 3.6111067217671967`*^9}, {3.61231292524485*^9, 
   3.6123129315058928`*^9}, 3.62095550352094*^9, {3.621644409678123*^9, 
   3.6216444339897223`*^9}, {3.621644473180698*^9, 3.6216445607273684`*^9}, 
   3.621644635166542*^9, {3.627679555171733*^9, 3.6276795560970173`*^9}, {
   3.627679597508625*^9, 3.6276796497591867`*^9}, {3.6276866023781633`*^9, 
   3.627686633214293*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`all$$ = True, $CellContext`instance$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`all$$], {False, True}}, {
      Hold[$CellContext`instance$$], {1, 2, 3, 4}}}, Typeset`size$$ = {
    500., {68., 84.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`all$14796$$ = 
    False, $CellContext`instance$14797$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`all$$ = False, $CellContext`instance$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`all$$, $CellContext`all$14796$$, False], 
        Hold[$CellContext`instance$$, $CellContext`instance$14797$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t1$, $CellContext`t2$, $CellContext`up$, \
$CellContext`over$, $CellContext`pentiamond$, $CellContext`plot$}, 
        Do[$CellContext`t1$[$CellContext`i] = Table[
            
            N[{Cos[2 Pi ($CellContext`n + 1/4)/3] + 
              6 Mod[$CellContext`i - 1, 4], 
              Sin[2 Pi ($CellContext`n + 1/4)/3]}], {$CellContext`n, 1, 
             4}], {$CellContext`i, 1, 4}]; 
        Do[$CellContext`t2$[$CellContext`i] = Table[
            
            N[{Cos[2 Pi ($CellContext`n - 1/4)/3] + 
              6 Mod[$CellContext`i - 1, 4], 
              Sin[2 Pi ($CellContext`n - 1/4)/3] - 0.5}], {$CellContext`n, 1, 
             4}], {$CellContext`i, 1, 4}]; $CellContext`up$ = Table[
           N[{0, 1.5}], {$CellContext`n, 1, 4}]; $CellContext`over$ = 
         0.5 Table[
            N[{
              Sqrt[3], 0}], {$CellContext`n, 1, 4}]; $CellContext`pentiamond$[
          1] = Map[Line, {
            $CellContext`t1$[1], $CellContext`over$ + $CellContext`t2$[1], 
            2 $CellContext`over$ + $CellContext`t1$[
             1], -$CellContext`over$ + $CellContext`t2$[
             1], (-2) $CellContext`over$ + $CellContext`t1$[
             1]}]; $CellContext`pentiamond$[2] = Map[Line, {
            $CellContext`t1$[2], $CellContext`over$ + $CellContext`t2$[2], 
            2 $CellContext`over$ + $CellContext`t1$[
             2], -$CellContext`over$ + $CellContext`t2$[
             2], -$CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             2]}]; $CellContext`pentiamond$[3] = Map[Line, {
            $CellContext`t1$[3], $CellContext`over$ + $CellContext`t2$[3], 
            2 $CellContext`over$ + $CellContext`t1$[
             3], -$CellContext`over$ + $CellContext`t2$[
             3], $CellContext`up$ + $CellContext`t2$[
             3]}]; $CellContext`pentiamond$[4] = Map[Line, {
            $CellContext`t1$[
            4], $CellContext`over$ + $CellContext`t2$[
             4], -$CellContext`over$ + $CellContext`t2$[
             4], -$CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             4], -$CellContext`up$ + $CellContext`t2$[4]}]; Do[
          PrependTo[
           $CellContext`pentiamond$[$CellContext`i], 
           Directive[Thick]], {$CellContext`i, 1, 4}]; 
        If[$CellContext`all$$ == True, $CellContext`plot$ = {
            $CellContext`pentiamond$[1], 
            $CellContext`pentiamond$[2], 
            $CellContext`pentiamond$[3], 
            $CellContext`pentiamond$[
            4]}, $CellContext`plot$ = \
$CellContext`pentiamond$[$CellContext`instance$$]]; 
        Graphics[$CellContext`plot$, BaseStyle -> 20, PlotLabel -> "11.4.3"]],
       "Specifications" :> {{$CellContext`all$$, {
         False, True}}, {$CellContext`instance$$, {1, 2, 3, 4}, ControlType -> 
         SetterBar}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`all$$, $CellContext`instance$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {150., 157.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.602813445090749*^9, 3.612312933625977*^9, 
  3.621644579666798*^9, 3.621644635933489*^9, 3.627679523573462*^9, 
  3.627679559177953*^9, 3.62768661398131*^9, 3.627686651414517*^9, 
  3.6306317547408457`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.4.4 Hexiamonds (6 connected equilateral triangles)", "Subsubsection",
 CellChangeTimes->{3.602813270966098*^9, 3.6209550962308397`*^9}],

Cell["There are 12 possible shapes for the hexiamond.  ", "Text",
 CellChangeTimes->{3.6028134681078787`*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{t1,t2,up,over,hexiamond,plot},
    Do[t1[i] = Table[N[{Cos[2\[Pi](n+1/4)/3] + 6 \
Mod[(i-1),4],Sin[2\[Pi](n+1/4)/3] - 6 Floor[(i-1)/4]}],{n,1,4}],{i,1,12}];
    Do[t2[i] = Table[N[{Cos[2\[Pi](n-1/4)/3] + 6 \
Mod[(i-1),4],Sin[2\[Pi](n-1/4)/3] - 0.5 - 6 \
Floor[(i-1)/4]}],{n,1,4}],{i,1,12}];
    up = Table[N[{0,1.5}],{n,1,4}];
    over = 0.5 Table[N[{Sqrt[3],0}],{n,1,4}];
    hexiamond[1] = Map[Line,{t1[1], over + t2[1], 2 over + t1[1], - over + \
t2[1], - 2 over + t1[1], 3 over + t2[1]}];
    hexiamond[2] = Map[Line,{t1[2], over + t2[2], 2 over + t1[2], - over + \
t2[2], over - up + t1[2], 2 over - up + t2[2]}];
    hexiamond[3] = Map[Line,{t1[3], over + t2[3], - over + t2[3], - up + \
t2[3], over -up + t1[3], - over - up + t1[3]}];
    hexiamond[4] = Map[Line,{t1[4], over + t2[4], 2 over + t1[4], - over + \
t2[4], - 2 over + t1[4], up + t2[4]}];
    hexiamond[5] = Map[Line,{t1[5], over + t2[5], 2 over + t1[5], - over + \
t2[5], - 2 over + t1[5], 2 over + up + t2[5]}];
    hexiamond[6] = Map[Line,{t1[6], over + t2[6], - 2 over + t1[6], - over + \
t2[6], - over - up + t1[6], up + t2[6]}];
    hexiamond[7] = Map[Line,{t1[7], over + t2[7], - over + t2[7], - up + \
t2[7], over -up + t1[7], up + t2[7]}];
    hexiamond[8] = Map[Line,{t1[8], over + t2[8], - over + t2[8], 2 over - up \
+ t2[8], over -up + t1[8], 3 over - up + t1[8]}];
    hexiamond[9] = Map[Line,{t1[9], over + t2[9], - over + t2[9], 2 over + \
t1[9], 2 over + up + t2[9], 3 over + up + t1[9]}];
    hexiamond[10] = Map[Line,{t1[10], over + t2[10], 2 over + t1[10], over - \
up + t1[10], up + t2[10], 2 over + up + t2[10]}];
    hexiamond[11] = Map[Line,{t1[11], over + t2[11], - over + t2[11], 2 over \
- up + t2[11], over -up + t1[11], - over - up + t1[11]}];
    hexiamond[12] = Map[Line,{t1[12], over + t2[12], 2 over + t1[12], - over \
+ t2[12], up + t2[12], 3 over + t2[12]}];
    Do[PrependTo[hexiamond[i],Directive[Thick]],{i,1,12}];
    If[all == True, 
      plot = \
{hexiamond[1],hexiamond[2],hexiamond[3],hexiamond[4],hexiamond[5],hexiamond[6]\
,hexiamond[7],hexiamond[8],hexiamond[9],hexiamond[10],hexiamond[11],hexiamond[\
12]}, 
      plot = hexiamond[instance]
    ];
    Graphics[plot,BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.4.4\"]
  ],
  {all,{False,True}},
  {instance,{1,2,3,4,5,6,7,8,9,10,11,12},ControlType\[Rule]SetterBar},
  TrackedSymbols\[Rule]{all,instance}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.602813481144581*^9, {3.606063890627232*^9, 3.606064009152738*^9}, {
   3.606064041259411*^9, 3.6060640678653717`*^9}, {3.611106733869061*^9, 
   3.6111067392925453`*^9}, 3.6123129498485317`*^9, 3.6209555237593107`*^9, {
   3.621644658791518*^9, 3.621644700341641*^9}, {3.621644783983821*^9, 
   3.6216448795427513`*^9}, {3.621644934856443*^9, 3.621644979079534*^9}, 
   3.621645038431003*^9, {3.627679585247272*^9, 3.6276795861217957`*^9}, {
   3.6276796736973743`*^9, 3.627679753220653*^9}, {3.6276866983038387`*^9, 
   3.6276867304659863`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`all$$ = True, $CellContext`instance$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`all$$], {False, True}}, {
      Hold[$CellContext`instance$$], {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
      12}}}, Typeset`size$$ = {500., {184., 200.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`all$15013$$ = False, $CellContext`instance$15014$$ = 
    0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`all$$ = False, $CellContext`instance$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`all$$, $CellContext`all$15013$$, False], 
        Hold[$CellContext`instance$$, $CellContext`instance$15014$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t1$, $CellContext`t2$, $CellContext`up$, \
$CellContext`over$, $CellContext`hexiamond$, $CellContext`plot$}, 
        Do[$CellContext`t1$[$CellContext`i] = Table[
            
            N[{Cos[2 Pi ($CellContext`n + 1/4)/3] + 
              6 Mod[$CellContext`i - 1, 4], 
              Sin[2 Pi ($CellContext`n + 1/4)/3] - 6 
              Floor[($CellContext`i - 1)/4]}], {$CellContext`n, 1, 
             4}], {$CellContext`i, 1, 12}]; 
        Do[$CellContext`t2$[$CellContext`i] = Table[
            
            N[{Cos[2 Pi ($CellContext`n - 1/4)/3] + 
              6 Mod[$CellContext`i - 1, 4], 
              Sin[2 Pi ($CellContext`n - 1/4)/3] - 0.5 - 6 
              Floor[($CellContext`i - 1)/4]}], {$CellContext`n, 1, 
             4}], {$CellContext`i, 1, 12}]; $CellContext`up$ = Table[
           N[{0, 1.5}], {$CellContext`n, 1, 4}]; $CellContext`over$ = 
         0.5 Table[
            N[{
              Sqrt[3], 0}], {$CellContext`n, 1, 4}]; $CellContext`hexiamond$[
          1] = Map[Line, {
            $CellContext`t1$[1], $CellContext`over$ + $CellContext`t2$[1], 
            2 $CellContext`over$ + $CellContext`t1$[
             1], -$CellContext`over$ + $CellContext`t2$[
             1], (-2) $CellContext`over$ + $CellContext`t1$[1], 
            3 $CellContext`over$ + $CellContext`t2$[
             1]}]; $CellContext`hexiamond$[2] = Map[Line, {
            $CellContext`t1$[2], $CellContext`over$ + $CellContext`t2$[2], 
            2 $CellContext`over$ + $CellContext`t1$[
             2], -$CellContext`over$ + $CellContext`t2$[
             2], $CellContext`over$ - $CellContext`up$ + $CellContext`t1$[2], 
            2 $CellContext`over$ - $CellContext`up$ + $CellContext`t2$[
             2]}]; $CellContext`hexiamond$[3] = Map[Line, {
            $CellContext`t1$[
            3], $CellContext`over$ + $CellContext`t2$[
             3], -$CellContext`over$ + $CellContext`t2$[
             3], -$CellContext`up$ + $CellContext`t2$[
             3], $CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             3], -$CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             3]}]; $CellContext`hexiamond$[4] = Map[Line, {
            $CellContext`t1$[4], $CellContext`over$ + $CellContext`t2$[4], 
            2 $CellContext`over$ + $CellContext`t1$[
             4], -$CellContext`over$ + $CellContext`t2$[
             4], (-2) $CellContext`over$ + $CellContext`t1$[
             4], $CellContext`up$ + $CellContext`t2$[
             4]}]; $CellContext`hexiamond$[5] = Map[Line, {
            $CellContext`t1$[5], $CellContext`over$ + $CellContext`t2$[5], 
            2 $CellContext`over$ + $CellContext`t1$[
             5], -$CellContext`over$ + $CellContext`t2$[
             5], (-2) $CellContext`over$ + $CellContext`t1$[5], 
            2 $CellContext`over$ + $CellContext`up$ + $CellContext`t2$[
             5]}]; $CellContext`hexiamond$[6] = Map[Line, {
            $CellContext`t1$[
            6], $CellContext`over$ + $CellContext`t2$[
             6], (-2) $CellContext`over$ + $CellContext`t1$[
             6], -$CellContext`over$ + $CellContext`t2$[
             6], -$CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             6], $CellContext`up$ + $CellContext`t2$[
             6]}]; $CellContext`hexiamond$[7] = Map[Line, {
            $CellContext`t1$[
            7], $CellContext`over$ + $CellContext`t2$[
             7], -$CellContext`over$ + $CellContext`t2$[
             7], -$CellContext`up$ + $CellContext`t2$[
             7], $CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             7], $CellContext`up$ + $CellContext`t2$[
             7]}]; $CellContext`hexiamond$[8] = Map[Line, {
            $CellContext`t1$[
            8], $CellContext`over$ + $CellContext`t2$[
             8], -$CellContext`over$ + $CellContext`t2$[8], 
            2 $CellContext`over$ - $CellContext`up$ + $CellContext`t2$[
             8], $CellContext`over$ - $CellContext`up$ + $CellContext`t1$[8], 
            3 $CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             8]}]; $CellContext`hexiamond$[9] = Map[Line, {
            $CellContext`t1$[
            9], $CellContext`over$ + $CellContext`t2$[
             9], -$CellContext`over$ + $CellContext`t2$[9], 
            2 $CellContext`over$ + $CellContext`t1$[9], 
            2 $CellContext`over$ + $CellContext`up$ + $CellContext`t2$[9], 
            3 $CellContext`over$ + $CellContext`up$ + $CellContext`t1$[
             9]}]; $CellContext`hexiamond$[10] = Map[Line, {
            $CellContext`t1$[10], $CellContext`over$ + $CellContext`t2$[10], 
            2 $CellContext`over$ + $CellContext`t1$[
             10], $CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             10], $CellContext`up$ + $CellContext`t2$[10], 
            2 $CellContext`over$ + $CellContext`up$ + $CellContext`t2$[
             10]}]; $CellContext`hexiamond$[11] = Map[Line, {
            $CellContext`t1$[
            11], $CellContext`over$ + $CellContext`t2$[
             11], -$CellContext`over$ + $CellContext`t2$[11], 
            2 $CellContext`over$ - $CellContext`up$ + $CellContext`t2$[
             11], $CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             11], -$CellContext`over$ - $CellContext`up$ + $CellContext`t1$[
             11]}]; $CellContext`hexiamond$[12] = Map[Line, {
            $CellContext`t1$[12], $CellContext`over$ + $CellContext`t2$[12], 
            2 $CellContext`over$ + $CellContext`t1$[
             12], -$CellContext`over$ + $CellContext`t2$[
             12], $CellContext`up$ + $CellContext`t2$[12], 
            3 $CellContext`over$ + $CellContext`t2$[12]}]; Do[
          PrependTo[
           $CellContext`hexiamond$[$CellContext`i], 
           Directive[Thick]], {$CellContext`i, 1, 12}]; 
        If[$CellContext`all$$ == True, $CellContext`plot$ = {
            $CellContext`hexiamond$[1], 
            $CellContext`hexiamond$[2], 
            $CellContext`hexiamond$[3], 
            $CellContext`hexiamond$[4], 
            $CellContext`hexiamond$[5], 
            $CellContext`hexiamond$[6], 
            $CellContext`hexiamond$[7], 
            $CellContext`hexiamond$[8], 
            $CellContext`hexiamond$[9], 
            $CellContext`hexiamond$[10], 
            $CellContext`hexiamond$[11], 
            $CellContext`hexiamond$[
            12]}, $CellContext`plot$ = \
$CellContext`hexiamond$[$CellContext`instance$$]]; 
        Graphics[$CellContext`plot$, BaseStyle -> 20, PlotLabel -> "11.4.4"]],
       "Specifications" :> {{$CellContext`all$$, {
         False, True}}, {$CellContext`instance$$, {1, 2, 3, 4, 5, 6, 7, 8, 9, 
         10, 11, 12}, ControlType -> SetterBar}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`all$$, $CellContext`instance$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {266., 273.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.621644982148032*^9, 3.621645039197275*^9, 
  3.627679768418645*^9, 3.6276867531927843`*^9, 3.630631778347314*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.5 Polyominoes", "Subsection",
 CellChangeTimes->{3.620955138618662*^9}],

Cell[CellGroupData[{

Cell["11.5.1 Trominoes (3 connected squares)", "Subsubsection",
 CellChangeTimes->{3.620955146042927*^9}],

Cell["There are 2 possible shapes for the tromino.  ", "Text",
 CellChangeTimes->{3.602813540108481*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{t,up,over,tromino},
    t[1] = {{0,0},{1,0},{1,1},{0,1},{0,0}};
    t[2] = t[1] + {{4,0},{4,0},{4,0},{4,0},{4,0}};
    up = Table[N[{0,1}],{n,1,5}];
    over = Table[N[{1,0}],{n,1,5}];
    tromino[1] = Map[Line,{t[1], over + t[1], 2 over + t[1]}];
    tromino[2] = Map[Line,{t[2], over + t[2], up + over + t[2]}];
    Do[PrependTo[tromino[i],Directive[Thick]],{i,1,2}];
    If[all == True, 
      plot = {tromino[1],tromino[2]}, 
      plot = tromino[instance]
    ];
    Graphics[plot,BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.5.1\"]
  ],
  {all,{False,True}},
  {instance,{1,2},ControlType\[Rule]SetterBar},
  TrackedSymbols\[Rule]{all,instance}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.6028135510200577`*^9, {3.60606411089915*^9, 3.606064136580257*^9}, {
   3.611106752417254*^9, 3.611106756054874*^9}, 3.612312993334312*^9, 
   3.620955411232883*^9, {3.621646384316278*^9, 3.621646468677156*^9}, {
   3.6276867873136263`*^9, 3.627686838276039*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`all$$ = True, $CellContext`instance$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`all$$], {False, True}}, {
      Hold[$CellContext`instance$$], {1, 2}}}, Typeset`size$$ = {
    500., {100., 115.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`all$15230$$ = 
    False, $CellContext`instance$15231$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`all$$ = False, $CellContext`instance$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`all$$, $CellContext`all$15230$$, False], 
        Hold[$CellContext`instance$$, $CellContext`instance$15231$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t$, $CellContext`up$, $CellContext`over$, \
$CellContext`tromino$}, $CellContext`t$[1] = {{0, 0}, {1, 0}, {1, 1}, {0, 
          1}, {0, 0}}; $CellContext`t$[
          2] = $CellContext`t$[1] + {{4, 0}, {4, 0}, {4, 0}, {4, 0}, {4, 
           0}}; $CellContext`up$ = Table[
           N[{0, 1}], {$CellContext`n, 1, 5}]; $CellContext`over$ = Table[
           N[{1, 0}], {$CellContext`n, 1, 5}]; $CellContext`tromino$[1] = 
         Map[Line, {
            $CellContext`t$[1], $CellContext`over$ + $CellContext`t$[1], 
            2 $CellContext`over$ + $CellContext`t$[
             1]}]; $CellContext`tromino$[2] = Map[Line, {
            $CellContext`t$[
            2], $CellContext`over$ + $CellContext`t$[
             2], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[2]}]; 
        Do[
          PrependTo[
           $CellContext`tromino$[$CellContext`i], 
           Directive[Thick]], {$CellContext`i, 1, 2}]; 
        If[$CellContext`all$$ == True, $CellContext`plot = {
            $CellContext`tromino$[1], 
            $CellContext`tromino$[
            2]}, $CellContext`plot = \
$CellContext`tromino$[$CellContext`instance$$]]; 
        Graphics[$CellContext`plot, BaseStyle -> 20, PlotLabel -> "11.5.1"]], 
      "Specifications" :> {{$CellContext`all$$, {
         False, True}}, {$CellContext`instance$$, {1, 2}, ControlType -> 
         SetterBar}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`all$$, $CellContext`instance$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {182., 189.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.602813551670238*^9, 3.6123129948101482`*^9, 
  3.621646506592292*^9, 3.627686856172904*^9, 3.63063186332192*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.5.2 Tetrominoes (4 connected squares)", "Subsubsection",
 CellChangeTimes->{3.6209551481686573`*^9}],

Cell["There are 5 possible shapes for the tetromino.  ", "Text",
 CellChangeTimes->{3.602813566296342*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{t,up,over,tetromino},
    Do[t[i] = {{0 + 5 Mod[(i-1),3],0 - 4 Floor[(i-1)/3]},
               {1 + 5 Mod[(i-1),3],0 - 4 Floor[(i-1)/3]},
               {1 + 5 Mod[(i-1),3],1 - 4 Floor[(i-1)/3]},
               {0 + 5 Mod[(i-1),3],1 - 4 Floor[(i-1)/3]},
               {0 + 5 Mod[(i-1),3],0 - 4 Floor[(i-1)/3]}},
      {i,1,5}
    ];
    up = Table[N[{0,1}],{n,1,5}];
    over = Table[N[{1,0}],{n,1,5}];
    tetromino[1] = Map[Line,{t[1], over + t[1], 2 over + t[1], 3 over + t[1]}];
    tetromino[2] = Map[Line,{t[2], over + t[2], 2 over + t[2], up + t[2]}];  
    tetromino[3] = Map[Line,{t[3], over + t[3], 2 over + t[3], over + up + \
t[3]}];
    tetromino[4] = Map[Line,{t[4], over + t[4], up + over + t[4], up + 2 over \
+ t[4]}];
    tetromino[5] = Map[Line,{t[5], over + t[5], up + t[5], up + over + t[5]}];
    Do[PrependTo[tetromino[i],Directive[Thick]],{i,1,5}];
    If[all == True, 
      plot = \
{tetromino[1],tetromino[2],tetromino[3],tetromino[4],tetromino[5]}, 
      plot = tetromino[instance]
    ];
    Graphics[plot,BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.5.2\"]
  ],
  {all,{False,True}},
  {instance,{1,2,3,4,5},ControlType\[Rule]SetterBar},
  TrackedSymbols\[Rule]{all,instance}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.602813581332659*^9, {3.606064164968697*^9, 3.606064220911098*^9}, {
   3.6111067634806147`*^9, 3.611106769915874*^9}, 3.612313002897682*^9, 
   3.620955426695612*^9, {3.6216465841313057`*^9, 3.621646665928007*^9}, {
   3.621646702616844*^9, 3.621646725179306*^9}, {3.6276868696137466`*^9, 
   3.627686980801489*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`all$$ = True, $CellContext`instance$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`all$$], {False, True}}, {
      Hold[$CellContext`instance$$], {1, 2, 3, 4, 5}}}, Typeset`size$$ = {
    500., {130., 146.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`all$15638$$ = 
    False, $CellContext`instance$15639$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`all$$ = False, $CellContext`instance$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`all$$, $CellContext`all$15638$$, False], 
        Hold[$CellContext`instance$$, $CellContext`instance$15639$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t$, $CellContext`up$, $CellContext`over$, \
$CellContext`tetromino$}, 
        Do[$CellContext`t$[$CellContext`i] = {{
            0 + 5 Mod[$CellContext`i - 1, 3], 0 - 4 
             Floor[($CellContext`i - 1)/3]}, {
            1 + 5 Mod[$CellContext`i - 1, 3], 0 - 4 
             Floor[($CellContext`i - 1)/3]}, {
            1 + 5 Mod[$CellContext`i - 1, 3], 1 - 4 
             Floor[($CellContext`i - 1)/3]}, {
            0 + 5 Mod[$CellContext`i - 1, 3], 1 - 4 
             Floor[($CellContext`i - 1)/3]}, {
            0 + 5 Mod[$CellContext`i - 1, 3], 0 - 4 
             Floor[($CellContext`i - 1)/3]}}, {$CellContext`i, 1, 
           5}]; $CellContext`up$ = Table[
           N[{0, 1}], {$CellContext`n, 1, 5}]; $CellContext`over$ = Table[
           N[{1, 0}], {$CellContext`n, 1, 5}]; $CellContext`tetromino$[1] = 
         Map[Line, {
            $CellContext`t$[1], $CellContext`over$ + $CellContext`t$[1], 
            2 $CellContext`over$ + $CellContext`t$[1], 
            3 $CellContext`over$ + $CellContext`t$[
             1]}]; $CellContext`tetromino$[2] = Map[Line, {
            $CellContext`t$[2], $CellContext`over$ + $CellContext`t$[2], 
            2 $CellContext`over$ + $CellContext`t$[
             2], $CellContext`up$ + $CellContext`t$[
             2]}]; $CellContext`tetromino$[3] = Map[Line, {
            $CellContext`t$[3], $CellContext`over$ + $CellContext`t$[3], 
            2 $CellContext`over$ + $CellContext`t$[
             3], $CellContext`over$ + $CellContext`up$ + $CellContext`t$[
             3]}]; $CellContext`tetromino$[4] = Map[Line, {
            $CellContext`t$[
            4], $CellContext`over$ + $CellContext`t$[
             4], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[
             4], $CellContext`up$ + 
            2 $CellContext`over$ + $CellContext`t$[
             4]}]; $CellContext`tetromino$[5] = Map[Line, {
            $CellContext`t$[
            5], $CellContext`over$ + $CellContext`t$[
             5], $CellContext`up$ + $CellContext`t$[
             5], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[5]}]; 
        Do[
          PrependTo[
           $CellContext`tetromino$[$CellContext`i], 
           Directive[Thick]], {$CellContext`i, 1, 5}]; 
        If[$CellContext`all$$ == True, $CellContext`plot = {
            $CellContext`tetromino$[1], 
            $CellContext`tetromino$[2], 
            $CellContext`tetromino$[3], 
            $CellContext`tetromino$[4], 
            $CellContext`tetromino$[
            5]}, $CellContext`plot = \
$CellContext`tetromino$[$CellContext`instance$$]]; 
        Graphics[$CellContext`plot, BaseStyle -> 20, PlotLabel -> "11.5.2"]], 
      "Specifications" :> {{$CellContext`all$$, {
         False, True}}, {$CellContext`instance$$, {1, 2, 3, 4, 5}, 
         ControlType -> SetterBar}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`all$$, $CellContext`instance$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {212., 219.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.602813581920143*^9, 3.612313004106504*^9, 3.6216466746514883`*^9, 
   3.621646726756031*^9, 3.6276869831095123`*^9, {3.630631884347636*^9, 
   3.630631887642017*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.5.3 Pentominoes (5 connected squares)", "Subsubsection",
 CellChangeTimes->{3.620955150093342*^9}],

Cell["There are 12 possible shapes for the pentomino.  ", "Text",
 CellChangeTimes->{3.6028135940715227`*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{t,up,over,pentomino},
    Do[t[i] = {{0 + 6 Mod[(i-1),4],0 - 4 Floor[(i-1)/4]},
               {1 + 6 Mod[(i-1),4],0 - 4 Floor[(i-1)/4]},
               {1 + 6 Mod[(i-1),4],1 - 4 Floor[(i-1)/4]},
               {0 + 6 Mod[(i-1),4],1 - 4 Floor[(i-1)/4]},
               {0 + 6 Mod[(i-1),4],0 - 4 Floor[(i-1)/4]}},
      {i,1,12}
    ];
    up = Table[N[{0,1}],{n,1,5}];
    over = Table[N[{1,0}],{n,1,5}];
    pentomino[1]  = Map[Line,{t[1], over + t[1], 2 over + t[1], 3 over + \
t[1], 4 over + t[1]}];
    pentomino[2]  = Map[Line,{t[2], over + t[2], 2 over + t[2], up + t[2], 2 \
up + t[2]}];
    pentomino[3]  = Map[Line,{t[3], over + t[3], 2 over + t[3], up + t[3], 2 \
over + up + t[3]}];
    pentomino[4]  = Map[Line,{t[4], over + t[4], 2 over + t[4], up + t[4], up \
+ over + t[4]}];
    pentomino[5]  = Map[Line,{t[5], over + t[5], 2 over + t[5], up + t[5], - \
up + 2 over + t[5]}];
    pentomino[6]  = Map[Line,{t[6], over + t[6], 2 over + t[6], up + t[6], - \
up + t[6]}];
    pentomino[7]  = Map[Line,{t[7], over + t[7], 2 over + t[7], 3 over + \
t[7], 2 over + up + t[7]}];
    pentomino[8]  = Map[Line,{t[8], over + t[8], 2 over + t[8], 3 over + \
t[8], up + t[8]}];
    pentomino[9]  = Map[Line,{t[9], over + t[9], over + up + t[9], 2 over + \
up + t[9], over - up + t[9]}];
    pentomino[10] = Map[Line,{t[10], over + t[10], 2 over + t[10], 2 over + \
up + t[10], 3 over + up + t[10]}];
    pentomino[11] = Map[Line,{t[11], over + t[11], over - up + t[11], 2 over \
- up + t[11], up + t[11]}];
    pentomino[12] = Map[Line,{t[12], over + t[12], 2 over + t[12], over - up \
+ t[12], over - 2 up + t[12]}];
    Do[PrependTo[pentomino[i],Directive[Thick]],{i,1,12}];
    If[all == True, 
      plot = \
{pentomino[1],pentomino[2],pentomino[3],pentomino[4],pentomino[5],pentomino[6]\
,pentomino[7],pentomino[8],pentomino[9],pentomino[10],pentomino[11],pentomino[\
12]}, 
      plot = pentomino[instance]
    ];
    Graphics[plot,BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.5.3\"]
  ],
  {all,{False,True}}, 
  {instance,{1,2,3,4,5,6,7,8,9,10,11,12},ControlType\[Rule]SetterBar},
  TrackedSymbols\[Rule]{all,instance}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.602813611170209*^9, {3.606064242751814*^9, 3.606064416549118*^9}, {
   3.611106777281458*^9, 3.6111067817160797`*^9}, 3.612313010923222*^9, 
   3.620955446195219*^9, {3.6216467893587027`*^9, 3.621646930805457*^9}, {
   3.627687039189312*^9, 3.6276871438394814`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`all$$ = True, $CellContext`instance$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`all$$], {False, True}}, {
      Hold[$CellContext`instance$$], {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
      12}}}, Typeset`size$$ = {500., {161., 177.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`all$16046$$ = False, $CellContext`instance$16047$$ = 
    0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`all$$ = False, $CellContext`instance$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`all$$, $CellContext`all$16046$$, False], 
        Hold[$CellContext`instance$$, $CellContext`instance$16047$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t$, $CellContext`up$, $CellContext`over$, \
$CellContext`pentomino$}, 
        Do[$CellContext`t$[$CellContext`i] = {{
            0 + 6 Mod[$CellContext`i - 1, 4], 0 - 4 
             Floor[($CellContext`i - 1)/4]}, {
            1 + 6 Mod[$CellContext`i - 1, 4], 0 - 4 
             Floor[($CellContext`i - 1)/4]}, {
            1 + 6 Mod[$CellContext`i - 1, 4], 1 - 4 
             Floor[($CellContext`i - 1)/4]}, {
            0 + 6 Mod[$CellContext`i - 1, 4], 1 - 4 
             Floor[($CellContext`i - 1)/4]}, {
            0 + 6 Mod[$CellContext`i - 1, 4], 0 - 4 
             Floor[($CellContext`i - 1)/4]}}, {$CellContext`i, 1, 
           12}]; $CellContext`up$ = Table[
           N[{0, 1}], {$CellContext`n, 1, 5}]; $CellContext`over$ = Table[
           N[{1, 0}], {$CellContext`n, 1, 5}]; $CellContext`pentomino$[1] = 
         Map[Line, {
            $CellContext`t$[1], $CellContext`over$ + $CellContext`t$[1], 
            2 $CellContext`over$ + $CellContext`t$[1], 
            3 $CellContext`over$ + $CellContext`t$[1], 
            4 $CellContext`over$ + $CellContext`t$[
             1]}]; $CellContext`pentomino$[2] = Map[Line, {
            $CellContext`t$[2], $CellContext`over$ + $CellContext`t$[2], 
            2 $CellContext`over$ + $CellContext`t$[
             2], $CellContext`up$ + $CellContext`t$[2], 
            2 $CellContext`up$ + $CellContext`t$[
             2]}]; $CellContext`pentomino$[3] = Map[Line, {
            $CellContext`t$[3], $CellContext`over$ + $CellContext`t$[3], 
            2 $CellContext`over$ + $CellContext`t$[
             3], $CellContext`up$ + $CellContext`t$[3], 
            2 $CellContext`over$ + $CellContext`up$ + $CellContext`t$[
             3]}]; $CellContext`pentomino$[4] = Map[Line, {
            $CellContext`t$[4], $CellContext`over$ + $CellContext`t$[4], 
            2 $CellContext`over$ + $CellContext`t$[
             4], $CellContext`up$ + $CellContext`t$[
             4], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[
             4]}]; $CellContext`pentomino$[5] = Map[Line, {
            $CellContext`t$[5], $CellContext`over$ + $CellContext`t$[5], 
            2 $CellContext`over$ + $CellContext`t$[
             5], $CellContext`up$ + $CellContext`t$[5], -$CellContext`up$ + 
            2 $CellContext`over$ + $CellContext`t$[
             5]}]; $CellContext`pentomino$[6] = Map[Line, {
            $CellContext`t$[6], $CellContext`over$ + $CellContext`t$[6], 
            2 $CellContext`over$ + $CellContext`t$[
             6], $CellContext`up$ + $CellContext`t$[
             6], -$CellContext`up$ + $CellContext`t$[
             6]}]; $CellContext`pentomino$[7] = Map[Line, {
            $CellContext`t$[7], $CellContext`over$ + $CellContext`t$[7], 
            2 $CellContext`over$ + $CellContext`t$[7], 
            3 $CellContext`over$ + $CellContext`t$[7], 
            2 $CellContext`over$ + $CellContext`up$ + $CellContext`t$[
             7]}]; $CellContext`pentomino$[8] = Map[Line, {
            $CellContext`t$[8], $CellContext`over$ + $CellContext`t$[8], 
            2 $CellContext`over$ + $CellContext`t$[8], 
            3 $CellContext`over$ + $CellContext`t$[
             8], $CellContext`up$ + $CellContext`t$[
             8]}]; $CellContext`pentomino$[9] = Map[Line, {
            $CellContext`t$[
            9], $CellContext`over$ + $CellContext`t$[
             9], $CellContext`over$ + $CellContext`up$ + $CellContext`t$[9], 
            2 $CellContext`over$ + $CellContext`up$ + $CellContext`t$[
             9], $CellContext`over$ - $CellContext`up$ + $CellContext`t$[
             9]}]; $CellContext`pentomino$[10] = Map[Line, {
            $CellContext`t$[10], $CellContext`over$ + $CellContext`t$[10], 
            2 $CellContext`over$ + $CellContext`t$[10], 
            2 $CellContext`over$ + $CellContext`up$ + $CellContext`t$[10], 
            3 $CellContext`over$ + $CellContext`up$ + $CellContext`t$[
             10]}]; $CellContext`pentomino$[11] = Map[Line, {
            $CellContext`t$[
            11], $CellContext`over$ + $CellContext`t$[
             11], $CellContext`over$ - $CellContext`up$ + $CellContext`t$[11],
             2 $CellContext`over$ - $CellContext`up$ + $CellContext`t$[
             11], $CellContext`up$ + $CellContext`t$[
             11]}]; $CellContext`pentomino$[12] = Map[Line, {
            $CellContext`t$[12], $CellContext`over$ + $CellContext`t$[12], 
            2 $CellContext`over$ + $CellContext`t$[
             12], $CellContext`over$ - $CellContext`up$ + $CellContext`t$[
             12], $CellContext`over$ - 
            2 $CellContext`up$ + $CellContext`t$[12]}]; Do[
          PrependTo[
           $CellContext`pentomino$[$CellContext`i], 
           Directive[Thick]], {$CellContext`i, 1, 12}]; 
        If[$CellContext`all$$ == True, $CellContext`plot = {
            $CellContext`pentomino$[1], 
            $CellContext`pentomino$[2], 
            $CellContext`pentomino$[3], 
            $CellContext`pentomino$[4], 
            $CellContext`pentomino$[5], 
            $CellContext`pentomino$[6], 
            $CellContext`pentomino$[7], 
            $CellContext`pentomino$[8], 
            $CellContext`pentomino$[9], 
            $CellContext`pentomino$[10], 
            $CellContext`pentomino$[11], 
            $CellContext`pentomino$[
            12]}, $CellContext`plot = \
$CellContext`pentomino$[$CellContext`instance$$]]; 
        Graphics[$CellContext`plot, BaseStyle -> 20, PlotLabel -> "11.5.3"]], 
      "Specifications" :> {{$CellContext`all$$, {
         False, True}}, {$CellContext`instance$$, {1, 2, 3, 4, 5, 6, 7, 8, 9, 
         10, 11, 12}, ControlType -> SetterBar}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`all$$, $CellContext`instance$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {243., 250.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.602813611802483*^9, 3.62164694345578*^9, 3.627687151281247*^9, {
   3.63063191232207*^9, 3.630631917810288*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.6 Polyhexes", "Subsection",
 CellChangeTimes->{3.620955156806169*^9}],

Cell[CellGroupData[{

Cell["11.6.1 Trihexes (3 connected regular hexagons)", "Subsubsection",
 CellChangeTimes->{3.6209551597938232`*^9}],

Cell["There are 3 possible shapes for the trihex.  ", "Text",
 CellChangeTimes->{3.602813620371891*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "up", ",", " ", "over", ",", " ", "trihex"}], 
      "}"}], ",", " ", "\n", "     ", 
     RowBox[{
      RowBox[{"Do", "[", "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{
         RowBox[{"t", "[", "i", "]"}], " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "/", "6"}], ")"}], "*", "Pi", "*", 
                 RowBox[{"(", 
                  RowBox[{"n", " ", "-", " ", "1"}], ")"}]}], "]"}], " ", "+",
                " ", 
               RowBox[{"4", "*", "i"}]}], ",", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "/", "6"}], ")"}], "*", "Pi", "*", 
                RowBox[{"(", 
                 RowBox[{"n", " ", "-", " ", "1"}], ")"}]}], "]"}]}], "}"}], 
            "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"n", ",", " ", "1", ",", " ", "7"}], "}"}]}], "]"}]}], 
        ",", " ", "\[IndentingNewLine]", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "3"}], "}"}]}], 
       "\[IndentingNewLine]", " ", "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"up", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"Pi", "/", "3"}], "]"}]}], "}"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"n", ",", " ", "1", ",", " ", "7"}], "}"}]}], "]"}]}], ";", 
      " ", "\n", "     ", 
      RowBox[{"over", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"{", 
           RowBox[{"1.5", ",", " ", "0"}], "}"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"n", ",", " ", "1", ",", " ", "7"}], "}"}]}], "]"}]}], ";", 
      " ", "\n", "     ", 
      RowBox[{
       RowBox[{"trihex", "[", "1", "]"}], " ", "=", " ", 
       RowBox[{"Line", " ", "/@", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"t", "[", "1", "]"}], ",", " ", 
          RowBox[{
           RowBox[{"2", "*", "up"}], " ", "+", " ", 
           RowBox[{"t", "[", "1", "]"}]}], ",", " ", 
          RowBox[{"up", " ", "-", " ", "over", " ", "+", " ", 
           RowBox[{"t", "[", "1", "]"}]}]}], "}"}]}]}], ";", " ", "\n", 
      "     ", 
      RowBox[{
       RowBox[{"trihex", "[", "2", "]"}], " ", "=", " ", 
       RowBox[{"Line", " ", "/@", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"t", "[", "2", "]"}], ",", " ", 
          RowBox[{"up", " ", "-", " ", "over", " ", "+", " ", 
           RowBox[{"t", "[", "2", "]"}]}], ",", " ", 
          RowBox[{"up", " ", "+", " ", "over", " ", "+", " ", 
           RowBox[{"t", "[", "2", "]"}]}]}], "}"}]}]}], ";", " ", "\n", 
      "     ", 
      RowBox[{
       RowBox[{"trihex", "[", "3", "]"}], " ", "=", " ", 
       RowBox[{"Line", " ", "/@", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"t", "[", "3", "]"}], ",", " ", 
          RowBox[{"up", " ", "+", " ", "over", " ", "+", " ", 
           RowBox[{"t", "[", "3", "]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"2", "*", "up"}], " ", "+", " ", 
           RowBox[{"2", "*", "over"}], " ", "+", " ", 
           RowBox[{"t", "[", "3", "]"}]}]}], "}"}]}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"PrependTo", "[", 
         RowBox[{
          RowBox[{"trihex", "[", "i", "]"}], ",", 
          RowBox[{"Directive", "[", "Thick", "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], ";", "\n", 
      "     ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"all", " ", "==", " ", "True"}], ",", " ", 
        "\[IndentingNewLine]", "   ", 
        RowBox[{"plot", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"trihex", "[", "1", "]"}], ",", " ", 
           RowBox[{"trihex", "[", "2", "]"}], ",", " ", 
           RowBox[{"trihex", "[", "3", "]"}]}], "}"}]}], ",", " ", "\n", 
        "           ", 
        RowBox[{"plot", " ", "=", " ", 
         RowBox[{"trihex", "[", "instance", "]"}]}]}], "\[IndentingNewLine]", 
       " ", "]"}], ";", " ", "\[IndentingNewLine]", "  ", 
      RowBox[{"Graphics", "[", 
       RowBox[{"plot", ",", " ", 
        RowBox[{"BaseStyle", "\[Rule]", "20"}], ",", " ", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<11.6.1\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"all", ",", " ", 
     RowBox[{"{", 
      RowBox[{"False", ",", " ", "True"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"instance", ",", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", " ", "2", ",", " ", "3"}], "}"}], ",", " ", 
     RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"all", ",", " ", "instance"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.6029803232651463`*^9, 3.602980323267974*^9}, 
   3.6029803755325813`*^9, 3.60298042365629*^9, {3.606064455109022*^9, 
   3.606064499883985*^9}, {3.611106794049376*^9, 3.611106797348361*^9}, {
   3.611186491346012*^9, 3.611186504525928*^9}, 3.612313032065453*^9, 
   3.620955369447227*^9, {3.621647001057062*^9, 3.6216470301713057`*^9}, {
   3.621647064470951*^9, 3.6216471026593943`*^9}, {3.621647140385047*^9, 
   3.6216471739458857`*^9}, {3.621647213646914*^9, 3.621647436934812*^9}, {
   3.62768719111584*^9, 3.627687204280138*^9}, {3.62768724808005*^9, 
   3.62768736065454*^9}, {3.627687488083152*^9, 3.627687532280223*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`all$$ = True, $CellContext`instance$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`all$$], {False, True}}, {
      Hold[$CellContext`instance$$], {1, 2, 3}}}, Typeset`size$$ = {
    500., {77., 93.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`all$16263$$ = 
    False, $CellContext`instance$16264$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`all$$ = False, $CellContext`instance$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`all$$, $CellContext`all$16263$$, False], 
        Hold[$CellContext`instance$$, $CellContext`instance$16264$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t$, $CellContext`up$, $CellContext`over$, \
$CellContext`trihex$}, Do[$CellContext`t$[$CellContext`i] = Table[
            N[{Cos[(2/6) Pi ($CellContext`n - 1)] + 4 $CellContext`i, 
              Sin[(2/6) Pi ($CellContext`n - 1)]}], {$CellContext`n, 1, 
             7}], {$CellContext`i, 1, 3}]; $CellContext`up$ = Table[
           N[{0, 
             Sin[Pi/3]}], {$CellContext`n, 1, 7}]; $CellContext`over$ = Table[
           N[{1.5, 0}], {$CellContext`n, 1, 7}]; $CellContext`trihex$[1] = 
         Map[Line, {
            $CellContext`t$[1], 
            2 $CellContext`up$ + $CellContext`t$[
             1], $CellContext`up$ - $CellContext`over$ + $CellContext`t$[
             1]}]; $CellContext`trihex$[2] = Map[Line, {
            $CellContext`t$[
            2], $CellContext`up$ - $CellContext`over$ + $CellContext`t$[
             2], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[
             2]}]; $CellContext`trihex$[3] = Map[Line, {
            $CellContext`t$[
            3], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[3], 
            2 $CellContext`up$ + 2 $CellContext`over$ + $CellContext`t$[3]}]; 
        Do[
          PrependTo[
           $CellContext`trihex$[$CellContext`i], 
           Directive[Thick]], {$CellContext`i, 1, 3}]; 
        If[$CellContext`all$$ == True, $CellContext`plot = {
            $CellContext`trihex$[1], 
            $CellContext`trihex$[2], 
            $CellContext`trihex$[
            3]}, $CellContext`plot = \
$CellContext`trihex$[$CellContext`instance$$]]; 
        Graphics[$CellContext`plot, BaseStyle -> 20, PlotLabel -> "11.6.1"]], 
      "Specifications" :> {{$CellContext`all$$, {
         False, True}}, {$CellContext`instance$$, {1, 2, 3}, ControlType -> 
         SetterBar}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`all$$, $CellContext`instance$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {159., 166.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.602980424586605*^9, 3.6123130335730343`*^9, 
  3.6216474604276*^9, 3.627687368425755*^9, 3.627687516717947*^9, 
  3.630631949270505*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.6.2 Tetrahexes (4 connected regular hexagons)", "Subsubsection",
 CellChangeTimes->{3.620955161868675*^9}],

Cell["There are 7 possible shapes for the tetrahex.  ", "Text",
 CellChangeTimes->{3.602813752995996*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{t, up, over, tetrahex},
    Do[
     t[i] = Table[N[{Cos[2\[Pi](n-1)/6] + 7 Mod[(i-1),4],Sin[2\[Pi](n-1)/6] - \
6 Floor[(i-1)/4]}],{n,1,7}]
     ,{i,1,7}
    ];
    up = Table[N[{0,Sin[\[Pi]/3]}],{n,1,7}];
    over = Table[N[{1.5,0}],{n,1,7}];
    tetrahex[1] = Map[Line,{t[1], 2 up + t[1], up - over + t[1], up + over + \
t[1]}];
    tetrahex[2] = Map[Line,{t[2], up + over + t[2], 2 up + 2 over + t[2], - \
up - over + t[2]}];
    tetrahex[3] = Map[Line,{t[3], up - over + t[3], 2 up + t[3], 3 up + over \
+ t[3]}];
    tetrahex[4] = Map[Line,{t[4], 2 up + t[4], - up - over + t[4], - up + \
over + t[4]}];
    tetrahex[5] = Map[Line,{t[5], - up - over + t[5], up + over + t[5], 3 up \
+ over + t[5]}];
    tetrahex[6] = Map[Line,{t[6], up + over + t[6], 2 over + t[6], 2 over - 2 \
up + t[6]}];
    tetrahex[7] = Map[Line,{t[7], up + over + t[7], up - over + t[7], + 2 \
over + t[7]}];
    Do[PrependTo[tetrahex[i],Directive[Thick]],{i,1,7}];
    If[all == True, 
      plot = \
{tetrahex[1],tetrahex[2],tetrahex[3],tetrahex[4],tetrahex[5],tetrahex[6],\
tetrahex[7]}, 
      plot = tetrahex[instance]
    ]; 
    Graphics[plot, BaseStyle\[Rule]20, PlotLabel\[Rule]\"11.6.2\"]
  ],
  {all, {False, True}},
  {instance, {1,2,3,4,5,6,7}, ControlType\[Rule]SetterBar}, 
  TrackedSymbols\[Rule]{all, instance}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{
  3.602813742985276*^9, {3.6060645256223907`*^9, 3.606064599034493*^9}, {
   3.611106806955673*^9, 3.611106814066062*^9}, 3.6123130458852797`*^9, 
   3.620955394645465*^9, {3.621647516537821*^9, 3.621647551708062*^9}, {
   3.621647582847377*^9, 3.6216477521961527`*^9}, 3.6216477829465218`*^9, {
   3.627687393452756*^9, 3.627687478255183*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`all$$ = True, $CellContext`instance$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`all$$], {False, True}}, {
      Hold[$CellContext`instance$$], {1, 2, 3, 4, 5, 6, 7}}}, 
    Typeset`size$$ = {500., {131., 146.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`all$16480$$ = False, $CellContext`instance$16481$$ = 
    0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`all$$ = False, $CellContext`instance$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`all$$, $CellContext`all$16480$$, False], 
        Hold[$CellContext`instance$$, $CellContext`instance$16481$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t$, $CellContext`up$, $CellContext`over$, \
$CellContext`tetrahex$}, Do[$CellContext`t$[$CellContext`i] = Table[
            
            N[{Cos[2 Pi ($CellContext`n - 1)/6] + 
              7 Mod[$CellContext`i - 1, 4], Sin[2 Pi ($CellContext`n - 1)/6] - 
              6 Floor[($CellContext`i - 1)/4]}], {$CellContext`n, 1, 
             7}], {$CellContext`i, 1, 7}]; $CellContext`up$ = Table[
           N[{0, 
             Sin[Pi/3]}], {$CellContext`n, 1, 7}]; $CellContext`over$ = Table[
           N[{1.5, 0}], {$CellContext`n, 1, 7}]; $CellContext`tetrahex$[1] = 
         Map[Line, {
            $CellContext`t$[1], 
            2 $CellContext`up$ + $CellContext`t$[
             1], $CellContext`up$ - $CellContext`over$ + $CellContext`t$[
             1], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[
             1]}]; $CellContext`tetrahex$[2] = Map[Line, {
            $CellContext`t$[
            2], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[2], 
            2 $CellContext`up$ + 
            2 $CellContext`over$ + $CellContext`t$[
             2], -$CellContext`up$ - $CellContext`over$ + $CellContext`t$[
             2]}]; $CellContext`tetrahex$[3] = Map[Line, {
            $CellContext`t$[
            3], $CellContext`up$ - $CellContext`over$ + $CellContext`t$[3], 
            2 $CellContext`up$ + $CellContext`t$[3], 
            3 $CellContext`up$ + $CellContext`over$ + $CellContext`t$[
             3]}]; $CellContext`tetrahex$[4] = Map[Line, {
            $CellContext`t$[4], 
            2 $CellContext`up$ + $CellContext`t$[
             4], -$CellContext`up$ - $CellContext`over$ + $CellContext`t$[
             4], -$CellContext`up$ + $CellContext`over$ + $CellContext`t$[
             4]}]; $CellContext`tetrahex$[5] = Map[Line, {
            $CellContext`t$[
            5], -$CellContext`up$ - $CellContext`over$ + $CellContext`t$[
             5], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[5], 
            3 $CellContext`up$ + $CellContext`over$ + $CellContext`t$[
             5]}]; $CellContext`tetrahex$[6] = Map[Line, {
            $CellContext`t$[
            6], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[6], 
            2 $CellContext`over$ + $CellContext`t$[6], 2 $CellContext`over$ - 
            2 $CellContext`up$ + $CellContext`t$[6]}]; $CellContext`tetrahex$[
          7] = Map[Line, {
            $CellContext`t$[
            7], $CellContext`up$ + $CellContext`over$ + $CellContext`t$[
             7], $CellContext`up$ - $CellContext`over$ + $CellContext`t$[7], 
            Plus[2] $CellContext`over$ + $CellContext`t$[7]}]; Do[
          PrependTo[
           $CellContext`tetrahex$[$CellContext`i], 
           Directive[Thick]], {$CellContext`i, 1, 7}]; 
        If[$CellContext`all$$ == True, $CellContext`plot = {
            $CellContext`tetrahex$[1], 
            $CellContext`tetrahex$[2], 
            $CellContext`tetrahex$[3], 
            $CellContext`tetrahex$[4], 
            $CellContext`tetrahex$[5], 
            $CellContext`tetrahex$[6], 
            $CellContext`tetrahex$[
            7]}, $CellContext`plot = \
$CellContext`tetrahex$[$CellContext`instance$$]]; 
        Graphics[$CellContext`plot, BaseStyle -> 20, PlotLabel -> "11.6.2"]], 
      "Specifications" :> {{$CellContext`all$$, {
         False, True}}, {$CellContext`instance$$, {1, 2, 3, 4, 5, 6, 7}, 
         ControlType -> SetterBar}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`all$$, $CellContext`instance$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {213., 220.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6028137570017138`*^9, 3.612313047106617*^9, {3.621647764770303*^9, 
   3.62164778428734*^9}, 3.6306319713698606`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.7 Miscellaneous Polygons", "Subsection",
 CellChangeTimes->{3.620955171843787*^9}],

Cell[CellGroupData[{

Cell["11.7.1 Reuleaux Polygons", "Subsubsection",
 CellChangeTimes->{3.6209551740938377`*^9}],

Cell[TextData[{
 "For a Reuleaux polygon, the number of sides is always odd.  The figure is \
made by centering a circle on a vertex of the regular polygon of ",
 StyleBox["n",
  FontSlant->"Italic"],
 " sides, letting its radius be the length of the sides of the polygon, and \
then using the arc between the two opposing points as a side of the Reuleaux \
polygon.  Repeat for each of the vertices to get ",
 StyleBox["n",
  FontSlant->"Italic"],
 " connected arcs.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "np", ",", "beta", ",", "v", ",", "r", ",", "q", ",", "alpha", ",", 
       "arc", ",", "rot", ",", "all", ",", "p"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"np", "=", "50"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"beta", "=", 
          RowBox[{"N", "[", 
           RowBox[{"2", "*", 
            RowBox[{"(", 
             RowBox[{"\[Pi]", "/", "n"}], ")"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"v", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"2", "*", "\[Pi]", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"m", "-", "1"}], ")"}], "/", "n"}], ")"}]}], "]"}],
               ",", 
              RowBox[{"Sin", "[", 
               RowBox[{"2", "*", "\[Pi]", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"m", "-", "1"}], ")"}], "/", "n"}], ")"}]}], 
               "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
         RowBox[{"v", "=", 
          RowBox[{"Append", "[", 
           RowBox[{"v", ",", 
            RowBox[{"v", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", "  ", 
         RowBox[{"r", "=", 
          RowBox[{"N", "[", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"v", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
                RowBox[{"v", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], ",", "1"}], 
                  "]"}], "]"}]}], ")"}], "^", "2"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"v", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", 
                RowBox[{"v", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], ",", "2"}], 
                  "]"}], "]"}]}], ")"}], "^", "2"}]}], "]"}], "]"}]}], ";", 
         "  ", 
         RowBox[{"q", "=", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"ArcTan", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"v", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], ",", "1"}], 
                 "]"}], "]"}]}], ",", 
              RowBox[{"v", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], ",", "2"}], 
                "]"}], "]"}]}], "]"}], "-", 
            RowBox[{"ArcTan", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"v", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "/", "2"}], ",", "1"}], 
                 "]"}], "]"}]}], ",", 
              RowBox[{"v", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "+", "1"}], ")"}], "/", "2"}], ",", "2"}], 
                "]"}], "]"}]}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"q", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"q", "<", "0"}], ",", 
            RowBox[{
             RowBox[{"2", "*", "\[Pi]"}], "+", "q"}], ",", "q"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"alpha", "=", 
          RowBox[{"N", "[", 
           RowBox[{"ArcTan", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"v", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
              RowBox[{"v", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], ",", "1"}], 
                "]"}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"v", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", 
              RowBox[{"v", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], ",", "2"}], 
                "]"}], "]"}]}]}], "]"}], "]"}]}], ";", 
         RowBox[{"arc", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"r", "*", 
                RowBox[{"Cos", "[", 
                 RowBox[{"alpha", "+", 
                  RowBox[{"i", "*", 
                   RowBox[{"(", 
                    RowBox[{"q", "/", "np"}], ")"}]}]}], "]"}]}], "+", 
               RowBox[{"v", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], ",", "1"}], 
                 "]"}], "]"}]}], ",", 
              RowBox[{
               RowBox[{"r", "*", 
                RowBox[{"Sin", "[", 
                 RowBox[{"alpha", "+", 
                  RowBox[{"i", "*", 
                   RowBox[{"(", 
                    RowBox[{"q", "/", "np"}], ")"}]}]}], "]"}]}], "+", 
               RowBox[{"v", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "+", "3"}], ")"}], "/", "2"}], ",", "2"}], 
                 "]"}], "]"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", 
              RowBox[{"np", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
         RowBox[{"rot", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Cos", "[", "beta", "]"}], ",", 
              RowBox[{"Sin", "[", "beta", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Sin", "[", "beta", "]"}]}], ",", 
              RowBox[{"Cos", "[", "beta", "]"}]}], "}"}]}], "}"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"all", "=", "arc"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"arc", "=", 
             RowBox[{"arc", ".", "rot"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"all", "=", 
             RowBox[{"Join", "[", 
              RowBox[{"all", ",", "arc"}], "]"}]}]}], "\[IndentingNewLine]", 
           ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", "2", ",", "n"}], "}"}]}], "\[IndentingNewLine]",
           "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"all", "=", 
          RowBox[{"Append", "[", 
           RowBox[{"all", ",", 
            RowBox[{"v", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"p", "[", "n", "]"}], "=", 
          RowBox[{"Graphics", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Thick", ",", 
              RowBox[{"Line", "[", "all", "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{
                RowBox[{"ToString", "[", "n", "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"BaseStyle", "\[Rule]", "24"}]}], "]"}]}], "}"}], ",", 
            RowBox[{"Prolog", "\[Rule]", 
             RowBox[{"AbsoluteThickness", "[", "3", "]"}]}]}], "]"}]}]}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "3", ",", "19", ",", "2"}], "}"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"p", "[", "m", "]"}], ",", 
        RowBox[{"BaseStyle", "\[Rule]", "20"}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<11.7.1\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"m", ",", "3", ",", "19", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "m", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.602814354606032*^9, 3.602814364126733*^9}, {
   3.602814402960945*^9, 3.602814415828511*^9}, {3.6028144548871202`*^9, 
   3.6028144840864363`*^9}, {3.602862066381547*^9, 3.602862076217888*^9}, {
   3.60606465270017*^9, 3.6060648349742317`*^9}, {3.606064867687766*^9, 
   3.6060649977269287`*^9}, {3.606065035233917*^9, 3.606065079413468*^9}, {
   3.6060651125781612`*^9, 3.606065114424555*^9}, 3.606065154789304*^9, {
   3.606065189519001*^9, 3.6060651954568167`*^9}, {3.611106829916483*^9, 
   3.611106834615219*^9}, 3.6111526110654078`*^9, 3.612313060934031*^9, {
   3.612313104019163*^9, 3.612313125605492*^9}, {3.6123131664565287`*^9, 
   3.612313167413233*^9}, {3.612313278995563*^9, 3.612313283717916*^9}, 
   3.620955191297863*^9, {3.621687621316882*^9, 3.621687688622027*^9}, {
   3.62168781131146*^9, 3.621687813472913*^9}, {3.621687849774269*^9, 
   3.621687880044327*^9}, {3.6216879172496767`*^9, 3.621687928097992*^9}, {
   3.627687642229101*^9, 3.62768770641677*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`m$$ = 3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`m$$], 3, 19, 2}}, Typeset`size$$ = {
    500., {259., 275.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`m$16891$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`m$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`m$$, $CellContext`m$16891$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`np$, $CellContext`beta$, $CellContext`v$, \
$CellContext`r$, $CellContext`q$, $CellContext`alpha$, $CellContext`arc$, \
$CellContext`rot$, $CellContext`all$, $CellContext`p$}, $CellContext`np$ = 50; 
        Do[$CellContext`beta$ = N[2 (Pi/$CellContext`n)]; $CellContext`v$ = 
           Table[{
              Cos[2 Pi (($CellContext`m$$ - 1)/$CellContext`n)], 
              Sin[
              2 Pi (($CellContext`m$$ - 
                 1)/$CellContext`n)]}, {$CellContext`m$$, 
              1, $CellContext`n}]; $CellContext`v$ = Append[$CellContext`v$, 
             Part[$CellContext`v$, 1]]; $CellContext`r$ = N[
             
             Sqrt[(Part[$CellContext`v$, 1, 1] - 
                Part[$CellContext`v$, ($CellContext`n + 3)/2, 1])^2 + (
                Part[$CellContext`v$, 1, 2] - 
                Part[$CellContext`v$, ($CellContext`n + 3)/2, 
                 2])^2]]; $CellContext`q$ = 
           N[ArcTan[-1 + Part[$CellContext`v$, ($CellContext`n + 3)/2, 1], 
               Part[$CellContext`v$, ($CellContext`n + 3)/2, 2]] - 
             ArcTan[-1 + Part[$CellContext`v$, ($CellContext`n + 1)/2, 1], 
              Part[$CellContext`v$, ($CellContext`n + 1)/2, 
               2]]]; $CellContext`q$ = 
           If[$CellContext`q$ < 0, 
             2 Pi + $CellContext`q$, $CellContext`q$]; $CellContext`alpha$ = N[
             ArcTan[
             Part[$CellContext`v$, 1, 1] - 
              Part[$CellContext`v$, ($CellContext`n + 3)/2, 1], 
              Part[$CellContext`v$, 1, 2] - 
              Part[$CellContext`v$, ($CellContext`n + 3)/2, 
               2]]]; $CellContext`arc$ = 
           Table[{$CellContext`r$ 
               Cos[$CellContext`alpha$ + $CellContext`i \
($CellContext`q$/$CellContext`np$)] + 
              Part[$CellContext`v$, ($CellContext`n + 3)/2, 
                1], $CellContext`r$ 
               Sin[$CellContext`alpha$ + $CellContext`i \
($CellContext`q$/$CellContext`np$)] + 
              Part[$CellContext`v$, ($CellContext`n + 3)/2, 
                2]}, {$CellContext`i, 0, $CellContext`np$ - 
              1}]; $CellContext`rot$ = {{
              Cos[$CellContext`beta$], 
              Sin[$CellContext`beta$]}, {-Sin[$CellContext`beta$], 
              
              Cos[$CellContext`beta$]}}; $CellContext`all$ = \
$CellContext`arc$; 
          Do[$CellContext`arc$ = 
             Dot[$CellContext`arc$, $CellContext`rot$]; $CellContext`all$ = 
             Join[$CellContext`all$, $CellContext`arc$], {$CellContext`m$$, 
             2, $CellContext`n}]; $CellContext`all$ = 
           Append[$CellContext`all$, 
             Part[$CellContext`v$, 1]]; $CellContext`p$[$CellContext`n] = 
           Graphics[{Thick, 
              Line[$CellContext`all$], 
              Text[
               ToString[$CellContext`n], {0, 0}, BaseStyle -> 24]}, Prolog -> 
             AbsoluteThickness[3]], {$CellContext`n, 3, 19, 2}]; Show[
          $CellContext`p$[$CellContext`m$$], BaseStyle -> 20, PlotLabel -> 
          "11.7.1"]], 
      "Specifications" :> {{$CellContext`m$$, 3, 19, 2, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`m$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {320., 327.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6123131274219837`*^9, 3.612313169871554*^9, 3.61231328485394*^9, 
   3.62168793704422*^9, 3.6276875843645*^9, {3.627687661867951*^9, 
   3.627687707196321*^9}, {3.6306320620525227`*^9, 3.630632070856312*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.7.2 Lune", "Subsubsection",
 CellChangeTimes->{3.6209551771309433`*^9}],

Cell[TextData[{
 "A lune is constructed from two intersecting circles such that one edge is \
concave and the other is convex.  Actually, two lunes are constructed by this \
intersection; they connect at two points.  Here we show only the left-hand \
lune.  Let the radii of the circles be ",
 StyleBox["a",
  FontSlant->"Italic"],
 " and ",
 StyleBox["b",
  FontSlant->"Italic"],
 " and the separation of their centers be ",
 StyleBox["c",
  FontSlant->"Italic"],
 ".  The intersection points are given by\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = -(",
 StyleBox["b",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]]],
 " - ",
 StyleBox["a",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]]],
 " - ",
 StyleBox["c",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]]],
 ")/(2",
 StyleBox["c",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{np,x1,x2,y1,y2,t1,t2,u,v,up,vp},
    np = 500; (*number of points in each arc -- be sure to keep even.*)
    (*Determine the intersection points of the circles.*)
    x1 = -(b^2 - a^2 - c^2)/(2 c);
    y1 = Sqrt[a^2 - x1^2];
    x2 = x1;
    y2 = -y1;
    t1 = ArcTan[x1,y1]//N;
    t2 = ArcTan[x1 - c,y1]//N;
    u = Table[{a Cos[2\[Pi](m - 1)/np],a Sin[2\[Pi](m - 1)/np]},{m,1,np + 1}];
    v = Table[{c + b Cos[2\[Pi](m - 1)/np],b Sin[2\[Pi](m - 1)/np]},{m,1,np + \
1}];
    (*Drop the values on the first circle for -t1 < \[Theta] < t1.*)
    up = {};
    Do[
      If[Abs[ArcTan[u[[i,1]],u[[i,2]]]] > t1,up = Append[up,u[[i]]]],
    {i,1,np + 1}];
    (*Drop the values on the second circle for -t2 < \[Theta] < t2.*)
    vp = {};
    Do[
      If[Abs[ArcTan[v[[i,1]] - c,v[[i,2]]]] > t2,vp = \
Append[vp,v[[i]]]],{i,1,np + 1}
      ];
    Show[Graphics[{Thick,Line[up],Line[vp]},Prolog\[Rule]AbsoluteThickness[3]]\
,PlotRange\[Rule]{{-1,1},{-1,1}},BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.7.2\"]
  ],
  {{a,0.5},0.25,1.0,Appearance\[Rule]\"Labeled\"},
  {{b,0.4},0.25,1.0,Appearance\[Rule]\"Labeled\"},
  {{c,(a+b)/2},Abs[b-a],a+b,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{a,b,c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.6028145832785063`*^9, 3.602814644477029*^9}, {
   3.602814698391802*^9, 3.602814853766466*^9}, {3.602814888216167*^9, 
   3.602814897696505*^9}, {3.60281499298623*^9, 3.602815147408266*^9}, {
   3.6028152660840054`*^9, 3.602815273556888*^9}, {3.602815319371852*^9, 
   3.602815329895196*^9}, {3.6028153951849194`*^9, 3.6028154191082287`*^9}, {
   3.6028154615852613`*^9, 3.602815465483862*^9}, {3.602862272578638*^9, 
   3.6028623034521847`*^9}, {3.602862508355402*^9, 3.602862514153762*^9}, {
   3.602862649431242*^9, 3.602862657142785*^9}, {3.6028627013445387`*^9, 
   3.6028627026051893`*^9}, 3.602863224713462*^9, {3.606065267047904*^9, 
   3.606065267261895*^9}, {3.61110685041003*^9, 3.611106854168317*^9}, 
   3.611161272027562*^9, {3.612313372837346*^9, 3.612313436459865*^9}, {
   3.612313468997994*^9, 3.612313475234069*^9}, 3.620955213670179*^9, {
   3.6276877498026752`*^9, 3.6276877793048677`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.4, $CellContext`c$$ = 
    Rational[1, 2] ($CellContext`a$$ + $CellContext`b$$), Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.25, 1.}, {{
       Hold[$CellContext`b$$], 0.4}, 0.25, 1.}, {{
       Hold[$CellContext`c$$], 
       Rational[1, 2] ($CellContext`a$$ + $CellContext`b$$)}, 
      Dynamic[
       Abs[$CellContext`b$$ - $CellContext`a$$]], 
      Dynamic[$CellContext`a$$ + $CellContext`b$$]}}, Typeset`size$$ = {
    500., {260., 275.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$17115$$ = 
    0, $CellContext`b$17116$$ = 0, $CellContext`c$17117$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.4, $CellContext`c$$ = 
        Rational[1, 2] ($CellContext`a$$ + $CellContext`b$$)}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$17115$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$17116$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$17117$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`np$, $CellContext`x1$, $CellContext`x2$, \
$CellContext`y1$, $CellContext`y2$, $CellContext`t1$, $CellContext`t2$, \
$CellContext`u$, $CellContext`v$, $CellContext`up$, $CellContext`vp$}, \
$CellContext`np$ = 
         500; $CellContext`x1$ = -($CellContext`b$$^2 - $CellContext`a$$^2 - \
$CellContext`c$$^2)/(2 $CellContext`c$$); $CellContext`y1$ = 
         Sqrt[$CellContext`a$$^2 - $CellContext`x1$^2]; $CellContext`x2$ = \
$CellContext`x1$; $CellContext`y2$ = -$CellContext`y1$; $CellContext`t1$ = N[
           ArcTan[$CellContext`x1$, $CellContext`y1$]]; $CellContext`t2$ = N[
           
           ArcTan[$CellContext`x1$ - $CellContext`c$$, $CellContext`y1$]]; \
$CellContext`u$ = 
         Table[{$CellContext`a$$ 
            Cos[2 Pi ($CellContext`m - 1)/$CellContext`np$], $CellContext`a$$ 
            Sin[2 Pi ($CellContext`m - 1)/$CellContext`np$]}, {$CellContext`m,
             1, $CellContext`np$ + 1}]; $CellContext`v$ = 
         Table[{$CellContext`c$$ + $CellContext`b$$ 
             Cos[2 Pi ($CellContext`m - 
                1)/$CellContext`np$], $CellContext`b$$ 
            Sin[2 Pi ($CellContext`m - 1)/$CellContext`np$]}, {$CellContext`m,
             1, $CellContext`np$ + 1}]; $CellContext`up$ = {}; Do[
          If[Abs[
             ArcTan[
              Part[$CellContext`u$, $CellContext`i, 1], 
              
              Part[$CellContext`u$, $CellContext`i, 
               2]]] > $CellContext`t1$, $CellContext`up$ = 
           Append[$CellContext`up$, 
             Part[$CellContext`u$, $CellContext`i]]], {$CellContext`i, 
           1, $CellContext`np$ + 1}]; $CellContext`vp$ = {}; Do[
          If[Abs[
             ArcTan[
             Part[$CellContext`v$, $CellContext`i, 1] - $CellContext`c$$, 
              
              Part[$CellContext`v$, $CellContext`i, 
               2]]] > $CellContext`t2$, $CellContext`vp$ = 
           Append[$CellContext`vp$, 
             Part[$CellContext`v$, $CellContext`i]]], {$CellContext`i, 
           1, $CellContext`np$ + 1}]; Show[
          Graphics[{Thick, 
            Line[$CellContext`up$], 
            Line[$CellContext`vp$]}, Prolog -> AbsoluteThickness[3]], 
          PlotRange -> {{-1, 1}, {-1, 1}}, BaseStyle -> 20, PlotLabel -> 
          "11.7.2"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.25, 1., Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.4}, 0.25, 1., Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 
          Rational[1, 2] ($CellContext`a$$ + $CellContext`b$$)}, 
         Dynamic[
          Abs[$CellContext`b$$ - $CellContext`a$$]], 
         Dynamic[$CellContext`a$$ + $CellContext`b$$], Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {366., 373.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.602814596105744*^9, {3.602814635418858*^9, 3.6028146452853527`*^9}, 
   3.602815159478869*^9, 3.602815275218454*^9, 3.602815334398391*^9, 
   3.6028154214654627`*^9, 3.602815466763402*^9, 3.6028621673418007`*^9, 
   3.6028623058286457`*^9, 3.602862518394459*^9, 3.602862659023098*^9, 
   3.6028627039062357`*^9, 3.602862827019244*^9, 3.612313362646303*^9, {
   3.6123133974660187`*^9, 3.612313437117371*^9}, 3.6123134764179707`*^9, 
   3.627687726755404*^9, 3.627687780855384*^9, 3.6306320887642317`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.7.3 Lens", "Subsubsection",
 CellChangeTimes->{3.6209551787311697`*^9}],

Cell[TextData[{
 "A lens is constructed from two intersecting circles, similar to the lune, \
but such that both edges are convex.  Let the radii of the circles be ",
 StyleBox["a",
  FontSlant->"Italic"],
 " and ",
 StyleBox["b",
  FontSlant->"Italic"],
 " and the separation of their centers be ",
 StyleBox["c",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.627687932714135*^9, 3.627687933677298*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{np,x1,x2,y1,y2,t1,t2,u,v,up,vp},
    np = 500; (*number of points in each arc -- be sure to keep even.*)
    (*Determine the intersection points of the circles.*)
    x1 = -(b^2 - a^2 - c^2)/(2 c);
    y1 = Sqrt[a^2 - x1^2];
    x2 = x1;
    y2 = -y1;
    t1 = ArcTan[x1,y1]//N;
    t2 = ArcTan[x1 - c,y1]//N;
    u = Table[{a Cos[2\[Pi](m - 1)/np],a Sin[2\[Pi](m - 1)/np]},{m,1,np + 1}];
    v = Table[{c + b Cos[2\[Pi](m - 1)/np],b Sin[2\[Pi](m - 1)/np]},{m,1,np + \
1}];
    (*Drop the values on the first circle for |\[Theta]| > t1.*)
    up = {};
    Do[If[Abs[ArcTan[u[[i,1]],u[[i,2]]]] < t1,up = Append[up,u[[i]]]],{i,1,np \
+ 1}];
    (*Need to rotate vector halfway to avoid connecting endpoints on top and \
bottom.*)
    alen = Length[up];
    up = RotateLeft[up,alen/2];
    (*Drop the values on the second circle for -t2 < \[Theta] < t2.*)
    vp = {};
    Do[If[Abs[ArcTan[v[[i,1]] - c,v[[i,2]]]] > t2,vp = \
Append[vp,v[[i]]]],{i,1,np + 1}];
   Show[Graphics[{Thick,Line[up],Line[vp]},Prolog\[Rule]AbsoluteThickness[3]],\
PlotRange\[Rule]{{-1,1},{-1,1}},BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.7.3\"]
  ],
  {{a,0.6},0.25,1.0,Appearance\[Rule]\"Labeled\"},
  {{b,0.8},0.25,1.0,Appearance\[Rule]\"Labeled\"},
  {{c,(a+b)/2},Abs[a-b]+0.01,a+b-0.01,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{a,b,c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.602863080862522*^9, 3.602863099475019*^9}, {
   3.6028631509103823`*^9, 3.602863151586546*^9}, 3.602863191913059*^9, {
   3.602863242536129*^9, 3.6028633339854193`*^9}, 3.602863562088894*^9, {
   3.6028636402146883`*^9, 3.6028636485502863`*^9}, {3.602863737490201*^9, 
   3.602863746476149*^9}, {3.606065274709621*^9, 3.606065274878455*^9}, {
   3.611106866344308*^9, 3.611106869392972*^9}, 3.611161287715147*^9, {
   3.61231349306854*^9, 3.612313518609167*^9}, {3.612313562111204*^9, 
   3.6123135709593287`*^9}, {3.612313616923723*^9, 3.612313626972493*^9}, {
   3.6123136573241053`*^9, 3.612313718997858*^9}, {3.612313827487482*^9, 
   3.612313837685857*^9}, {3.61231388176309*^9, 3.612313983211918*^9}, 
   3.620955302482771*^9, {3.627687803327146*^9, 3.6276878218508883`*^9}, {
   3.627687857700368*^9, 3.627687862812607*^9}, {3.630632149086791*^9, 
   3.630632152097498*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.6, $CellContext`b$$ = 
    0.8, $CellContext`c$$ = 
    Rational[1, 2] ($CellContext`a$$ + $CellContext`b$$), Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.6}, 0.25, 1.}, {{
       Hold[$CellContext`b$$], 0.8}, 0.25, 1.}, {{
       Hold[$CellContext`c$$], 
       Rational[1, 2] ($CellContext`a$$ + $CellContext`b$$)}, 
      Dynamic[Abs[$CellContext`a$$ - $CellContext`b$$] + 0.01], 
      Dynamic[$CellContext`a$$ + $CellContext`b$$ - 0.01]}}, 
    Typeset`size$$ = {500., {260., 275.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`a$17562$$ = 0, $CellContext`b$17563$$ = 
    0, $CellContext`c$17564$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.6, $CellContext`b$$ = 
        0.8, $CellContext`c$$ = 
        Rational[1, 2] ($CellContext`a$$ + $CellContext`b$$)}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$17562$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$17563$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$17564$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`np$, $CellContext`x1$, $CellContext`x2$, \
$CellContext`y1$, $CellContext`y2$, $CellContext`t1$, $CellContext`t2$, \
$CellContext`u$, $CellContext`v$, $CellContext`up$, $CellContext`vp$}, \
$CellContext`np$ = 
         500; $CellContext`x1$ = -($CellContext`b$$^2 - $CellContext`a$$^2 - \
$CellContext`c$$^2)/(2 $CellContext`c$$); $CellContext`y1$ = 
         Sqrt[$CellContext`a$$^2 - $CellContext`x1$^2]; $CellContext`x2$ = \
$CellContext`x1$; $CellContext`y2$ = -$CellContext`y1$; $CellContext`t1$ = N[
           ArcTan[$CellContext`x1$, $CellContext`y1$]]; $CellContext`t2$ = N[
           
           ArcTan[$CellContext`x1$ - $CellContext`c$$, $CellContext`y1$]]; \
$CellContext`u$ = 
         Table[{$CellContext`a$$ 
            Cos[2 Pi ($CellContext`m - 1)/$CellContext`np$], $CellContext`a$$ 
            Sin[2 Pi ($CellContext`m - 1)/$CellContext`np$]}, {$CellContext`m,
             1, $CellContext`np$ + 1}]; $CellContext`v$ = 
         Table[{$CellContext`c$$ + $CellContext`b$$ 
             Cos[2 Pi ($CellContext`m - 
                1)/$CellContext`np$], $CellContext`b$$ 
            Sin[2 Pi ($CellContext`m - 1)/$CellContext`np$]}, {$CellContext`m,
             1, $CellContext`np$ + 1}]; $CellContext`up$ = {}; Do[
          If[Abs[
             ArcTan[
              Part[$CellContext`u$, $CellContext`i, 1], 
              
              Part[$CellContext`u$, $CellContext`i, 
               2]]] < $CellContext`t1$, $CellContext`up$ = 
           Append[$CellContext`up$, 
             Part[$CellContext`u$, $CellContext`i]]], {$CellContext`i, 
           1, $CellContext`np$ + 1}]; $CellContext`alen = 
         Length[$CellContext`up$]; $CellContext`up$ = 
         RotateLeft[$CellContext`up$, $CellContext`alen/
           2]; $CellContext`vp$ = {}; Do[
          If[Abs[
             ArcTan[
             Part[$CellContext`v$, $CellContext`i, 1] - $CellContext`c$$, 
              
              Part[$CellContext`v$, $CellContext`i, 
               2]]] > $CellContext`t2$, $CellContext`vp$ = 
           Append[$CellContext`vp$, 
             Part[$CellContext`v$, $CellContext`i]]], {$CellContext`i, 
           1, $CellContext`np$ + 1}]; Show[
          Graphics[{Thick, 
            Line[$CellContext`up$], 
            Line[$CellContext`vp$]}, Prolog -> AbsoluteThickness[3]], 
          PlotRange -> {{-1, 1}, {-1, 1}}, BaseStyle -> 20, PlotLabel -> 
          "11.7.3"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.6}, 0.25, 1., Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.8}, 0.25, 1., Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 
          Rational[1, 2] ($CellContext`a$$ + $CellContext`b$$)}, 
         Dynamic[Abs[$CellContext`a$$ - $CellContext`b$$] + 0.01], 
         Dynamic[$CellContext`a$$ + $CellContext`b$$ - 0.01], Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {366., 373.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6028633733779488`*^9, 3.602863508944338*^9, 3.602863603009458*^9, 
   3.602863649825172*^9, 3.602863750939994*^9, {3.612313512825802*^9, 
   3.612313519831911*^9}, {3.612313564046871*^9, 3.6123135728485727`*^9}, 
   3.612313627730699*^9, {3.6123137089627132`*^9, 3.6123137360443172`*^9}, 
   3.6123138387081833`*^9, 3.612313885674272*^9, 3.612313942056574*^9, 
   3.6123139838873987`*^9, 3.627687829102921*^9, 3.627687864474572*^9, 
   3.627687947772067*^9, 3.630632120500491*^9, 3.63063215340281*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.7.4 Annulus", "Subsubsection",
 CellChangeTimes->{3.620955180731189*^9}],

Cell[TextData[{
 "The annulus is the area between two concentric circles.  Let the radius of \
the outer circle be ",
 StyleBox["a",
  FontSlant->"Italic"],
 " = 1 and that of the variable-radius inner circle be ",
 StyleBox["b",
  FontSlant->"Italic"],
 ".  "
}], "Text",
 CellChangeTimes->{{3.6028646962358713`*^9, 3.602864768546988*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
Show[Graphics[{{GrayLevel[0.0],Disk[{0,0},1]},{GrayLevel[1.0],Disk[{0,0},b]}},\
Prolog\[Rule]AbsoluteThickness[3]],BaseStyle\[Rule]20,PlotLabel\[Rule]\"11.7.\
4\"],
  {{b,0.8},0,1-0.01,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{b}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.602863847203727*^9, 3.6028639167153378`*^9}, {
   3.602863947590364*^9, 3.602864169754654*^9}, {3.6028642042327642`*^9, 
   3.602864233704976*^9}, {3.6028644748459253`*^9, 3.602864498058763*^9}, {
   3.602864528972056*^9, 3.602864581632921*^9}, {3.60286461434827*^9, 
   3.602864617310135*^9}, {3.602864661122921*^9, 3.602864680008726*^9}, 
   3.6028647972110977`*^9, {3.606065318890815*^9, 3.606065392874998*^9}, {
   3.611106876817751*^9, 3.611106879930709*^9}, 3.611161299177649*^9, {
   3.6123140101133204`*^9, 3.61231406677739*^9}, 3.620955326632077*^9, {
   3.621688043811266*^9, 3.6216880731588383`*^9}, {3.627688027889071*^9, 
   3.6276880531375647`*^9}, {3.630632197347397*^9, 3.630632205496868*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`b$$ = 0.8, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`b$$], 0.8}, 0, 0.99}}, Typeset`size$$ = {
    500., {259., 275.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`b$18158$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`b$$ = 0.8}, 
      "ControllerVariables" :> {
        Hold[$CellContext`b$$, $CellContext`b$18158$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        Graphics[{{
           GrayLevel[0.], 
           Disk[{0, 0}, 1]}, {
           GrayLevel[1.], 
           Disk[{0, 0}, $CellContext`b$$]}}, Prolog -> AbsoluteThickness[3]], 
        BaseStyle -> 20, PlotLabel -> "11.7.4"], 
      "Specifications" :> {{{$CellContext`b$$, 0.8}, 0, 0.99, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`b$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {320., 327.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.602864483605072*^9, 3.602864498772654*^9}, {
   3.602864530389124*^9, 3.602864547005134*^9}, 3.602864583221663*^9, 
   3.602864620572054*^9, {3.602864662600745*^9, 3.602864682300747*^9}, {
   3.602864787925241*^9, 3.602864798463622*^9}, {3.612314017324691*^9, 
   3.612314067634801*^9}, {3.6216880273110447`*^9, 3.6216880739764767`*^9}, 
   3.627688054475922*^9, 3.63063218564122*^9, 3.6306322223305473`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["11.7.5 Yin-Yang", "Subsubsection",
 CellChangeTimes->{3.620955182643763*^9}],

Cell[TextData[{
 "The yin-yang figure is composed of three circles.  The outer circle has \
radius ",
 StyleBox["a",
  FontSlant->"Italic"],
 " = 1, and the two inner circles have radius ",
 StyleBox["a",
  FontSlant->"Italic"],
 "/2 = 1/2.  The two inner circles are adjacent, with centers on the diameter \
of the larger circle.  The outer circle is divided into semicircles of \
opposite colors (often black and white).  Each of the smaller circles are of \
opposite color , arranged such that two final areas of contiguous color \
appear within the area of the outer circle.   "
}], "Text",
 CellChangeTimes->{{3.6028648323490543`*^9, 3.602864886373063*^9}, {
  3.6028653705540237`*^9, 3.602865370939311*^9}, {3.621688171421661*^9, 
  3.621688172283778*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Show[Graphics[{{Thick,Circle[{0,0},1]},{GrayLevel[0.0],Disk[{0,0},1,{\[Pi] \
+ \[Alpha] Degree,2\[Pi] + \[Alpha] \
Degree}]},{GrayLevel[0.0],Disk[{(1/2)*Cos[\[Alpha] Degree],(1/2)*Sin[\[Alpha] \
Degree]},1/2,{0,2\[Pi]}]},{GrayLevel[1.0],Disk[{-(1/2)*Cos[\[Alpha] \
Degree],-(1/2)*Sin[\[Alpha] \
Degree]},1/2,{0,2\[Pi]}]}},Prolog\[Rule]AbsoluteThickness[3]],BaseStyle\[Rule]\
20,PlotLabel\[Rule]\"11.7.5\"],
  {\[Alpha],0,360,10,Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{\[Alpha]}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.602864896410677*^9, 3.602864899010868*^9}, {
   3.602864940089374*^9, 3.602864990736452*^9}, {3.602865036401075*^9, 
   3.602865049636736*^9}, {3.602865119914019*^9, 3.6028651206375237`*^9}, {
   3.602865295565287*^9, 3.602865306790484*^9}, {3.611106887367958*^9, 
   3.611106890668356*^9}, 3.6111613116510687`*^9, {3.612314086113536*^9, 
   3.612314092087367*^9}, 3.6209553458321877`*^9, {3.6276883633889093`*^9, 
   3.627688364349882*^9}, {3.6276884264249897`*^9, 3.627688636737211*^9}, {
   3.627688708963723*^9, 3.6276887686373463`*^9}, {3.627688832411833*^9, 
   3.627688864212329*^9}, {3.6276889195624857`*^9, 3.627689014912167*^9}, {
   3.627689047513565*^9, 3.6276890977619743`*^9}, {3.627689398728404*^9, 
   3.6276894649994*^9}, {3.627690496102088*^9, 3.627690502361333*^9}, {
   3.627690619762373*^9, 3.627690631485898*^9}, {3.62769076031247*^9, 
   3.627690784875256*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`\[Alpha]$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`\[Alpha]$$], 0, 360, 10}}, Typeset`size$$ = {
    500., {259., 275.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`\[Alpha]$18373$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`\[Alpha]$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`\[Alpha]$$, $CellContext`\[Alpha]$18373$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        Graphics[{{Thick, 
           Circle[{0, 0}, 1]}, {
           GrayLevel[0.], 
           
           Disk[{0, 0}, 1, {
            Pi + $CellContext`\[Alpha]$$ Degree, 
             2 Pi + $CellContext`\[Alpha]$$ Degree}]}, {
           GrayLevel[0.], 
           
           Disk[{(1/2) Cos[$CellContext`\[Alpha]$$ Degree], (1/2) 
             Sin[$CellContext`\[Alpha]$$ Degree]}, 1/2, {0, 2 Pi}]}, {
           GrayLevel[1.], 
           
           Disk[{-(1/2) Cos[$CellContext`\[Alpha]$$ Degree], -(1/2) 
             Sin[$CellContext`\[Alpha]$$ Degree]}, 1/2, {0, 2 Pi}]}}, Prolog -> 
         AbsoluteThickness[3]], BaseStyle -> 20, PlotLabel -> "11.7.5"], 
      "Specifications" :> {{$CellContext`\[Alpha]$$, 0, 360, 10, Appearance -> 
         "Labeled"}}, 
      "Options" :> {TrackedSymbols -> {$CellContext`\[Alpha]$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {320., 327.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.602864991441803*^9, 3.602865056174821*^9, 3.6028651250900087`*^9, {
   3.602865296921423*^9, 3.602865309070594*^9}, {3.61231407940285*^9, 
   3.6123140931287613`*^9}, 3.62168810284473*^9, 3.6276883347530737`*^9, 
   3.6276883663313923`*^9, 3.627689103143981*^9, {3.6276894312292023`*^9, 
   3.627689456250111*^9}, 3.627689714227746*^9, 3.6276906326017427`*^9, {
   3.627690761156692*^9, 3.627690785989304*^9}, 3.6306322421490993`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
WindowSize->{936, 1044},
WindowMargins->{{35, Automatic}, {Automatic, 0}},
Magnification:>1.25 Inherited,
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 25, \
2016)",
StyleDefinitions->"myStyles.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 127, 2, 37, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1616, 39, 1094, 20, 247, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[2747, 64, 32, 0, 51, "Section"],
Cell[2782, 66, 589, 9, 132, "Text"],
Cell[CellGroupData[{
Cell[3396, 79, 65, 0, 57, "Subsection"],
Cell[3464, 81, 458, 8, 206, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3959, 94, 120, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[4104, 99, 140, 2, 43, "Subsubsection"],
Cell[4247, 103, 540, 19, 462, "Text"],
Cell[CellGroupData[{
Cell[4812, 126, 3014, 63, 322, "Input"],
Cell[7829, 191, 2865, 55, 753, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[10743, 252, 115, 1, 32, "Subsubsection"],
Cell[10861, 255, 481, 14, 136, "Text"],
Cell[CellGroupData[{
Cell[11367, 273, 4366, 100, 487, "Input"],
Cell[15736, 375, 3255, 64, 983, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[19052, 446, 88, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[19165, 451, 139, 1, 43, "Subsubsection"],
Cell[19307, 454, 178, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[19510, 460, 761, 18, 248, "Input"],
Cell[20274, 480, 2294, 45, 891, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[22617, 531, 134, 1, 32, "Subsubsection"],
Cell[22754, 534, 161, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[22940, 540, 731, 18, 248, "Input"],
Cell[23674, 560, 2480, 49, 891, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[26203, 615, 140, 1, 32, "Subsubsection"],
Cell[26346, 618, 486, 8, 76, "Text"],
Cell[CellGroupData[{
Cell[26857, 630, 1393, 29, 376, "Input"],
Cell[28253, 661, 3324, 65, 788, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[31626, 732, 138, 1, 32, "Subsubsection"],
Cell[31767, 735, 391, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[32183, 746, 1091, 25, 376, "Input"],
Cell[33277, 773, 3226, 63, 443, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[36564, 843, 95, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[36684, 848, 148, 3, 43, "Subsubsection"],
Cell[36835, 853, 177, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[37037, 859, 808, 19, 248, "Input"],
Cell[37848, 880, 2625, 52, 591, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[40522, 938, 233, 5, 32, "Subsubsection"],
Cell[40758, 945, 318, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[41101, 954, 1118, 24, 325, "Input"],
Cell[42222, 980, 3101, 58, 588, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[45372, 1044, 218, 5, 32, "Subsubsection"],
Cell[45593, 1051, 248, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[45866, 1059, 713, 18, 300, "Input"],
Cell[46582, 1079, 2386, 47, 396, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[49017, 1132, 152, 3, 32, "Subsubsection"],
Cell[49172, 1137, 458, 8, 46, "Text"],
Cell[CellGroupData[{
Cell[49655, 1149, 1052, 23, 325, "Input"],
Cell[50710, 1174, 2996, 57, 628, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[53755, 1237, 123, 2, 32, "Subsubsection"],
Cell[53881, 1241, 362, 6, 76, "Text"],
Cell[CellGroupData[{
Cell[54268, 1251, 9436, 229, 900, "Input"],
Cell[63707, 1482, 5411, 98, 991, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[69179, 1587, 82, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[69286, 1592, 141, 1, 43, "Subsubsection"],
Cell[69430, 1595, 300, 5, 76, "Text"],
Cell[CellGroupData[{
Cell[69755, 1604, 1542, 30, 376, "Input"],
Cell[71300, 1636, 3034, 60, 481, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[74383, 1702, 170, 2, 32, "Subsubsection"],
Cell[74556, 1706, 107, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[74688, 1711, 2090, 43, 680, "Input"],
Cell[76781, 1756, 4824, 94, 453, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[81654, 1856, 145, 1, 32, "Subsubsection"],
Cell[81802, 1859, 109, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[81936, 1864, 1688, 37, 705, "Input"],
Cell[83627, 1903, 4887, 94, 408, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[88563, 2003, 144, 1, 32, "Subsubsection"],
Cell[88710, 2006, 109, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[88844, 2011, 3010, 58, 1186, "Input"],
Cell[91857, 2071, 8749, 160, 698, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[100667, 2238, 80, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[100772, 2243, 105, 1, 43, "Subsubsection"],
Cell[100880, 2246, 104, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[101009, 2251, 1007, 26, 502, "Input"],
Cell[102019, 2279, 3366, 66, 488, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[105434, 2351, 109, 1, 32, "Subsubsection"],
Cell[105546, 2354, 106, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[105677, 2359, 1617, 38, 856, "Input"],
Cell[107297, 2399, 4888, 96, 563, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[112234, 2501, 107, 1, 32, "Subsubsection"],
Cell[112344, 2504, 109, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[112478, 2509, 2489, 56, 1261, "Input"],
Cell[114970, 2567, 7707, 142, 641, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[122738, 2716, 78, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[122841, 2721, 115, 1, 43, "Subsubsection"],
Cell[122959, 2724, 103, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[123087, 2729, 6156, 147, 707, "Input"],
Cell[129246, 2878, 3777, 74, 431, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[133072, 2958, 115, 1, 32, "Subsubsection"],
Cell[133190, 2961, 105, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[133320, 2966, 1746, 44, 932, "Input"],
Cell[135069, 3012, 5439, 104, 566, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[140569, 3123, 91, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[140685, 3128, 93, 1, 43, "Subsubsection"],
Cell[140781, 3131, 482, 11, 136, "Text"],
Cell[CellGroupData[{
Cell[141288, 3146, 10448, 262, 982, "Input"],
Cell[151739, 3410, 4882, 95, 833, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[156670, 3511, 80, 1, 32, "Subsubsection"],
Cell[156753, 3514, 1192, 48, 227, "Text"],
Cell[CellGroupData[{
Cell[157970, 3566, 2206, 48, 856, "Input"],
Cell[160179, 3616, 5491, 107, 948, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[165719, 3729, 80, 1, 32, "Subsubsection"],
Cell[165802, 3732, 422, 13, 76, "Text"],
Cell[CellGroupData[{
Cell[166249, 3749, 2301, 49, 882, "Input"],
Cell[168553, 3800, 5650, 109, 948, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[174252, 3915, 81, 1, 32, "Subsubsection"],
Cell[174336, 3918, 340, 10, 76, "Text"],
Cell[CellGroupData[{
Cell[174701, 3932, 1038, 19, 173, "Input"],
Cell[175742, 3953, 2292, 45, 833, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[178083, 4004, 82, 1, 32, "Subsubsection"],
Cell[178168, 4007, 762, 16, 165, "Text"],
Cell[CellGroupData[{
Cell[178955, 4027, 1465, 26, 248, "Input"],
Cell[180423, 4055, 2811, 57, 833, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 7uDtlUPC30tj0BKXmtmq#b@T *)
