(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 10.4' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[    314974,       8518]
NotebookOptionsPosition[    304083,       8135]
NotebookOutlinePosition[    304471,       8152]
CellTagsIndexPosition[    304428,       8149]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Initialization", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.621868553824958*^9}],

Cell["\<\
linestyle = \
{{Thickness[.01],RGBColor[0,0,0]},{Thickness[.01],RGBColor[0,0,0]}};
labelstyle = {Black,20};
axes3D[range_]:= \
Graphics3D[{Thickness[.005],Black,Line[{{-range,0,0},{range,0,0}}],Thickness[\
0.005],Black,Line[{{0,-range,0},{0,range,0}}],Thickness[0.005],Black,Line[{{0,\
0,-range},{0,0,range}}]}];
SetOptions[Plot3D,PlotRange\[Rule]{{-1,1},{-1,1},{-1,1}},Mesh\[Rule]True, \
Boxed\[Rule]True,BoxRatios\[Rule]{1,1,1},Axes\[Rule]True,Ticks\[Rule]\
Automatic,BoxStyle\[Rule]Thickness[.005],LabelStyle\[Rule]labelstyle,\
BaseStyle\[Rule]20,ImageSize\[Rule]400, \
ColorFunction\[Rule]\"GrayTones\",ClippingStyle\[Rule]None];
SetOptions[ParametricPlot3D,PlotRange\[Rule]{{-1,1},{-1,1},{-1,1}},Mesh\[Rule]\
True, Boxed\[Rule]True,BoxRatios\[Rule]{1,1,1},Axes\[Rule]True,Ticks\[Rule]\
Automatic,BoxStyle\[Rule]Thickness[.005],LabelStyle\[Rule]labelstyle,\
BaseStyle\[Rule]20,ImageSize\[Rule]400, ColorFunction\[Rule]\"GrayTones\"];
SetOptions[ContourPlot3D,PlotRange\[Rule]{{-1,1},{-1,1},{-1,1}},Mesh\[Rule]\
True, Boxed\[Rule]True,BoxRatios\[Rule]{1,1,1},Axes\[Rule]True,Ticks\[Rule]\
Automatic,BoxStyle\[Rule]Thickness[.005],LabelStyle\[Rule]labelstyle,\
BaseStyle\[Rule]20,ImageSize\[Rule]400, ColorFunction\[Rule]\"GrayTones\"];
SetOptions[RevolutionPlot3D,PlotRange\[Rule]{{-1,1},{-1,1},{-1,1}},Mesh\[Rule]\
True, Boxed\[Rule]True,BoxRatios\[Rule]{1,1,1},Axes\[Rule]True,Ticks\[Rule]\
Automatic,BoxStyle\[Rule]Thickness[.005],LabelStyle\[Rule]labelstyle,\
BaseStyle\[Rule]20,ImageSize\[Rule]400, ColorFunction\[Rule]\"GrayTones\"];
SetOptions[SphericalPlot3D,PlotRange\[Rule]{{-1,1},{-1,1},{-1,1}},Mesh\[Rule]\
True, Boxed\[Rule]True,BoxRatios\[Rule]{1,1,1},Axes\[Rule]True,Ticks\[Rule]\
Automatic,BoxStyle\[Rule]Thickness[.005],LabelStyle\[Rule]labelstyle,\
BaseStyle\[Rule]20,ImageSize\[Rule]400, ColorFunction\[Rule]\"GrayTones\"];
SetOptions[Manipulate,LabelStyle\[Rule]labelstyle];
SetOptions[Manipulator,LabelStyle\[Rule]labelstyle];
$TextStyle = {FontSize \[Rule]14, FontFamily \[Rule]\"TimesRoman\", \
FontWeight \[Rule] \"Bold\"};
SetOptions[$FrontEnd, DynamicEvaluationTimeout\[Rule]300];\
\>", "Input",
 PageWidth->WindowWidth,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.603389644118922*^9, 3.603389675194922*^9}, 
   3.603389718395277*^9, {3.603389764272524*^9, 3.603389883256543*^9}, {
   3.603501995190625*^9, 3.603501999801301*^9}, {3.603502560791518*^9, 
   3.6035025996978693`*^9}, {3.603502778111023*^9, 3.6035027969238358`*^9}, {
   3.611152721400055*^9, 3.611152721475275*^9}, {3.611161420280561*^9, 
   3.611161436839149*^9}, {3.612400323937862*^9, 3.612400357721422*^9}, {
   3.621868540290799*^9, 3.621868553825193*^9}, {3.6277707356797543`*^9, 
   3.627770787468645*^9}, 3.627813562859367*^9, 3.627813679734172*^9, {
   3.627815212569511*^9, 3.627815213797701*^9}, 3.627910755325472*^9, {
   3.630767829253456*^9, 3.630767840000004*^9}, {3.630767874570943*^9, 
   3.630767903295759*^9}, {3.6308093780531178`*^9, 3.630809383164955*^9}, 
   3.63080946816926*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["13.  Algebraic Surfaces", "Section"],

Cell[TextData[{
 "This chapter treats algebraic surfaces.  Many are extensions of \
two-dimensional curves into three-dimensional space.  Wherever common names \
exist for these surfaces, they are given.  The final two sections deal with \
surfaces that are more easily expressed in polar coordinates or \
parametrically; this facilitates computation of the surfaces more than the \
form ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ").  For surfaces involving radicals, both the positive and negative \
branches are plotted the show the symmetry."
}], "Text",
 CellChangeTimes->{{3.606070975690564*^9, 3.606071064162051*^9}, 
   3.606071124823894*^9, {3.606071183783475*^9, 3.606071266043545*^9}, {
   3.606072098812742*^9, 3.606072224307251*^9}, 3.606245875290773*^9}],

Cell[CellGroupData[{

Cell["13.0  Plotting Information for This Chapter", "Subsection"],

Cell[TextData[{
 "The following forms are plotted in the perspective projection described at \
the beginning of Chapter 12.  There are numerous, different ways to represent \
3-D surfaces.  The method chosen here is a shaded-relief type of \
illustration, with a grid superimposed to show lines of constant ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " on the surface.  The viewpoint of the observer is given as (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 ") coordinates relative to the origin of the projection plane, which is \
coincident with the origin of the surface and normal to the line connecting \
the origin with the observer.  The surfaces are shown in their true aspect \
ratios, and a bounding box is placed about the surface in each case.  In most \
cases this box extends from - 1 to + 1 on both the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " axes.  The ",
 StyleBox["z",
  FontSlant->"Italic"],
 " range is also - 1 to + 1, with a few exceptions as indicated.  The \
surfaces sometimes intersect the top or bottom of the box due to becoming \
unbounded; at these intersections, the surface is truncated at the box \
boundary.\n\nThis chapter uses the objects Plot3D, ParametricPlot3D, and \
other 3-D plotting functions to plot the figures.  Correct use of the \
BoxRatios and PlotRange options attains the true aspect ratios for the \
surfaces.  All boxes, unless otherwise set, are cubes with length = 2 on each \
side, centered on (0,0,0)."
}], "Text",
 CellChangeTimes->{{3.603389922144925*^9, 3.6033899268193808`*^9}, {
  3.6039883107196207`*^9, 3.603988350129706*^9}, {3.606071112289927*^9, 
  3.6060711311024113`*^9}, {3.60607132736692*^9, 3.6060713854964323`*^9}, {
  3.606071434906616*^9, 3.60607146046551*^9}, {3.632319458743803*^9, 
  3.632319459254375*^9}, {3.632319567530201*^9, 3.632319568230049*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.1  Functions with ",
 StyleBox["ax",
  FontSlant->"Italic"],
 " + ",
 StyleBox["by",
  FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
 "13.1.1 ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["ax",
  FontSlant->"Italic"],
 " + ",
 StyleBox["by",
  FontSlant->"Italic"]
}], "Subsubsection",
 CellChangeTimes->{{3.6033900002737827`*^9, 3.603390035808435*^9}, {
   3.603390216226233*^9, 3.603390223160015*^9}, 3.603390303682499*^9, {
   3.6033903559873*^9, 3.603390364823533*^9}}],

Cell["\"plane\"", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", " ", "y"}], "}"}], ",", " ", "\[IndentingNewLine]", 
      RowBox[{"Plot3D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "*", "x"}], " ", "+", " ", 
         RowBox[{"b", "*", "y"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", ",", " ", 
          RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"y", ",", " ", 
          RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", "\n", "     ", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"5", ",", " ", 
           RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
        RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.1.1\>\""}]}], "]"}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0.5"}], "}"}], ",", "0", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"b", ",", "0.5"}], "}"}], ",", "0", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}]}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.603390426329095*^9, 3.603390615590831*^9}, 
   3.603390906156006*^9, {3.6035024646833763`*^9, 3.60350247259505*^9}, {
   3.603502531635304*^9, 3.603502533165942*^9}, {3.603990297962247*^9, 
   3.603990304948954*^9}, {3.6111475116217117`*^9, 3.611147516792617*^9}, {
   3.6111475776805077`*^9, 3.611147580468244*^9}, {3.627770848056061*^9, 
   3.627770874366168*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 0.5, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0, 1}, {{
       Hold[$CellContext`b$$], 0.5}, 0, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$4430$$ = 
    0, $CellContext`b$4431$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$4430$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$4431$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`x$, $CellContext`y$}, 
        Plot3D[$CellContext`a$$ $CellContext`x$ + $CellContext`b$$ \
$CellContext`y$, {$CellContext`x$, -1, 1}, {$CellContext`y$, -1, 1}, 
         ViewPoint -> {5, -6, 4}, ClippingStyle -> None, PlotLabel -> 
         "13.1.1"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.5}, 0, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {334., 341.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.6033905859634123`*^9, 3.603390617611437*^9, 
  3.603501778428595*^9, 3.603502473854932*^9, 3.6035025348542023`*^9, 
  3.612400375193503*^9, 3.620847931119543*^9, 3.627770833212685*^9, 
  3.6277708815323677`*^9, 3.630767756585163*^9, 3.63076779949588*^9, 
  3.63076784990656*^9, 3.6307679211785727`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.1.2 ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = 1/(",
 StyleBox["ax",
  FontSlant->"Italic"],
 " + ",
 StyleBox["by",
  FontSlant->"Italic"],
 ")"
}], "Subsubsection",
 CellChangeTimes->{
  3.603390312244143*^9, {3.603390371211194*^9, 3.603390380497923*^9}, {
   3.6111476039521914`*^9, 3.611147606926714*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "mp", ",", "np", ",", " ", "x", ",", " ", "y", ",", " ", "p1", ",", " ",
        "p2"}], "}"}], ",", "\n", "     ", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "40"}], ";", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "40"}], ";", "\[IndentingNewLine]", 
      RowBox[{"p1", " ", "=", " ", 
       RowBox[{"Plot3D", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", "*", "x"}], " ", "+", " ", 
                RowBox[{"b", "*", "y"}]}], ")"}]}], " ", ">", " ", "0"}], " ",
             "&&", " ", 
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", "*", "x"}], " ", "+", " ", 
                RowBox[{"b", "*", "y"}]}], ")"}]}], " ", "<", " ", 
             "0.999"}]}], ",", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "*", "x"}], " ", "+", " ", 
              RowBox[{"b", "*", "y"}]}], ")"}]}], ",", " ", "999"}], "]"}], 
         ",", " ", 
         RowBox[{"{", 
          RowBox[{"x", ",", " ", 
           RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"y", ",", " ", 
           RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", 
         RowBox[{"PlotPoints", " ", "\[Rule]", " ", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}]}], "]"}]}], ";", " ", "\n", 
      "     ", 
      RowBox[{"p2", " ", "=", " ", 
       RowBox[{"Plot3D", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", "*", "x"}], " ", "+", " ", 
                RowBox[{"b", "*", "y"}]}], ")"}]}], " ", "<", " ", "0"}], " ",
             "&&", " ", 
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"a", "*", "x"}], " ", "+", " ", 
                RowBox[{"b", "*", "y"}]}], ")"}]}], " ", ">", " ", 
             RowBox[{"-", "0.999"}]}]}], ",", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "*", "x"}], " ", "+", " ", 
              RowBox[{"b", "*", "y"}]}], ")"}]}], ",", 
           RowBox[{"-", "999"}]}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"x", ",", " ", 
           RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"y", ",", " ", 
           RowBox[{"-", "1"}], ",", " ", "1"}], "}"}], ",", " ", 
         RowBox[{"PlotPoints", " ", "\[Rule]", " ", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}]}], "]"}]}], ";", " ", "\n", 
      "     ", 
      RowBox[{"Show", "[", 
       RowBox[{"p1", ",", " ", "p2", ",", " ", 
        RowBox[{"ViewPoint", " ", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"6", ",", " ", 
           RowBox[{"-", "4"}], ",", " ", "3"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.1.2\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", " ", "3"}], "}"}], ",", " ", "1", ",", " ", "5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", " ", "3"}], "}"}], ",", " ", "1", ",", " ", "5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.603390837443307*^9, 3.603390841954425*^9}, 
   3.6033908848930807`*^9, {3.6033910502190113`*^9, 3.603391105075016*^9}, {
   3.603391374302187*^9, 3.6033913883582163`*^9}, {3.603391423590807*^9, 
   3.603391450770945*^9}, 3.6033914809136343`*^9, {3.6035021372861767`*^9, 
   3.603502402998571*^9}, 3.603990325648518*^9, {3.6060715004244823`*^9, 
   3.606071510751815*^9}, {3.611147529035635*^9, 3.611147535196024*^9}, {
   3.6111475871836348`*^9, 3.611147599008647*^9}, {3.6111527215050783`*^9, 
   3.611152721576468*^9}, {3.627770910728242*^9, 3.6277709237036448`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 3, $CellContext`b$$ = 3, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 3}, 1, 5}, {{
       Hold[$CellContext`b$$], 3}, 1, 5}}, Typeset`size$$ = {
    500., {276., 291.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$4734$$ = 
    0, $CellContext`b$4735$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 3, $CellContext`b$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$4734$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$4735$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`x$, \
$CellContext`y$, $CellContext`p1$, $CellContext`p2$}, $CellContext`mp$ = 
         40; $CellContext`np$ = 40; $CellContext`p1$ = Plot3D[
           If[
            And[
            1/($CellContext`a$$ $CellContext`x$ + $CellContext`b$$ \
$CellContext`y$) > 0, 
             1/($CellContext`a$$ $CellContext`x$ + $CellContext`b$$ \
$CellContext`y$) < 0.999], 
            1/($CellContext`a$$ $CellContext`x$ + $CellContext`b$$ \
$CellContext`y$), 999], {$CellContext`x$, -1, 1}, {$CellContext`y$, -1, 1}, 
           PlotPoints -> {$CellContext`mp$, $CellContext`np$}]; \
$CellContext`p2$ = Plot3D[
           If[
            And[
            1/($CellContext`a$$ $CellContext`x$ + $CellContext`b$$ \
$CellContext`y$) < 0, 
             1/($CellContext`a$$ $CellContext`x$ + $CellContext`b$$ \
$CellContext`y$) > -0.999], 
            1/($CellContext`a$$ $CellContext`x$ + $CellContext`b$$ \
$CellContext`y$), -999], {$CellContext`x$, -1, 1}, {$CellContext`y$, -1, 1}, 
           PlotPoints -> {$CellContext`mp$, $CellContext`np$}]; 
        Show[$CellContext`p1$, $CellContext`p2$, ViewPoint -> {6, -4, 3}, 
          PlotLabel -> "13.1.2"]], 
      "Specifications" :> {{{$CellContext`a$$, 3}, 1, 5, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 3}, 1, 5, Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {359., 366.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6033908431213217`*^9, 3.60339105913997*^9, {3.60339111065252*^9, 
   3.603391120489114*^9}, {3.6033913894303913`*^9, 3.60339139846758*^9}, 
   3.6035020604471807`*^9, 3.603502412426543*^9, 3.6035028089377117`*^9, {
   3.6124003839878597`*^9, 3.612400398150359*^9}, 3.627770927847314*^9, 
   3.630767931197958*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.2  Functions with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["x",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 "/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["a",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 " \[PlusMinus] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["y",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 "/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["b",
     FontSlant->"Italic"], "2"], TraditionalForm]]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
 "13.2.1 ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["x", "2"], 
    SuperscriptBox["a", "2"]], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["y", "2"], 
    SuperscriptBox["b", "2"]], TraditionalForm]]],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.603502983499951*^9, 3.603503017999949*^9}, {
  3.60350305258571*^9, 3.60350315179879*^9}}],

Cell["\"elliptic paraboloid\"", "Text",
 CellChangeTimes->{{3.619226370261416*^9, 3.61922637076161*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[c*(x^2/a^2 + y^2/b^2), {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4}, PlotLabel\[Rule]\"13.2.1\
\"]
  ],
  {{a,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  {{b,0.25},0.1,1,Appearance\[Rule]\"Labeled\"},
  {{c,0.25},0,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{a,b,c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
   3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
   3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
   3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
   3.603504442664386*^9}, {3.611147547890439*^9, 3.61114756223897*^9}, {
   3.61240043758206*^9, 3.6124004571431704`*^9}, {3.612400504295669*^9, 
   3.6124005113559303`*^9}, {3.612400560795295*^9, 3.612400589243705*^9}, {
   3.627770966500737*^9, 3.6277709837649403`*^9}, 3.627771094062051*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.25, $CellContext`c$$ = 0.25, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`b$$], 0.25}, 0.1, 1}, {{
       Hold[$CellContext`c$$], 0.25}, 0, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$1911$$ = 
    0, $CellContext`b$1912$$ = 0, $CellContext`c$1913$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.25, $CellContext`c$$ = 0.25}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$1911$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$1912$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$1913$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[$CellContext`c$$ ($CellContext`x^2/$CellContext`a$$^2 + \
$CellContext`y^2/$CellContext`b$$^2), {$CellContext`x, -1, 
           1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.2.1"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.25}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.25}, 0, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {357., 364.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603503565856209*^9, 3.6035035742861423`*^9}, {
   3.6035036191129627`*^9, 3.603503633970017*^9}, {3.603503706599737*^9, 
   3.603503722535171*^9}, {3.603504351088819*^9, 3.603504358889732*^9}, 
   3.6124004240046186`*^9, 3.612400458514737*^9, {3.612400492988585*^9, 
   3.612400512030451*^9}, {3.6124005618279657`*^9, 3.6124005901438923`*^9}, 
   3.627770986741097*^9, 3.627771094846834*^9, 3.6308092269382687`*^9, 
   3.6308094851440287`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.2.2  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["x", "2"], 
    SuperscriptBox["a", "2"]], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["y", "2"], 
    SuperscriptBox["b", "2"]], TraditionalForm]]],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.603502983499951*^9, 3.603503017999949*^9}, {
   3.60350305258571*^9, 3.60350315179879*^9}, 3.603503773479087*^9, 
   3.60350527479181*^9, 3.6035652758125467`*^9}],

Cell[TextData[{
 "\"hyperbolic paraboloid\" (commonly called \"saddle\")\nThe surface ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["cxy",
  FontSlant->"Italic"],
 " can be represented by a 45\[Degree] rotation of the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " axes of this plot when ",
 StyleBox["a ",
  FontSlant->"Italic"],
 "= ",
 StyleBox["b",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.60350493553793*^9, 3.60350494379948*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[c*(x^2/a^2 - y^2/b^2), {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4}, PlotLabel\[Rule]\"13.2.2\
\"]
  ],
  {{a,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  {{b,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  {{c,0.5},0.01,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{a,b,c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
   3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
   3.603503702299521*^9}, 3.603503823017981*^9, {3.6035039148668756`*^9, 
   3.603503938942502*^9}, {3.6035042028336973`*^9, 3.6035042103186913`*^9}, {
   3.603504334507169*^9, 3.603504335757142*^9}, {3.603504392746504*^9, 
   3.603504392750226*^9}, {3.6111476702053337`*^9, 3.6111476772646523`*^9}, {
   3.627771003275702*^9, 3.627771062286748*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.5, $CellContext`c$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`b$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`c$$], 0.5}, 0.01, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$2930$$ = 
    0, $CellContext`b$2931$$ = 0, $CellContext`c$2932$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.5, $CellContext`c$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$2930$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2931$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2932$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[$CellContext`c$$ ($CellContext`x^2/$CellContext`a$$^2 - \
$CellContext`y^2/$CellContext`b$$^2), {$CellContext`x, -1, 
           1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.2.2"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.5}, 0.01, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {357., 364.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603503829080367*^9, 3.603503848432972*^9}, {
   3.603503901382059*^9, 3.603503903715413*^9}, {3.60350393392992*^9, 
   3.6035039404173603`*^9}, 3.603503981298808*^9, 3.612400521887721*^9, 
   3.627771103624763*^9, 3.630809283386972*^9, 3.63080949169396*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.2.3  1 = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["x", "2"], 
    SuperscriptBox["a", "2"]], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["y", "2"], 
    SuperscriptBox["b", "2"]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.603502983499951*^9, 3.603503017999949*^9}, {
   3.60350305258571*^9, 3.60350315179879*^9}, {3.6035040702938337`*^9, 
   3.6035040863436203`*^9}, 3.603505277602076*^9, 3.6035652774994497`*^9}],

Cell["\"elliptic cylinder\"", "Text",
 CellChangeTimes->{{3.6192265539749203`*^9, 3.6192265541610117`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 21;
    ParametricPlot3D[{a Cos[v],b Sin[v],u},{u,-1,1},{v,0,2\[Pi]}, PlotPoints\
\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4}, PlotLabel\[Rule]\"13.2.3\"]
  ],
  {{a,0.5},0.1,1},
  {{b,0.5},0.1,1},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{a,b}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
   3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
   3.603503702299521*^9}, 3.603503823017981*^9, {3.6035039148668756`*^9, 
   3.603503938942502*^9}, {3.603504159947432*^9, 3.603504171793282*^9}, {
   3.6035043077710733`*^9, 3.6035043271195803`*^9}, {3.6035043792626667`*^9, 
   3.603504379264924*^9}, {3.603504500949629*^9, 3.60350450389589*^9}, {
   3.611147695317953*^9, 3.611147700866373*^9}, {3.6277711204489183`*^9, 
   3.6277711291116*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 0.5, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`b$$], 0.5}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$3165$$ = 
    0, $CellContext`b$3166$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$3165$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$3166$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 21; 
        ParametricPlot3D[{$CellContext`a$$ 
           Cos[$CellContext`v], $CellContext`b$$ 
           Sin[$CellContext`v], $CellContext`u}, {$CellContext`u, -1, 
           1}, {$CellContext`v, 0, 2 Pi}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.2.3"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.1, 
         1}, {{$CellContext`b$$, 0.5}, 0.1, 1}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {333., 340.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.603504248777947*^9, 3.6035043101971283`*^9, 
  3.603504454296691*^9, 3.612400533287717*^9, 3.6277711412773247`*^9, 
  3.630809308604439*^9, 3.630809497952104*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.2.4  1 = ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["x", "2"], 
    SuperscriptBox["a", "2"]], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["y", "2"], 
    SuperscriptBox["b", "2"]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.603502983499951*^9, 3.603503017999949*^9}, {
   3.60350305258571*^9, 3.60350315179879*^9}, {3.6035040702938337`*^9, 
   3.6035040863436203`*^9}, 3.6035045525728397`*^9, 3.603505280089675*^9, 
   3.603565278899103*^9}],

Cell["\"hyperbolic cylinder\"", "Text",
 CellChangeTimes->{{3.619226612088031*^9, 3.619226612336513*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np,p1,p2},
    mp = 50;
    np = 21;
    p1 = ParametricPlot3D[{a Sec[v],b \
Tan[v],u},{u,-1,1},{v,-\[Pi]/2,\[Pi]/2}, PlotPoints\[Rule]{mp,np}];
    p2 = ParametricPlot3D[{a Sec[v],b \
Tan[v],u},{u,-1,1},{v,\[Pi]/2,3\[Pi]/2}, PlotPoints\[Rule]{mp,np}];
    Show[p1,p2,ViewPoint\[Rule]{4,-6,3}, PlotLabel\[Rule]\"13.2.4\"]
  ],
  {{a,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  {{b,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{a,b}
]
\
\>", "Input",
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
   3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
   3.603503702299521*^9}, 3.603503823017981*^9, {3.6035039148668756`*^9, 
   3.603503938942502*^9}, {3.603504159947432*^9, 3.603504171793282*^9}, {
   3.6035043077710733`*^9, 3.6035043271195803`*^9}, {3.6035043792626667`*^9, 
   3.603504379264924*^9}, {3.603504500949629*^9, 3.60350450389589*^9}, {
   3.603504579735414*^9, 3.60350460853428*^9}, {3.603504727237754*^9, 
   3.6035047614110947`*^9}, {3.6035047922756643`*^9, 3.603504872248816*^9}, {
   3.611147718078871*^9, 3.611147722854265*^9}, 3.611152721657633*^9, {
   3.627771153525104*^9, 3.627771166153326*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 0.5, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`b$$], 0.5}, 0.1, 1}}, Typeset`size$$ = {
    500., {276., 291.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$3673$$ = 
    0, $CellContext`b$3674$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$3673$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$3674$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`p1$, \
$CellContext`p2$}, $CellContext`mp$ = 50; $CellContext`np$ = 
         21; $CellContext`p1$ = 
         ParametricPlot3D[{$CellContext`a$$ 
            Sec[$CellContext`v], $CellContext`b$$ 
            Tan[$CellContext`v], $CellContext`u}, {$CellContext`u, -1, 
            1}, {$CellContext`v, -Pi/2, Pi/2}, 
           PlotPoints -> {$CellContext`mp$, $CellContext`np$}]; \
$CellContext`p2$ = 
         ParametricPlot3D[{$CellContext`a$$ 
            Sec[$CellContext`v], $CellContext`b$$ 
            Tan[$CellContext`v], $CellContext`u}, {$CellContext`u, -1, 
            1}, {$CellContext`v, Pi/2, 3 Pi/2}, 
           PlotPoints -> {$CellContext`mp$, $CellContext`np$}]; 
        Show[$CellContext`p1$, $CellContext`p2$, ViewPoint -> {4, -6, 3}, 
          PlotLabel -> "13.2.4"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {359., 366.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.60350463477322*^9, {3.603504674168611*^9, 3.603504694743927*^9}, {
   3.603504873697822*^9, 3.603504885365045*^9}, 3.61240054172965*^9, 
   3.6277711672598057`*^9, 3.630809539961761*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.3  Functions with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        StyleBox["x",
         FontSlant->"Italic"], "2"], "/", 
       SuperscriptBox[
        StyleBox["a",
         FontSlant->"Italic"], "2"]}], " ", "+", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         StyleBox["y",
          FontSlant->"Italic"], "2"], "/", 
        SuperscriptBox[
         StyleBox["b",
          FontSlant->"Italic"], "2"]}], " ", "\[PlusMinus]", " ", 
       SuperscriptBox[
        StyleBox["c",
         FontSlant->"Italic"], "2"]}]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
 "13.3.1  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", 
      SuperscriptBox["x", "2"], " ", "-", " ", 
      SuperscriptBox["y", "2"]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.60350530483228*^9, 3.6035054314931498`*^9}, 
   3.603562287462956*^9}],

Cell[TextData[{
 "\"sphere\" (special case of the ellipsoid)\nParametrically, ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")."
}], "Text",
 CellChangeTimes->{3.603505035337357*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
 Module[{},
  ParametricPlot3D[c{Sin[u] Cos[v], Sin[u] Sin[v], Cos[u]},
{u,0,\[Pi]}, {v,0,2\[Pi]}, ViewPoint\[Rule]{4,-5,2}, PlotLabel\[Rule]\"13.3.1\
\"]
 ],
 {{c,0.9},0.1,1,Appearance\[Rule]\"Labeled\"},
 ContinuousAction\[Rule]False,
 TrackedSymbols\[Rule]{c}
]\
\>", "Input",
 CellChangeTimes->{{3.603505083126355*^9, 3.603505143826326*^9}, {
  3.6035615385036373`*^9, 3.603561538507615*^9}, {3.611147757266281*^9, 
  3.61114776381497*^9}, {3.621714710183879*^9, 3.6217147376937447`*^9}, {
  3.621714774769389*^9, 3.621714775018811*^9}, {3.627771273788137*^9, 
  3.627771367561254*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 0.9, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 0.9}, 0.1, 1}}, Typeset`size$$ = {
    500., {260., 276.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$352$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 0.9}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$352$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Module[{}, 
        ParametricPlot3D[$CellContext`c$$ {
          Sin[$CellContext`u] Cos[$CellContext`v], Sin[$CellContext`u] 
           Sin[$CellContext`v], 
           Cos[$CellContext`u]}, {$CellContext`u, 0, Pi}, {$CellContext`v, 0, 
          2 Pi}, ViewPoint -> {4, -5, 2}, PlotLabel -> "13.3.1"]], 
      "Specifications" :> {{{$CellContext`c$$, 0.9}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {321., 328.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.603505149852427*^9, 3.612400615546176*^9, {3.621714768394927*^9, 
   3.621714776581065*^9}, 3.627771212792636*^9, {3.627771303933763*^9, 
   3.6277713268108*^9}, 3.6308096324117126`*^9, 3.6308105718656397`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.3.2  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", 
      FractionBox[
       SuperscriptBox["x", "2"], 
       SuperscriptBox["a", "2"]], " ", "-", " ", 
      FractionBox[
       SuperscriptBox["y", "2"], 
       SuperscriptBox["b", "2"]]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.60350530483228*^9, 3.6035054314931498`*^9}, {
   3.603505491549569*^9, 3.6035055149194307`*^9}, 3.603505626932069*^9, 
   3.603561152905218*^9, 3.603562285012985*^9}],

Cell[TextData[{
 "\"ellipsoid\"\nParametrically, ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 ").  With ",
 StyleBox["a",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 " and ",
 StyleBox["c",
  FontSlant->"Italic"],
 " > {",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"],
 "}, the ellipsoid is called \[OpenCurlyDoubleQuote]prolate\
\[CloseCurlyDoubleQuote]; with ",
 StyleBox["a",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 " and ",
 StyleBox["c",
  FontSlant->"Italic"],
 " < {",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"],
 "}, the ellipsoid is called \[OpenCurlyDoubleQuote]oblate\
\[CloseCurlyDoubleQuote]."
}], "Text",
 CellChangeTimes->{
  3.603505521341219*^9, {3.603505788869813*^9, 3.603505871045102*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "50"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"Sin", "[", "u", "]"}], " ", 
            RowBox[{"Cos", "[", "v", "]"}]}], ",", 
           RowBox[{"b", " ", 
            RowBox[{"Sin", "[", "u", "]"}], " ", 
            RowBox[{"Sin", "[", "v", "]"}]}], ",", 
           RowBox[{"c", " ", 
            RowBox[{"Cos", "[", "u", "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.3.2\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0.5"}], "}"}], ",", "0.1", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"b", ",", "0.75"}], "}"}], ",", "0.1", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "0.9"}], "}"}], ",", "0.1", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}], "\n", "]"}], 
  "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
  3.603505701887616*^9, 3.603505717213767*^9}, {3.611147778086692*^9, 
  3.611147781483927*^9}, {3.612400643149857*^9, 3.612400661249611*^9}, {
  3.627771236427038*^9, 3.6277712604906197`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.75, $CellContext`c$$ = 0.9, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`b$$], 0.75}, 0.1, 1}, {{
       Hold[$CellContext`c$$], 0.9}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$4614$$ = 
    0, $CellContext`b$4615$$ = 0, $CellContext`c$4616$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.75, $CellContext`c$$ = 0.9}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$4614$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$4615$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$4616$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 21; 
        ParametricPlot3D[{$CellContext`a$$ Sin[$CellContext`u] 
           Cos[$CellContext`v], $CellContext`b$$ Sin[$CellContext`u] 
           Sin[$CellContext`v], $CellContext`c$$ 
           Cos[$CellContext`u]}, {$CellContext`u, 0, Pi}, {$CellContext`v, 0, 
           2 Pi}, PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.3.2"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.75}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.9}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {357., 364.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.603505675607766*^9, {3.6035057198608313`*^9, 3.603505730583605*^9}, {
   3.603560166482728*^9, 3.603560171061013*^9}, {3.612400621554357*^9, 
   3.612400662012664*^9}, 3.6308096593490047`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.3.3  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", "+", " ", 
      SuperscriptBox["y", "2"]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.603560222836543*^9, 3.603560228495143*^9}, {
  3.603560289636011*^9, 3.603560501298532*^9}, {3.603560702044285*^9, 
  3.603560702044379*^9}, {3.603561159704406*^9, 3.603561159704494*^9}}],

Cell[TextData[{
 "\"circular cone\" (special case of the elliptic cone)\nParametrically, ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["u",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["u",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["u",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 21;
    ParametricPlot3D[{u Cos[v], u Sin[v], c u},{u,-1,1},{v,0,2\[Pi]}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4}, PlotLabel\[Rule]\"13.3.3\
\"]
  ],
  {{c,1},0.1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{c}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603560544712758*^9, 3.603560554938857*^9}, {
   3.6035605922178917`*^9, 3.603560669089592*^9}, {3.611147788379285*^9, 
   3.611147791091885*^9}, {3.612400692945957*^9, 3.612400698207005*^9}, {
   3.627771399362895*^9, 3.6277714048786793`*^9}, 3.62777155935441*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 1}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$5007$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$5007$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 21; 
        ParametricPlot3D[{$CellContext`u Cos[$CellContext`v], $CellContext`u 
           Sin[$CellContext`v], $CellContext`c$$ $CellContext`u}, \
{$CellContext`u, -1, 1}, {$CellContext`v, 0, 2 Pi}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.3.3"]], 
      "Specifications" :> {{{$CellContext`c$$, 1}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {312., 319.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603560673334622*^9, 3.603560684857854*^9}, {
   3.61240067145365*^9, 3.612400699006126*^9}, 3.6277714200267887`*^9, 
   3.627771563902994*^9, 3.630809683480608*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.3.4  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["x", "2"], 
       SuperscriptBox["a", "2"]], " ", "+", " ", 
      FractionBox[
       SuperscriptBox["y", "2"], 
       SuperscriptBox["b", "2"]]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.603560222836543*^9, 3.603560228495143*^9}, {
  3.603560289636011*^9, 3.603560501298532*^9}, {3.603560702044285*^9, 
  3.603560702044379*^9}, {3.603560739528372*^9, 3.60356076769265*^9}, {
  3.603561165971531*^9, 3.6035611659716253`*^9}}],

Cell[TextData[{
 "\"elliptic cone\"  (circular cone if ",
 StyleBox["a",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 ")\nParametrically, ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), y = ",
 StyleBox["b",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{
  3.6035607712009706`*^9, {3.6035608231969967`*^9, 3.603560833229381*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", " ", "np", ",", " ", "umax"}], "}"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "50"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "21"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"umax", " ", "=", " ", 
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{"1", "/", "a"}], ",", " ", 
         RowBox[{"1", "/", "b"}]}], "]"}]}], ";", " ", "\n", "     ", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", "*", "u", "*", 
           RowBox[{"Cos", "[", "v", "]"}]}], ",", " ", 
          RowBox[{"b", "*", "u", "*", 
           RowBox[{"Sin", "[", "v", "]"}]}], ",", " ", 
          RowBox[{"c", "*", "u"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"u", ",", " ", 
          RowBox[{"-", "umax"}], ",", " ", "umax"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"v", ",", " ", "0", ",", " ", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", " ", "\n", "     ", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", " ", "np"}], "}"}]}], ",", " ", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"5", ",", " ", 
           RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.3.4\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", " ", "0.25"}], "}"}], ",", " ", "0.1", ",", " ", "1", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", " ", "0.75"}], "}"}], ",", " ", "0.1", ",", " ", "1", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "1"}], "}"}], ",", " ", "0.1", ",", " ", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", "\n", "  ", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", " ", "b", ",", " ", "c"}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
  3.603505701887616*^9, 3.603505717213767*^9}, {3.603560904363338*^9, 
  3.603560924201836*^9}, {3.6035609604643917`*^9, 3.603561032106309*^9}, {
  3.6035614877333927`*^9, 3.603561503478368*^9}, {3.6035616706121187`*^9, 
  3.6035616718178883`*^9}, {3.611147798223692*^9, 3.61114780162153*^9}, {
  3.612400713724976*^9, 3.61240072520877*^9}, {3.6277714365909224`*^9, 
  3.627771454775387*^9}, {3.627771540966757*^9, 3.627771544204289*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.25, $CellContext`b$$ = 
    0.75, $CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.25}, 0.1, 1}, {{
       Hold[$CellContext`b$$], 0.75}, 0.1, 1}, {{
       Hold[$CellContext`c$$], 1}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$5390$$ = 
    0, $CellContext`b$5391$$ = 0, $CellContext`c$5392$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.25, $CellContext`b$$ = 
        0.75, $CellContext`c$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$5390$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$5391$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$5392$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`umax$}, \
$CellContext`mp$ = 50; $CellContext`np$ = 21; $CellContext`umax$ = 
         Max[1/$CellContext`a$$, 1/$CellContext`b$$]; 
        ParametricPlot3D[{$CellContext`a$$ $CellContext`u 
           Cos[$CellContext`v], $CellContext`b$$ $CellContext`u 
           Sin[$CellContext`v], $CellContext`c$$ $CellContext`u}, \
{$CellContext`u, -$CellContext`umax$, $CellContext`umax$}, {$CellContext`v, 0,
            2 Pi}, PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.3.4"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.25}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.75}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 1}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {357., 364.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603561037772409*^9, 3.603561089167509*^9}, {
   3.612400707151553*^9, 3.612400741108067*^9}, 3.6277714603311462`*^9, 
   3.627771548169599*^9, 3.627771587043457*^9, 3.6308097076828003`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.3.5  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["x", "2"], 
       SuperscriptBox["a", "2"]], " ", "+", " ", 
      FractionBox[
       SuperscriptBox["y", "2"], 
       SuperscriptBox["b", "2"]], " ", "-", " ", "1"}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.603560222836543*^9, 3.603560228495143*^9}, {
  3.603560289636011*^9, 3.603560501298532*^9}, {3.603560702044285*^9, 
  3.603560702044379*^9}, {3.603560739528372*^9, 3.60356076769265*^9}, {
  3.603561165971531*^9, 3.6035611659716253`*^9}, {3.603561235803261*^9, 
  3.603561240130259*^9}}],

Cell[TextData[{
 "\"hyperboloid of one sheet\"\nParametrically, ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["c",
     FontSlant->"Italic"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        StyleBox["u",
         FontSlant->"Italic"], "2"], "-", "1"}], ")"}], 
     RowBox[{"1", "/", "2"}]]}], TraditionalForm]]],
 " for the half above ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = 0; a reversal of the sign of ",
 StyleBox["z",
  FontSlant->"Italic"],
 " produces the lower half.  The figure is computed as two separate parts."
}], "Text",
 CellChangeTimes->{
  3.6035612496046333`*^9, {3.6035613199569187`*^9, 3.6035613321481743`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "mp", ",", "np", ",", "umax", ",", "xmax", ",", "ymax", ",", "zmax", 
       ",", "p1", ",", "p2"}], "}"}], ",", " ", "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "50"}], ";", " ", "\[IndentingNewLine]", 
      " ", 
      RowBox[{"np", " ", "=", " ", "21"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"umax", " ", "=", " ", "5.0"}], ";", "    ", 
      RowBox[{"(*", "arbitrary", "*)"}], "\n", "     ", 
      RowBox[{"xmax", " ", "=", " ", 
       RowBox[{"a", "*", "umax"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ymax", " ", "=", " ", 
       RowBox[{"b", "*", "umax"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"zmax", " ", "=", " ", 
       RowBox[{"c", "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"umax", "^", "2"}], " ", "-", " ", "1"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", " ", "u", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], ",", 
          RowBox[{"b", " ", "u", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}], ",", " ", 
          RowBox[{"c", " ", 
           RowBox[{"Sign", "[", "u", "]"}], " ", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"u", "^", "2"}], "-", "1"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", 
          RowBox[{"-", "umax"}], ",", "umax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", "100", "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", 
           RowBox[{"-", "5"}], ",", "2"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.3.5\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", " ", "0.5"}], "}"}], ",", " ", "0.1", ",", " ", "1", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", " ", "0.5"}], "}"}], ",", " ", "0.1", ",", " ", "1", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "0.6"}], "}"}], ",", " ", "0.1", ",", " ", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", "\n", "   ", 
   RowBox[{"TrackedSymbols", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"a", ",", " ", "b", ",", " ", "c"}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603560904363338*^9, 
   3.603560924201836*^9}, {3.6035609604643917`*^9, 3.603561032106309*^9}, {
   3.603561430239449*^9, 3.603561477455783*^9}, {3.603561591689386*^9, 
   3.6035616502026253`*^9}, {3.603561899264674*^9, 3.603561904414463*^9}, {
   3.606071710696783*^9, 3.6060717170317307`*^9}, {3.611147809349454*^9, 
   3.611147811947981*^9}, 3.611152721810446*^9, {3.612400781201741*^9, 
   3.612400787937612*^9}, {3.627771476650804*^9, 3.627771532415126*^9}, 
   3.627771601239685*^9, {3.630809806745529*^9, 3.630809819593336*^9}, {
   3.630809850207509*^9, 3.630809899756242*^9}, {3.630810056620967*^9, 
   3.63081007139502*^9}, {3.630810111633668*^9, 3.630810112169183*^9}, 
   3.630810154184471*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.5, $CellContext`c$$ = 0.6, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`b$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`c$$], 0.6}, 0.1, 1}}, Typeset`size$$ = {
    500., {281., 288.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$498$$ = 
    0, $CellContext`b$503$$ = 0, $CellContext`c$504$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.5, $CellContext`c$$ = 0.6}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$498$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$503$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$504$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`umax$, \
$CellContext`xmax$, $CellContext`ymax$, $CellContext`zmax$, $CellContext`p1$, \
$CellContext`p2$}, $CellContext`mp$ = 50; $CellContext`np$ = 
         21; $CellContext`umax$ = 
         5.; $CellContext`xmax$ = $CellContext`a$$ $CellContext`umax$; \
$CellContext`ymax$ = $CellContext`b$$ $CellContext`umax$; $CellContext`zmax$ = \
$CellContext`c$$ Sqrt[$CellContext`umax$^2 - 1]; 
        ParametricPlot3D[{$CellContext`a$$ $CellContext`u 
           Cos[$CellContext`v], $CellContext`b$$ $CellContext`u 
           Sin[$CellContext`v], $CellContext`c$$ Sign[$CellContext`u] 
           Sqrt[$CellContext`u^2 - 
             1]}, {$CellContext`u, -$CellContext`umax$, $CellContext`umax$}, \
{$CellContext`v, 0, 2 Pi}, PlotPoints -> {100}, ViewPoint -> {4, -5, 2}, 
          PlotLabel -> "13.3.5"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.6}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {383., 390.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6035616983369513`*^9, 3.603561729839735*^9}, {
   3.6124007506144867`*^9, 3.6124007886104107`*^9}, 3.627771607797061*^9, 
   3.630809741248047*^9, 3.630809821495502*^9, 3.6308098560293417`*^9, 
   3.630809904744299*^9, 3.630810072854417*^9, 3.630810113221127*^9, 
   3.630810167923387*^9, 3.630810222976802*^9, 3.630810297199026*^9, 
   3.63081038621988*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.3.6  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["x", "2"], 
       SuperscriptBox["a", "2"]], " ", "+", " ", 
      FractionBox[
       SuperscriptBox["y", "2"], 
       SuperscriptBox["b", "2"]], " ", "+", " ", "1"}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.603560222836543*^9, 3.603560228495143*^9}, {
  3.603560289636011*^9, 3.603560501298532*^9}, {3.603560702044285*^9, 
  3.603560702044379*^9}, {3.603560739528372*^9, 3.60356076769265*^9}, {
  3.603561165971531*^9, 3.6035611659716253`*^9}, {3.603561235803261*^9, 
  3.603561240130259*^9}, {3.603562236465066*^9, 3.60356223646518*^9}, {
  3.611147835165843*^9, 3.611147835165962*^9}}],

Cell[TextData[{
 "\"hyperboloid of two sheets\"\nParametrically, ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["u", "2"], "+", "1"}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 " for the upper sheet; a reversal of the sign of ",
 StyleBox["z",
  FontSlant->"Italic"],
 " produces the lower sheet.  In order to avoid connecting the upper and \
lower sheets, the figure is computed as two separate parts which are then \
combined for plotting.    "
}], "Text",
 CellChangeTimes->{{3.6035617791614447`*^9, 3.603561877847253*^9}, {
  3.6035619993493633`*^9, 3.6035620040896873`*^9}, {3.61922764743143*^9, 
  3.619227663522522*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "mp", ",", "np", ",", "umax", ",", "xmax", ",", "ymax", ",", "zmax", 
       ",", "p1", ",", "p2"}], "}"}], ",", " ", "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "50"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "21"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"umax", " ", "=", " ", "5.0"}], ";", "    ", 
      RowBox[{"(*", "arbitrary", "*)"}], "\n", "     ", 
      RowBox[{"xmax", " ", "=", " ", 
       RowBox[{"a", "*", "umax"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ymax", " ", "=", " ", 
       RowBox[{"b", "*", "umax"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"zmax", " ", "=", " ", 
       RowBox[{"c", "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"umax", "^", "2"}], " ", "+", " ", "1"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p1", "=", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"a", " ", "u", " ", 
            RowBox[{"Cos", "[", "v", "]"}]}], ",", 
           RowBox[{"b", " ", "u", " ", 
            RowBox[{"Sin", "[", "v", "]"}]}], ",", " ", 
           RowBox[{"c", " ", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{"u", "^", "2"}], " ", "+", " ", "1"}], "]"}]}]}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", "umax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}]}], ";", "\n", "     ", 
      RowBox[{"p2", "=", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"a", " ", "u", " ", 
            RowBox[{"Cos", "[", "v", "]"}]}], ",", 
           RowBox[{"b", " ", "u", " ", 
            RowBox[{"Sin", "[", "v", "]"}]}], ",", 
           RowBox[{
            RowBox[{"-", "c"}], " ", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{"u", "^", "2"}], " ", "+", " ", "1"}], "]"}]}]}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", "umax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}]}], ";", "\n", "    ", 
      RowBox[{"Show", "[", 
       RowBox[{"p1", ",", "p2", ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", 
           RowBox[{"-", "5"}], ",", "2"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.3.6\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", " ", "0.25"}], "}"}], ",", " ", "0.1", ",", " ", "1", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", " ", "0.25"}], "}"}], ",", " ", "0.1", ",", " ", "1", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "0.25"}], "}"}], ",", " ", "0.1", ",", " ", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", "\n", "   ", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", " ", "b", ",", " ", "c"}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603560904363338*^9, 
   3.603560924201836*^9}, {3.6035609604643917`*^9, 3.603561032106309*^9}, {
   3.603561430239449*^9, 3.603561477455783*^9}, {3.603561591689386*^9, 
   3.6035616502026253`*^9}, {3.603561899264674*^9, 3.603561904414463*^9}, {
   3.6035619683692703`*^9, 3.6035619700902452`*^9}, {3.603562060154944*^9, 
   3.603562088880864*^9}, 3.603562203975596*^9, {3.606071726931341*^9, 
   3.6060717310937653`*^9}, {3.611147819561863*^9, 3.61114783869705*^9}, {
   3.612400816064289*^9, 3.6124008411007347`*^9}, {3.627771624589952*^9, 
   3.627771659937998*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.25, $CellContext`b$$ = 
    0.25, $CellContext`c$$ = 0.25, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.25}, 0.1, 1}, {{
       Hold[$CellContext`b$$], 0.25}, 0.1, 1}, {{
       Hold[$CellContext`c$$], 0.25}, 0.1, 1}}, Typeset`size$$ = {
    500., {260., 276.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$599$$ = 
    0, $CellContext`b$600$$ = 0, $CellContext`c$601$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.25, $CellContext`b$$ = 
        0.25, $CellContext`c$$ = 0.25}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$599$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$600$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$601$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`umax$, \
$CellContext`xmax$, $CellContext`ymax$, $CellContext`zmax$, $CellContext`p1$, \
$CellContext`p2$}, $CellContext`mp$ = 50; $CellContext`np$ = 
         21; $CellContext`umax$ = 
         5.; $CellContext`xmax$ = $CellContext`a$$ $CellContext`umax$; \
$CellContext`ymax$ = $CellContext`b$$ $CellContext`umax$; $CellContext`zmax$ = \
$CellContext`c$$ Sqrt[$CellContext`umax$^2 + 1]; $CellContext`p1$ = 
         ParametricPlot3D[{$CellContext`a$$ $CellContext`u 
            Cos[$CellContext`v], $CellContext`b$$ $CellContext`u 
            Sin[$CellContext`v], $CellContext`c$$ 
            Sqrt[$CellContext`u^2 + 1]}, {$CellContext`u, 
            0, $CellContext`umax$}, {$CellContext`v, 0, 2 
            Pi}]; $CellContext`p2$ = 
         ParametricPlot3D[{$CellContext`a$$ $CellContext`u 
            Cos[$CellContext`v], $CellContext`b$$ $CellContext`u 
            Sin[$CellContext`v], (-$CellContext`c$$) 
            Sqrt[$CellContext`u^2 + 1]}, {$CellContext`u, 
            0, $CellContext`umax$}, {$CellContext`v, 0, 2 Pi}]; 
        Show[$CellContext`p1$, $CellContext`p2$, ViewPoint -> {4, -5, 2}, 
          PlotLabel -> "13.3.6"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.25}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.25}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.25}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {366., 373.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.603562030543476*^9, {3.603562063406001*^9, 3.603562122782937*^9}, 
   3.603562165765481*^9, {3.612400798637438*^9, 3.612400841825725*^9}, 
   3.6277716678074417`*^9, 3.630810442496236*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.4  Functions with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["x",
     FontSlant->"Italic"], "3"], TraditionalForm]]],
 "/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["a",
     FontSlant->"Italic"], "3"], TraditionalForm]]],
 " \[PlusMinus] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["y",
     FontSlant->"Italic"], "3"], TraditionalForm]]],
 "/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["b",
     FontSlant->"Italic"], "3"], TraditionalForm]]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
 "13.4.1  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["x", "3"], 
    SuperscriptBox["a", "3"]], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["y", "3"], 
    SuperscriptBox["b", "3"]], TraditionalForm]]],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.603562356771688*^9, 3.603562555490116*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[c*(x^3/a^3 + y^3/b^3), {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{-5, 6, 4}, PlotLabel\[Rule]\"13.4.1\
\"]
  ],
  {a,0.5,2,Appearance\[Rule]\"Labeled\"},
  {{b,1},0.5,2,Appearance\[Rule]\"Labeled\"},
  {{c,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{a,b,c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
  3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
  3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
  3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
  3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
  3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6111478518670063`*^9, 
  3.6111478566798487`*^9}, {3.612400893872613*^9, 3.612400929722207*^9}, {
  3.627771706023675*^9, 3.627771753861175*^9}, {3.6277719885735893`*^9, 
  3.627771988848624*^9}, {3.6308106222091637`*^9, 3.6308106253948812`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    1, $CellContext`c$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.5, 2}, {{
       Hold[$CellContext`b$$], 1}, 0.5, 2}, {{
       Hold[$CellContext`c$$], 0.5}, 0.1, 1}}, Typeset`size$$ = {
    500., {242., 257.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$2080$$ = 
    0, $CellContext`b$2081$$ = 0, $CellContext`c$2082$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        1, $CellContext`c$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$2080$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2081$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2082$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[$CellContext`c$$ ($CellContext`x^3/$CellContext`a$$^3 + \
$CellContext`y^3/$CellContext`b$$^3), {$CellContext`x, -1, 
           1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {-5, 6, 4}, PlotLabel -> "13.4.1"]], 
      "Specifications" :> {{$CellContext`a$$, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 1}, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {348., 355.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.60356381304322*^9, {3.6035638501028633`*^9, 3.6035639371013603`*^9}, {
   3.6124008699684277`*^9, 3.612400881804449*^9}, {3.612400923083864*^9, 
   3.6124009393400106`*^9}, {3.627771744115494*^9, 3.627771754778825*^9}, 
   3.630810591328432*^9, 3.630810627127632*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.4.2  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["x", "3"], 
    SuperscriptBox["a", "3"]], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["y", "3"], 
    SuperscriptBox["b", "3"]], TraditionalForm]]],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.603562356771688*^9, 3.603562575016046*^9}}],

Cell[TextData[{
 "This surface is a reflection about the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-",
 StyleBox["z",
  FontSlant->"Italic"],
 " plane of the previous surface."
}], "Text",
 CellChangeTimes->{{3.6111852652601137`*^9, 3.611185265733622*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[c*(x^3/a^3 - y^3/b^3), {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4}, PlotLabel\[Rule]\"13.4.2\
\"]
  ],
  {a,0.5,2,Appearance\[Rule]\"Labeled\"},
  {b,0.5,2,Appearance\[Rule]\"Labeled\"},
  {{c,1},0.1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{a,b,c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
   3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
   3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
   3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
   3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
   3.6035638657392597`*^9, 3.603563873325672*^9}, 3.603564003427855*^9, {
   3.61114786414214*^9, 3.611147869303146*^9}, {3.627771781413415*^9, 
   3.627771811836011*^9}, {3.627771999123889*^9, 3.627772006411014*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.5, $CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.5, 2}, {
      Hold[$CellContext`b$$], 0.5, 2}, {{
       Hold[$CellContext`c$$], 1}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$2495$$ = 
    0, $CellContext`b$2496$$ = 0, $CellContext`c$2497$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.5, $CellContext`c$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$2495$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2496$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2497$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[$CellContext`c$$ ($CellContext`x^3/$CellContext`a$$^3 - \
$CellContext`y^3/$CellContext`b$$^3), {$CellContext`x, -1, 
           1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.4.2"]], 
      "Specifications" :> {{$CellContext`a$$, 0.5, 2, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 1}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {357., 364.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603564005825585*^9, 3.60356403091639*^9}, {
   3.612400948498582*^9, 3.612400961287341*^9}, 3.6277718169925413`*^9, 
   3.630810654159088*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.5  Functions with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["x",
     FontSlant->"Italic"], "4"], TraditionalForm]]],
 "/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["a",
     FontSlant->"Italic"], "4"], TraditionalForm]]],
 " \[PlusMinus] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["y",
     FontSlant->"Italic"], "4"], TraditionalForm]]],
 "/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["b",
     FontSlant->"Italic"], "4"], TraditionalForm]]]
}], "Subsection",
 CellChangeTimes->{{3.603389517238284*^9, 3.603389521571972*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "13.5.1  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["x", "4"], 
    SuperscriptBox["a", "4"]], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["y", "4"], 
    SuperscriptBox["b", "4"]], TraditionalForm]]],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.603562356771688*^9, 3.603562555490116*^9}, {
   3.603564084092244*^9, 3.603564092715781*^9}, 3.611147890741322*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[c*(x^4/a^4 + y^4/b^4), {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4}, PlotLabel\[Rule]\"13.5.1\
\"]
  ],
  {a,0.5,2,Appearance\[Rule]\"Labeled\"},
  {{b,0.8},0.5,2,Appearance\[Rule]\"Labeled\"},
  {{c,0.5},0.1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{a,b,c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
  3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
  3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
  3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
  3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
  3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6035641153914022`*^9, 
  3.603564120340847*^9}, {3.61114788222976*^9, 3.6111478862799997`*^9}, {
  3.612400993035038*^9, 3.612401031773119*^9}, {3.627771847899527*^9, 
  3.627771890410842*^9}, {3.627771951313011*^9, 3.627771951573564*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.8, $CellContext`c$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.5, 2}, {{
       Hold[$CellContext`b$$], 0.8}, 0.5, 2}, {{
       Hold[$CellContext`c$$], 0.5}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$2930$$ = 
    0, $CellContext`b$2931$$ = 0, $CellContext`c$2932$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.8, $CellContext`c$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$2930$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2931$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2932$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[$CellContext`c$$ ($CellContext`x^4/$CellContext`a$$^4 + \
$CellContext`y^4/$CellContext`b$$^4), {$CellContext`x, -1, 
           1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.5.1"]], 
      "Specifications" :> {{$CellContext`a$$, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.8}, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {357., 364.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6035641300155783`*^9, 3.603564146247816*^9}, {
   3.612400977592434*^9, 3.612401033868676*^9}, {3.6277718803558817`*^9, 
   3.627771891042753*^9}, 3.630810682214575*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.5.2  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["x", "4"], 
    SuperscriptBox["a", "4"]], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["y", "4"], 
    SuperscriptBox["b", "4"]], TraditionalForm]]],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.603562356771688*^9, 3.603562555490116*^9}, {
   3.603564084092244*^9, 3.603564092715781*^9}, 3.60356419025453*^9, {
   3.6111479012159977`*^9, 3.61114790269096*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[c*(x^4/a^4 - y^4/b^4), {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4}, PlotLabel\[Rule]\"13.5.2\
\"]
  ],
  {a,0.5,2,Appearance\[Rule]\"Labeled\"},
  {b,0.5,2,Appearance\[Rule]\"Labeled\"},
  {{c,1},0.1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{a,b,c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
   3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
   3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
   3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
   3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
   3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6035641153914022`*^9, 
   3.603564120340847*^9}, 3.6035642075053062`*^9, {3.611147906142264*^9, 
   3.611147911003334*^9}, {3.627771908136293*^9, 3.627771941177351*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.5, $CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.5, 2}, {
      Hold[$CellContext`b$$], 0.5, 2}, {{
       Hold[$CellContext`c$$], 1}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$3346$$ = 
    0, $CellContext`b$3347$$ = 0, $CellContext`c$3348$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.5, $CellContext`c$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$3346$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$3347$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$3348$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[$CellContext`c$$ ($CellContext`x^4/$CellContext`a$$^4 - \
$CellContext`y^4/$CellContext`b$$^4), {$CellContext`x, -1, 
           1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.5.2"]], 
      "Specifications" :> {{$CellContext`a$$, 0.5, 2, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 1}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {357., 364.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6035642135875263`*^9, 3.603564229996364*^9}, 
   3.612401043126539*^9, 3.627771967270028*^9, 3.630810708566853*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.6  Miscellaneous Functions", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
 "13.6.1  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "-", " ", 
      SuperscriptBox[
       RowBox[{"[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], " ", "+", " ", 
            SuperscriptBox["y", "2"]}], ")"}], 
          RowBox[{"1", "/", "2"}]], " ", "-", "b"}], "]"}], "2"]}], ")"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.6035648217389297`*^9, 3.603564841995557*^9}, {
  3.6035648985758457`*^9, 3.603565016253924*^9}}],

Cell[TextData[{
 "\"torus\"  (",
 StyleBox["a",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 " gives \"spindle torus\")  \n\nThe radius of the centerline of the torus is \
",
 StyleBox["a",
  FontSlant->"Italic"],
 " while its cross-sectional radius is ",
 StyleBox["b",
  FontSlant->"Italic"],
 ".\n\nParametrically, ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = [",
 StyleBox["a",
  FontSlant->"Italic"],
 " + ",
 StyleBox["b",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")]cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 "), ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = [",
 StyleBox["a",
  FontSlant->"Italic"],
 " + ",
 StyleBox["b",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")]sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 "), ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")."
}], "Text",
 CellChangeTimes->{
  3.603564321492276*^9, {3.603564620584919*^9, 3.60356465489421*^9}, {
   3.603565070674818*^9, 3.6035650903858347`*^9}, {3.6060718513585863`*^9, 
   3.606071854970046*^9}, 3.612401084973415*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "50"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", 
              RowBox[{"b", " ", 
               RowBox[{"Cos", "[", "v", "]"}]}]}], ")"}], 
            RowBox[{"Cos", "[", "u", "]"}]}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", 
              RowBox[{"b", " ", 
               RowBox[{"Cos", "[", "v", "]"}]}]}], ")"}], 
            RowBox[{"Sin", "[", "u", "]"}]}], ",", 
           RowBox[{"b", " ", 
            RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.6.1\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0.75"}], "}"}], ",", "0.1", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "0.1", ",", "a", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}]}]}], "\n", "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.6111479252609797`*^9, 3.6111479283472843`*^9}, 3.612401096425699*^9, {
   3.627772072712826*^9, 3.627772085564034*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.75, $CellContext`b$$ = 0.1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.75}, 0.1, 1}, {
      Hold[$CellContext`b$$], 0.1, 
      Dynamic[$CellContext`a$$]}}, Typeset`size$$ = {500., {251., 266.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`a$4801$$ = 0, $CellContext`b$4802$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.75, $CellContext`b$$ = 0.1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$4801$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$4802$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 21; 
        ParametricPlot3D[{($CellContext`a$$ + $CellContext`b$$ 
             Cos[$CellContext`v]) 
           Cos[$CellContext`u], ($CellContext`a$$ + $CellContext`b$$ 
             Cos[$CellContext`v]) Sin[$CellContext`u], $CellContext`b$$ 
           Sin[$CellContext`v]}, {$CellContext`u, 0, 2 Pi}, {$CellContext`v, 
           0, 2 Pi}, PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.6.1"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.75}, 0.1, 1, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 0.1, 
         Dynamic[$CellContext`a$$], Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {334., 341.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603564546340263*^9, 3.603564564540461*^9}, {
   3.603564708193466*^9, 3.603564725620989*^9}, 3.603564764286996*^9, {
   3.6124010715729017`*^9, 3.612401097586452*^9}, 3.6277720915012207`*^9, 
   3.6308769105109463`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.6.2  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "3"], TraditionalForm]]],
 " - 3",
 StyleBox["x",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.60356513466497*^9, 3.603565184285893*^9}}],

Cell["\"monkey saddle\"", "Text"],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[c*(x^3 - 3x y^2), {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4},PlotLabel\[Rule]\"13.6.2\"]
  ],
  {{c,1},0.1,1},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
  3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
  3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
  3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
  3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
  3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6035641153914022`*^9, 
  3.603564120340847*^9}, {3.603565327800887*^9, 3.6035653625252438`*^9}, {
  3.611147938858624*^9, 3.611147945568027*^9}, {3.6277721038498983`*^9, 
  3.627772123973352*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 1}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$1440$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$1440$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[$CellContext`c$$ ($CellContext`x^3 - 
           3 $CellContext`x $CellContext`y^2), {$CellContext`x, -1, 
           1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.6.2"]], 
      "Specifications" :> {{{$CellContext`c$$, 1}, 0.1, 1}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {311., 318.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603565368949173*^9, 3.603565375126485*^9}, 
   3.612401121005917*^9, 3.627772136844981*^9, 3.630877034132725*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.6.3  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["cx",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.60356513466497*^9, 3.603565184285893*^9}, {
   3.6035654550138693`*^9, 3.603565465750565*^9}, 3.603565637215873*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[c*x*y^2, {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4},PlotLabel\[Rule]\"13.6.3\"]
  ],
  {c,-1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
  3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
  3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
  3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
  3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
  3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6035641153914022`*^9, 
  3.603564120340847*^9}, {3.603565327800887*^9, 3.6035653625252438`*^9}, {
  3.603565567181282*^9, 3.6035655824149446`*^9}, {3.611147954104981*^9, 
  3.6111479576553087`*^9}, {3.6277721452614317`*^9, 3.6277721743883142`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = -1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`c$$], -1, 1}}, Typeset`size$$ = {500., {251., 266.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`c$2643$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = -1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$2643$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[$CellContext`c$$ $CellContext`x $CellContext`y^2, \
{$CellContext`x, -1, 1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.6.3"]], 
      "Specifications" :> {{$CellContext`c$$, -1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {312., 319.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.603565512483098*^9, {3.6035655755168133`*^9, 3.603565599405944*^9}, 
   3.6124011316305933`*^9, {3.6277721617986317`*^9, 3.627772175801421*^9}, 
   3.630877061505796*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.6.4  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.60356513466497*^9, 3.603565184285893*^9}, {
  3.6035654550138693`*^9, 3.603565465750565*^9}, {3.603565637215873*^9, 
  3.6035656595151043`*^9}}],

Cell["\"crossed trough\"", "Text"],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[c*x^2*y^2, {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4},PlotLabel\[Rule]\"13.6.4\"]
  ],
  {{c,1},0.1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
  3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
  3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
  3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
  3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
  3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6035641153914022`*^9, 
  3.603564120340847*^9}, {3.603565327800887*^9, 3.6035653625252438`*^9}, {
  3.603565567181282*^9, 3.6035655824149446`*^9}, {3.603565692540923*^9, 
  3.603565692952381*^9}, {3.6111479667051277`*^9, 3.611147971130365*^9}, {
  3.627772187837284*^9, 3.6277722145976067`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 1}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$3025$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$3025$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[$CellContext`c$$ $CellContext`x^2 $CellContext`y^2, \
{$CellContext`x, -1, 1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.6.4"]], 
      "Specifications" :> {{{$CellContext`c$$, 1}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {312., 319.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6035656950689373`*^9, 3.603565704720765*^9}, 
   3.612401140847883*^9, 3.627772215239059*^9, 3.630877088004738*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.6.5  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = (",
 StyleBox["a",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 "  + ",
 StyleBox["b",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 ")/(",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.603588979786518*^9, 3.60358901229606*^9}, {
  3.603589049321405*^9, 3.603589088160129*^9}, {3.603589139118093*^9, 
  3.603589183700745*^9}}],

Cell[TextData[{
 "\"conoid of Plucker\" or \"cylindroid\"\n\nAn alternate expression is ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["cxy",
  FontSlant->"Italic"],
 "/(",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["x",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["y",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 ").  Note that ",
 StyleBox["z",
  FontSlant->"Italic"],
 " is undefined at (",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 ") = (0, 0).  A small increment is needed to properly show the surface in \
the region of this point."
}], "Text",
 CellChangeTimes->{
  3.603589195611835*^9, {3.603589234185308*^9, 3.6035892420364857`*^9}, 
   3.60607187731212*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[(a x^2 + b y^2)/(x^2 + y^2), {x, -1, 1}, {y, -1, 1}, PlotPoints\
\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4},PlotLabel\[Rule]\"13.6.5\"]
  ],
  {{a,0.5},-1,1,Appearance\[Rule]\"Labeled\"},
  {{b,-0.5},-1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{a,b}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
  3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
  3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
  3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
  3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
  3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6035641153914022`*^9, 
  3.603564120340847*^9}, {3.603565327800887*^9, 3.6035653625252438`*^9}, {
  3.603565567181282*^9, 3.6035655824149446`*^9}, {3.603565692540923*^9, 
  3.603565692952381*^9}, {3.603589280499658*^9, 3.603589353261259*^9}, {
  3.60358942252815*^9, 3.603589447424613*^9}, {3.603589511151808*^9, 
  3.603589515612441*^9}, {3.603589558626382*^9, 3.603589583200611*^9}, {
  3.6111479779802523`*^9, 3.611147980705346*^9}, {3.627772231812337*^9, 
  3.627772276810946*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = -0.5, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, -1, 1}, {{
       Hold[$CellContext`b$$], -0.5}, -1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$3810$$ = 
    0, $CellContext`b$3811$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = -0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$3810$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$3811$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[($CellContext`a$$ $CellContext`x^2 + $CellContext`b$$ \
$CellContext`y^2)/($CellContext`x^2 + $CellContext`y^2), {$CellContext`x, -1, 
           1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.6.5"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, -1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, -0.5}, -1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {334., 341.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603589369147955*^9, 3.603589475257003*^9}, {
   3.603589516995467*^9, 3.603589549355736*^9}, {3.603589584510651*^9, 
   3.6035895916049767`*^9}, 3.612401149638728*^9, 3.627772278115037*^9, {
   3.630877122971702*^9, 3.630877149562633*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.6.6  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["x",
  FontSlant->"Italic"],
 "(",
 StyleBox["a",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 " + ",
 StyleBox["b",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.603589636505869*^9, 3.603589672301199*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[x*(a*x^2 + b*y^2), {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4},PlotLabel\[Rule]\"13.6.6\"]
  ],
  {{a,0.5},-1,1,Appearance\[Rule]\"Labeled\"},
  {{b,-0.5},-1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{a,b}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
   3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
   3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
   3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
   3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
   3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6035641153914022`*^9, 
   3.603564120340847*^9}, {3.603565327800887*^9, 3.6035653625252438`*^9}, {
   3.603565567181282*^9, 3.6035655824149446`*^9}, {3.603565692540923*^9, 
   3.603565692952381*^9}, {3.603589280499658*^9, 3.603589353261259*^9}, {
   3.60358942252815*^9, 3.603589447424613*^9}, {3.603589511151808*^9, 
   3.603589515612441*^9}, {3.603589558626382*^9, 3.603589583200611*^9}, 
   3.603589763729293*^9, {3.6111479901180973`*^9, 3.6111479939806843`*^9}, {
   3.627772288725182*^9, 3.627772302523225*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = -0.5, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, -1, 1}, {{
       Hold[$CellContext`b$$], -0.5}, -1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$4211$$ = 
    0, $CellContext`b$4212$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = -0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$4211$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$4212$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[$CellContext`x ($CellContext`a$$ $CellContext`x^2 + \
$CellContext`b$$ $CellContext`y^2), {$CellContext`x, -1, 
           1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.6.6"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, -1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, -0.5}, -1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {334., 341.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603589777205578*^9, 3.60358981550108*^9}, 
   3.6124011605386*^9, 3.621714940615952*^9, 3.627772305981542*^9, 
   3.63087717849129*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.6.7  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = \[PlusMinus]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"[", 
     RowBox[{
      SuperscriptBox["a", "n"], " ", "-", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[LeftBracketingBar]", "x", "\[RightBracketingBar]"}], "n"],
         " ", "+", " ", 
        SuperscriptBox[
         RowBox[{"\[LeftBracketingBar]", "y", "\[RightBracketingBar]"}], 
         "n"]}], " ", ")"}]}], "]"}], 
    RowBox[{"1", "/", "n"}]], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.6035898654095984`*^9, 3.603589872429727*^9}, {
  3.603589919768612*^9, 3.6035900559191008`*^9}, {3.603592932226742*^9, 
  3.603592943027217*^9}}],

Cell[TextData[{
 "\"hypersphere\"  \n\nFor ",
 StyleBox["n",
  FontSlant->"Italic"],
 " odd, use the absolute value of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".  Parameter ",
 StyleBox["a",
  FontSlant->"Italic"],
 " is the \[OpenCurlyDoubleQuote]radius\[CloseCurlyDoubleQuote] of the \
hypersphere.  For ",
 StyleBox["n",
  FontSlant->"Italic"],
 " = 1, the figure degenerates to an octohedron."
}], "Text",
 CellChangeTimes->{
  3.6035900863811283`*^9, {3.603590120206438*^9, 3.6035901295798197`*^9}, {
   3.6035921541597767`*^9, 3.603592183583331*^9}, 3.6060719042335043`*^9}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,x,y,z,afunc},
    mp = 50;
    afunc = If[OddQ[n], Abs[x]^n + Abs[y]^n + Abs[z]^n, x^n + y^n + z^n];
    ContourPlot3D[afunc == 1, {x, -1, 1}, {y, -1, 1}, {z, -1, 1}, Contours\
\[Rule]{a},ViewPoint\[Rule]{5, -6, 4},PlotLabel\[Rule]\"13.6.7\"]
  ],
  {{n,3},1,5,1,Appearance\[Rule]\"Labeled\"}, 
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{n}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
   3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
   3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
   3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
   3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
   3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6035641153914022`*^9, 
   3.603564120340847*^9}, {3.603565327800887*^9, 3.6035653625252438`*^9}, {
   3.603565567181282*^9, 3.6035655824149446`*^9}, {3.603565692540923*^9, 
   3.603565692952381*^9}, {3.603589280499658*^9, 3.603589353261259*^9}, {
   3.60358942252815*^9, 3.603589447424613*^9}, {3.603589511151808*^9, 
   3.603589515612441*^9}, {3.603589558626382*^9, 3.603589583200611*^9}, 
   3.603589763729293*^9, {3.6035901928327913`*^9, 3.60359030041966*^9}, 
   3.6035903423212748`*^9, {3.603590381400526*^9, 3.60359038140567*^9}, 
   3.603590429595886*^9, {3.6035905080217657`*^9, 3.603590527495309*^9}, {
   3.603590643595179*^9, 3.603590643696385*^9}, {3.603590957888942*^9, 
   3.603591055662691*^9}, {3.603591392217853*^9, 3.6035914011026487`*^9}, {
   3.6035920436207247`*^9, 3.603592114333659*^9}, {3.603592216871771*^9, 
   3.603592218559472*^9}, {3.6111480033055067`*^9, 3.611148005980771*^9}, {
   3.627772321361545*^9, 3.627772331105616*^9}, {3.627772410562591*^9, 
   3.62777242986094*^9}, {3.627772482710396*^9, 3.627772493410503*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`n$$ = 4, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n$$], 3}, 1, 5, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`n$5031$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`n$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$5031$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`x$, $CellContext`y$, \
$CellContext`z$, $CellContext`afunc$}, $CellContext`mp$ = 
         50; $CellContext`afunc$ = If[
           OddQ[$CellContext`n$$], Abs[$CellContext`x$]^$CellContext`n$$ + 
           Abs[$CellContext`y$]^$CellContext`n$$ + 
           Abs[$CellContext`z$]^$CellContext`n$$, \
$CellContext`x$^$CellContext`n$$ + $CellContext`y$^$CellContext`n$$ + \
$CellContext`z$^$CellContext`n$$]; 
        ContourPlot3D[$CellContext`afunc$ == 
          1, {$CellContext`x$, -1, 1}, {$CellContext`y$, -1, 
           1}, {$CellContext`z$, -1, 1}, Contours -> {$CellContext`a}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.6.7"]], 
      "Specifications" :> {{{$CellContext`n$$, 3}, 1, 5, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`n$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {312., 319.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.603592079800302*^9, {3.603592116627556*^9, 3.603592139177256*^9}, 
   3.603592222712347*^9, 3.61240118908033*^9, {3.6277723510365677`*^9, 
   3.62777239210748*^9}, 3.627772436512183*^9, {3.630877214450708*^9, 
   3.630877241943774*^9}, {3.630877276073633*^9, 3.63087728834002*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.6.8  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "(",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "2"], TraditionalForm]]],
 "/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]]],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.603592481742214*^9, 3.603592520009453*^9}}],

Cell[TextData[{
 "\"Whitney's umbrella\"\n\nParametrically ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["u",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["v",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["u",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["c",
     FontSlant->"Italic"], "\[CenterDot]", 
    SuperscriptBox[
     StyleBox["v",
      FontSlant->"Italic"], "2"]}], TraditionalForm]]],
 "; this gives a smoother plotted surface than plotting the equation \
directly. "
}], "Text",
 CellChangeTimes->{{3.603592292482438*^9, 3.6035923280354357`*^9}, {
   3.603592428127561*^9, 3.6035924329790373`*^9}, 3.6060719175081453`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "50"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"u", " ", "v"}], ",", "u", ",", 
           RowBox[{"c", "*", 
            RowBox[{"v", "^", "2"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", 
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", 
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.6.8\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "0.5"}], "}"}], ",", "0.1", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", "c", "}"}]}]}], "\n", "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
  3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
  3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
  3.603592386957271*^9, 3.603592410240465*^9}, {3.6111480138974657`*^9, 
  3.611148017185017*^9}, {3.627772506688718*^9, 3.627772522348803*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 0.5}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$5755$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$5755$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 21; 
        ParametricPlot3D[{$CellContext`u $CellContext`v, $CellContext`u, \
$CellContext`c$$ $CellContext`v^2}, {$CellContext`u, -1, 
           1}, {$CellContext`v, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.6.8"]], 
      "Specifications" :> {{{$CellContext`c$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {312., 319.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603592454904811*^9, 3.6035924636384277`*^9}, 
   3.612401197997096*^9, 3.6277725310386744`*^9, 3.6308773364298697`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "13.6.9  ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    FractionBox[
     StyleBox["xy",
      FontSlant->"Italic"], 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]], ")"}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.603592559136042*^9, 3.6035926810790462`*^9}}],

Cell[TextData[{
 "There is an unresolvable discontinuity at ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 0. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np},
    mp = 50;
    np = 50;
    Plot3D[(c x y)/(x^2 + y^2), {x, -1, 1}, {y, -1, 1}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4},PlotLabel\[Rule]\"13.6.9\"]
  ],
  {{c,1},0.1,1,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
   3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
   3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
   3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
   3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
   3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6035641153914022`*^9, 
   3.603564120340847*^9}, {3.603565327800887*^9, 3.6035653625252438`*^9}, {
   3.603565567181282*^9, 3.6035655824149446`*^9}, {3.603565692540923*^9, 
   3.603565692952381*^9}, 3.603592777154387*^9, {3.603592813075707*^9, 
   3.60359282830153*^9}, {3.611148025218446*^9, 3.611148029743054*^9}, {
   3.6277725396004457`*^9, 3.627772568301428*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 1}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$6126$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$6126$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 50; 
        Plot3D[($CellContext`c$$ $CellContext`x \
$CellContext`y)/($CellContext`x^2 + $CellContext`y^2), {$CellContext`x, -1, 
           1}, {$CellContext`y, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.6.9"]], 
      "Specifications" :> {{{$CellContext`c$$, 1}, 0.1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {312., 319.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603592839599989*^9, 3.603592865781437*^9}, 
   3.612401209226367*^9, 3.6277725708709784`*^9, 3.630877366925578*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7  Miscellaneous Functions Expressed Parametrically", "Subsection"],

Cell[CellGroupData[{

Cell["13.7.1  Eight surface", "Subsubsection"],

Cell[TextData[{
 "\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 ") sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")/",
 StyleBox["a",
  FontSlant->"Italic"],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 ") sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")/",
 StyleBox["a",
  FontSlant->"Italic"],
 "\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t\nImplicit equation: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       StyleBox["a",
        FontSlant->"Italic"], "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         StyleBox["x",
          FontSlant->"Italic"], "2"], "+", 
        SuperscriptBox[
         StyleBox["y",
          FontSlant->"Italic"], "2"]}], ")"}]}], " ", "-", 
     StyleBox[" ",
      FontSlant->"Italic"], 
     SuperscriptBox[
      StyleBox["z",
       FontSlant->"Italic"], "2"], "-", 
     StyleBox[" ",
      FontSlant->"Italic"], 
     SuperscriptBox[
      StyleBox["z",
       FontSlant->"Italic"], "4"]}], "=", " ", "0"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.603669965099573*^9, 3.603669970610927*^9}, {
  3.606136991288069*^9, 3.606137014285326*^9}, {3.606137444552359*^9, 
  3.606137455488922*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "50"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Cos", "[", "u", "]"}], 
            RowBox[{"Cos", "[", "v", "]"}], 
            RowBox[{
             RowBox[{"Sin", "[", "v", "]"}], "/", "a"}]}], ",", 
           RowBox[{
            RowBox[{"Sin", "[", "u", "]"}], 
            RowBox[{"Cos", "[", "v", "]"}], 
            RowBox[{
             RowBox[{"Sin", "[", "v", "]"}], "/", "a"}]}], ",", 
           RowBox[{"Sin", "[", "v", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", 
           RowBox[{
            RowBox[{"-", "\[Pi]"}], "/", "2"}], ",", 
           RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.1\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "0.5", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", "a", "}"}]}]}], "\n", "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
  3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
  3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
  3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
  3.603670177153167*^9}, {3.611148045385269*^9, 3.611148048010332*^9}, {
  3.627772618328401*^9, 3.627772629186706*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.5, 1}}, Typeset`size$$ = {500., {268., 275.}},
     Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`a$6576$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$6576$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 21; 
        ParametricPlot3D[{
          Cos[$CellContext`u] 
           Cos[$CellContext`v] (Sin[$CellContext`v]/$CellContext`a$$), 
           Sin[$CellContext`u] 
           Cos[$CellContext`v] (Sin[$CellContext`v]/$CellContext`a$$), 
           Sin[$CellContext`v]}, {$CellContext`u, 0, 2 
           Pi}, {$CellContext`v, (-Pi)/2, Pi/2}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.1"]], 
      "Specifications" :> {{$CellContext`a$$, 0.5, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {325., 332.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603670132122682*^9, 3.6036701827288523`*^9}, 
   3.612401250481183*^9, 3.627772638426833*^9, 3.630877504214069*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.2  Goursat's  surface", "Subsubsection"],

Cell[TextData[{
 "For positive ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", the surface is a cube made convex; for negative ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", the surface is a cube made concave.\n\nImplicit equation: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      StyleBox["x",
       FontSlant->"Italic"], "4"], " ", "+", " ", 
     SuperscriptBox[
      StyleBox["y",
       FontSlant->"Italic"], "4"], " ", "+", " ", 
     SuperscriptBox[
      StyleBox["z",
       FontSlant->"Italic"], "4"], 
     StyleBox["+",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     RowBox[{
      StyleBox["a",
       FontSlant->"Italic"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          StyleBox["x",
           FontSlant->"Italic"], "2"], " ", "+", " ", 
         SuperscriptBox[
          StyleBox["y",
           FontSlant->"Italic"], "2"], "+", " ", 
         SuperscriptBox[
          StyleBox["z",
           FontSlant->"Italic"], "2"]}], ")"}], "2"]}]}], "  ", "=", 
    StyleBox[" ",
     FontSlant->"Italic"], 
    StyleBox["c",
     FontSlant->"Italic"]}], TraditionalForm]]],
 "\n\nGoursat's surface is actually composed of two surfaces.  Let ",
 StyleBox["c",
  FontSlant->"Italic"],
 " = 1 + ",
 StyleBox["a",
  FontSlant->"Italic"],
 "; then the two surfaces are:\n\t\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["x",
      FontSlant->"Italic"], "4"], " ", "+", " ", 
    SuperscriptBox[
     StyleBox["y",
      FontSlant->"Italic"], "4"], " ", "+", " ", 
    SuperscriptBox[
     StyleBox["z",
      FontSlant->"Italic"], "4"]}], TraditionalForm]]],
 "  = 1  (hypersphere -- see 13.6.7)\n\t",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       StyleBox["x",
        FontSlant->"Italic"], "2"], " ", "+", " ", 
      SuperscriptBox[
       StyleBox["y",
        FontSlant->"Italic"], "2"], "+", " ", 
      SuperscriptBox[
       StyleBox["z",
        FontSlant->"Italic"], "2"]}], ")"}], "2"], TraditionalForm]]],
 " = 1\n\t\nParametrically, these two equations are, with 0 < \[Theta] < 2\
\[Pi] and 0 < \[CurlyPhi] < \[Pi]:\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"[", 
     RowBox[{"cos\[Theta]", " ", "sin\[CurlyPhi]"}], "]"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 "\t\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{"cos\[Theta]", " ", "sin\[CurlyPhi]"}], "]"}], TraditionalForm]]],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"[", 
     RowBox[{"sin\[Theta]", " ", "sin\[CurlyPhi]"}], "]"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 "\t\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{"sin\[Theta]", " ", "sin\[CurlyPhi]"}], "]"}], TraditionalForm]]],
 "\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"[", "cos\[CurlyPhi]", "]"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 "\t\t\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"[", "cos\[CurlyPhi]", "]"}], TraditionalForm]]],
 "\n\t\nThis surface takes awhile to be plotted."
}], "Text",
 CellChangeTimes->{{3.6036703075856457`*^9, 3.6036704247052107`*^9}, {
  3.603670456505266*^9, 3.603670502649665*^9}, {3.603670567804413*^9, 
  3.6036705881204443`*^9}, {3.60613706579957*^9, 3.6061370905986567`*^9}, {
  3.606137346238563*^9, 3.606137369775737*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "mp", "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "25"}], ";", "\n", "    ", 
       RowBox[{"ContourPlot3D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "^", "4"}], "+", 
          RowBox[{"y", "^", "4"}], "+", 
          RowBox[{"z", "^", "4"}], "+", 
          RowBox[{"a", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"x", "^", "2"}], "+", 
              RowBox[{"y", "^", "2"}], "+", 
              RowBox[{"z", "^", "2"}]}], ")"}], "^", "2"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
         RowBox[{"Contours", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"1", "+", "a"}], "}"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "mp", ",", "mp"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.2\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "0.3"}]}], "}"}], ",", 
      RowBox[{"-", "1"}], ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", "a", "}"}]}]}], "\n", "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
  3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
  3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
  3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
  3.603670177153167*^9}, {3.60367074797711*^9, 3.603670756084838*^9}, {
  3.603670860035123*^9, 3.603670861246537*^9}, {3.603670928960581*^9, 
  3.603670950784642*^9}, {3.60367098181133*^9, 3.603670996658833*^9}, {
  3.603671071199663*^9, 3.6036711375621653`*^9}, {3.6111480614617643`*^9, 
  3.611148065872013*^9}, {3.61240129450319*^9, 3.6124012954266148`*^9}, {
  3.6277726488008432`*^9, 3.627772661351272*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = -0.3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], -0.3}, -1, 1}}, Typeset`size$$ = {
    500., {274., 289.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$464$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = -0.3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$464$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$}, $CellContext`mp$ = 25; 
        ContourPlot3D[$CellContext`x^4 + $CellContext`y^4 + $CellContext`z^4 + \
$CellContext`a$$ ($CellContext`x^2 + $CellContext`y^2 + $CellContext`z^2)^2, \
{$CellContext`x, -2, 2}, {$CellContext`y, -2, 2}, {$CellContext`z, -2, 2}, 
          Contours -> {1 + $CellContext`a$$}, 
          PlotRange -> {{-2, 2}, {-2, 2}, {-2, 2}}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`mp$, \
$CellContext`mp$}, ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.2"]], 
      "Specifications" :> {{{$CellContext`a$$, -0.3}, -1, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {335., 342.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6036708998427973`*^9, {3.6036709529863863`*^9, 3.603670998401718*^9}, {
   3.60367108150419*^9, 3.603671091696374*^9}, {3.603671139905616*^9, 
   3.603671152928636*^9}, {3.603671189711344*^9, 3.603671195511238*^9}, {
   3.612401259248088*^9, 3.612401296434894*^9}, 3.627772668246969*^9, 
   3.630877552423493*^9, 3.630877628031342*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.3  Moebius strip", "Subsubsection"],

Cell[TextData[{
 "\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")[1 + ",
 StyleBox["v",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 "/2)]\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")[1 + ",
 StyleBox["v",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 "/2)]\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["v",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 "/2)\n\t"
}], "Text",
 CellChangeTimes->{{3.606137392925914*^9, 3.6061374211511593`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "25"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Cos", "[", "u", "]"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"v", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"u", "/", "2"}], "]"}]}]}], ")"}]}], ",", 
           RowBox[{
            RowBox[{"Sin", "[", "u", "]"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"v", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"u", "/", "2"}], "]"}]}]}], ")"}]}], ",", 
           RowBox[{"v", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"u", "/", "2"}], "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", 
           RowBox[{"-", "a"}], ",", "a"}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.3\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0.3"}], "}"}], ",", "0.1", ",", "0.5", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", "a", "}"}]}]}], "\n", "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.611148075135726*^9, 
   3.61114807814813*^9}, {3.612401318753915*^9, 3.6124013233399076`*^9}, {
   3.627772677638516*^9, 3.627772687087267*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.3}, 0.1, 0.5}}, Typeset`size$$ = {
    500., {269., 284.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$1837$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 0.3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$1837$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         25; $CellContext`np$ = 21; 
        ParametricPlot3D[{
          Cos[$CellContext`u] (1 + $CellContext`v Cos[$CellContext`u/2]), 
           Sin[$CellContext`u] (
            1 + $CellContext`v Cos[$CellContext`u/2]), $CellContext`v 
           Sin[$CellContext`u/2]}, {$CellContext`u, 0, 2 
           Pi}, {$CellContext`v, -$CellContext`a$$, $CellContext`a$$}, 
          PlotRange -> {{-1.5, 1.5}, {-1.5, 1.5}, {-1.5, 1.5}}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.3"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.3}, 0.1, 0.5, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {330., 337.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.603671428502261*^9, {3.603671520726427*^9, 3.60367160775408*^9}, {
   3.6124013065121183`*^9, 3.612401324094264*^9}, 3.6277726902188473`*^9, 
   3.630877636927163*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.4  Crosscap", "Subsubsection"],

Cell[TextData[{
 "\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") sin(2",
 StyleBox["v",
  FontSlant->"Italic"],
 ")/2\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = sin(2",
 StyleBox["u",
  FontSlant->"Italic"],
 ")",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["cos", "2"]}], TraditionalForm]]],
 "(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = cos(2",
 StyleBox["u",
  FontSlant->"Italic"],
 ")",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["cos", "2"]}], TraditionalForm]]],
 "(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t"
}], "Text",
 CellChangeTimes->{{3.603671687915388*^9, 3.603671703818705*^9}, {
  3.6061374784023237`*^9, 3.606137496751623*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "25"}], ";", "\n", "    ", 
      RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"c", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Sin", "[", "u", "]"}], 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"2", "v"}], "]"}], "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"2", "u"}], "]"}], " ", 
            RowBox[{
             RowBox[{"Cos", "[", "v", "]"}], "^", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"2", "u"}], "]"}], 
            RowBox[{
             RowBox[{"Cos", "[", "v", "]"}], "^", "2"}]}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}], ",", 
          RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"5", ",", " ", 
           RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.4\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "1"}], "}"}], ",", "0.1", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "c", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.6036717459810553`*^9, 
   3.603671811307948*^9}, {3.611148084847683*^9, 3.611148088046105*^9}, {
   3.621714983560849*^9, 3.621715028722444*^9}, {3.627772699864197*^9, 
   3.627772742336894*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 1}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$1183$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$1183$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         25; $CellContext`np$ = 21; 
        ParametricPlot3D[$CellContext`c$$ {
           Sin[$CellContext`u] (Sin[2 $CellContext`v]/2), 
            Sin[2 $CellContext`u] Cos[$CellContext`v]^2, 
            Cos[2 $CellContext`u] Cos[$CellContext`v]^2}, {$CellContext`u, 0, 
           Pi}, {$CellContext`v, (-Pi)/2, Pi/2}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.4"]], 
      "Specifications" :> {{{$CellContext`c$$, 1}, 0.1, 1, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {312., 319.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603671796502193*^9, 3.603671813110516*^9}, 
   3.612401332449191*^9, 3.621715032949127*^9, 3.62777274592946*^9, 
   3.630877659313696*^9, 3.630877765390136*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.5  Bohemian dome", "Subsubsection"],

Cell[TextData[{
 "\n \t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") + ",
 StyleBox["b",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n \t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 ") \n \n Only the lower half of the figure is plotted in order to show the \
internal geometry, but the whole figure can be plotted using ",
 StyleBox["v",
  FontSlant->"Italic"],
 " \[Element] [0, 2\[Pi]]."
}], "Text",
 CellChangeTimes->{{3.603671842028635*^9, 3.603671843888826*^9}, {
  3.6036722806059523`*^9, 3.603672356766851*^9}, {3.606137515402918*^9, 
  3.606137558939707*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "25"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"Cos", "[", "u", "]"}]}], ",", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"Sin", "[", "u", "]"}]}], "+", 
            RowBox[{"b", " ", 
             RowBox[{"Cos", "[", "v", "]"}]}]}], ",", 
           RowBox[{"c", " ", 
            RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", "\[Pi]", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.5\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "0.5", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "0.5", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "0.5"}], "}"}], ",", "0.25", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}], "\n", "]"}], 
  "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.6036719253938437`*^9, 
   3.6036719782459993`*^9}, {3.603672066157997*^9, 3.603672121456051*^9}, {
   3.6036722247707357`*^9, 3.603672244907728*^9}, {3.611148094973341*^9, 
   3.611148098547894*^9}, {3.6124013515032053`*^9, 3.6124013649770527`*^9}, {
   3.6277727565757008`*^9, 3.627772767811751*^9}, {3.627772859628187*^9, 
   3.627772862790781*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.5, $CellContext`c$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.5, 1}, {
      Hold[$CellContext`b$$], 0.5, 1}, {{
       Hold[$CellContext`c$$], 0.5}, 0.25, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$2400$$ = 
    0, $CellContext`b$2401$$ = 0, $CellContext`c$2402$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.5, $CellContext`c$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$2400$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2401$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2402$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         25; $CellContext`np$ = 21; 
        ParametricPlot3D[{$CellContext`a$$ 
           Cos[$CellContext`u], $CellContext`a$$ 
            Sin[$CellContext`u] + $CellContext`b$$ 
            Cos[$CellContext`v], $CellContext`c$$ 
           Sin[$CellContext`v]}, {$CellContext`u, 0, 2 Pi}, {$CellContext`v, 
           Pi, 2 Pi}, PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.5"]], 
      "Specifications" :> {{$CellContext`a$$, 0.5, 1, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 0.5, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.5}, 0.25, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {357., 364.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6036720087971478`*^9, 3.603672122833664*^9}, {
   3.603672226167583*^9, 3.6036722476818237`*^9}, {3.612401341922866*^9, 
   3.612401366845283*^9}, {3.627772771245994*^9, 3.627772793918975*^9}, 
   3.630877789573934*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.6  Conical wedge", "Subsubsection"],

Cell[TextData[{
 "\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["v",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["v",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"[", 
     RowBox[{
      SuperscriptBox[
       StyleBox["a",
        FontSlant->"Italic"], "2"], " ", "-", " ", 
      RowBox[{
       SuperscriptBox[
        StyleBox["b",
         FontSlant->"Italic"], "2"], 
       SuperscriptBox["cos", "2"], 
       RowBox[{"(", "u", ")"}]}]}], "]"}], 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 "\n\t\nUsing ",
 StyleBox["a",
  FontSlant->"Italic"],
 " = 1, ",
 StyleBox["b",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SqrtBox["2"], TraditionalForm]]],
 " gives \[OpenCurlyDoubleQuote]Conocuneus of Wallis\[CloseCurlyDoubleQuote]."
}], "Text",
 CellChangeTimes->{
  3.6036724010294113`*^9, 3.603672449617464*^9, {3.606137577840951*^9, 
   3.606137608177845*^9}, {3.60613764228351*^9, 3.606137642305028*^9}, {
   3.611185323009378*^9, 3.611185332596849*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "25"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"v", " ", 
            RowBox[{"Cos", "[", "u", "]"}]}], ",", 
           RowBox[{"v", " ", 
            RowBox[{"Sin", "[", "u", "]"}]}], ",", 
           RowBox[{"c", " ", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{"a", "^", "2"}], "-", 
              RowBox[{
               RowBox[{"b", "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Cos", "[", "u", "]"}], "^", "2"}]}]}], "]"}]}]}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", 
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.6\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "0.5", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "0.5", ",", "2", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "1"}], "}"}], ",", "0", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}], "\n", "]"}], 
  "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.6036719253938437`*^9, 
   3.6036719782459993`*^9}, {3.603672066157997*^9, 3.603672121456051*^9}, {
   3.6036722247707357`*^9, 3.603672244907728*^9}, 3.603672501642338*^9, {
   3.6036725516970377`*^9, 3.603672601965577*^9}, 3.603672692861946*^9, {
   3.611148105173085*^9, 3.6111481081853943`*^9}, 3.612401399541082*^9, {
   3.627772801213417*^9, 3.6277728111742563`*^9}, {3.627772849927841*^9, 
   3.627772853791522*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.5, $CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.5, 1}, {
      Hold[$CellContext`b$$], 0.5, 2}, {{
       Hold[$CellContext`c$$], 1}, 0, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$2792$$ = 
    0, $CellContext`b$2793$$ = 0, $CellContext`c$2794$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.5, $CellContext`c$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$2792$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2793$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2794$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         25; $CellContext`np$ = 21; 
        ParametricPlot3D[{$CellContext`v Cos[$CellContext`u], $CellContext`v 
           Sin[$CellContext`u], $CellContext`c$$ 
           Sqrt[$CellContext`a$$^2 - $CellContext`b$$^2 
             Cos[$CellContext`u]^2]}, {$CellContext`u, 0, 
           Pi}, {$CellContext`v, -1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.6"]], 
      "Specifications" :> {{$CellContext`a$$, 0.5, 1, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 1}, 0, 1, Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {357., 364.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603672511474099*^9, 3.603672525271469*^9}, {
   3.603672579059985*^9, 3.603672618528926*^9}, {3.603672649885969*^9, 
   3.603672739451082*^9}, {3.612401380959661*^9, 3.612401409927462*^9}, 
   3.627772822039114*^9, 3.6308778139055653`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.7  Astroidal surface", "Subsubsection"],

Cell[TextData[{
 "\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"[", 
     RowBox[{
      StyleBox["a",
       FontSlant->"Italic"], " ", "cos", 
      RowBox[{"(", 
       StyleBox["u",
        FontSlant->"Italic"], ")"}], "cos", 
      RowBox[{"(", 
       StyleBox["v",
        FontSlant->"Italic"], ")"}]}], "]"}], "3"], TraditionalForm]]],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"[", 
     RowBox[{
      StyleBox["a",
       FontSlant->"Italic"], " ", "sin", 
      RowBox[{"(", 
       StyleBox["u",
        FontSlant->"Italic"], ")"}], "cos", 
      RowBox[{"(", 
       StyleBox["v",
        FontSlant->"Italic"], ")"}]}], "]"}], "3"], TraditionalForm]]],
 "\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"[", 
     RowBox[{
      StyleBox["a",
       FontSlant->"Italic"], " ", "sin", 
      RowBox[{"(", 
       StyleBox["v",
        FontSlant->"Italic"], ")"}]}], "]"}], "3"], TraditionalForm]]],
 "\n\t\nImplicit equation: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      StyleBox["x",
       FontSlant->"Italic"], 
      RowBox[{"2", "/", "3"}]], " ", "+", " ", 
     SuperscriptBox[
      StyleBox["y",
       FontSlant->"Italic"], 
      RowBox[{"2", "/", "3"}]], " ", "+", " ", 
     SuperscriptBox[
      StyleBox["z",
       FontSlant->"Italic"], 
      RowBox[{"2", "/", "3"}]]}], " ", "=", " ", 
    SuperscriptBox[
     StyleBox["a",
      FontSlant->"Italic"], "2"]}], TraditionalForm]]],
 "Null"
}], "Text",
 CellChangeTimes->{{3.603672828445558*^9, 3.6036728296823063`*^9}, {
  3.603672864883184*^9, 3.6036728685012302`*^9}, {3.606137650305183*^9, 
  3.606137668940538*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "25"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"Cos", "[", "u", "]"}], 
             RowBox[{"Cos", "[", "v", "]"}]}], ",", 
            RowBox[{"a", " ", 
             RowBox[{"Sin", "[", "u", "]"}], 
             RowBox[{"Cos", "[", "v", "]"}]}], ",", 
            RowBox[{"a", " ", 
             RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}], "^", "3"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", 
           RowBox[{
            RowBox[{"-", "\[Pi]"}], "/", "2"}], ",", 
           RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.7\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "1.1"}], "}"}], ",", "0.9", ",", "1.1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", "a", "}"}]}]}], "\n", "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.603672988639448*^9, 
   3.6036730116673307`*^9}, {3.603673064651318*^9, 3.603673089464676*^9}, {
   3.611148116710643*^9, 3.611148119623364*^9}, {3.6124014371294327`*^9, 
   3.612401441615172*^9}, {3.62777283356063*^9, 3.627772842838895*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1.1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 1.1}, 0.9, 1.1}}, Typeset`size$$ = {
    500., {269., 284.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$3189$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 1.1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$3189$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         25; $CellContext`np$ = 21; 
        ParametricPlot3D[{$CellContext`a$$ Cos[$CellContext`u] 
            Cos[$CellContext`v], $CellContext`a$$ Sin[$CellContext`u] 
            Cos[$CellContext`v], $CellContext`a$$ 
            Sin[$CellContext`v]}^3, {$CellContext`u, 0, 2 
           Pi}, {$CellContext`v, (-Pi)/2, Pi/2}, 
          PlotRange -> {{-1.5, 1.5}, {-1.5, 1.5}, {-1.5, 1.5}}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.7"]], 
      "Specifications" :> {{{$CellContext`a$$, 1.1}, 0.9, 1.1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {330., 337.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603673017883852*^9, 3.603673024312807*^9}, {
   3.603673072951165*^9, 3.6036730963620996`*^9}, {3.6124014183111362`*^9, 
   3.612401442406458*^9}, 3.630877836737866*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.8  Corkscrew surface", "Subsubsection"],

Cell[TextData[{
 "\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["a",
     FontSlant->"Italic"], " ", "cos", 
    RowBox[{"(", 
     StyleBox["u",
      FontSlant->"Italic"], ")"}], "cos", 
    RowBox[{"(", 
     StyleBox["v",
      FontSlant->"Italic"], ")"}]}], TraditionalForm]]],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["a",
     FontSlant->"Italic"], " ", "sin", 
    RowBox[{"(", 
     StyleBox["u",
      FontSlant->"Italic"], ")"}], "cos", 
    RowBox[{"(", 
     StyleBox["v",
      FontSlant->"Italic"], ")"}]}], TraditionalForm]]],
 "\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["a",
      FontSlant->"Italic"], " ", "sin", 
     RowBox[{"(", 
      StyleBox["v",
       FontSlant->"Italic"], ")"}]}], " ", "+", " ", 
    StyleBox["u",
     FontSlant->"Italic"]}], TraditionalForm]]],
 "/(2\[Pi])\n\nThis surface is also called a \[OpenCurlyDoubleQuote]twisted \
sphere",
 StyleBox["\[CloseCurlyDoubleQuote]",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.6036731549568777`*^9, 3.6036732019355507`*^9}, {
  3.603674161757413*^9, 3.603674161757536*^9}, {3.60367432282157*^9, 
  3.603674334195997*^9}, {3.606137703067625*^9, 3.606137735041381*^9}, {
  3.611185382310749*^9, 3.611185397447259*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "25"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"Cos", "[", "u", "]"}], 
            RowBox[{"Cos", "[", "v", "]"}]}], ",", 
           RowBox[{"a", " ", 
            RowBox[{"Sin", "[", "u", "]"}], 
            RowBox[{"Cos", "[", "v", "]"}]}], ",", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"Sin", "[", "v", "]"}]}], "+", 
            RowBox[{"u", "/", 
             RowBox[{"(", 
              RowBox[{"2", "\[Pi]"}], ")"}]}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", 
           RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "a"}], ",", "a"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "a"}], ",", "a"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "a"}], ",", 
              RowBox[{"a", "+", "1"}]}], "}"}]}], "}"}]}], ",", 
         RowBox[{"BoxRatios", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "a"}], ",", 
            RowBox[{"2", "a"}], ",", 
            RowBox[{
             RowBox[{"2", "a"}], "+", "1"}]}], "}"}]}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.8\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0.5"}], "}"}], ",", "0.1", ",", "1.0", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", "a", "}"}]}]}], "\n", "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.603672988639448*^9, 
   3.6036730116673307`*^9}, {3.603673064651318*^9, 3.603673089464676*^9}, {
   3.603673228764433*^9, 3.6036733041450567`*^9}, {3.603673426493277*^9, 
   3.6036734589866*^9}, {3.60367359743256*^9, 3.6036736335601*^9}, {
   3.6036736695709467`*^9, 3.603673705356945*^9}, 3.60367373744344*^9, 
   3.6036737732449102`*^9, {3.603673805972374*^9, 3.603673820884074*^9}, {
   3.603673871546977*^9, 3.603673904128047*^9}, {3.6036741573500338`*^9, 
   3.60367421248741*^9}, {3.603674343312234*^9, 3.603674414424646*^9}, {
   3.603674448089486*^9, 3.603674484625493*^9}, {3.603674699142418*^9, 
   3.603674723977683*^9}, {3.611148127961337*^9, 3.611148131011475*^9}, {
   3.627772888988318*^9, 3.6277728991643057`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.1, 1.}}, Typeset`size$$ = {
    500., {391., 407.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$3564$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 0.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$3564$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         25; $CellContext`np$ = 21; 
        ParametricPlot3D[{$CellContext`a$$ Cos[$CellContext`u] 
           Cos[$CellContext`v], $CellContext`a$$ Sin[$CellContext`u] 
           Cos[$CellContext`v], $CellContext`a$$ 
            Sin[$CellContext`v] + $CellContext`u/(2 Pi)}, {$CellContext`u, 0, 
           2 Pi}, {$CellContext`v, -Pi, Pi}, 
          PlotRange -> {{-$CellContext`a$$, $CellContext`a$$}, \
{-$CellContext`a$$, $CellContext`a$$}, {-$CellContext`a$$, $CellContext`a$$ + 
             1}}, BoxRatios -> {
           2 $CellContext`a$$, 2 $CellContext`a$$, 2 $CellContext`a$$ + 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.8"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.1, 1., Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {452., 459.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6036737388973503`*^9, {3.6036737760230503`*^9, 3.603673847065158*^9}, 
   3.603673911824937*^9, {3.603674188100746*^9, 3.603674235675076*^9}, {
   3.603674274891068*^9, 3.6036742772244663`*^9}, 3.60367434959866*^9, {
   3.60367439304803*^9, 3.603674423638483*^9}, {3.60367448618775*^9, 
   3.603674516986847*^9}, {3.6036745628360643`*^9, 3.603674566835894*^9}, 
   3.603674667517467*^9, 3.603674700722892*^9, {3.603674737572514*^9, 
   3.603674747049514*^9}, 3.6124014548758507`*^9, 3.627772901287911*^9, 
   3.6308778660545273`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.9  Dini's  surface", "Subsubsection"],

Cell[TextData[{
 "\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["a",
     FontSlant->"Italic"], " ", "cos", 
    RowBox[{"(", 
     StyleBox["u",
      FontSlant->"Italic"], ")"}], "sin", 
    RowBox[{"(", 
     StyleBox["v",
      FontSlant->"Italic"], ")"}]}], TraditionalForm]]],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["a",
     FontSlant->"Italic"], " ", "sin", 
    RowBox[{"(", 
     StyleBox["u",
      FontSlant->"Italic"], ")"}], "sin", 
    RowBox[{"(", 
     StyleBox["v",
      FontSlant->"Italic"], ")"}]}], TraditionalForm]]],
 "\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["c",
      FontSlant->"Italic"], " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"cos", 
        RowBox[{"(", 
         StyleBox["v",
          FontSlant->"Italic"], ")"}]}], " ", "+", " ", 
       RowBox[{"ln", "[", 
        RowBox[{"tan", 
         RowBox[{"(", 
          RowBox[{
           StyleBox["v",
            FontSlant->"Italic"], "/", "2"}], ")"}]}], "]"}]}], "}"}]}], " ", 
    "+", " ", 
    RowBox[{
     StyleBox["u",
      FontSlant->"Italic"], "/", 
     RowBox[{"(", 
      RowBox[{"2", "\[Pi]"}], ")"}]}]}], TraditionalForm]]],
 "\n\t"
}], "Text",
 CellChangeTimes->{{3.6036748665782146`*^9, 3.6036748665782967`*^9}, {
  3.6036752130800323`*^9, 3.603675222254632*^9}, {3.606137757467948*^9, 
  3.6061377750788393`*^9}, {3.612401486765786*^9, 3.612401486765873*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np", ",", "b"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "25"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\[IndentingNewLine]", 
       RowBox[{"b", "=", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]"}], ")"}]}]}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"Cos", "[", "u", "]"}], 
            RowBox[{"Sin", "[", "v", "]"}]}], ",", 
           RowBox[{"a", " ", 
            RowBox[{"Sin", "[", "u", "]"}], 
            RowBox[{"Sin", "[", "v", "]"}]}], ",", 
           RowBox[{
            RowBox[{"a", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", "v", "]"}], "+", 
               RowBox[{"Log", "[", 
                RowBox[{"Tan", "[", 
                 RowBox[{"v", "/", "2"}], "]"}], "]"}]}], ")"}]}], "+", " ", 
            RowBox[{"u", "/", 
             RowBox[{"(", 
              RowBox[{"2", "\[Pi]"}], ")"}]}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", 
           RowBox[{"2", "\[Pi]"}], ",", 
           RowBox[{"6", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", "0", ",", 
           RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "a"}], ",", "a"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "a"}], ",", "a"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "a"}], ",", 
              RowBox[{"a", "+", "3"}]}], "}"}]}], "}"}]}], ",", 
         RowBox[{"BoxRatios", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "a"}], ",", 
            RowBox[{"2", "a"}], ",", "c"}], "}"}]}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.9\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0.5"}], "}"}], ",", "0.5", ",", "3.0", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "1", ",", "2", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", "a", "}"}]}]}], "\n", "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.603672988639448*^9, 
   3.6036730116673307`*^9}, {3.603673064651318*^9, 3.603673089464676*^9}, {
   3.603673228764433*^9, 3.6036733041450567`*^9}, {3.603673426493277*^9, 
   3.6036734589866*^9}, {3.60367359743256*^9, 3.6036736335601*^9}, {
   3.6036736695709467`*^9, 3.603673705356945*^9}, 3.60367373744344*^9, 
   3.6036737732449102`*^9, {3.603673805972374*^9, 3.603673820884074*^9}, {
   3.603673871546977*^9, 3.603673904128047*^9}, {3.6036741573500338`*^9, 
   3.60367421248741*^9}, {3.603674343312234*^9, 3.603674414424646*^9}, {
   3.603674448089486*^9, 3.603674484625493*^9}, {3.603674699142418*^9, 
   3.603674723977683*^9}, {3.603674910280397*^9, 3.6036749139277563`*^9}, 
   3.603674958196929*^9, {3.60367499985574*^9, 3.603675000632288*^9}, 
   3.603675098256867*^9, 3.603675134057083*^9, {3.603675266594593*^9, 
   3.6036752778456*^9}, 3.603675329432851*^9, 3.60367539513449*^9, 
   3.603675522485126*^9, {3.611148138612083*^9, 3.611148141799231*^9}, {
   3.6124014909541597`*^9, 3.6124015406793833`*^9}, {3.612402378209487*^9, 
   3.6124023913962173`*^9}, {3.627772912413678*^9, 3.627772925890533*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`c$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.5, 3.}, {
      Hold[$CellContext`c$$], 1, 2}}, Typeset`size$$ = {500., {267., 282.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`a$3946$$ = 0, $CellContext`c$3947$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`c$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$3946$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$3947$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`b$}, \
$CellContext`mp$ = 25; $CellContext`np$ = 21; $CellContext`b$ = 1/(2 Pi); 
        ParametricPlot3D[{$CellContext`a$$ Cos[$CellContext`u] 
           Sin[$CellContext`v], $CellContext`a$$ Sin[$CellContext`u] 
           Sin[$CellContext`v], $CellContext`a$$ (Cos[$CellContext`v] + Log[
               Tan[$CellContext`v/2]]) + $CellContext`u/(2 
            Pi)}, {$CellContext`u, 2 Pi, 6 Pi}, {$CellContext`v, 0, Pi/2}, 
          PlotRange -> {{-$CellContext`a$$, $CellContext`a$$}, \
{-$CellContext`a$$, $CellContext`a$$}, {-$CellContext`a$$, $CellContext`a$$ + 
             3}}, BoxRatios -> {
           2 $CellContext`a$$, 2 $CellContext`a$$, $CellContext`c$$}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.9"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.5, 3., Appearance -> 
         "Labeled"}, {$CellContext`c$$, 1, 2, Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`a$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {350., 357.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603675071462695*^9, 3.603675147142564*^9}, {
   3.603675334660479*^9, 3.603675345405794*^9}, {3.6036753961454353`*^9, 
   3.603675407471377*^9}, {3.6036755022697163`*^9, 3.603675528222064*^9}, 
   3.6124014663951797`*^9, {3.6124015198253613`*^9, 3.612401541393957*^9}, 
   3.6124023955759068`*^9, 3.627772927325028*^9, 3.630877898068851*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.10  Cyclide of Dupin", "Subsubsection"],

Cell[TextData[{
 "\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       StyleBox["c",
        FontSlant->"Italic"], "[", 
       RowBox[{
        StyleBox["b",
         FontSlant->"Italic"], " ", "-", " ", 
        RowBox[{
         StyleBox["c",
          FontSlant->"Italic"], " ", "cos", 
         RowBox[{"(", 
          StyleBox["u",
           FontSlant->"Italic"], ")"}]}]}], "]"}], " ", "+", " ", 
      RowBox[{
       StyleBox["a",
        FontSlant->"Italic"], " ", "cos", 
       RowBox[{
        RowBox[{"(", 
         StyleBox["u",
          FontSlant->"Italic"], ")"}], " ", "[", 
        RowBox[{
         StyleBox["a",
          FontSlant->"Italic"], " ", "-", " ", 
         RowBox[{
          StyleBox["b",
           FontSlant->"Italic"], " ", "cos", 
          RowBox[{"(", 
           StyleBox["v",
            FontSlant->"Italic"], ")"}]}]}], "]"}]}]}], "}"}], "/", 
    RowBox[{"[", 
     RowBox[{
      StyleBox["a",
       FontSlant->"Italic"], " ", "-", " ", 
      RowBox[{
       StyleBox["c",
        FontSlant->"Italic"], " ", "cos", 
       RowBox[{"(", 
        StyleBox["u",
         FontSlant->"Italic"], ")"}], " ", "cos", 
       RowBox[{"(", 
        StyleBox["v",
         FontSlant->"Italic"], ")"}]}]}], "]"}]}], TraditionalForm]]],
 " \n \t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        StyleBox["a",
         FontSlant->"Italic"], "2"], " ", "-", 
       StyleBox[" ",
        FontSlant->"Italic"], 
       SuperscriptBox[
        StyleBox["c",
         FontSlant->"Italic"], "2"]}]], "[", 
     RowBox[{
      StyleBox["a",
       FontSlant->"Italic"], " ", "-", " ", 
      RowBox[{
       StyleBox["b",
        FontSlant->"Italic"], " ", "cos", 
       RowBox[{"(", 
        StyleBox["v",
         FontSlant->"Italic"], ")"}]}]}], "]"}], " ", "sin"}], 
   TraditionalForm]]],
 "(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")}/[",
 StyleBox["a",
  FontSlant->"Italic"],
 " - ",
 StyleBox["c",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")]\n \t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        StyleBox["a",
         FontSlant->"Italic"], "2"], " ", "-", " ", 
       SuperscriptBox[
        StyleBox["c",
         FontSlant->"Italic"], "2"]}]], "[", 
     RowBox[{"b", " ", "-", " ", 
      RowBox[{
       StyleBox["c",
        FontSlant->"Italic"], " ", "cos", 
       RowBox[{"(", 
        StyleBox["u",
         FontSlant->"Italic"], ")"}]}]}], "]"}], " ", "sin"}], 
   TraditionalForm]]],
 "(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")}/[",
 StyleBox["a",
  FontSlant->"Italic"],
 " - ",
 StyleBox["c",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")]\n \t\n Note: For ",
 StyleBox["b",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 ", the figure has an infinitesimal cross-section at ",
 StyleBox["u",
  FontSlant->"Italic"],
 " = 0; for ",
 StyleBox["c",
  FontSlant->"Italic"],
 " > ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", the figure has two such cross-sections. \t"
}], "Text",
 CellChangeTimes->{{3.606137792480295*^9, 3.606137804454321*^9}, {
  3.606137860379936*^9, 3.606137863631473*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
      RowBox[{
       RowBox[{"mp", " ", "=", " ", "50"}], ";", "\n", "    ", 
       RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"c", 
               RowBox[{"(", 
                RowBox[{"b", "-", 
                 RowBox[{"c", " ", 
                  RowBox[{"Cos", "[", "u", "]"}]}]}], ")"}]}], "+", 
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", "u", "]"}], 
               RowBox[{"(", 
                RowBox[{"a", "-", 
                 RowBox[{"b", " ", 
                  RowBox[{"Cos", "[", "v", "]"}]}]}], ")"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"a", "-", 
              RowBox[{"c", " ", 
               RowBox[{"Cos", "[", "u", "]"}], 
               RowBox[{"Cos", "[", "v", "]"}]}]}], ")"}]}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{
                RowBox[{"a", "^", "2"}], "-", 
                RowBox[{"c", "^", "2"}]}], "]"}], 
              RowBox[{"(", 
               RowBox[{"a", "-", 
                RowBox[{"b", " ", 
                 RowBox[{"Cos", "[", "v", "]"}]}]}], ")"}], 
              RowBox[{"Sin", "[", "u", "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"a", "-", 
              RowBox[{"c", " ", 
               RowBox[{"Cos", "[", "u", "]"}], 
               RowBox[{"Cos", "[", "v", "]"}]}]}], ")"}]}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{
                RowBox[{"a", "^", "2"}], "-", 
                RowBox[{"c", "^", "2"}]}], "]"}], 
              RowBox[{"(", 
               RowBox[{"b", "-", 
                RowBox[{"c", " ", 
                 RowBox[{"Cos", "[", "u", "]"}]}]}], ")"}], 
              RowBox[{"Sin", "[", "v", "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"a", "-", 
              RowBox[{"c", " ", 
               RowBox[{"Cos", "[", "u", "]"}], 
               RowBox[{"Cos", "[", "v", "]"}]}]}], ")"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"u", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", " ", 
         RowBox[{"PlotPoints", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", 
            RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.10\>\""}]}], "]"}]}]}], 
     "\n", "  ", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0.5"}], "}"}], ",", "0.1", ",", "1", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"b", ",", "0.2"}], "}"}], ",", "0.1", ",", "a", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "0.2"}], "}"}], ",", "0.1", ",", "a", ",", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}], "\n", "]"}], 
  "\n"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603717793968172*^9, 3.6037178211446*^9}, 3.603717910286168*^9, {
   3.611148149750773*^9, 3.6111481542869263`*^9}, {3.612401593363473*^9, 
   3.6124016103803167`*^9}, {3.62777293858871*^9, 3.627772952878262*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    0.2, $CellContext`c$$ = 0.2, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.1, 1}, {{
       Hold[$CellContext`b$$], 0.2}, 0.1, 
      Dynamic[$CellContext`a$$]}, {{
       Hold[$CellContext`c$$], 0.2}, 0.1, 
      Dynamic[$CellContext`a$$]}}, Typeset`size$$ = {500., {251., 266.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`a$4340$$ = 0, $CellContext`b$4341$$ = 
    0, $CellContext`c$4342$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        0.2, $CellContext`c$$ = 0.2}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$4340$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$4341$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$4342$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         50; $CellContext`np$ = 21; 
        ParametricPlot3D[{($CellContext`c$$ ($CellContext`b$$ - \
$CellContext`c$$ Cos[$CellContext`u]) + $CellContext`a$$ 
             Cos[$CellContext`u] ($CellContext`a$$ - $CellContext`b$$ 
              Cos[$CellContext`v]))/($CellContext`a$$ - $CellContext`c$$ 
           Cos[$CellContext`u] 
           Cos[$CellContext`v]), (
            Sqrt[$CellContext`a$$^2 - $CellContext`c$$^2] ($CellContext`a$$ - \
$CellContext`b$$ Cos[$CellContext`v]) 
            Sin[$CellContext`u])/($CellContext`a$$ - $CellContext`c$$ 
           Cos[$CellContext`u] 
           Cos[$CellContext`v]), (
            Sqrt[$CellContext`a$$^2 - $CellContext`c$$^2] ($CellContext`b$$ - \
$CellContext`c$$ Cos[$CellContext`u]) 
            Sin[$CellContext`v])/($CellContext`a$$ - $CellContext`c$$ 
           Cos[$CellContext`u] Cos[$CellContext`v])}, {$CellContext`u, 0, 2 
           Pi}, {$CellContext`v, 0, 2 Pi}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.10"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.2}, 0.1, 
         Dynamic[$CellContext`a$$], Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.2}, 0.1, 
         Dynamic[$CellContext`a$$], Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {357., 364.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603717857156147*^9, 3.603717996994238*^9}, {
   3.612401561841888*^9, 3.612401611243093*^9}, 3.6277729541576843`*^9, 
   3.630877926569055*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.11  Sine  surface", "Subsubsection"],

Cell[TextData[{
 StyleBox["\n\tx",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"sin", 
    RowBox[{"(", 
     StyleBox["u",
      FontSlant->"Italic"], ")"}]}], TraditionalForm]]],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"sin", 
    RowBox[{"(", 
     StyleBox["v",
      FontSlant->"Italic"], ")"}]}], TraditionalForm]]],
 "\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"sin", 
    RowBox[{"(", 
     RowBox[{
      StyleBox["u",
       FontSlant->"Italic"], " ", "+", 
      StyleBox[" ",
       FontSlant->"Italic"], 
      StyleBox["v",
       FontSlant->"Italic"]}], ")"}]}], TraditionalForm]]],
 "\n"
}], "Text",
 CellChangeTimes->{
  3.603718056930029*^9, {3.603718186549262*^9, 3.603718192148756*^9}, {
   3.606137902444696*^9, 3.6061379705056973`*^9}, {3.6217150786724443`*^9, 
   3.621715086195526*^9}, {3.6323196241431723`*^9, 3.63231964056643*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"mp", " ", "=", " ", "25"}], ";", "\n", "    ", 
        RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"c", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sin", "[", "u", "]"}], ",", 
             RowBox[{"Sin", "[", "v", "]"}], ",", 
             RowBox[{"Sin", "[", 
              RowBox[{"u", "+", "v"}], "]"}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"u", ",", "0", ",", 
            RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"v", ",", 
            RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", " ", 
          RowBox[{"PlotPoints", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
          RowBox[{"ViewPoint", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"5", ",", " ", 
             RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.11\>\""}]}], "]"}]}]}], 
      "\n", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"c", ",", "1"}], "}"}], ",", "0.1", ",", "1", ",", 
       RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"TrackedSymbols", "\[Rule]", 
      RowBox[{"{", "c", "}"}]}]}], "\[IndentingNewLine]", "]"}], 
   "\n"}]}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.603672988639448*^9, 
   3.6036730116673307`*^9}, {3.603673064651318*^9, 3.603673089464676*^9}, {
   3.603673228764433*^9, 3.6036733041450567`*^9}, {3.603673426493277*^9, 
   3.6036734589866*^9}, {3.60367359743256*^9, 3.6036736335601*^9}, {
   3.6036736695709467`*^9, 3.603673705356945*^9}, 3.60367373744344*^9, 
   3.6036737732449102`*^9, {3.603673805972374*^9, 3.603673820884074*^9}, {
   3.603673871546977*^9, 3.603673904128047*^9}, {3.6036741573500338`*^9, 
   3.60367421248741*^9}, {3.603674343312234*^9, 3.603674414424646*^9}, {
   3.603674448089486*^9, 3.603674484625493*^9}, {3.603674699142418*^9, 
   3.603674723977683*^9}, {3.603674910280397*^9, 3.6036749139277563`*^9}, 
   3.603674958196929*^9, {3.60367499985574*^9, 3.603675000632288*^9}, 
   3.603675098256867*^9, 3.603675134057083*^9, {3.603675266594593*^9, 
   3.6036752778456*^9}, 3.603675329432851*^9, 3.60367539513449*^9, 
   3.603675522485126*^9, {3.603718099274288*^9, 3.603718157097145*^9}, {
   3.6037182050464478`*^9, 3.603718228245143*^9}, {3.6111481635719023`*^9, 
   3.611148166996846*^9}, {3.621715095161121*^9, 3.621715110559985*^9}, {
   3.62777296828793*^9, 3.627773005263534*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 1}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$4736$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$4736$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         25; $CellContext`np$ = 21; ParametricPlot3D[$CellContext`c$$ {
            Sin[$CellContext`u], 
            Sin[$CellContext`v], 
            Sin[$CellContext`u + $CellContext`v]}, {$CellContext`u, 0, 2 
           Pi}, {$CellContext`v, -Pi, Pi}, 
          PlotRange -> {{-1, 1}, {-1, 1}, {-1, 1}}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.11"]], 
      "Specifications" :> {{{$CellContext`c$$, 1}, 0.1, 1, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {312., 319.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6037181621024847`*^9, 3.603718231035899*^9, 3.6124016233512373`*^9, 
   3.621715115363323*^9, {3.627772998010325*^9, 3.6277730069579697`*^9}, 
   3.630877948753023*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.12  Cosine  surface", "Subsubsection"],

Cell[TextData[{
 StyleBox["\n\tx",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"cos", 
    RowBox[{"(", 
     StyleBox["u",
      FontSlant->"Italic"], ")"}]}], TraditionalForm]]],
 "\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"cos", 
    RowBox[{"(", 
     StyleBox["v",
      FontSlant->"Italic"], ")"}]}], TraditionalForm]]],
 "\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      StyleBox["u",
       FontSlant->"Italic"], " ", "+", 
      StyleBox[" ",
       FontSlant->"Italic"], 
      StyleBox["v",
       FontSlant->"Italic"]}], ")"}]}], TraditionalForm]]],
 "\n\t"
}], "Text",
 CellChangeTimes->{{3.603718270743989*^9, 3.6037183036302567`*^9}, {
  3.606138048482003*^9, 3.606138070693797*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"mp", ",", "np"}], "}"}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"mp", " ", "=", " ", "25"}], ";", "\n", "    ", 
        RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "    ", 
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"c", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", "u", "]"}], ",", 
             RowBox[{"Cos", "[", "v", "]"}], ",", 
             RowBox[{"Cos", "[", 
              RowBox[{"u", "+", "v"}], "]"}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"u", ",", "0", ",", 
            RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"v", ",", 
            RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", " ", 
          RowBox[{"PlotPoints", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
          RowBox[{"ViewPoint", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"5", ",", " ", 
             RowBox[{"-", "6"}], ",", " ", "4"}], "}"}]}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.12\>\""}]}], "]"}]}]}], 
      "\n", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"c", ",", "1"}], "}"}], ",", "0.1", ",", "1", ",", 
       RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"TrackedSymbols", "\[Rule]", 
      RowBox[{"{", "c", "}"}]}]}], "\[IndentingNewLine]", "]"}], 
   "\n"}]}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.603672988639448*^9, 
   3.6036730116673307`*^9}, {3.603673064651318*^9, 3.603673089464676*^9}, {
   3.603673228764433*^9, 3.6036733041450567`*^9}, {3.603673426493277*^9, 
   3.6036734589866*^9}, {3.60367359743256*^9, 3.6036736335601*^9}, {
   3.6036736695709467`*^9, 3.603673705356945*^9}, 3.60367373744344*^9, 
   3.6036737732449102`*^9, {3.603673805972374*^9, 3.603673820884074*^9}, {
   3.603673871546977*^9, 3.603673904128047*^9}, {3.6036741573500338`*^9, 
   3.60367421248741*^9}, {3.603674343312234*^9, 3.603674414424646*^9}, {
   3.603674448089486*^9, 3.603674484625493*^9}, {3.603674699142418*^9, 
   3.603674723977683*^9}, {3.603674910280397*^9, 3.6036749139277563`*^9}, 
   3.603674958196929*^9, {3.60367499985574*^9, 3.603675000632288*^9}, 
   3.603675098256867*^9, 3.603675134057083*^9, {3.603675266594593*^9, 
   3.6036752778456*^9}, 3.603675329432851*^9, 3.60367539513449*^9, 
   3.603675522485126*^9, {3.603718099274288*^9, 3.603718157097145*^9}, {
   3.6037182050464478`*^9, 3.603718228245143*^9}, {3.60371832443478*^9, 
   3.603718333859724*^9}, {3.611148175371751*^9, 3.611148179709525*^9}, {
   3.621715128434969*^9, 3.621715153436961*^9}, {3.6277730318405313`*^9, 
   3.627773047199201*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 1}, 0.1, 1}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$5109$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$5109$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         25; $CellContext`np$ = 21; ParametricPlot3D[$CellContext`c$$ {
            Cos[$CellContext`u], 
            Cos[$CellContext`v], 
            Cos[$CellContext`u + $CellContext`v]}, {$CellContext`u, 0, 2 
           Pi}, {$CellContext`v, -Pi, Pi}, 
          PlotRange -> {{-1, 1}, {-1, 1}, {-1, 1}}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.12"]], 
      "Specifications" :> {{{$CellContext`c$$, 1}, 0.1, 1, Appearance -> 
         "Labeled"}}, "Options" :> {TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {312., 319.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.603718338999213*^9, 3.612401633314006*^9, 3.6217151552125053`*^9, {
   3.62777303450937*^9, 3.6277730477387877`*^9}, 3.630877972304865*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.13  Catenoid", "Subsubsection"],

Cell[TextData[{
 "\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), \n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["u",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 "), \n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 "\[PlusMinus]",
 "arccosh(",
 StyleBox["u",
  FontSlant->"Italic"],
 ").  \n\nThe catenoid is the only surface of revolution which is also a \
\"minimal surface.\"  In the following, the top (",
 StyleBox["z",
  FontSlant->"Italic"],
 " > 0) and bottom (",
 StyleBox["z",
  FontSlant->"Italic"],
 " < 0) halves are constructed separately and then combined in the final \
plot.    \n"
}], "Text",
 CellChangeTimes->{{3.603718418170115*^9, 3.6037184314844418`*^9}, {
  3.606138117419464*^9, 3.6061381500355177`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", " ", "np", ",", " ", "minu", ",", " ", "maxu"}], 
      "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "41"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "41"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"minu", " ", "=", " ", 
       RowBox[{"-", "10"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"maxu", " ", "=", " ", "10"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", "*", "u", "*", 
           RowBox[{"Cos", "[", "v", "]"}]}], ",", 
          RowBox[{"a", "*", "u", "*", 
           RowBox[{"Sin", "[", "v", "]"}]}], ",", 
          RowBox[{"a", "*", 
           RowBox[{"Sign", "[", "u", "]"}], 
           RowBox[{"ArcCosh", "[", 
            RowBox[{"Abs", "[", "u", "]"}], "]"}]}]}], "}"}], ",", " ", "\n", 
        "      ", 
        RowBox[{"{", 
         RowBox[{"u", ",", " ", "minu", ",", " ", "maxu"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"v", ",", " ", "0", ",", " ", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", " ", "np"}], "}"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], "*", "maxu"}], ",", 
            RowBox[{"a", "*", "maxu"}]}], "}"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", 
           RowBox[{"-", "5"}], ",", "1"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.13\>\""}]}], "]"}]}]}], 
    "  ", "\[IndentingNewLine]", "]"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "0.3"}], "}"}], ",", " ", "0.1", ",", " ", "0.5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", "a", "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.603672988639448*^9, 
   3.6036730116673307`*^9}, {3.603673064651318*^9, 3.603673089464676*^9}, {
   3.603718490787071*^9, 3.6037187286960773`*^9}, {3.603718760439679*^9, 
   3.6037188102518253`*^9}, {3.603718908852*^9, 3.6037189171412973`*^9}, {
   3.603718949927916*^9, 3.603719007376978*^9}, {3.603719083157634*^9, 
   3.603719094000058*^9}, {3.6111481864990673`*^9, 3.611148189136529*^9}, {
   3.612401666318838*^9, 3.612401672030264*^9}, {3.6124023334838448`*^9, 
   3.6124023473335752`*^9}, {3.627773066216009*^9, 3.627773107998129*^9}, {
   3.630883678743628*^9, 3.630883698827813*^9}, {3.630883730141487*^9, 
   3.630883733100377*^9}, {3.630883787500452*^9, 3.630883788549239*^9}, 
   3.630883831169166*^9, {3.630883870332157*^9, 3.630883895361988*^9}, 
   3.630883971765389*^9, {3.630884024238792*^9, 3.630884028674548*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.3}, 0.1, 0.5}}, Typeset`size$$ = {
    500., {229., 244.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$8732$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`a$$ = 0.3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$8732$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`minu$, \
$CellContext`maxu$}, $CellContext`mp$ = 41; $CellContext`np$ = 
         41; $CellContext`minu$ = -10; $CellContext`maxu$ = 10; 
        ParametricPlot3D[{$CellContext`a$$ $CellContext`u 
           Cos[$CellContext`v], $CellContext`a$$ $CellContext`u 
           Sin[$CellContext`v], $CellContext`a$$ Sign[$CellContext`u] ArcCosh[
             
             Abs[$CellContext`u]]}, {$CellContext`u, $CellContext`minu$, \
$CellContext`maxu$}, {$CellContext`v, 0, 2 Pi}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          PlotRange -> {{(-$CellContext`a$$) $CellContext`maxu$, \
$CellContext`a$$ $CellContext`maxu$}}, ViewPoint -> {4, -5, 1}, PlotLabel -> 
          "13.7.13"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.3}, 0.1, 0.5, Appearance -> 
         "Labeled"}}, 
      "Options" :> {ContinuousAction -> False, TrackedSymbols -> {0.3}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {290., 297.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603718814505508*^9, 3.6037188399029922`*^9}, {
   3.6037189236181917`*^9, 3.603719029383052*^9}, 3.612401641341629*^9, 
   3.612401672922119*^9, 3.627773112369349*^9, 3.630877997505808*^9, 
   3.630883710754979*^9, 3.630883761310007*^9, 3.630883800289382*^9, 
   3.6308838981317997`*^9, 3.630883975573069*^9, 3.630884029220562*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.14  Right helicoid", "Subsubsection"],

Cell[TextData[{
 "The equation of the right helicoid is given by ",
 StyleBox["z ",
  FontSlant->"Italic"],
 "=",
 StyleBox[" ",
  FontSlant->"Italic"],
 "arctan(",
 StyleBox["y",
  FontSlant->"Italic"],
 "/",
 StyleBox["x",
  FontSlant->"Italic"],
 ") + 2",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[Pi] where ",
 StyleBox["n",
  FontSlant->"Italic"],
 " is the number of twists.  Parametrically, \n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["u",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[Pi]",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["u",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[Pi]",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["v",
  FontSlant->"Italic"],
 "\n\nSurfaces generated with min(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") < 0 and max(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") > 0 appear as twisted ribbons.  Surfaces generated with min(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") > 0 and max(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") > 0 or with min(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") < 0 and max(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") < 0 appear as spiral staircases.  In the limit as min(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") = max(",
 StyleBox["u",
  FontSlant->"Italic"],
 "), the surface degenerates to a simple 3-D space curve.  In the following, ",
 StyleBox["n",
  FontSlant->"Italic"],
 " is the number of full twists of the helicoid between ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = -1 and ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = 1."
}], "Text",
 CellChangeTimes->{{3.603719195062105*^9, 3.603719195066928*^9}, 
   3.6037206481960793`*^9, {3.603720689825589*^9, 3.603720689986402*^9}, {
   3.6037208116990623`*^9, 3.603720817337224*^9}, {3.606138181021246*^9, 
   3.60613824044724*^9}, {3.606138271472034*^9, 3.606138279358314*^9}, 
   3.619230658815126*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", " ", "np"}], "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "6"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "21"}], ";", "\n", "     ", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"n", " ", "\[Pi]", " ", "v"}], "]"}]}], ",", 
          RowBox[{"u", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"n", " ", "\[Pi]", " ", "v"}], "]"}]}], ",", "v"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "minu", ",", "maxu"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"PlotRange", " ", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", " ", 
        RowBox[{"BoxRatios", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", 
           RowBox[{"-", "5"}], ",", "1"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.14\>\""}]}], "]"}]}]}], 
    "\n", "   ", "]"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"minu", ",", 
       RowBox[{"-", "0.4"}]}], "}"}], ",", 
     RowBox[{"-", "2"}], ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"maxu", ",", "0.4"}], "}"}], ",", "minu", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"n", ",", "minu", ",", "maxu"}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.603505606128927*^9, 3.603505663834598*^9}, {
   3.603505701887616*^9, 3.603505717213767*^9}, {3.603564507692615*^9, 
   3.603564540350038*^9}, {3.6035646780851517`*^9, 3.6035647064850693`*^9}, {
   3.603670098676634*^9, 3.6036701167405777`*^9}, {3.603670169505514*^9, 
   3.603670177153167*^9}, 3.603671383267417*^9, {3.603671419789736*^9, 
   3.603671423275942*^9}, {3.60367147272805*^9, 3.603671542077236*^9}, {
   3.60367158521729*^9, 3.6036715954653473`*^9}, {3.603672988639448*^9, 
   3.6036730116673307`*^9}, {3.603673064651318*^9, 3.603673089464676*^9}, {
   3.603718490787071*^9, 3.6037187286960773`*^9}, {3.603718760439679*^9, 
   3.6037188102518253`*^9}, {3.603718908852*^9, 3.6037189171412973`*^9}, {
   3.603718949927916*^9, 3.603719007376978*^9}, {3.603719083157634*^9, 
   3.603719094000058*^9}, {3.603719254270371*^9, 3.603719454193747*^9}, {
   3.603719497531605*^9, 3.603719499868704*^9}, 3.603719550332416*^9, 
   3.60371958093377*^9, {3.6037197522096777`*^9, 3.603719754626832*^9}, {
   3.60371980669869*^9, 3.603719914115428*^9}, {3.603720009875557*^9, 
   3.603720015223247*^9}, {3.603720261701483*^9, 3.603720271512823*^9}, {
   3.603720385502399*^9, 3.603720393863626*^9}, {3.6037204368140297`*^9, 
   3.603720442964096*^9}, {3.603720477464559*^9, 3.603720499965723*^9}, {
   3.60372055936495*^9, 3.603720559925486*^9}, {3.6037206947671824`*^9, 
   3.60372069874082*^9}, {3.611148196236472*^9, 3.611148199449332*^9}, 
   3.611152722225363*^9, {3.6124017078433533`*^9, 3.612401713079651*^9}, {
   3.612401744881319*^9, 3.612401747579741*^9}, {3.612402315982862*^9, 
   3.612402317107554*^9}, {3.627773123175089*^9, 3.627773190427848*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`maxu$$ = 
    0.4, $CellContext`minu$$ = -0.4, $CellContext`n$$ = 1, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`n$$], 1, 5, 1}, {{
       Hold[$CellContext`minu$$], -0.4}, -2, 2}, {{
       Hold[$CellContext`maxu$$], 0.4}, 
      Dynamic[$CellContext`minu$$], 2}}, Typeset`size$$ = {
    500., {228., 236.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`n$5807$$ = 
    0, $CellContext`minu$5808$$ = 0, $CellContext`maxu$5809$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`maxu$$ = 
        0.4, $CellContext`minu$$ = -0.4, $CellContext`n$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$5807$$, 0], 
        Hold[$CellContext`minu$$, $CellContext`minu$5808$$, 0], 
        Hold[$CellContext`maxu$$, $CellContext`maxu$5809$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         6; $CellContext`np$ = 21; 
        ParametricPlot3D[{$CellContext`u 
           Cos[$CellContext`n$$ Pi $CellContext`v], $CellContext`u 
           Sin[$CellContext`n$$ 
             Pi $CellContext`v], $CellContext`v}, {$CellContext`u, \
$CellContext`minu$$, $CellContext`maxu$$}, {$CellContext`v, -1, 1}, 
          PlotRange -> {{-1, 1}, {-1, 1}, {-1, 1}}, BoxRatios -> {1, 1, 1}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {4, -5, 1}, PlotLabel -> "13.7.14"]], 
      "Specifications" :> {{$CellContext`n$$, 1, 5, 1, Appearance -> 
         "Labeled"}, {{$CellContext`minu$$, -0.4}, -2, 2, Appearance -> 
         "Labeled"}, {{$CellContext`maxu$$, 0.4}, 
         Dynamic[$CellContext`minu$$], 2, Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`n$$, $CellContext`minu$$, \
$CellContext`maxu$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {330., 337.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6037194560075283`*^9, 3.603719551219894*^9, 3.603719583286337*^9, 
   3.603719876267918*^9, {3.60371992009968*^9, 3.6037199459504433`*^9}, 
   3.603720217585126*^9, {3.603720279529456*^9, 3.603720304710862*^9}, {
   3.603720505119767*^9, 3.603720520640442*^9}, {3.603720561534267*^9, 
   3.6037206519548264`*^9}, 3.6124016824054337`*^9, 3.6124017139733953`*^9, 
   3.61240174902278*^9, 3.627773164034684*^9, 3.627773194712508*^9, 
   3.630878257728751*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.15  Fresnel's elasticity surface", "Subsubsection"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["r",
     FontSlant->"Italic"], "2"], TraditionalForm]]],
 " be given by the sum of scaled squared coordinates, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{
     StyleBox["x",
      FontSlant->"Italic"], "'"}], "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{
     StyleBox["y",
      FontSlant->"Italic"], "'"}], "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{
     StyleBox["z",
      FontSlant->"Italic"], "'"}], "2"], TraditionalForm]]],
 ", with scaling given by ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["x",
  FontSlant->"Italic"],
 "', ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["y",
  FontSlant->"Italic"],
 "', and ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["z",
  FontSlant->"Italic"],
 "'.  The surface approaches a cylindrical shape as one of ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", or ",
 StyleBox["c",
  FontSlant->"Italic"],
 " becomes large relative to the other two.  Parametrically, \n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")cos(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")sin(",
 StyleBox["v",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 ")\n\t"
}], "Text",
 CellChangeTimes->{{3.603719661579486*^9, 3.603719682845662*^9}, {
  3.603762518037977*^9, 3.6037625493738127`*^9}, {3.603762586135747*^9, 
  3.603762641524221*^9}, {3.606138347696752*^9, 3.6061383647214603`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", "np", ",", "rsq"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "21"}], ";", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "21"}], ";", "\[IndentingNewLine]", 
      RowBox[{"rsq", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "^", "2"}], "*", 
         RowBox[{
          RowBox[{"Sin", "[", "u", "]"}], "^", "2"}], "*", 
         RowBox[{
          RowBox[{"Cos", "[", "v", "]"}], "^", "2"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"b", "^", "2"}], "*", 
         RowBox[{
          RowBox[{"Sin", "[", "u", "]"}], "^", "2"}], "*", 
         RowBox[{
          RowBox[{"Sin", "[", "v", "]"}], "^", "2"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"c", "^", "2"}], "*", 
         RowBox[{
          RowBox[{"Cos", "[", "u", "]"}], "^", "2"}]}]}]}], ";", " ", "\n", 
      "  ", 
      RowBox[{"SphericalPlot3D", "[", 
       RowBox[{
        RowBox[{"Sqrt", "[", "rsq", "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"u", ",", " ", "0", ",", " ", "\[Pi]"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"v", ",", " ", "0", ",", " ", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", " ", 
           RowBox[{"-", "3"}], ",", " ", "3"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.15\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "0.9"}], "}"}], ",", "0.5", ",", "1.0", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", "0.5"}], "}"}], ",", "0.25", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "0.5"}], "}"}], ",", "0.5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.603762124878059*^9, 3.6037623241689*^9}, {
  3.6037624035645638`*^9, 3.6037624111818533`*^9}, {3.603762964293679*^9, 
  3.6037630005942297`*^9}, {3.61114820636187*^9, 3.611148211199052*^9}, {
  3.612401773168416*^9, 3.612401814017075*^9}, {3.612401856182148*^9, 
  3.6124018940678864`*^9}, {3.627773204226995*^9, 3.6277732213524837`*^9}, {
  3.630878306228939*^9, 3.630878321002754*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.9, $CellContext`b$$ = 
    0.5, $CellContext`c$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.9}, 0.5, 1.}, {{
       Hold[$CellContext`b$$], 0.5}, 0.25, 1}, {{
       Hold[$CellContext`c$$], 0.5}, 0.5, 1}}, Typeset`size$$ = {
    500., {253., 260.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$7416$$ = 
    0, $CellContext`b$7417$$ = 0, $CellContext`c$7418$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.9, $CellContext`b$$ = 
        0.5, $CellContext`c$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$7416$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$7417$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$7418$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`rsq$}, \
$CellContext`mp$ = 21; $CellContext`np$ = 
         21; $CellContext`rsq$ = $CellContext`a$$^2 Sin[$CellContext`u]^2 
           Cos[$CellContext`v]^2 + $CellContext`b$$^2 Sin[$CellContext`u]^2 
           Sin[$CellContext`v]^2 + $CellContext`c$$^2 Cos[$CellContext`u]^2; 
        SphericalPlot3D[
          
          Sqrt[$CellContext`rsq$], {$CellContext`u, 0, Pi}, {$CellContext`v, 
           0, 2 Pi}, PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {4, -3, 3}, PlotLabel -> "13.7.15"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.9}, 0.5, 1., Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.5}, 0.25, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.5}, 0.5, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {355., 362.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603762440325013*^9, 3.603762489713722*^9}, {
  3.612401765734066*^9, 3.612401928070015*^9}, {3.627773222684576*^9, 
  3.6277732353437567`*^9}, {3.630878280877975*^9, 3.63087832182514*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.16  Cornucopia", "Subsubsection"],

Cell[TextData[{
 "The axis of the cornucopia below lies in the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-",
 StyleBox["y",
  FontSlant->"Italic"],
 " plane and is a logarithmic spiral (",
 StyleBox["r",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"b", "\[CenterDot]", "v"}]], TraditionalForm]]],
 ").  The cross-section is circular and grows as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"a", "\[CenterDot]", "v"}]], TraditionalForm]]],
 ". \n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    StyleBox["bv",
     FontSlant->"Italic"]], TraditionalForm]]],
 " cos",
 StyleBox["v",
  FontSlant->"Italic"],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    StyleBox["av",
     FontSlant->"Italic"]], TraditionalForm]]],
 " cos",
 StyleBox["u",
  FontSlant->"Italic"],
 " cos",
 StyleBox["v",
  FontSlant->"Italic"],
 "]\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    StyleBox["bv",
     FontSlant->"Italic"]], TraditionalForm]]],
 " cos",
 StyleBox["v",
  FontSlant->"Italic"],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    StyleBox["av",
     FontSlant->"Italic"]], TraditionalForm]]],
 " cos",
 StyleBox["u",
  FontSlant->"Italic"],
 " sin",
 StyleBox["v",
  FontSlant->"Italic"],
 "]\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 "[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    StyleBox["av",
     FontSlant->"Italic"]], TraditionalForm]]],
 " sin",
 StyleBox["u",
  FontSlant->"Italic"],
 "]\n "
}], "Text",
 CellChangeTimes->{{3.6037627410377502`*^9, 3.603762790175457*^9}, {
  3.606138518797802*^9, 3.606138641879908*^9}, {3.632319682243737*^9, 
  3.632319687729735*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", "np", ",", "vmin", ",", "vmax"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "21"}], ";", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "21"}], ";", "\[IndentingNewLine]", 
      RowBox[{"vmin", " ", "=", " ", 
       RowBox[{"-", "7"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"vmax", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ParametricPlot3D", "[", "\n", "    ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"c", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"b", " ", "v"}], "]"}], " ", 
              RowBox[{"Cos", "[", "v", "]"}]}], " ", "+", " ", 
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"a", " ", "v"}], "]"}], " ", 
              RowBox[{"Cos", "[", "u", "]"}], " ", 
              RowBox[{"Cos", "[", "v", "]"}]}]}], ")"}]}], ",", "\n", "     ", 
          RowBox[{"c", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"b", " ", "v"}], "]"}], " ", 
              RowBox[{"Sin", "[", "v", "]"}]}], " ", "+", " ", 
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"a", " ", "v"}], "]"}], " ", 
              RowBox[{"Cos", "[", "u", "]"}], " ", 
              RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], ",", "\n", "     ", 
          RowBox[{"c", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Exp", "[", 
              RowBox[{"a", " ", "v"}], "]"}], " ", 
             RowBox[{"Sin", "[", "u", "]"}]}], ")"}]}]}], "}"}], ",", "\n", 
        "     ", 
        RowBox[{"{", 
         RowBox[{"u", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"v", ",", "vmin", ",", "vmax"}], "}"}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", " ", "3", ",", " ", "3"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.16\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "0.2"}], "}"}], ",", "0.1", ",", "0.5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"b", ",", "0.1", ",", "0.5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "0.4"}], "}"}], ",", "0.25", ",", "0.4", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.603762124878059*^9, 3.6037623241689*^9}, {
  3.6037624035645638`*^9, 3.6037624111818533`*^9}, {3.6037628172314863`*^9, 
  3.603762954444364*^9}, {3.60376307384718*^9, 3.603763074382951*^9}, {
  3.6037631391246023`*^9, 3.603763206573585*^9}, {3.611148220700632*^9, 
  3.611148223786887*^9}, {3.612401968231585*^9, 3.6124019854804983`*^9}, {
  3.61240202061973*^9, 3.612402044419293*^9}, {3.6124020762335978`*^9, 
  3.612402080268958*^9}, {3.6124022761210537`*^9, 3.61240228615835*^9}, {
  3.627773245327568*^9, 3.627773264090287*^9}, {3.630878367703657*^9, 
  3.630878370528276*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.2, $CellContext`b$$ = 
    0.1, $CellContext`c$$ = 0.4, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.2}, 0.1, 0.5}, {
      Hold[$CellContext`b$$], 0.1, 0.5}, {{
       Hold[$CellContext`c$$], 0.4}, 0.25, 0.4}}, Typeset`size$$ = {
    500., {229., 236.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$8150$$ = 
    0, $CellContext`b$8151$$ = 0, $CellContext`c$8152$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.2, $CellContext`b$$ = 
        0.1, $CellContext`c$$ = 0.4}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$8150$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$8151$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$8152$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`vmin$, \
$CellContext`vmax$}, $CellContext`mp$ = 21; $CellContext`np$ = 
         21; $CellContext`vmin$ = -7; $CellContext`vmax$ = 1; 
        ParametricPlot3D[{$CellContext`c$$ (
            Exp[$CellContext`b$$ $CellContext`v] Cos[$CellContext`v] + 
            Exp[$CellContext`a$$ $CellContext`v] Cos[$CellContext`u] 
             Cos[$CellContext`v]), $CellContext`c$$ (
            Exp[$CellContext`b$$ $CellContext`v] Sin[$CellContext`v] + 
            Exp[$CellContext`a$$ $CellContext`v] Cos[$CellContext`u] 
             Sin[$CellContext`v]), $CellContext`c$$ (
            Exp[$CellContext`a$$ $CellContext`v] 
            Sin[$CellContext`u])}, {$CellContext`u, 0, 2 
           Pi}, {$CellContext`v, $CellContext`vmin$, $CellContext`vmax$}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {-4, 3, 3}, PlotLabel -> "13.7.16"]], 
      "Specifications" :> {{{$CellContext`a$$, 0.2}, 0.1, 0.5, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 0.1, 0.5, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.4}, 0.25, 0.4, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {331., 338.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603763028254657*^9, 3.603763106086355*^9}, {
   3.60376315097935*^9, 3.603763214617796*^9}, {3.612401936665044*^9, 
   3.612401952247262*^9}, {3.6124019866775713`*^9, 3.612402096296515*^9}, 
   3.627773265484573*^9, {3.630878349795875*^9, 3.630878371376135*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.17  Cylindrical spiral", "Subsubsection"],

Cell[TextData[{
 "This figure is formed by a circle of radius ",
 StyleBox["a",
  FontSlant->"Italic"],
 " which is tied to the vertical axis and rotates about this axis.  While \
rotating, the spiral  linearly increases upward at a rate ",
 StyleBox["b",
  FontSlant->"Italic"],
 " along the vertical axis.  The circle\[CloseCurlyQuote]s center is \
displaced radially from the vertical axis by an amount ",
 StyleBox["c",
  FontSlant->"Italic"],
 ".  The number of turns of the spiral upon reaching the height ",
 StyleBox["b",
  FontSlant->"Italic"],
 " is given by ",
 StyleBox["n",
  FontSlant->"Italic"],
 ".  The spiral is \"flat\" when ",
 StyleBox["b",
  FontSlant->"Italic"],
 " = 0 and is then equivalent to a torus.  If ",
 StyleBox["b",
  FontSlant->"Italic"],
 " = ",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["a",
  FontSlant->"Italic"],
 ", then the \"coils\" touch along a continuous line which is a spiral curve \
of radius ",
 StyleBox["a",
  FontSlant->"Italic"],
 " + ",
 StyleBox["c",
  FontSlant->"Italic"],
 ".\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\[CenterDot]cos(",
 StyleBox["nv",
  FontSlant->"Italic"],
 ") [1 + cos",
 StyleBox["u",
  FontSlant->"Italic"],
 "] + ",
 StyleBox["c",
  FontSlant->"Italic"],
 "\[CenterDot]cos(",
 StyleBox["nv",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\[CenterDot]sin(",
 StyleBox["nv",
  FontSlant->"Italic"],
 ") [1 + cos",
 StyleBox["u",
  FontSlant->"Italic"],
 "] + ",
 StyleBox["c",
  FontSlant->"Italic"],
 "\[CenterDot]sin(",
 StyleBox["nv",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["v",
  FontSlant->"Italic"],
 "/(2\[Pi]) + ",
 StyleBox["a",
  FontSlant->"Italic"],
 "\[CenterDot]sin",
 StyleBox["u",
  FontSlant->"Italic"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.603763287799968*^9, 3.603763287803112*^9}, {
   3.603763354594667*^9, 3.603763359392735*^9}, 3.603763393743585*^9, {
   3.603763423806117*^9, 3.603763434168672*^9}, {3.603763475380728*^9, 
   3.6037635275818253`*^9}, {3.606138663836442*^9, 3.606138769355044*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", "np", ",", "vmin", ",", "vmax"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "21"}], ";", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "51"}], ";", "\[IndentingNewLine]", 
      RowBox[{"vmin", " ", "=", " ", 
       RowBox[{"-", "7"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"vmax", " ", "=", " ", "1"}], ";", "\n", "     ", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"n", " ", "v"}], "]"}], 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"Cos", "[", "u", "]"}]}], ")"}]}], " ", "+", " ", 
           RowBox[{"c", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"n", " ", "v"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"n", " ", "v"}], "]"}], 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"Cos", "[", "u", "]"}]}], ")"}]}], " ", "+", " ", 
           RowBox[{"c", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"n", " ", "v"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"b", " ", 
            RowBox[{"v", "/", 
             RowBox[{"(", 
              RowBox[{"2", "\[Pi]"}], ")"}]}]}], " ", "+", " ", 
           RowBox[{"a", " ", 
            RowBox[{"Sin", "[", "u", "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "}"}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", " ", 
           RowBox[{"-", "3"}], ",", " ", "3"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.17\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"a", ",", "0.1", ",", "0.25", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b", ",", "1"}], "}"}], ",", "0.5", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "0.5"}], "}"}], ",", "0.25", ",", "0.75", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "4"}], "}"}], ",", "1", ",", "9", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "n"}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.603762124878059*^9, 3.6037623241689*^9}, {
   3.6037624035645638`*^9, 3.6037624111818533`*^9}, {3.6037628172314863`*^9, 
   3.603762954444364*^9}, {3.60376307384718*^9, 3.603763074382951*^9}, {
   3.6037631391246023`*^9, 3.603763206573585*^9}, {3.6037635660134687`*^9, 
   3.603763583524777*^9}, {3.603763676918874*^9, 3.603763703725678*^9}, {
   3.6037637609151382`*^9, 3.603763780576038*^9}, 3.603763862328573*^9, {
   3.611148232599625*^9, 3.611148235662106*^9}, {3.6124021293584557`*^9, 
   3.612402178771999*^9}, {3.6124022554345493`*^9, 3.612402265058216*^9}, {
   3.627773274002469*^9, 3.627773299199164*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.1, $CellContext`b$$ = 
    1, $CellContext`c$$ = 0.5, $CellContext`n$$ = 4, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.1, 0.25}, {{
       Hold[$CellContext`b$$], 1}, 0.5, 2}, {{
       Hold[$CellContext`c$$], 0.5}, 0.25, 0.75}, {{
       Hold[$CellContext`n$$], 4}, 1, 9, 1}}, Typeset`size$$ = {
    500., {246., 253.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$8578$$ = 
    0, $CellContext`b$8579$$ = 0, $CellContext`c$8580$$ = 
    0, $CellContext`n$8581$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.1, $CellContext`b$$ = 
        1, $CellContext`c$$ = 0.5, $CellContext`n$$ = 4}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$8578$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$8579$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$8580$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$8581$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`vmin$, \
$CellContext`vmax$}, $CellContext`mp$ = 21; $CellContext`np$ = 
         51; $CellContext`vmin$ = -7; $CellContext`vmax$ = 1; 
        ParametricPlot3D[{$CellContext`a$$ 
            Cos[$CellContext`n$$ $CellContext`v] (1 + 
             Cos[$CellContext`u]) + $CellContext`c$$ 
            Cos[$CellContext`n$$ $CellContext`v], $CellContext`a$$ 
            Sin[$CellContext`n$$ $CellContext`v] (1 + 
             Cos[$CellContext`u]) + $CellContext`c$$ 
            
            Sin[$CellContext`n$$ $CellContext`v], $CellContext`b$$ \
($CellContext`v/(2 Pi)) + $CellContext`a$$ 
            Sin[$CellContext`u]}, {$CellContext`u, 0, 2 
           Pi}, {$CellContext`v, -Pi, Pi}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {4, -3, 3}, PlotLabel -> "13.7.17"]], 
      "Specifications" :> {{$CellContext`a$$, 0.1, 0.25, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 1}, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.5}, 0.25, 0.75, Appearance -> 
         "Labeled"}, {{$CellContext`n$$, 4}, 1, 9, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$, $CellContext`n$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {370., 377.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6037637939577627`*^9, 3.603763832790389*^9}, {
   3.603763875739637*^9, 3.603763945955111*^9}, {3.603763984404429*^9, 
   3.603763986587652*^9}, {3.612402104735214*^9, 3.612402179309491*^9}, {
   3.6277733027055387`*^9, 3.627773314578649*^9}, 3.6308784059217587`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.18  Conical spiral", "Subsubsection"],

Cell[TextData[{
 "This figure is formed by a circle of variable radius which is tied to the \
vertical axis and rotates about this axis.    While rotating, the spiral  \
linearly increases upward at a rate ",
 StyleBox["b",
  FontSlant->"Italic"],
 " along the vertical axis.   The center of the circle is displaced radially \
from the vertical axis by an amount ",
 StyleBox["c",
  FontSlant->"Italic"],
 ".  The number of turns of the spiral upon reaching the height ",
 StyleBox["b",
  FontSlant->"Italic"],
 " is given by ",
 StyleBox["n",
  FontSlant->"Italic"],
 ".  The spiral is \"flat\" when ",
 StyleBox["b",
  FontSlant->"Italic"],
 " = 0.\n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "[1 - ",
 StyleBox["v",
  FontSlant->"Italic"],
 "/(2\[Pi])] cos(",
 StyleBox["nv",
  FontSlant->"Italic"],
 ") [1 + cos",
 StyleBox["u",
  FontSlant->"Italic"],
 "] + ",
 StyleBox["c",
  FontSlant->"Italic"],
 "\[CenterDot]cos(",
 StyleBox["nv",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["y",
  FontSlant->"Italic"],
 " = ",
 StyleBox["a",
  FontSlant->"Italic"],
 "[1 - ",
 StyleBox["v",
  FontSlant->"Italic"],
 "/(2\[Pi])] sin(",
 StyleBox["nv",
  FontSlant->"Italic"],
 ") [1 + cos",
 StyleBox["u",
  FontSlant->"Italic"],
 "] + ",
 StyleBox["c",
  FontSlant->"Italic"],
 "\[CenterDot]sin(",
 StyleBox["nv",
  FontSlant->"Italic"],
 ")\n\t",
 StyleBox["z",
  FontSlant->"Italic"],
 " = ",
 StyleBox["b",
  FontSlant->"Italic"],
 "\[CenterDot]",
 StyleBox["v",
  FontSlant->"Italic"],
 "/(2\[Pi]) + ",
 StyleBox["a",
  FontSlant->"Italic"],
 "[1 - ",
 StyleBox["v",
  FontSlant->"Italic"],
 "/(2\[Pi])] sin",
 StyleBox["u",
  FontSlant->"Italic"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.603764043251544*^9, 3.603764058623331*^9}, {
  3.603764114314309*^9, 3.603764146811507*^9}, {3.6061387813388557`*^9, 
  3.6061388454911633`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mp", ",", "np"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mp", " ", "=", " ", "21"}], ";", "\[IndentingNewLine]", 
      RowBox[{"np", " ", "=", " ", "51"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"a", 
            RowBox[{"(", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"v", "/", 
               RowBox[{"(", 
                RowBox[{"2", "\[Pi]"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"n", " ", "v"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"Cos", "[", "u", "]"}]}], ")"}]}], " ", "+", " ", 
           RowBox[{"c", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"n", " ", "v"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"a", 
            RowBox[{"(", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"v", "/", 
               RowBox[{"(", 
                RowBox[{"2", "\[Pi]"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"n", " ", "v"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"Cos", "[", "u", "]"}]}], ")"}]}], " ", "+", " ", 
           RowBox[{"c", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"n", " ", "v"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"b", " ", 
            RowBox[{"v", "/", 
             RowBox[{"(", 
              RowBox[{"2", "\[Pi]"}], ")"}]}]}], " ", "+", " ", 
           RowBox[{"a", 
            RowBox[{"(", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"v", "/", 
               RowBox[{"(", 
                RowBox[{"2", "\[Pi]"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Sin", "[", "u", "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"-", "\[Pi]"}], ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"mp", ",", "np"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"4", ",", " ", 
           RowBox[{"-", "3"}], ",", " ", "3"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<13.7.18\>\""}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"a", ",", "0.1", ",", "0.25", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"b", ",", "0.5", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", "0.5"}], "}"}], ",", "0.25", ",", "0.75", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "4"}], "}"}], ",", "1", ",", "9", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "n"}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.603762124878059*^9, 3.6037623241689*^9}, {
   3.6037624035645638`*^9, 3.6037624111818533`*^9}, {3.6037628172314863`*^9, 
   3.603762954444364*^9}, {3.60376307384718*^9, 3.603763074382951*^9}, {
   3.6037631391246023`*^9, 3.603763206573585*^9}, {3.6037635660134687`*^9, 
   3.603763583524777*^9}, {3.603763676918874*^9, 3.603763703725678*^9}, {
   3.6037637609151382`*^9, 3.603763780576038*^9}, 3.603763862328573*^9, 
   3.603764202083926*^9, {3.603764256033361*^9, 3.603764260806903*^9}, {
   3.60613887025745*^9, 3.60613887091671*^9}, {3.611148243150558*^9, 
   3.6111482459878197`*^9}, {3.6124022003595657`*^9, 3.612402219633135*^9}, {
   3.627773322628338*^9, 3.627773340627861*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.1, $CellContext`b$$ = 
    0.5, $CellContext`c$$ = 0.5, $CellContext`n$$ = 4, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.1, 0.25}, {
      Hold[$CellContext`b$$], 0.5, 2}, {{
       Hold[$CellContext`c$$], 0.5}, 0.25, 0.75}, {{
       Hold[$CellContext`n$$], 4}, 1, 9, 1}}, Typeset`size$$ = {
    500., {209., 216.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$9014$$ = 
    0, $CellContext`b$9015$$ = 0, $CellContext`c$9016$$ = 
    0, $CellContext`n$9017$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.1, $CellContext`b$$ = 
        0.5, $CellContext`c$$ = 0.5, $CellContext`n$$ = 4}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$9014$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$9015$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$9016$$, 0], 
        Hold[$CellContext`n$$, $CellContext`n$9017$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$}, $CellContext`mp$ = 
         21; $CellContext`np$ = 51; 
        ParametricPlot3D[{$CellContext`a$$ (1 - $CellContext`v/(2 Pi)) 
            Cos[$CellContext`n$$ $CellContext`v] (1 + 
             Cos[$CellContext`u]) + $CellContext`c$$ 
            Cos[$CellContext`n$$ $CellContext`v], $CellContext`a$$ (
             1 - $CellContext`v/(2 Pi)) 
            Sin[$CellContext`n$$ $CellContext`v] (1 + 
             Cos[$CellContext`u]) + $CellContext`c$$ 
            Sin[$CellContext`n$$ $CellContext`v], $CellContext`b$$ \
($CellContext`v/(2 Pi)) + $CellContext`a$$ (1 - $CellContext`v/(2 Pi)) 
            Sin[$CellContext`u]}, {$CellContext`u, 0, 2 
           Pi}, {$CellContext`v, -Pi, 2 Pi}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {4, -3, 3}, PlotLabel -> "13.7.18"]], 
      "Specifications" :> {{$CellContext`a$$, 0.1, 0.25, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.5}, 0.25, 0.75, Appearance -> 
         "Labeled"}, {{$CellContext`n$$, 4}, 1, 9, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$, $CellContext`n$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {333., 340.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6037642625710163`*^9, 3.603764357192472*^9}, {
   3.612402191167335*^9, 3.61240222056777*^9}, 3.6277733420021152`*^9, 
   3.6308784310551167`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["13.7.19  Roman surface", "Subsubsection"],

Cell[TextData[{
 "The point (0,0,0) is a triple point of the surface.  This surface is \
expressed parametrically by \n\n\t",
 StyleBox["x",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 " cos(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") sin(2",
 StyleBox["v",
  FontSlant->"Italic"],
 ")/2\n\ty = ",
 StyleBox["c",
  FontSlant->"Italic"],
 " sin(",
 StyleBox["u",
  FontSlant->"Italic"],
 ") sin(2",
 StyleBox["v",
  FontSlant->"Italic"],
 ")/2\n\tz = c sin(2u)",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["cos", "2"], TraditionalForm]]],
 "(v)"
}], "Text",
 CellChangeTimes->{
  3.603592796453179*^9, {3.6107664385955343`*^9, 3.610766461330701*^9}, {
   3.610766637344557*^9, 3.6107667477007627`*^9}, {3.61076679442096*^9, 
   3.610766802582592*^9}, {3.610766845221703*^9, 3.6107668599952793`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{mp,np,x,y,z},
    mp = 50;
    np = 50;
    x = c Cos[u]Sin[2v]/2;
    y = c Sin[u]Sin[2v]/2;
    z = c Sin[2u]Cos[v]^2/2;
    ParametricPlot3D[{x,y,z}, {u, 0, 2\[Pi]}, {v, 0, \[Pi]}, \
PlotPoints\[Rule]{mp,np},ViewPoint\[Rule]{5, -6, 4},PlotLabel\[Rule]\"13.7.19\
\"]
  ],
  {{c,1.5},0.5,2,Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False, 
  TrackedSymbols\[Rule]{c}
]
\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.603503381152491*^9, 3.603503550341003*^9}, {
   3.603503615491228*^9, 3.6035036162515297`*^9}, {3.6035036660580473`*^9, 
   3.603503702299521*^9}, {3.603504225359686*^9, 3.603504230844832*^9}, {
   3.603504344169775*^9, 3.6035043468079977`*^9}, {3.603504401640356*^9, 
   3.603504442664386*^9}, {3.603563797951302*^9, 3.603563804262732*^9}, {
   3.6035638657392597`*^9, 3.603563873325672*^9}, {3.6035641153914022`*^9, 
   3.603564120340847*^9}, {3.603565327800887*^9, 3.6035653625252438`*^9}, {
   3.603565567181282*^9, 3.6035655824149446`*^9}, {3.603565692540923*^9, 
   3.603565692952381*^9}, 3.603592777154387*^9, {3.603592813075707*^9, 
   3.60359282830153*^9}, {3.6107655571398993`*^9, 3.610765669876677*^9}, 
   3.6107657085020733`*^9, 3.6107657714049263`*^9, {3.610766065942721*^9, 
   3.6107661746847878`*^9}, {3.610766212843335*^9, 3.6107662473048143`*^9}, {
   3.61076632380617*^9, 3.6107663255168667`*^9}, {3.610766371244396*^9, 
   3.610766405968029*^9}, {3.611148254596086*^9, 3.611148257494385*^9}, {
   3.627773354348679*^9, 3.627773361422476*^9}, {3.627773435828182*^9, 
   3.627773454535055*^9}, {3.630878489590798*^9, 3.630878489912909*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 1.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], 1.5}, 0.5, 2}}, Typeset`size$$ = {
    500., {251., 266.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$484$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 1.5}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$484$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`mp$, $CellContext`np$, $CellContext`x$, \
$CellContext`y$, $CellContext`z$}, $CellContext`mp$ = 50; $CellContext`np$ = 
         50; $CellContext`x$ = $CellContext`c$$ Cos[$CellContext`u] 
          Sin[2 $CellContext`v]/2; $CellContext`y$ = $CellContext`c$$ 
          Sin[$CellContext`u] Sin[2 $CellContext`v]/
          2; $CellContext`z$ = $CellContext`c$$ Sin[2 $CellContext`u] 
          Cos[$CellContext`v]^2/2; 
        ParametricPlot3D[{$CellContext`x$, $CellContext`y$, $CellContext`z$}, \
{$CellContext`u, 0, 2 Pi}, {$CellContext`v, 0, Pi}, 
          PlotPoints -> {$CellContext`mp$, $CellContext`np$}, 
          ViewPoint -> {5, -6, 4}, PlotLabel -> "13.7.19"]], 
      "Specifications" :> {{{$CellContext`c$$, 1.5}, 0.5, 2, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, TrackedSymbols -> {$CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {312., 319.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.603592839599989*^9, 3.603592865781437*^9}, {
   3.610766388330813*^9, 3.610766415070221*^9}, 3.6124022351004343`*^9, 
   3.627773370145945*^9, {3.627773439690943*^9, 3.627773455822195*^9}, {
   3.630878473421359*^9, 3.630878501909698*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
WindowSize->{799, 935},
WindowMargins->{{6, Automatic}, {Automatic, 2}},
Magnification:>1.25 Inherited,
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 25, \
2016)",
StyleDefinitions->"myStyles.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 125, 2, 37, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1614, 39, 3064, 49, 1228, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[4715, 93, 42, 0, 51, "Section"],
Cell[4760, 95, 906, 23, 156, "Text"],
Cell[CellGroupData[{
Cell[5691, 122, 65, 0, 57, "Subsection"],
Cell[5759, 124, 2023, 45, 492, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[7819, 174, 146, 7, 46, "Subsection"],
Cell[CellGroupData[{
Cell[7990, 185, 370, 13, 82, "Subsubsection"],
Cell[8363, 200, 25, 0, 88, "Text"],
Cell[CellGroupData[{
Cell[8413, 204, 2004, 47, 575, "Input"],
Cell[10420, 253, 2506, 49, 1695, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[12975, 308, 334, 14, 62, "Subsubsection"],
Cell[CellGroupData[{
Cell[13334, 326, 4794, 117, 1003, "Input"],
Cell[18131, 445, 3469, 70, 1816, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[21661, 522, 553, 25, 48, "Subsection"],
Cell[CellGroupData[{
Cell[22239, 551, 514, 22, 95, "Subsubsection"],
Cell[22756, 575, 104, 1, 71, "Text"],
Cell[CellGroupData[{
Cell[22885, 580, 1050, 25, 587, "Input"],
Cell[23938, 607, 3101, 59, 1446, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[27088, 672, 587, 23, 77, "Subsubsection"],
Cell[27678, 697, 519, 21, 118, "Text"],
Cell[CellGroupData[{
Cell[28222, 722, 959, 24, 587, "Input"],
Cell[29184, 748, 2913, 56, 1446, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[32146, 810, 522, 16, 77, "Subsubsection"],
Cell[32671, 828, 107, 1, 71, "Text"],
Cell[CellGroupData[{
Cell[32803, 833, 903, 23, 546, "Input"],
Cell[33709, 858, 2516, 51, 1352, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[36274, 915, 548, 17, 77, "Subsubsection"],
Cell[36825, 934, 105, 1, 71, "Text"],
Cell[CellGroupData[{
Cell[36955, 939, 1249, 27, 587, "Input"],
Cell[38207, 968, 3023, 61, 1453, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[41291, 1036, 718, 26, 54, "Subsection"],
Cell[CellGroupData[{
Cell[42034, 1066, 425, 15, 81, "Subsubsection"],
Cell[42462, 1083, 526, 27, 118, "Text"],
Cell[CellGroupData[{
Cell[43013, 1114, 612, 16, 387, "Input"],
Cell[43628, 1132, 2200, 44, 1306, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[45877, 1182, 670, 22, 81, "Subsubsection"],
Cell[46550, 1206, 1329, 69, 165, "Text"],
Cell[CellGroupData[{
Cell[47904, 1279, 2587, 64, 675, "Input"],
Cell[50494, 1345, 2949, 57, 1446, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[53492, 1408, 561, 18, 63, "Subsubsection"],
Cell[54056, 1428, 480, 26, 118, "Text"],
Cell[CellGroupData[{
Cell[54561, 1458, 660, 18, 468, "Input"],
Cell[55224, 1478, 2270, 45, 1270, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[57543, 1529, 721, 23, 81, "Subsubsection"],
Cell[58267, 1554, 776, 40, 118, "Text"],
Cell[CellGroupData[{
Cell[59068, 1598, 3097, 71, 675, "Input"],
Cell[62168, 1671, 3037, 57, 1446, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[65254, 1734, 790, 24, 81, "Subsubsection"],
Cell[66047, 1760, 1129, 50, 178, "Text"],
Cell[CellGroupData[{
Cell[67201, 1814, 3900, 88, 803, "Input"],
Cell[71104, 1904, 3473, 65, 1547, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[74626, 1975, 884, 25, 81, "Subsubsection"],
Cell[75513, 2002, 1182, 47, 226, "Text"],
Cell[CellGroupData[{
Cell[76720, 2053, 4419, 103, 890, "Input"],
Cell[81142, 2158, 3664, 69, 1481, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[84867, 2234, 553, 25, 48, "Subsection"],
Cell[CellGroupData[{
Cell[85445, 2263, 468, 21, 95, "Subsubsection"],
Cell[CellGroupData[{
Cell[85938, 2288, 1116, 26, 587, "Input"],
Cell[87057, 2316, 2900, 57, 1410, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[90006, 2379, 468, 21, 77, "Subsubsection"],
Cell[90477, 2402, 258, 9, 71, "Text"],
Cell[CellGroupData[{
Cell[90760, 2415, 1033, 25, 587, "Input"],
Cell[91796, 2442, 2758, 55, 1446, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[94615, 2504, 619, 26, 48, "Subsection"],
Cell[CellGroupData[{
Cell[95259, 2534, 540, 22, 95, "Subsubsection"],
Cell[CellGroupData[{
Cell[95824, 2560, 1111, 26, 587, "Input"],
Cell[96938, 2588, 2808, 55, 1446, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[99795, 2649, 590, 23, 77, "Subsubsection"],
Cell[CellGroupData[{
Cell[100410, 2676, 1038, 25, 587, "Input"],
Cell[101451, 2703, 2731, 54, 1446, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[104243, 2764, 51, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[104319, 2768, 696, 23, 77, "Subsubsection"],
Cell[105018, 2793, 1198, 58, 206, "Text"],
Cell[CellGroupData[{
Cell[106241, 2855, 2581, 63, 506, "Input"],
Cell[108825, 2920, 2796, 54, 1085, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[111670, 2980, 409, 19, 43, "Subsubsection"],
Cell[112082, 3001, 33, 0, 57, "Text"],
Cell[CellGroupData[{
Cell[112140, 3005, 935, 23, 406, "Input"],
Cell[113078, 3030, 2148, 43, 1013, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[115275, 3079, 349, 12, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[115649, 3095, 1002, 23, 406, "Input"],
Cell[116654, 3120, 2186, 45, 1016, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[118889, 3171, 451, 16, 43, "Subsubsection"],
Cell[119343, 3189, 34, 0, 57, "Text"],
Cell[CellGroupData[{
Cell[119402, 3193, 1056, 24, 406, "Input"],
Cell[120461, 3219, 2142, 43, 1016, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[122652, 3268, 668, 28, 43, "Subsubsection"],
Cell[123323, 3298, 824, 33, 172, "Text"],
Cell[CellGroupData[{
Cell[124172, 3335, 1315, 28, 437, "Input"],
Cell[125490, 3365, 2637, 52, 1085, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[128176, 3423, 448, 21, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[128649, 3448, 1341, 28, 437, "Input"],
Cell[129993, 3478, 2510, 51, 1085, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[132552, 3535, 751, 23, 43, "Subsubsection"],
Cell[133306, 3560, 632, 21, 170, "Text"],
Cell[CellGroupData[{
Cell[133963, 3585, 1904, 34, 437, "Input"],
Cell[135870, 3621, 2655, 52, 1016, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[138574, 3679, 368, 17, 43, "Subsubsection"],
Cell[138945, 3698, 784, 32, 171, "Text"],
Cell[CellGroupData[{
Cell[139754, 3734, 1997, 47, 437, "Input"],
Cell[141754, 3783, 2208, 44, 1016, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[144011, 3833, 425, 17, 63, "Subsubsection"],
Cell[144439, 3852, 170, 8, 57, "Text"],
Cell[CellGroupData[{
Cell[144634, 3864, 1144, 25, 406, "Input"],
Cell[145781, 3891, 2190, 44, 1016, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[148032, 3942, 76, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[148133, 3946, 46, 0, 43, "Subsubsection"],
Cell[148182, 3948, 1482, 67, 251, "Text"],
Cell[CellGroupData[{
Cell[149689, 4019, 2380, 56, 506, "Input"],
Cell[152072, 4077, 2355, 48, 1057, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[154476, 4131, 51, 0, 32, "Subsubsection"],
Cell[154530, 4133, 3839, 142, 727, "Text"],
Cell[CellGroupData[{
Cell[158394, 4279, 3150, 76, 506, "Input"],
Cell[161547, 4357, 2546, 49, 1088, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[164142, 4412, 46, 0, 32, "Subsubsection"],
Cell[164191, 4414, 654, 36, 206, "Text"],
Cell[CellGroupData[{
Cell[164870, 4454, 3213, 77, 575, "Input"],
Cell[168086, 4533, 2489, 50, 1072, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[170624, 4589, 41, 0, 32, "Subsubsection"],
Cell[170668, 4591, 803, 41, 208, "Text"],
Cell[CellGroupData[{
Cell[171496, 4636, 2705, 63, 471, "Input"],
Cell[174204, 4701, 2315, 45, 1016, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[176568, 4752, 46, 0, 32, "Subsubsection"],
Cell[176617, 4754, 935, 42, 281, "Text"],
Cell[CellGroupData[{
Cell[177577, 4800, 3091, 70, 540, "Input"],
Cell[180671, 4872, 2958, 58, 1157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[183678, 4936, 46, 0, 32, "Subsubsection"],
Cell[183727, 4938, 1282, 55, 260, "Text"],
Cell[CellGroupData[{
Cell[185034, 4997, 3245, 74, 575, "Input"],
Cell[188282, 5073, 2953, 57, 1157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[191284, 5136, 50, 0, 32, "Subsubsection"],
Cell[191337, 5138, 1834, 73, 251, "Text"],
Cell[CellGroupData[{
Cell[193196, 5215, 3126, 72, 575, "Input"],
Cell[196325, 5289, 2448, 48, 1072, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[198822, 5343, 50, 0, 32, "Subsubsection"],
Cell[198875, 5345, 1422, 55, 247, "Text"],
Cell[CellGroupData[{
Cell[200322, 5404, 3912, 88, 540, "Input"],
Cell[204237, 5494, 3015, 57, 1453, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[207301, 5557, 48, 0, 32, "Subsubsection"],
Cell[207352, 5559, 1582, 63, 210, "Text"],
Cell[CellGroupData[{
Cell[208959, 5626, 4787, 105, 608, "Input"],
Cell[213749, 5733, 3117, 56, 1135, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[216915, 5795, 50, 0, 32, "Subsubsection"],
Cell[216968, 5797, 3560, 151, 320, "Text"],
Cell[CellGroupData[{
Cell[220553, 5952, 4471, 112, 746, "Input"],
Cell[225027, 6066, 3648, 71, 1157, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[228724, 6143, 47, 0, 32, "Subsubsection"],
Cell[228774, 6145, 983, 40, 168, "Text"],
Cell[CellGroupData[{
Cell[229782, 6189, 3804, 79, 405, "Input"],
Cell[233589, 6270, 2310, 46, 813, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[235948, 6322, 49, 0, 32, "Subsubsection"],
Cell[236000, 6324, 860, 38, 210, "Text"],
Cell[CellGroupData[{
Cell[236885, 6366, 3854, 80, 506, "Input"],
Cell[240742, 6448, 2281, 45, 1016, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[243072, 6499, 42, 0, 32, "Subsubsection"],
Cell[243117, 6501, 993, 44, 353, "Text"],
Cell[CellGroupData[{
Cell[244135, 6549, 3734, 75, 575, "Input"],
Cell[247872, 6626, 2771, 52, 947, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[250692, 6684, 48, 0, 32, "Subsubsection"],
Cell[250743, 6686, 2056, 88, 466, "Text"],
Cell[CellGroupData[{
Cell[252824, 6778, 4471, 96, 575, "Input"],
Cell[257298, 6876, 3393, 65, 1072, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[260740, 6947, 62, 0, 32, "Subsubsection"],
Cell[260805, 6949, 2126, 101, 321, "Text"],
Cell[CellGroupData[{
Cell[262956, 7054, 3101, 76, 575, "Input"],
Cell[266060, 7132, 3035, 58, 1151, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[269144, 7196, 44, 0, 32, "Subsubsection"],
Cell[269191, 7198, 2041, 93, 233, "Text"],
Cell[CellGroupData[{
Cell[271257, 7295, 3966, 93, 542, "Input"],
Cell[275226, 7390, 3453, 64, 861, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[278728, 7460, 52, 0, 32, "Subsubsection"],
Cell[278783, 7462, 2267, 93, 428, "Text"],
Cell[CellGroupData[{
Cell[281075, 7559, 4049, 96, 643, "Input"],
Cell[285127, 7657, 3664, 70, 1197, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[288840, 7733, 48, 0, 32, "Subsubsection"],
Cell[288891, 7735, 1885, 83, 391, "Text"],
Cell[CellGroupData[{
Cell[290801, 7822, 4476, 107, 643, "Input"],
Cell[295280, 7931, 3532, 68, 1082, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[298861, 8005, 47, 0, 32, "Subsubsection"],
Cell[298911, 8007, 829, 32, 207, "Text"],
Cell[CellGroupData[{
Cell[299765, 8043, 1638, 34, 501, "Input"],
Cell[301406, 8079, 2625, 50, 1016, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature DxpJC5TccW0yqAKN3H6Wcjoo *)
