(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 10.4' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[    160090,       3803]
NotebookOptionsPosition[    156202,       3652]
NotebookOutlinePosition[    156592,       3669]
CellTagsIndexPosition[    156549,       3666]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Initialization", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.621868726048538*^9}],

Cell["\<\
labelstyle = {Black,20};
SetOptions[Graphics3D,BoxRatios\[Rule]Automatic,PlotRange\[Rule]All,Boxed\
\[Rule]False,BaseStyle\[Rule]20,ImageSize\[Rule]400,Lighting\[Rule]{{\"\
Ambient\",Gray}}];
SetOptions[Manipulate,LabelStyle\[Rule]labelstyle];
SetOptions[Manipulator,LabelStyle\[Rule]labelstyle];
$TextStyle = {FontSize\[Rule]14, FontFamily\[Rule]\"TimesRoman\", FontWeight\
\[Rule]\"Bold\"};\
\>", "Input",
 PageWidth->WindowWidth,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.604618224243945*^9, 3.60461831019226*^9}, {
   3.611162354734775*^9, 3.611162355219103*^9}, {3.613814532034585*^9, 
   3.6138145359944143`*^9}, 3.613814566833336*^9, {3.621868718442871*^9, 
   3.621868726048712*^9}, {3.627821702721075*^9, 3.6278217040713787`*^9}, {
   3.627910889944344*^9, 3.627910890995614*^9}, {3.6309825539036417`*^9, 
   3.6309825542465057`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["18.  Irregular and Miscellaneous Solids", "Section"],

Cell["\<\
In contrast to the previous chapter, this chapter presents solids which are \
not regular (or semi-regular).  Smooth, closed surfaces may form part of, or \
the whole of, the boundary of such solids in a way that the outward normal of \
the surface at any point is everywhere continuous in all directions about \
that point (for example, a sphere or torus).  This chapter also contains a \
collection of surfaces with edges having no particular regularity or symmetry.\
\>", "Text",
 CellChangeTimes->{{3.606249648373747*^9, 3.606249676458102*^9}}],

Cell[CellGroupData[{

Cell["18.0  Plotting Information for This Chapter", "Subsection"],

Cell["\<\
The 3-D forms of this chapter are displayed with the Graphics3D object.  \
Viewpoints have been set at large distances so that the perspective is \
approximately the isometric one.  All plotted figures are rotatable in 3-D.  \
Simple gray shading is provided, but this can be modified to produce more \
colorfully shaded figures.\
\>", "Text",
 CellChangeTimes->{{3.604618421083373*^9, 3.604618447530521*^9}, {
  3.604684445959594*^9, 3.604684454337953*^9}, {3.6138145962709427`*^9, 
  3.613814616055683*^9}, {3.6138147100952873`*^9, 3.613814754068767*^9}}],

Cell["Null", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1  Irregular Polyhedra", "Subsection"],

Cell[CellGroupData[{

Cell["18.1.1  Prism", "Subsubsection"],

Cell[TextData[{
 "A prism has identical top and bottom regular polygons and sides which meet \
them at right angles.  A prism with any number of sides can be created by \
modifying the parameter below.  The horizontal cross-section of the prism has \
dimension  which is the distance from the center of the regular polygon to \
any vertex.   The length of a side is given by the parameter ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", and the length of the prism's vertical axis is given by the parameter ",
 StyleBox["b",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.604684583600762*^9, 3.60468464801726*^9}, {
  3.604685210914302*^9, 3.6046852174254627`*^9}, {3.627827521386115*^9, 
  3.627827560532078*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"top", ",", "bot", ",", "t", ",", "sides", ",", "whole"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"top", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", "\[Pi]", " ", 
               RowBox[{"n", "/", "m"}]}], "]"}]}], ",", 
            RowBox[{"a", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", "\[Pi]", " ", 
               RowBox[{"n", "/", "m"}]}], "]"}]}], ",", "b"}], "}"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"bot", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"a", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", "\[Pi]", " ", 
               RowBox[{"n", "/", "m"}]}], "]"}]}], ",", 
            RowBox[{"a", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", "\[Pi]", " ", 
               RowBox[{"n", "/", "m"}]}], "]"}]}], ",", "0"}], "}"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"t", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "-", "1"}], ")"}], "/", "m"}]}], "]"}]}], ",", 
              RowBox[{"a", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "-", "1"}], ")"}], "/", "m"}]}], "]"}]}], ",",
               "b"}], "}"}], "]"}], ",", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{"n", "/", "m"}]}], "]"}]}], ",", 
              RowBox[{"a", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{"n", "/", "m"}]}], "]"}]}], ",", "b"}], "}"}], "]"}],
            ",", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{"n", "/", "m"}]}], "]"}]}], ",", 
              RowBox[{"a", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{"n", "/", "m"}]}], "]"}]}], ",", "0"}], "}"}], "]"}],
            ",", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "-", "1"}], ")"}], "/", "m"}]}], "]"}]}], ",", 
              RowBox[{"a", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "-", "1"}], ")"}], "/", "m"}]}], "]"}]}], ",",
               "0"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";", "\n", 
      "    ", 
      RowBox[{"sides", "=", 
       RowBox[{"Map", "[", 
        RowBox[{"Polygon", ",", "t"}], "]"}]}], ";", "\n", "    ", 
      RowBox[{"whole", "=", 
       RowBox[{"Join", "[", 
        RowBox[{"sides", ",", 
         RowBox[{"{", 
          RowBox[{"Polygon", "[", "top", "]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Polygon", "[", "bot", "]"}], "}"}]}], "]"}]}], ";", "\n", 
      "    ", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Graphics3D", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", "whole"}], "}"}], 
         "]"}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"8", ",", "8", ",", "4"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<18.1.1\>\""}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"a", ",", "0.5", ",", "1", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"b", ",", "1", ",", "3", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "5"}], "}"}], ",", "3", ",", "9", ",", "1", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "m"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.604684661021934*^9, 3.6046848045044394`*^9}, 
   3.60468491506213*^9, {3.6046850851370993`*^9, 3.604685090626379*^9}, {
   3.6047032184385242`*^9, 3.604703232556651*^9}, {3.611150715634017*^9, 
   3.6111507237142153`*^9}, {3.627827380154047*^9, 3.6278274102216587`*^9}, {
   3.627827772836341*^9, 3.627827776309717*^9}, {3.627828237684679*^9, 
   3.627828260448724*^9}, {3.630982579613353*^9, 3.630982589074978*^9}, {
   3.630982826528469*^9, 3.6309828623038054`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    1, $CellContext`m$$ = 5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.5, 1}, {
      Hold[$CellContext`b$$], 1, 3}, {{
       Hold[$CellContext`m$$], 5}, 3, 9, 1}}, Typeset`size$$ = {
    500., {269., 285.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$3766$$ = 
    0, $CellContext`b$3767$$ = 0, $CellContext`m$3768$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        1, $CellContext`m$$ = 5}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$3766$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$3767$$, 0], 
        Hold[$CellContext`m$$, $CellContext`m$3768$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`top$, $CellContext`bot$, $CellContext`t$, \
$CellContext`sides$, $CellContext`whole$}, $CellContext`top$ = Table[
           
           N[{$CellContext`a$$ 
             Cos[2 Pi ($CellContext`n/$CellContext`m$$)], $CellContext`a$$ 
             Sin[2 Pi ($CellContext`n/$CellContext`m$$)], $CellContext`b$$}], \
{$CellContext`n, 1, $CellContext`m$$}]; $CellContext`bot$ = Table[
           
           N[{$CellContext`a$$ 
             Cos[2 Pi ($CellContext`n/$CellContext`m$$)], $CellContext`a$$ 
             Sin[2 Pi ($CellContext`n/$CellContext`m$$)], 
             0}], {$CellContext`n, 1, $CellContext`m$$}]; $CellContext`t$ = 
         Table[{
            
            N[{$CellContext`a$$ 
              Cos[2 Pi (($CellContext`n - 
                  1)/$CellContext`m$$)], $CellContext`a$$ 
              Sin[
               2 Pi (($CellContext`n - 
                  1)/$CellContext`m$$)], $CellContext`b$$}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n/$CellContext`m$$)], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n/$CellContext`m$$)], $CellContext`b$$}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n/$CellContext`m$$)], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n/$CellContext`m$$)], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi (($CellContext`n - 
                  1)/$CellContext`m$$)], $CellContext`a$$ 
              Sin[2 Pi (($CellContext`n - 1)/$CellContext`m$$)], 
              0}]}, {$CellContext`n, 
            1, $CellContext`m$$}]; $CellContext`sides$ = 
         Map[Polygon, $CellContext`t$]; $CellContext`whole$ = 
         Join[$CellContext`sides$, {
            Polygon[$CellContext`top$]}, {
            Polygon[$CellContext`bot$]}]; Show[
          Graphics3D[{
            EdgeForm[Thick], $CellContext`whole$}], ViewPoint -> {8, 8, 4}, 
          PlotLabel -> "18.1.1", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{$CellContext`a$$, 0.5, 1, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 1, 3, Appearance -> 
         "Labeled"}, {{$CellContext`m$$, 5}, 3, 9, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`m$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {375., 382.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604684843532044*^9, 3.604684917736188*^9, 3.604685093880748*^9, 
   3.613814635914124*^9, 3.627827431831558*^9, 3.6278276506710997`*^9, 
   3.627827779035144*^9, 3.63098252362831*^9, {3.630982560143704*^9, 
   3.630982589652379*^9}, 3.6309827312742853`*^9, 3.630982863725587*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1.2  Star Prism", "Subsubsection"],

Cell[TextData[{
 "A star prism is composed of star polygons on the ends, with the number of \
star points given by ",
 StyleBox["m",
  FontSlant->"Italic"],
 ".  There are then 2",
 StyleBox["m",
  FontSlant->"Italic"],
 " sides joining the top and bottom.   The distance from the center of the \
interior polygon to any vertex is given by ",
 StyleBox["a",
  FontSlant->"Italic"],
 ".  The distance from the center to any star vertex is given by the \
parameter ",
 StyleBox["c",
  FontSlant->"Italic"],
 ".  The length of the prism's vertical axis is given by the parameter ",
 StyleBox["b",
  FontSlant->"Italic"],
 ".  Due to the method of 3-D polygon formation, the points of the star on \
the top and bottom must be specified separately from their interior polygons. "
}], "Text",
 CellChangeTimes->{{3.604685236414505*^9, 3.6046852481934958`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "top", ",", " ", "bot", ",", " ", "t1", ",", " ", "t2", ",", " ", "t3", 
       ",", " ", "t4", ",", " ", "toppoints", ",", " ", "\n", "    ", 
       "botpoints", ",", " ", "sides1", ",", " ", "sides2", ",", " ", 
       "whole"}], "}"}], ",", " ", "\n", "    ", 
     RowBox[{
      RowBox[{"top", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"a", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
              "]"}]}], ",", " ", 
            RowBox[{"a", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
              "]"}]}], ",", " ", "b"}], "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", " ", "1", ",", " ", "m"}], "}"}]}], "]"}]}], ";", 
      " ", "\[IndentingNewLine]", "  ", 
      RowBox[{"bot", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"a", "*", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
              "]"}]}], ",", " ", 
            RowBox[{"a", "*", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
              "]"}]}], ",", " ", "0"}], "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", " ", "1", ",", " ", "m"}], "}"}]}], "]"}]}], ";", 
      " ", "\n", "    ", 
      RowBox[{"t1", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{"n", " ", "-", " ", "1"}], ")"}]}], ")"}], "/", 
                 "m"}], "]"}]}], ",", " ", "\n", "         ", 
              RowBox[{"a", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{"n", " ", "-", " ", "1"}], ")"}]}], ")"}], "/", 
                 "m"}], "]"}]}], ",", " ", "b"}], "}"}], "]"}], ",", " ", 
           "\n", "       ", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"c", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "\n", 
              "         ", 
              RowBox[{"c", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "b"}], 
             "}"}], "]"}], ",", " ", "\n", "       ", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
                "]"}]}], ",", " ", 
              RowBox[{"a", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
                "]"}]}], ",", " ", "b"}], "}"}], "]"}]}], "}"}], ",", " ", 
         "\n", "    ", 
         RowBox[{"{", 
          RowBox[{"n", ",", " ", "1", ",", " ", "m"}], "}"}]}], "]"}]}], ";", 
      " ", "\n", "    ", 
      RowBox[{"t2", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{"n", " ", "-", " ", "1"}], ")"}]}], ")"}], "/", 
                 "m"}], "]"}]}], ",", " ", "\n", "         ", 
              RowBox[{"a", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{"n", " ", "-", " ", "1"}], ")"}]}], ")"}], "/", 
                 "m"}], "]"}]}], ",", " ", "0"}], "}"}], "]"}], ",", " ", 
           "\n", "       ", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"c", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "\n", 
              "         ", 
              RowBox[{"c", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "0"}], 
             "}"}], "]"}], ",", " ", "\n", "       ", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
                "]"}]}], ",", " ", 
              RowBox[{"a", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
                "]"}]}], ",", " ", "0"}], "}"}], "]"}]}], "}"}], ",", " ", 
         "\n", "    ", 
         RowBox[{"{", 
          RowBox[{"n", ",", " ", "1", ",", " ", "m"}], "}"}]}], "]"}]}], ";", 
      " ", "\n", "    ", 
      RowBox[{"t3", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{"n", " ", "-", " ", "1"}], ")"}]}], ")"}], "/", 
                 "m"}], "]"}]}], ",", " ", "\n", "         ", 
              RowBox[{"a", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{"n", " ", "-", " ", "1"}], ")"}]}], ")"}], "/", 
                 "m"}], "]"}]}], ",", " ", "b"}], "}"}], "]"}], ",", " ", 
           "\n", "       ", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"c", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "\n", 
              "         ", 
              RowBox[{"c", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "b"}], 
             "}"}], "]"}], ",", " ", "\n", "       ", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"c", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "\n", 
              "         ", 
              RowBox[{"c", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "0"}], 
             "}"}], "]"}], ",", " ", "\n", "       ", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{"n", " ", "-", " ", "1"}], ")"}]}], ")"}], "/", 
                 "m"}], "]"}]}], ",", " ", 
              RowBox[{"a", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{"n", " ", "-", " ", "1"}], ")"}]}], ")"}], "/", 
                 "m"}], "]"}]}], ",", " ", "0"}], "}"}], "]"}]}], "}"}], ",", 
         "       ", 
         RowBox[{"{", 
          RowBox[{"n", ",", " ", "1", ",", " ", "m"}], "}"}]}], "]"}]}], ";", 
      " ", "\n", "    ", 
      RowBox[{"t4", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"c", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "\n", 
              "         ", 
              RowBox[{"c", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "b"}], 
             "}"}], "]"}], ",", " ", "\n", "       ", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
                "]"}]}], ",", " ", 
              RowBox[{"a", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
                "]"}]}], ",", " ", "b"}], "}"}], "]"}], ",", " ", "\n", 
           "       ", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"a", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
                "]"}]}], ",", " ", 
              RowBox[{"a", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", "n"}], ")"}], "/", "m"}], 
                "]"}]}], ",", " ", "0"}], "}"}], "]"}], ",", " ", "\n", 
           "       ", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"c", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "\n", 
              "         ", 
              RowBox[{"c", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "*", "\[Pi]", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", "n"}], " ", "-", " ", "1"}], ")"}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "m"}], ")"}]}], "]"}]}], ",", " ", "0"}], 
             "}"}], "]"}]}], "}"}], ",", " ", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"n", ",", " ", "1", ",", " ", "m"}], "}"}]}], "]"}]}], ";", 
      " ", "\n", "    ", 
      RowBox[{"toppoints", " ", "=", " ", 
       RowBox[{"Polygon", " ", "/@", " ", "t1"}]}], ";", " ", 
      RowBox[{"botpoints", " ", "=", " ", 
       RowBox[{"Polygon", " ", "/@", " ", "t2"}]}], ";", " ", "\n", "    ", 
      RowBox[{"sides1", " ", "=", " ", 
       RowBox[{"Polygon", " ", "/@", " ", "t3"}]}], ";", " ", 
      RowBox[{"sides2", " ", "=", " ", 
       RowBox[{"Polygon", " ", "/@", " ", "t4"}]}], ";", " ", "\n", "    ", 
      RowBox[{"whole", " ", "=", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
        "sides1", ",", " ", "sides2", ",", " ", "toppoints", ",", " ", 
         "botpoints", ",", " ", "\n", "      ", 
         RowBox[{"{", 
          RowBox[{"Polygon", "[", "top", "]"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"Polygon", "[", "bot", "]"}], "}"}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Graphics3D", "[", "whole", "]"}], ",", 
        RowBox[{"ViewPoint", " ", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"4", ",", " ", "5", ",", " ", "5"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "\"\<18.1.2\>\""}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"a", ",", " ", "0.5", ",", " ", "1", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"b", ",", " ", "1", ",", " ", "3", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"c", ",", " ", "a", ",", " ", "2", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "4"}], "}"}], ",", " ", "3", ",", " ", "9", ",", " ", 
     "1", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"a", ",", " ", "b", ",", " ", "c", ",", " ", "m"}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.604685310934717*^9, 3.6046854144230547`*^9}, {
   3.6046854454520473`*^9, 3.6046855638448668`*^9}, 3.6047022435237703`*^9, 
   3.604702279689097*^9, {3.604702312458598*^9, 3.6047023473656187`*^9}, 
   3.604702381769197*^9, {3.604702998428075*^9, 3.60470317359499*^9}, {
   3.6111507428099947`*^9, 3.611150746033853*^9}, {3.611152891058364*^9, 
   3.611152891089641*^9}, {3.611186750134397*^9, 3.611186924315782*^9}, {
   3.611186958826641*^9, 3.611186970353785*^9}, {3.627827608502088*^9, 
   3.627827620587696*^9}, {3.627827803799994*^9, 3.627827804427465*^9}, {
   3.627828270601673*^9, 3.627828276231138*^9}, 3.630983010469503*^9, {
   3.630983101942747*^9, 3.630983105843749*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    1, $CellContext`c$$ = Dynamic[$CellContext`a$$], $CellContext`m$$ = 4, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.5, 1}, {
      Hold[$CellContext`b$$], 1, 3}, {
      Hold[$CellContext`c$$], 
      Dynamic[$CellContext`a$$], 2}, {{
       Hold[$CellContext`m$$], 4}, 3, 9, 1}}, Typeset`size$$ = {
    500., {293., 308.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$5493$$ = 
    0, $CellContext`b$5494$$ = 0, $CellContext`c$5495$$ = 
    0, $CellContext`m$5496$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        1, $CellContext`c$$ = Dynamic[$CellContext`a$$], $CellContext`m$$ = 
        4}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$5493$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$5494$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$5495$$, 0], 
        Hold[$CellContext`m$$, $CellContext`m$5496$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`top$, $CellContext`bot$, $CellContext`t1$, \
$CellContext`t2$, $CellContext`t3$, $CellContext`t4$, \
$CellContext`toppoints$, $CellContext`botpoints$, $CellContext`sides1$, \
$CellContext`sides2$, $CellContext`whole$}, $CellContext`top$ = Table[
           
           N[{$CellContext`a$$ 
             Cos[(2 Pi $CellContext`n)/$CellContext`m$$], $CellContext`a$$ 
             Sin[(2 Pi $CellContext`n)/$CellContext`m$$], $CellContext`b$$}], \
{$CellContext`n, 1, $CellContext`m$$}]; $CellContext`bot$ = Table[
           
           N[{$CellContext`a$$ 
             Cos[(2 Pi $CellContext`n)/$CellContext`m$$], $CellContext`a$$ 
             Sin[(2 Pi $CellContext`n)/$CellContext`m$$], 
             0}], {$CellContext`n, 1, $CellContext`m$$}]; $CellContext`t1$ = 
         Table[{
            
            N[{$CellContext`a$$ 
              Cos[(2 Pi ($CellContext`n - 
                  1))/$CellContext`m$$], $CellContext`a$$ 
              Sin[(2 Pi ($CellContext`n - 
                  1))/$CellContext`m$$], $CellContext`b$$}], 
            
            N[{$CellContext`c$$ 
              Cos[(2 Pi (2 $CellContext`n - 1))/(
                2 $CellContext`m$$)], $CellContext`c$$ 
              Sin[(2 Pi (2 $CellContext`n - 1))/(
                2 $CellContext`m$$)], $CellContext`b$$}], 
            
            N[{$CellContext`a$$ 
              Cos[(2 Pi $CellContext`n)/$CellContext`m$$], $CellContext`a$$ 
              Sin[(2 Pi $CellContext`n)/$CellContext`m$$], \
$CellContext`b$$}]}, {$CellContext`n, 1, $CellContext`m$$}]; $CellContext`t2$ = 
         Table[{
            
            N[{$CellContext`a$$ 
              Cos[(2 Pi ($CellContext`n - 
                  1))/$CellContext`m$$], $CellContext`a$$ 
              Sin[(2 Pi ($CellContext`n - 1))/$CellContext`m$$], 0}], 
            
            N[{$CellContext`c$$ 
              Cos[(2 Pi (2 $CellContext`n - 1))/(
                2 $CellContext`m$$)], $CellContext`c$$ 
              Sin[(2 Pi (2 $CellContext`n - 1))/(2 $CellContext`m$$)], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[(2 Pi $CellContext`n)/$CellContext`m$$], $CellContext`a$$ 
              Sin[(2 Pi $CellContext`n)/$CellContext`m$$], 
              0}]}, {$CellContext`n, 1, $CellContext`m$$}]; $CellContext`t3$ = 
         Table[{
            
            N[{$CellContext`a$$ 
              Cos[(2 Pi ($CellContext`n - 
                  1))/$CellContext`m$$], $CellContext`a$$ 
              Sin[(2 Pi ($CellContext`n - 
                  1))/$CellContext`m$$], $CellContext`b$$}], 
            
            N[{$CellContext`c$$ 
              Cos[(2 Pi (2 $CellContext`n - 1))/(
                2 $CellContext`m$$)], $CellContext`c$$ 
              Sin[(2 Pi (2 $CellContext`n - 1))/(
                2 $CellContext`m$$)], $CellContext`b$$}], 
            
            N[{$CellContext`c$$ 
              Cos[(2 Pi (2 $CellContext`n - 1))/(
                2 $CellContext`m$$)], $CellContext`c$$ 
              Sin[(2 Pi (2 $CellContext`n - 1))/(2 $CellContext`m$$)], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[(2 Pi ($CellContext`n - 
                  1))/$CellContext`m$$], $CellContext`a$$ 
              Sin[(2 Pi ($CellContext`n - 1))/$CellContext`m$$], 
              0}]}, {$CellContext`n, 1, $CellContext`m$$}]; $CellContext`t4$ = 
         Table[{
            
            N[{$CellContext`c$$ 
              Cos[(2 Pi (2 $CellContext`n - 1))/(
                2 $CellContext`m$$)], $CellContext`c$$ 
              Sin[(2 Pi (2 $CellContext`n - 1))/(
                2 $CellContext`m$$)], $CellContext`b$$}], 
            
            N[{$CellContext`a$$ 
              Cos[(2 Pi $CellContext`n)/$CellContext`m$$], $CellContext`a$$ 
              Sin[(2 Pi $CellContext`n)/$CellContext`m$$], $CellContext`b$$}], 
            
            N[{$CellContext`a$$ 
              Cos[(2 Pi $CellContext`n)/$CellContext`m$$], $CellContext`a$$ 
              Sin[(2 Pi $CellContext`n)/$CellContext`m$$], 0}], 
            
            N[{$CellContext`c$$ 
              Cos[(2 Pi (2 $CellContext`n - 1))/(
                2 $CellContext`m$$)], $CellContext`c$$ 
              Sin[(2 Pi (2 $CellContext`n - 1))/(2 $CellContext`m$$)], 
              0}]}, {$CellContext`n, 
            1, $CellContext`m$$}]; $CellContext`toppoints$ = 
         Map[Polygon, $CellContext`t1$]; $CellContext`botpoints$ = 
         Map[Polygon, $CellContext`t2$]; $CellContext`sides1$ = 
         Map[Polygon, $CellContext`t3$]; $CellContext`sides2$ = 
         Map[Polygon, $CellContext`t4$]; $CellContext`whole$ = 
         Join[$CellContext`sides1$, $CellContext`sides2$, \
$CellContext`toppoints$, $CellContext`botpoints$, {
            Polygon[$CellContext`top$]}, {
            Polygon[$CellContext`bot$]}]; Show[
          Graphics3D[$CellContext`whole$], ViewPoint -> {4, 5, 5}, PlotLabel -> 
          "18.1.2", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{$CellContext`a$$, 0.5, 1, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 1, 3, Appearance -> 
         "Labeled"}, {$CellContext`c$$, 
         Dynamic[$CellContext`a$$], 2, Appearance -> 
         "Labeled"}, {{$CellContext`m$$, 4}, 3, 9, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$, $CellContext`m$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {421., 428.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604685576662187*^9, 3.604702031340958*^9, 3.604702251377201*^9, 
   3.60470234948287*^9, 3.60470238281767*^9, 3.613814656247048*^9, 
   3.627827622273587*^9, 3.627827817121372*^9, 3.630982603493004*^9, 
   3.630982945336218*^9, 3.63098301128025*^9, {3.63098308846729*^9, 
   3.6309831286673098`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1.3 Anti-Prism", "Subsubsection"],

Cell[TextData[{
 "An anti-prism has identical top and bottom regular polygons of ",
 StyleBox["m",
  FontSlant->"Italic"],
 " sides, but one is rotated by 180/",
 StyleBox["m",
  FontSlant->"Italic"],
 " degrees with respect to the other.  Consequently, the connection between \
top and bottom is composed of 2",
 StyleBox["m",
  FontSlant->"Italic"],
 " identical triangles, ",
 StyleBox["m",
  FontSlant->"Italic"],
 " of which point down and ",
 StyleBox["m",
  FontSlant->"Italic"],
 " of which point up.  An anti-prism with any desired number of sides in the \
top or bottom can be created by manipulating the parameter ",
 StyleBox["m",
  FontSlant->"Italic"],
 " below.  The distance from the center to any vertex of the top or bottom \
polygon is given by ",
 StyleBox["a",
  FontSlant->"Italic"],
 ".  The length of the prism's vertical axis is given by the parameter ",
 StyleBox["b",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.604702503550507*^9, 3.604702531451495*^9}, {
  3.604702848610812*^9, 3.604702856234123*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{top,bot,t1,t2,sides1,sides2,whole},
    top = Table[N[{a Cos[2\[Pi] n/m],a Sin[2\[Pi] n/m],b}],{n,1,m}];
    bot = Table[N[{a Cos[2\[Pi](2n+1)/(2m)],a \
Sin[2\[Pi](2n+1)/(2m)],0}],{n,1,m}];
    t1 = Table[{N[{a Cos[2\[Pi](n-1)/m],a Sin[2\[Pi](n-1)/m],b}],
            N[{a Cos[2\[Pi] n/m],a Sin[2\[Pi] n/m],b}],
            N[{a Cos[2\[Pi](2n-1)/(2m)],
               a Sin[2\[Pi](2n-1)/(2m)],0}]},{n,1,m}];
    t2 = Table[{N[{a Cos[2\[Pi](2n-1)/(2m)],a Sin[2\[Pi](2n-1)/(2m)],0}],
            N[{a Cos[2\[Pi](2n+1)/(2m)],a Sin[2\[Pi](2n+1)/(2m)],0}],
            N[{a Cos[2\[Pi] n/m],a Sin[2\[Pi] n/m],b}]},{n,1,m}];
    sides1 = Map[Polygon,t1];
    sides2 = Map[Polygon,t2];
    whole = Join[sides1,sides2,{Polygon[top]},{Polygon[bot]}];
    Show[Graphics3D[whole],ViewPoint\[Rule]{6,16,4},PlotLabel\[Rule]\"18.1.3\"\
,LabelStyle\[Rule]{Black,20}]
  ],
  {a,0.5,1, Appearance\[Rule]\"Labeled\"},
  {b,1,3, Appearance\[Rule]\"Labeled\"},
  {{m,4},3,9,1, Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{a,b,m}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604702554016713*^9, 3.6047027906131897`*^9}, {
   3.611150758434969*^9, 3.611150763583089*^9}, 3.611152891148922*^9, {
   3.627827826346385*^9, 3.627827859281787*^9}, {3.6278282859226217`*^9, 
   3.627828289196179*^9}, {3.631025217911717*^9, 3.631025222397526*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    1, $CellContext`m$$ = 4, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 0.5, 1}, {
      Hold[$CellContext`b$$], 1, 3}, {{
       Hold[$CellContext`m$$], 4}, 3, 9, 1}}, Typeset`size$$ = {
    500., {254., 270.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$2048$$ = 
    0, $CellContext`b$2049$$ = 0, $CellContext`m$2050$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        1, $CellContext`m$$ = 4}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$2048$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2049$$, 0], 
        Hold[$CellContext`m$$, $CellContext`m$2050$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`top$, $CellContext`bot$, $CellContext`t1$, \
$CellContext`t2$, $CellContext`sides1$, $CellContext`sides2$, \
$CellContext`whole$}, $CellContext`top$ = Table[
           
           N[{$CellContext`a$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`b$$}], \
{$CellContext`n, 1, $CellContext`m$$}]; $CellContext`bot$ = Table[
           
           N[{$CellContext`a$$ 
             Cos[2 Pi (2 $CellContext`n + 1)/(
               2 $CellContext`m$$)], $CellContext`a$$ 
             Sin[2 Pi (2 $CellContext`n + 1)/(2 $CellContext`m$$)], 
             0}], {$CellContext`n, 1, $CellContext`m$$}]; $CellContext`t1$ = 
         Table[{
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$$], $CellContext`b$$}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`b$$}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi (2 $CellContext`n - 1)/(
                2 $CellContext`m$$)], $CellContext`a$$ 
              Sin[2 Pi (2 $CellContext`n - 1)/(2 $CellContext`m$$)], 
              0}]}, {$CellContext`n, 1, $CellContext`m$$}]; $CellContext`t2$ = 
         Table[{
            
            N[{$CellContext`a$$ 
              Cos[2 Pi (2 $CellContext`n - 1)/(
                2 $CellContext`m$$)], $CellContext`a$$ 
              Sin[2 Pi (2 $CellContext`n - 1)/(2 $CellContext`m$$)], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi (2 $CellContext`n + 1)/(
                2 $CellContext`m$$)], $CellContext`a$$ 
              Sin[2 Pi (2 $CellContext`n + 1)/(2 $CellContext`m$$)], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`b$$}]}, \
{$CellContext`n, 1, $CellContext`m$$}]; $CellContext`sides1$ = 
         Map[Polygon, $CellContext`t1$]; $CellContext`sides2$ = 
         Map[Polygon, $CellContext`t2$]; $CellContext`whole$ = 
         Join[$CellContext`sides1$, $CellContext`sides2$, {
            Polygon[$CellContext`top$]}, {
            Polygon[$CellContext`bot$]}]; Show[
          Graphics3D[$CellContext`whole$], ViewPoint -> {6, 16, 4}, PlotLabel -> 
          "18.1.3", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{$CellContext`a$$, 0.5, 1, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 1, 3, Appearance -> 
         "Labeled"}, {{$CellContext`m$$, 4}, 3, 9, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`m$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {359., 366.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.604702804849862*^9, 3.6138146746852293`*^9, 
  3.630983157200108*^9, 3.631024207426825*^9, 3.6310252230980453`*^9, 
  3.653092030572777*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1.4  Prismoid", "Subsubsection"],

Cell[TextData[{
 "A prismoid has parallel top and bottom regular polygons with equal number \
of sides, but of different sizes.  The centers of the top and bottom both lie \
on an axis which is normal to them.  The distance from the center to any \
vertex is given by ",
 StyleBox["a",
  FontSlant->"Italic"],
 "1 and ",
 StyleBox["a",
  FontSlant->"Italic"],
 "2 for the top and bottom, respectively. The length of the prism's vertical \
axis is given by the parameter ",
 StyleBox["b",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.604705799558823*^9, 3.604705865654948*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{top,bot,t,sides,whole},
    top = Table[N[{a1 Cos[2\[Pi] n/m],a1 Sin[2\[Pi] n/m],b}],{n,1,m}];
    bot = Table[N[{a2 Cos[2\[Pi] n/m],a2 Sin[2\[Pi] n/m],0}],{n,1,m}];
    t = Table[{N[{a1 Cos[2\[Pi] (n-1)/m],a1 Sin[2\[Pi] (n-1)/m],b}],
           N[{a1 Cos[2\[Pi]     n/m],a1 Sin[2\[Pi]     n/m],b}],
           N[{a2 Cos[2\[Pi]     n/m], a2 Sin[2\[Pi]     n/m],0}],
           N[{a2 Cos[2\[Pi] (n-1)/m], a2 Sin[2\[Pi] (n-1)/m],0}]},
           {n,1,m}];
    sides = Map[Polygon,t];
    whole = Join[sides,{Polygon[top]},{Polygon[bot]}];
    Show[Graphics3D[whole],ViewPoint\[Rule]{8,6,3},PlotLabel\[Rule]\"18.1.4\",\
LabelStyle\[Rule]{Black,20}]
  ],
  {{a1,0.25},0.1,1, Appearance\[Rule]\"Labeled\"},
  {{a2,0.5},a1,1, Appearance\[Rule]\"Labeled\"},
  {b,1,3, Appearance\[Rule]\"Labeled\"},
  {m,3,9,1, Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{a1,a2,b,m}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604705873789344*^9, 3.604706031817297*^9}, {
   3.60470607229501*^9, 3.60470614414826*^9}, {3.611150775220797*^9, 
   3.611150780383*^9}, 3.6111528912069683`*^9, {3.627827883559371*^9, 
   3.6278279024067307`*^9}, {3.6278282961712933`*^9, 3.627828301147147*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.25, $CellContext`a2$$ = 
    0.5, $CellContext`b$$ = 1, $CellContext`m$$ = 3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a1$$], 0.25}, 0.1, 1}, {{
       Hold[$CellContext`a2$$], 0.5}, 
      Dynamic[$CellContext`a1$$], 1}, {
      Hold[$CellContext`b$$], 1, 3}, {
      Hold[$CellContext`m$$], 3, 9, 1}}, Typeset`size$$ = {
    500., {286., 302.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a1$5167$$ = 
    0, $CellContext`a2$5168$$ = 0, $CellContext`b$5169$$ = 
    0, $CellContext`m$5170$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.25, $CellContext`a2$$ = 
        0.5, $CellContext`b$$ = 1, $CellContext`m$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a1$$, $CellContext`a1$5167$$, 0], 
        Hold[$CellContext`a2$$, $CellContext`a2$5168$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$5169$$, 0], 
        Hold[$CellContext`m$$, $CellContext`m$5170$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`top$, $CellContext`bot$, $CellContext`t$, \
$CellContext`sides$, $CellContext`whole$}, $CellContext`top$ = Table[
           
           N[{$CellContext`a1$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a1$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`b$$}], \
{$CellContext`n, 1, $CellContext`m$$}]; $CellContext`bot$ = Table[
           
           N[{$CellContext`a2$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a2$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m$$], 0}], {$CellContext`n, 
            1, $CellContext`m$$}]; $CellContext`t$ = Table[{
            
            N[{$CellContext`a1$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$$], $CellContext`a1$$ 
              Sin[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$$], $CellContext`b$$}], 
            
            N[{$CellContext`a1$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a1$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`b$$}], 
            
            N[{$CellContext`a2$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a2$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$$], 0}], 
            
            N[{$CellContext`a2$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$$], $CellContext`a2$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m$$], 
              0}]}, {$CellContext`n, 
            1, $CellContext`m$$}]; $CellContext`sides$ = 
         Map[Polygon, $CellContext`t$]; $CellContext`whole$ = 
         Join[$CellContext`sides$, {
            Polygon[$CellContext`top$]}, {
            Polygon[$CellContext`bot$]}]; Show[
          Graphics3D[$CellContext`whole$], ViewPoint -> {8, 6, 3}, PlotLabel -> 
          "18.1.4", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a1$$, 0.25}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`a2$$, 0.5}, 
         Dynamic[$CellContext`a1$$], 1, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 1, 3, Appearance -> 
         "Labeled"}, {$CellContext`m$$, 3, 9, 1, Appearance -> "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`a1$$, $CellContext`a2$$, \
$CellContext`b$$, $CellContext`m$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {415., 422.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.604706150652245*^9, 3.613814686591098*^9, 
  3.627827909931725*^9, 3.631024233694977*^9, 3.631024341503186*^9, 
  3.631024781774605*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1.5  Prismatoid", "Subsubsection"],

Cell[TextData[{
 "A prismatoid has parallel top and bottom regular polygons of unequal number \
of sides.  The ratio of number of sides of the top and bottom polygons must \
be a whole number.  The top and bottom centers lie on a single axis which is \
normal to both.  The top and bottom polygons are assigned ",
 StyleBox["m",
  FontSlant->"Italic"],
 "1 and ",
 StyleBox["m",
  FontSlant->"Italic"],
 "2 sides, respectively, with ",
 StyleBox["m",
  FontSlant->"Italic"],
 "1 > ",
 StyleBox["m",
  FontSlant->"Italic"],
 "2 and ",
 StyleBox["m",
  FontSlant->"Italic"],
 "1/",
 StyleBox["m",
  FontSlant->"Italic"],
 "2 being integer.  With the display code here, the general case is not \
allowed; and the ratio of ",
 StyleBox["m",
  FontSlant->"Italic"],
 "1 to ",
 StyleBox["m",
  FontSlant->"Italic"],
 "2 must be 2.  ",
 "The distance from the center to the vertices is given by ",
 StyleBox["a",
  FontSlant->"Italic"],
 "1 and ",
 StyleBox["a",
  FontSlant->"Italic"],
 "2 for the top and bottom polygons, respectively;",
 " and the length of the prism's vertical axis is given by the parameter ",
 StyleBox["b",
  FontSlant->"Italic"],
 ".   A special case, called a \"cupola\", is where the sides are all either \
squares or equilateral triangles and all edges are of the same length.  "
}], "Text",
 CellChangeTimes->{{3.604706304967844*^9, 3.604706316812106*^9}, {
  3.604706419322562*^9, 3.604706467069406*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{m2,top,bot,t1,t2,sides1,sides2,whole},
    m2 = m1/2;(*number of sides on the bottom*)
    top = Table[N[{a1 Cos[2\[Pi] n/m1],a1 Sin[2\[Pi] n/m1],b}],{n,1,m1}];
    bot = Table[N[{a2 Cos[2\[Pi](n/m2)-\[Pi]/m1],a2 \
Sin[2\[Pi](n/m2)-\[Pi]/m1],0}],{n,1,m2}];
    t1 = Table[{N[{a1 Cos[2\[Pi](2n-1)/m1],a1 Sin[2\[Pi](2n-1)/m1],b}],
            N[{a1 Cos[2\[Pi](2n  )/m1],a1 Sin[2\[Pi](2n  )/m1],b}],
            N[{a2 Cos[2\[Pi](n/m2)-\[Pi]/m1],a2 \
Sin[2\[Pi](n/m2)-\[Pi]/m1],0}]},
            {n,1,m2}];
    t2 = Table[{N[{a1 Cos[2\[Pi](2n-2)/m1],a1 Sin[2\[Pi](2n-2)/m1],b}],
            N[{a1 Cos[2\[Pi](2n-1)/m1],a1 Sin[2\[Pi](2n-1)/m1],b}],
            N[{a2 Cos[2\[Pi] n/m2 - \[Pi]/m1],a2 Sin[2\[Pi] n/m2 - \
\[Pi]/m1],0}],
            N[{a2 Cos[2\[Pi](n-1)/m2 - \[Pi]/m1],a2 Sin[2\[Pi](n-1)/m2 - \
\[Pi]/m1],0}]},
            {n,1,m2}];
    sides1 = Map[Polygon,t1];
    sides2 = Map[Polygon,t2];
    whole = Join[sides1,sides2,{Polygon[top]},{Polygon[bot]}];
    Show[Graphics3D[whole],ViewPoint\[Rule]{8,-3,3},PlotLabel\[Rule]\"18.1.5\"\
,LabelStyle\[Rule]{Black,20}]
  ],
  {m1,6,12,2, Appearance\[Rule]\"Labeled\"},
  {{a2,0.25},0.1,1, Appearance\[Rule]\"Labeled\"},
  {{a1,0.5},a2,1, Appearance\[Rule]\"Labeled\"},
  {b,1,3, Appearance\[Rule]\"Labeled\"},
  TrackedSymbols\[Rule]{m1,a1,a2,b}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.6047065734825277`*^9, 3.6047068030807543`*^9}, 
   3.604706890169506*^9, {3.604707000688286*^9, 3.60470700110375*^9}, {
   3.611150787958907*^9, 3.611150790695887*^9}, 3.6111528912918653`*^9, {
   3.627827926859398*^9, 3.6278279482193317`*^9}, {3.627828308696721*^9, 
   3.6278283195103893`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 0.5, $CellContext`a2$$ = 
    0.25, $CellContext`b$$ = 1, $CellContext`m1$$ = 6, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`m1$$], 6, 12, 2}, {{
       Hold[$CellContext`a2$$], 0.25}, 0.1, 1}, {{
       Hold[$CellContext`a1$$], 0.5}, 
      Dynamic[$CellContext`a2$$], 1}, {
      Hold[$CellContext`b$$], 1, 3}}, Typeset`size$$ = {500., {296., 312.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`m1$2297$$ = 0, $CellContext`a2$2298$$ = 
    0, $CellContext`a1$2299$$ = 0, $CellContext`b$2300$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 0.5, $CellContext`a2$$ = 
        0.25, $CellContext`b$$ = 1, $CellContext`m1$$ = 6}, 
      "ControllerVariables" :> {
        Hold[$CellContext`m1$$, $CellContext`m1$2297$$, 0], 
        Hold[$CellContext`a2$$, $CellContext`a2$2298$$, 0], 
        Hold[$CellContext`a1$$, $CellContext`a1$2299$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2300$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`m2$, $CellContext`top$, $CellContext`bot$, \
$CellContext`t1$, $CellContext`t2$, $CellContext`sides1$, \
$CellContext`sides2$, $CellContext`whole$}, $CellContext`m2$ = \
$CellContext`m1$$/2; $CellContext`top$ = Table[
           
           N[{$CellContext`a1$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m1$$], $CellContext`a1$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m1$$], $CellContext`b$$}], \
{$CellContext`n, 1, $CellContext`m1$$}]; $CellContext`bot$ = Table[
           
           N[{$CellContext`a2$$ 
             Cos[2 Pi ($CellContext`n/$CellContext`m2$) - 
               Pi/$CellContext`m1$$], $CellContext`a2$$ 
             Sin[2 Pi ($CellContext`n/$CellContext`m2$) - 
               Pi/$CellContext`m1$$], 0}], {$CellContext`n, 
            1, $CellContext`m2$}]; $CellContext`t1$ = Table[{
            
            N[{$CellContext`a1$$ 
              Cos[2 Pi (2 $CellContext`n - 
                 1)/$CellContext`m1$$], $CellContext`a1$$ 
              Sin[2 Pi (2 $CellContext`n - 
                 1)/$CellContext`m1$$], $CellContext`b$$}], 
            
            N[{$CellContext`a1$$ 
              Cos[2 Pi (
                 2 $CellContext`n)/$CellContext`m1$$], $CellContext`a1$$ 
              Sin[2 Pi (
                 2 $CellContext`n)/$CellContext`m1$$], $CellContext`b$$}], 
            
            N[{$CellContext`a2$$ 
              Cos[2 Pi ($CellContext`n/$CellContext`m2$) - 
                Pi/$CellContext`m1$$], $CellContext`a2$$ 
              Sin[2 Pi ($CellContext`n/$CellContext`m2$) - 
                Pi/$CellContext`m1$$], 0}]}, {$CellContext`n, 
            1, $CellContext`m2$}]; $CellContext`t2$ = Table[{
            
            N[{$CellContext`a1$$ 
              Cos[2 Pi (2 $CellContext`n - 
                 2)/$CellContext`m1$$], $CellContext`a1$$ 
              Sin[2 Pi (2 $CellContext`n - 
                 2)/$CellContext`m1$$], $CellContext`b$$}], 
            
            N[{$CellContext`a1$$ 
              Cos[2 Pi (2 $CellContext`n - 
                 1)/$CellContext`m1$$], $CellContext`a1$$ 
              Sin[2 Pi (2 $CellContext`n - 
                 1)/$CellContext`m1$$], $CellContext`b$$}], 
            
            N[{$CellContext`a2$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m2$ - 
                Pi/$CellContext`m1$$], $CellContext`a2$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m2$ - 
                Pi/$CellContext`m1$$], 0}], 
            
            N[{$CellContext`a2$$ 
              Cos[2 Pi ($CellContext`n - 1)/$CellContext`m2$ - 
                Pi/$CellContext`m1$$], $CellContext`a2$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m2$ - 
                Pi/$CellContext`m1$$], 0}]}, {$CellContext`n, 
            1, $CellContext`m2$}]; $CellContext`sides1$ = 
         Map[Polygon, $CellContext`t1$]; $CellContext`sides2$ = 
         Map[Polygon, $CellContext`t2$]; $CellContext`whole$ = 
         Join[$CellContext`sides1$, $CellContext`sides2$, {
            Polygon[$CellContext`top$]}, {
            Polygon[$CellContext`bot$]}]; Show[
          Graphics3D[$CellContext`whole$], ViewPoint -> {8, -3, 3}, PlotLabel -> 
          "18.1.5", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{$CellContext`m1$$, 6, 12, 2, Appearance -> 
         "Labeled"}, {{$CellContext`a2$$, 0.25}, 0.1, 1, Appearance -> 
         "Labeled"}, {{$CellContext`a1$$, 0.5}, 
         Dynamic[$CellContext`a2$$], 1, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 1, 3, Appearance -> "Labeled"}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`m1$$, $CellContext`a1$$, \
$CellContext`a2$$, $CellContext`b$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {425., 432.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.604706827037671*^9, 3.60470689120352*^9, 
  3.60470700241584*^9, 3.6138146975041943`*^9, 3.62782795121334*^9, 
  3.63102445854353*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1.6  Parallelepiped", "Subsubsection"],

Cell[TextData[{
 "A parallelepiped has six sides, of which opposing sides are identical and \
parallel.  If the sides all join at right angles, it is a \"right\" \
parallelepiped; if two opposing sides meet the ends at an angle other than a \
right angle, it is an \"oblique\" parallelepiped.  Let the dimensions of the \
ends be ",
 StyleBox["a",
  FontSlant->"Italic"],
 " by ",
 StyleBox["b",
  FontSlant->"Italic"],
 " and the remaining side length be ",
 StyleBox["c",
  FontSlant->"Italic"],
 ".  Let the angle between the two faces joined along the edges of length ",
 StyleBox["b",
  FontSlant->"Italic"],
 " be 90\[Degree] \[PlusMinus]  ",
 StyleBox["p",
  FontSlant->"Italic"],
 "\[Degree].  The remaining two faces join the ends along the edges of length \
",
 StyleBox["a",
  FontSlant->"Italic"],
 " at right angles."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{q,bot,top,side1,side2,side3,side4,whole},
    q = p Degree;
    top = {{c Sin[q], 0, c Cos[q]},{c Sin[q], b, c Cos[q]},
       {a + c Sin[q], b, c Cos[q]},{a + c Sin[q], 0, c Cos[q]}};
    bot = {{0, 0, 0},{0, b, 0},{a, b, 0},{a, 0, 0}};
    side1 = {{c Sin[q], 0, c Cos[q]},{c Sin[q], b, c Cos[q]},
         {0, b, 0},{0, 0, 0}};
    side2 = {{c Sin[q], b, c Cos[q]},{a + c Sin[q], b, c Cos[q]},
         {a, b, 0},{0, b, 0}};
    side3 = {{a + c Sin[q], b, c Cos[q]},{a + c Sin[q], 0, c Cos[q]},
         {a, 0, 0},{a, b, 0}};
    side4 = {{a + c Sin[q], 0, c Cos[q]},{c Sin[q], 0, c Cos[q]},
         {0, 0, 0},{a, 0, 0}};
    whole = Join[{Polygon[top]},{Polygon[bot]},{Polygon[side1]},
             {Polygon[side2]},{Polygon[side3]},{Polygon[side4]}];
    Show[Graphics3D[whole],ViewPoint\[Rule]{3,-6,2},PlotLabel\[Rule]\"18.1.6\"\
,LabelStyle\[Rule]{Black,20}]
  ],
  {{p,15},0,45, Appearance\[Rule]\"Labeled\"},
  {a,1,2, Appearance\[Rule]\"Labeled\"},
  {b,1,2, Appearance\[Rule]\"Labeled\"},
  {c,1,3, Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False,
  TrackedSymbols\[Rule]{p,a,b,c}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604754106080621*^9, 3.6047541165343857`*^9}, {
   3.604754149948537*^9, 3.604754310540258*^9}, {3.60475434264826*^9, 
   3.6047543619409513`*^9}, {3.604754392586351*^9, 3.604754410484941*^9}, 
   3.6047544505591707`*^9, {3.604754723134059*^9, 3.604754723140802*^9}, {
   3.611150798808507*^9, 3.6111508289818163`*^9}, {3.6278279708310966`*^9, 
   3.627827998847044*^9}, {3.627828329334503*^9, 3.627828334884799*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`b$$ = 
    1, $CellContext`c$$ = 1, $CellContext`p$$ = 15, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`p$$], 15}, 0, 45}, {
      Hold[$CellContext`a$$], 1, 2}, {
      Hold[$CellContext`b$$], 1, 2}, {
      Hold[$CellContext`c$$], 1, 3}}, Typeset`size$$ = {500., {221., 236.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`p$2557$$ = 0, $CellContext`a$2558$$ = 
    0, $CellContext`b$2559$$ = 0, $CellContext`c$2560$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`b$$ = 
        1, $CellContext`c$$ = 1, $CellContext`p$$ = 15}, 
      "ControllerVariables" :> {
        Hold[$CellContext`p$$, $CellContext`p$2557$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$2558$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2559$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$2560$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`q$, $CellContext`bot$, $CellContext`top$, \
$CellContext`side1$, $CellContext`side2$, $CellContext`side3$, \
$CellContext`side4$, $CellContext`whole$}, $CellContext`q$ = $CellContext`p$$ 
          Degree; $CellContext`top$ = {{$CellContext`c$$ Sin[$CellContext`q$],
             0, $CellContext`c$$ Cos[$CellContext`q$]}, {$CellContext`c$$ 
            Sin[$CellContext`q$], $CellContext`b$$, $CellContext`c$$ 
            Cos[$CellContext`q$]}, {$CellContext`a$$ + $CellContext`c$$ 
             Sin[$CellContext`q$], $CellContext`b$$, $CellContext`c$$ 
            Cos[$CellContext`q$]}, {$CellContext`a$$ + $CellContext`c$$ 
             Sin[$CellContext`q$], 0, $CellContext`c$$ 
            Cos[$CellContext`q$]}}; $CellContext`bot$ = {{0, 0, 0}, {
           0, $CellContext`b$$, 0}, {$CellContext`a$$, $CellContext`b$$, 
            0}, {$CellContext`a$$, 0, 
            0}}; $CellContext`side1$ = {{$CellContext`c$$ 
            Sin[$CellContext`q$], 0, $CellContext`c$$ 
            Cos[$CellContext`q$]}, {$CellContext`c$$ 
            Sin[$CellContext`q$], $CellContext`b$$, $CellContext`c$$ 
            Cos[$CellContext`q$]}, {0, $CellContext`b$$, 0}, {0, 0, 
           0}}; $CellContext`side2$ = {{$CellContext`c$$ 
            Sin[$CellContext`q$], $CellContext`b$$, $CellContext`c$$ 
            Cos[$CellContext`q$]}, {$CellContext`a$$ + $CellContext`c$$ 
             Sin[$CellContext`q$], $CellContext`b$$, $CellContext`c$$ 
            Cos[$CellContext`q$]}, {$CellContext`a$$, $CellContext`b$$, 0}, {
           0, $CellContext`b$$, 
            0}}; $CellContext`side3$ = {{$CellContext`a$$ + $CellContext`c$$ 
             Sin[$CellContext`q$], $CellContext`b$$, $CellContext`c$$ 
            Cos[$CellContext`q$]}, {$CellContext`a$$ + $CellContext`c$$ 
             Sin[$CellContext`q$], 0, $CellContext`c$$ 
            Cos[$CellContext`q$]}, {$CellContext`a$$, 0, 
            0}, {$CellContext`a$$, $CellContext`b$$, 
            0}}; $CellContext`side4$ = {{$CellContext`a$$ + $CellContext`c$$ 
             Sin[$CellContext`q$], 0, $CellContext`c$$ 
            Cos[$CellContext`q$]}, {$CellContext`c$$ Sin[$CellContext`q$], 
            0, $CellContext`c$$ Cos[$CellContext`q$]}, {0, 0, 
           0}, {$CellContext`a$$, 0, 0}}; $CellContext`whole$ = Join[{
            Polygon[$CellContext`top$]}, {
            Polygon[$CellContext`bot$]}, {
            Polygon[$CellContext`side1$]}, {
            Polygon[$CellContext`side2$]}, {
            Polygon[$CellContext`side3$]}, {
            Polygon[$CellContext`side4$]}]; Show[
          Graphics3D[$CellContext`whole$], ViewPoint -> {3, -6, 2}, PlotLabel -> 
          "18.1.6", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`p$$, 15}, 0, 45, Appearance -> 
         "Labeled"}, {$CellContext`a$$, 1, 2, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 1, 2, Appearance -> 
         "Labeled"}, {$CellContext`c$$, 1, 3, Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`p$$, $CellContext`a$$, \
$CellContext`b$$, $CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {349., 356.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604754422131679*^9, 3.6047544839816504`*^9}, 
   3.6138147967211647`*^9, {3.627827994291094*^9, 3.6278280012697897`*^9}, 
   3.631024486880279*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1.7  Pyramid", "Subsubsection"],

Cell[TextData[{
 "A pyramid has a base of ",
 StyleBox["m",
  FontSlant->"Italic"],
 " sides, with ",
 StyleBox["m",
  FontSlant->"Italic"],
 " triangles joining the base and meeting at a single apex.  The pyramid is \
\"regular\" if the base is a regular polygon; in this case, the sides are all \
identical and the apex lies on a line which is normal to the center of the \
base.  \"Irregular\" pyramids have irregular polygons as their bases.  The \
following display is for the regular pyramid only.  ",
 "For the regular pyramid displayed here,",
 " the length of the line joining any of the vertices of the base to its \
central axis is ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", and the height of the pyramid is ",
 StyleBox["b",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.604754573093811*^9, 3.6047545802586737`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{base,t,sides,whole},
    base = Table[N[{a Cos[2\[Pi] n/m],a Sin[2\[Pi] n/m],0}],{n,1,m}];
    t = Table[{N[{0,0,b}],
           N[{a Cos[2\[Pi]     n/m],a Sin[2\[Pi]     n/m],0}],
           N[{a Cos[2\[Pi] (n-1)/m],a Sin[2\[Pi] (n-1)/m],0}]},
           {n,1,m}];
    sides = Map[Polygon,t];
    whole = Join[sides,{Polygon[base]}];
    Show[Graphics3D[whole],ViewPoint\[Rule]{-3,9,4},PlotLabel\[Rule]\"18.1.7\"\
,LabelStyle\[Rule]{Black,20}]
  ],
  {m,3,6,1, Appearance\[Rule]\"Labeled\"},
  {a,1,2, Appearance\[Rule]\"Labeled\"},
  {b,1,2, Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False,
  TrackedSymbols\[Rule]{m,a,b}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604754600856989*^9, 3.604754695693726*^9}, {
   3.60475473879427*^9, 3.604754779483481*^9}, 3.6047548111992407`*^9, {
   3.61115080906387*^9, 3.6111508203693438`*^9}, {3.627828010672449*^9, 
   3.62782804054388*^9}, {3.627828345610242*^9, 3.627828348260149*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`b$$ = 
    1, $CellContext`m$$ = 3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`m$$], 3, 6, 1}, {
      Hold[$CellContext`a$$], 1, 2}, {
      Hold[$CellContext`b$$], 1, 2}}, Typeset`size$$ = {500., {229., 244.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`m$2815$$ = 0, $CellContext`a$2816$$ = 
    0, $CellContext`b$2817$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`b$$ = 
        1, $CellContext`m$$ = 3}, "ControllerVariables" :> {
        Hold[$CellContext`m$$, $CellContext`m$2815$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$2816$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$2817$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`base$, $CellContext`t$, $CellContext`sides$, \
$CellContext`whole$}, $CellContext`base$ = Table[
           
           N[{$CellContext`a$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m$$], 0}], {$CellContext`n, 
            1, $CellContext`m$$}]; $CellContext`t$ = Table[{
            N[{0, 0, $CellContext`b$$}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$$], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m$$], 
              0}]}, {$CellContext`n, 
            1, $CellContext`m$$}]; $CellContext`sides$ = 
         Map[Polygon, $CellContext`t$]; $CellContext`whole$ = 
         Join[$CellContext`sides$, {
            Polygon[$CellContext`base$]}]; Show[
          Graphics3D[$CellContext`whole$], ViewPoint -> {-3, 9, 4}, PlotLabel -> 
          "18.1.7", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{$CellContext`m$$, 3, 6, 1, Appearance -> 
         "Labeled"}, {$CellContext`a$$, 1, 2, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 1, 2, Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`m$$, $CellContext`a$$, \
$CellContext`b$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {335., 342.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604754787349766*^9, 3.604754838093594*^9}, 
   3.613814808608333*^9, 3.627828041805504*^9, 3.6310245106789103`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1.8  Dipyramid", "Subsubsection"],

Cell[TextData[{
 "The dypyramid is simple two pyramids joined base-to-base.  The length of \
the line joining any of the vertices of the mutual base to its center is ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", and the height of each pyramid is ",
 StyleBox["b",
  FontSlant->"Italic"],
 ".  The number of sides of each pyramid is given by ",
 StyleBox["m",
  FontSlant->"Italic"],
 ". As for simple pyramids, the figure is \"regular\" if the base is a \
regular polygon and \"irregular\" if the base is not.  Only regular polygons \
are used here."
}], "Text",
 CellChangeTimes->{{3.604754895675495*^9, 3.604754916992042*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{t,s,sidestop,sidesbot,whole},
    t = Table[{N[{0,0,b}],
           N[{a Cos[2\[Pi]     n/m],a Sin[2\[Pi]     n/m],0}],
           N[{a Cos[2\[Pi] (n-1)/m],a Sin[2\[Pi] (n-1)/m],0}]},
           {n,1,m}];
    s = Table[{N[{0,0,-b}],
           N[{a Cos[2\[Pi]     n/m],a Sin[2\[Pi]     n/m],0}],
           N[{a Cos[2\[Pi] (n-1)/m],a Sin[2\[Pi] (n-1)/m],0}]},
           {n,1,m}];
    sidestop = Map[Polygon,t];
    sidesbot = Map[Polygon,s];
    whole = Join[sidestop,sidesbot];
    Show[Graphics3D[whole],ViewPoint\[Rule]{-6,8,4},PlotLabel\[Rule]\"18.1.8\"\
,LabelStyle\[Rule]{Black,20}]
  ],
  {m,3,6,1, Appearance\[Rule]\"Labeled\"},
  {a,1,2, Appearance\[Rule]\"Labeled\"},
  {{b,1.5},1,2, Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False,
  TrackedSymbols\[Rule]{m,a,b}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604754937582941*^9, 3.604755038840528*^9}, {
   3.611150844195765*^9, 3.611150846821047*^9}, 3.61115289138734*^9, {
   3.627828057295972*^9, 3.627828081693757*^9}, {3.627828354860402*^9, 
   3.627828357609707*^9}, {3.6310245783551483`*^9, 3.631024583443902*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`b$$ = 
    1.5, $CellContext`m$$ = 3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`m$$], 3, 6, 1}, {
      Hold[$CellContext`a$$], 1, 2}, {{
       Hold[$CellContext`b$$], 1.5}, 1, 2}}, Typeset`size$$ = {
    500., {408., 424.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`m$3632$$ = 
    0, $CellContext`a$3633$$ = 0, $CellContext`b$3634$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`b$$ = 
        1.5, $CellContext`m$$ = 3}, "ControllerVariables" :> {
        Hold[$CellContext`m$$, $CellContext`m$3632$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$3633$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$3634$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`t$, $CellContext`s$, $CellContext`sidestop$, \
$CellContext`sidesbot$, $CellContext`whole$}, $CellContext`t$ = Table[{
            N[{0, 0, $CellContext`b$$}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$$], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m$$], 
              0}]}, {$CellContext`n, 1, $CellContext`m$$}]; $CellContext`s$ = 
         Table[{
            N[{0, 0, -$CellContext`b$$}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$$], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m$$], 
              0}]}, {$CellContext`n, 
            1, $CellContext`m$$}]; $CellContext`sidestop$ = 
         Map[Polygon, $CellContext`t$]; $CellContext`sidesbot$ = 
         Map[Polygon, $CellContext`s$]; $CellContext`whole$ = 
         Join[$CellContext`sidestop$, $CellContext`sidesbot$]; Show[
          Graphics3D[$CellContext`whole$], ViewPoint -> {-6, 8, 4}, PlotLabel -> 
          "18.1.8", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{$CellContext`m$$, 3, 6, 1, Appearance -> 
         "Labeled"}, {$CellContext`a$$, 1, 2, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 1.5}, 1, 2, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`m$$, $CellContext`a$$, \
$CellContext`b$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {514., 521.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604755045965291*^9, 3.604755058663019*^9}, {
   3.604755132225092*^9, 3.604755140432934*^9}, 3.6138148358293056`*^9, 
   3.62782808292248*^9, 3.631024536201077*^9, {3.631024570237183*^9, 
   3.63102458635431*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1.9  Trapezohedron", "Subsubsection"],

Cell[TextData[{
 "The trapezohedron has ",
 StyleBox["m",
  FontSlant->"Italic"],
 " sides extending from each of two apices.  It is similar to the dipyramid, \
but here each side is a rhombus rather than a triangle.  Like the dipyramid, \
it can be constructed from two identical parts, except for suitable \
translations and rotations.  ",
 "The length of the line perpendicular to the central axis and connecting to \
the outermost vertices is ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", and the height of each pyramid formed by connecting the outermost \
vertices with the nearest apex is ",
 StyleBox["b",
  FontSlant->"Italic"],
 ".  The number of sides of either of the top or bottom part is ",
 StyleBox["m",
  FontSlant->"Italic"],
 ".  A pseudo-base normal to the central axis is formed by a plane which \
intersects all the vertices of the top of the figure; similarly for the \
bottom of the figure, a separate pseudo-base is formed.  "
}], "Text",
 CellChangeTimes->{{3.604755313824843*^9, 3.60475536520348*^9}, 
   3.6047554546203547`*^9, {3.6047555087630672`*^9, 3.6047555671501093`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{h,c,t,s,sidestop,sidesbot,whole},
    h = Cos[\[Pi]/m];
    c = b(1-h)/h;
    t = Table[{N[{0,0,+b+c/2}],
           N[{a Cos[2\[Pi] n/m]        ,a Sin[2\[Pi] n/m]        , c/2}],
           N[{a Cos[2\[Pi] (2n-1)/(2m)],a Sin[2\[Pi] (2n-1)/(2m)],-c/2}],
           N[{a Cos[2\[Pi] (n-1)/m]    ,a Sin[2\[Pi] (n-1)/m]    , c/2}]},
           {n,1,m}];
    s = Table[{N[{0,0,-b-c/2}],
           N[{a Cos[2\[Pi] (2n+1)/(2m)],a Sin[2\[Pi] (2n+1)/(2m)],-c/2}],
           N[{a Cos[2\[Pi] n/m]        ,a Sin[2\[Pi] n/m]        , c/2}],
           N[{a Cos[2\[Pi] (2n-1)/(2m)],a Sin[2\[Pi] (2n-1)/(2m)],-c/2}]},
           {n,1,m}];
    sidestop = Map[Polygon,t];
    sidesbot = Map[Polygon,s];
    whole = Join[sidestop,sidesbot];
    Show[Graphics3D[whole],ViewPoint\[Rule]{6,16,10},PlotLabel\[Rule]\"18.1.9\
\",LabelStyle\[Rule]{Black,20}]
  ],
  {m,3,6,1, Appearance\[Rule]\"Labeled\"},
  {a,1,2, Appearance\[Rule]\"Labeled\"},
  {b,1,2, Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False,
  TrackedSymbols\[Rule]{m,a,b}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604755585194892*^9, 3.6047556837226667`*^9}, {
  3.6047557635705643`*^9, 3.604755768457225*^9}, {3.611150855108994*^9, 
  3.6111508585833187`*^9}, {3.6278280935863047`*^9, 3.627828115330533*^9}, {
  3.627828367110587*^9, 3.627828370210616*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`b$$ = 
    1, $CellContext`m$$ = 3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`m$$], 3, 6, 1}, {
      Hold[$CellContext`a$$], 1, 2}, {
      Hold[$CellContext`b$$], 1, 2}}, Typeset`size$$ = {500., {384., 399.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`m$3878$$ = 0, $CellContext`a$3879$$ = 
    0, $CellContext`b$3880$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`b$$ = 
        1, $CellContext`m$$ = 3}, "ControllerVariables" :> {
        Hold[$CellContext`m$$, $CellContext`m$3878$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$3879$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$3880$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`h$, $CellContext`c$, $CellContext`t$, \
$CellContext`s$, $CellContext`sidestop$, $CellContext`sidesbot$, \
$CellContext`whole$}, $CellContext`h$ = 
         Cos[Pi/$CellContext`m$$]; $CellContext`c$ = $CellContext`b$$ (
           1 - $CellContext`h$)/$CellContext`h$; $CellContext`t$ = Table[{
            N[{0, 0, $CellContext`b$$ + $CellContext`c$/2}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`c$/2}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi (2 $CellContext`n - 1)/(
                2 $CellContext`m$$)], $CellContext`a$$ 
              Sin[2 Pi (2 $CellContext`n - 1)/(
                2 $CellContext`m$$)], -$CellContext`c$/2}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$$], $CellContext`c$/2}]}, {$CellContext`n, 
            1, $CellContext`m$$}]; $CellContext`s$ = Table[{
            N[{0, 0, -$CellContext`b$$ - $CellContext`c$/2}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi (2 $CellContext`n + 1)/(
                2 $CellContext`m$$)], $CellContext`a$$ 
              Sin[2 Pi (2 $CellContext`n + 1)/(
                2 $CellContext`m$$)], -$CellContext`c$/2}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$$], $CellContext`c$/2}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi (2 $CellContext`n - 1)/(
                2 $CellContext`m$$)], $CellContext`a$$ 
              Sin[2 Pi (2 $CellContext`n - 1)/(
                2 $CellContext`m$$)], -$CellContext`c$/2}]}, {$CellContext`n, 
            1, $CellContext`m$$}]; $CellContext`sidestop$ = 
         Map[Polygon, $CellContext`t$]; $CellContext`sidesbot$ = 
         Map[Polygon, $CellContext`s$]; $CellContext`whole$ = 
         Join[$CellContext`sidestop$, $CellContext`sidesbot$]; Show[
          Graphics3D[$CellContext`whole$], ViewPoint -> {6, 16, 10}, 
          PlotLabel -> "18.1.9", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{$CellContext`m$$, 3, 6, 1, Appearance -> 
         "Labeled"}, {$CellContext`a$$, 1, 2, Appearance -> 
         "Labeled"}, {$CellContext`b$$, 1, 2, Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`m$$, $CellContext`a$$, \
$CellContext`b$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {490., 497.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6047557092475977`*^9, 3.604755718888083*^9}, 
   3.604755769978232*^9, 3.613814850478579*^9, 3.6278281195917673`*^9, 
   3.631024616590467*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1.10  Obelisk", "Subsubsection"],

Cell[TextData[{
 "An obelisk has parallel, but non-congruent, top and bottom rectangles.  The \
centers of the top and bottom both lie on an axis which is normal to them and \
are separated by the distance ",
 StyleBox["h",
  FontSlant->"Italic"],
 ".  The top rectangle has dimensions of ",
 StyleBox["a",
  FontSlant->"Italic"],
 " and ",
 StyleBox["b",
  FontSlant->"Italic"],
 " while the bottom one has dimensions of ",
 StyleBox["c",
  FontSlant->"Italic"],
 " and ",
 StyleBox["d",
  FontSlant->"Italic"],
 ".  Trapezoids then connect the top and bottom."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{top,bot,t,sides,whole},
    top = {{b/2,a/2,h},{-b/2,a/2,h},{-b/2,-a/2,h},{b/2,-a/2,h}};
    bot = {{d/2,c/2,0},{-d/2,c/2,0},{-d/2,-c/2,0},{d/2,-c/2,0}};
    t = {{{b/2,a/2,h},{d/2,c/2,0},{d/2,-c/2,0},{b/2,-a/2,h}},{{b/2,a/2,h},{d/\
2,c/2,0},{-d/2,c/2,0},{-b/2,a/2,h}},{{-b/2,a/2,h},{-d/2,c/2,0},{-d/2,-c/2,0},{\
-b/2,-a/2,h}},{{-b/2,-a/2,h},{-d/2,-c/2,0},{d/2,-c/2,0},{b/2,-a/2,h}}};
    sides = Map[Polygon,t];
    whole = Join[sides,{Polygon[top]},{Polygon[bot]}];
    Show[Graphics3D[whole],ViewPoint\[Rule]{8,6,3},PlotLabel\[Rule]\"18.1.10\"\
,LabelStyle\[Rule]{Black,20}]
  ],
  {{h,1},0.5,2, Appearance\[Rule]\"Labeled\"},
  {{a,0.5},0.5,2, Appearance\[Rule]\"Labeled\"},
  {{b,1},0.5,2, Appearance\[Rule]\"Labeled\"},
  {{c,1},0.5,2, Appearance\[Rule]\"Labeled\"},
  {{d,2},0.5,2, Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False,
  TrackedSymbols\[Rule]{a,b,c,d,h}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604755843395005*^9, 3.604756099724215*^9}, {
   3.604756148820922*^9, 3.6047561577174397`*^9}, 3.604756198443492*^9, {
   3.6111508665843*^9, 3.611150869183154*^9}, 3.611152891499559*^9, {
   3.627828140693781*^9, 3.627828171084298*^9}, {3.627828383536858*^9, 
   3.627828390548182*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    1, $CellContext`c$$ = 1, $CellContext`d$$ = 2, $CellContext`h$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`h$$], 1}, 0.5, 2}, {{
       Hold[$CellContext`a$$], 0.5}, 0.5, 2}, {{
       Hold[$CellContext`b$$], 1}, 0.5, 2}, {{
       Hold[$CellContext`c$$], 1}, 0.5, 2}, {{
       Hold[$CellContext`d$$], 2}, 0.5, 2}}, Typeset`size$$ = {
    500., {208., 223.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`h$4128$$ = 
    0, $CellContext`a$4129$$ = 0, $CellContext`b$4130$$ = 
    0, $CellContext`c$4131$$ = 0, $CellContext`d$4132$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        1, $CellContext`c$$ = 1, $CellContext`d$$ = 2, $CellContext`h$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`h$$, $CellContext`h$4128$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$4129$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$4130$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$4131$$, 0], 
        Hold[$CellContext`d$$, $CellContext`d$4132$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`top$, $CellContext`bot$, $CellContext`t$, \
$CellContext`sides$, $CellContext`whole$}, $CellContext`top$ = \
{{$CellContext`b$$/2, $CellContext`a$$/
            2, $CellContext`h$$}, {-$CellContext`b$$/2, $CellContext`a$$/
            2, $CellContext`h$$}, {-$CellContext`b$$/2, -$CellContext`a$$/
            2, $CellContext`h$$}, {$CellContext`b$$/2, -$CellContext`a$$/
            2, $CellContext`h$$}}; $CellContext`bot$ = {{$CellContext`d$$/
            2, $CellContext`c$$/2, 0}, {-$CellContext`d$$/2, $CellContext`c$$/
            2, 0}, {-$CellContext`d$$/2, -$CellContext`c$$/2, 
            0}, {$CellContext`d$$/2, -$CellContext`c$$/2, 
            0}}; $CellContext`t$ = {{{$CellContext`b$$/2, $CellContext`a$$/
             2, $CellContext`h$$}, {$CellContext`d$$/2, $CellContext`c$$/2, 
             0}, {$CellContext`d$$/2, -$CellContext`c$$/2, 
             0}, {$CellContext`b$$/2, -$CellContext`a$$/
             2, $CellContext`h$$}}, {{$CellContext`b$$/2, $CellContext`a$$/
             2, $CellContext`h$$}, {$CellContext`d$$/2, $CellContext`c$$/2, 
             0}, {-$CellContext`d$$/2, $CellContext`c$$/2, 
             0}, {-$CellContext`b$$/2, $CellContext`a$$/
             2, $CellContext`h$$}}, {{-$CellContext`b$$/2, $CellContext`a$$/
             2, $CellContext`h$$}, {-$CellContext`d$$/2, $CellContext`c$$/2, 
             0}, {-$CellContext`d$$/2, -$CellContext`c$$/2, 
             0}, {-$CellContext`b$$/2, -$CellContext`a$$/
             2, $CellContext`h$$}}, {{-$CellContext`b$$/2, -$CellContext`a$$/
             2, $CellContext`h$$}, {-$CellContext`d$$/2, -$CellContext`c$$/2, 
             0}, {$CellContext`d$$/2, -$CellContext`c$$/2, 
             0}, {$CellContext`b$$/2, -$CellContext`a$$/
             2, $CellContext`h$$}}}; $CellContext`sides$ = 
         Map[Polygon, $CellContext`t$]; $CellContext`whole$ = 
         Join[$CellContext`sides$, {
            Polygon[$CellContext`top$]}, {
            Polygon[$CellContext`bot$]}]; Show[
          Graphics3D[$CellContext`whole$], ViewPoint -> {8, 6, 3}, PlotLabel -> 
          "18.1.10", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`h$$, 1}, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`a$$, 0.5}, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 1}, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 1}, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`d$$, 2}, 0.5, 2, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$, $CellContext`d$$, $CellContext`h$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {359., 366.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604756111207287*^9, 3.604756128978826*^9}, {
   3.6047561594119387`*^9, 3.604756205912162*^9}, 3.6138148655598087`*^9, 
   3.613814896407898*^9, 3.627828177290206*^9, 3.63102464488573*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.1.11  Irregular Dodecahedron", "Subsubsection"],

Cell[TextData[{
 "This particular polyhedron has parallel squares at the top and bottom.  The \
sides are composed of ten additional quadrilaterals.  Eight of these are \
identical, except for rotation and translation; and the two remaining ones \
are identical.  Let the distance from the center of the square to its \
vertices be ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", the axial distance between top and bottom be",
 StyleBox[" c",
  FontSlant->"Italic"],
 ", and the lateral extension of the middle of the figure beyond ",
 StyleBox["a ",
  FontSlant->"Italic"],
 "be ",
 StyleBox["b",
  FontSlant->"Italic"],
 ".  Note that for ",
 StyleBox["b",
  FontSlant->"Italic"],
 " = 0 the figure degenerates to a right parallelepiped. "
}], "Text",
 CellChangeTimes->{{3.604756270196569*^9, 3.6047562719383993`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{top,bot,sidet1,sidet2,sidet3,sidet4,sideb1,sideb2,sideb3,sideb4,\
side1,side2,whole},
    top = Table[N[{a Cos[2\[Pi] n/4], a Sin[2\[Pi] n/4], c/2}],{n,1,4}];
    bot = Table[N[{a Cos[2\[Pi] n/4], a Sin[2\[Pi] n/4],-c/2}],{n,1,4}];
    sidet1 = {N[{ a, 0, c/2}],N[{ a+b, 0, 0}],N[{ b, a, 0}],N[{0, a, c/2}]};
    sidet2 = {N[{ a, 0, c/2}],N[{ a+b, 0, 0}],N[{ b,-a, 0}],N[{0,-a, c/2}]};
    sidet3 = {N[{-a, 0, c/2}],N[{-a-b, 0, 0}],N[{-b, a, 0}],N[{0, a, c/2}]};
    sidet4 = {N[{-a, 0, c/2}],N[{-a-b, 0, 0}],N[{-b,-a, 0}],N[{0,-a, c/2}]};
    sideb1 = {N[{ a, 0,-c/2}],N[{ a+b, 0, 0}],N[{ b, a, 0}],N[{0, a,-c/2}]};
    sideb2 = {N[{ a, 0,-c/2}],N[{ a+b, 0, 0}],N[{ b,-a, 0}],N[{0,-a,-c/2}]};
    sideb3 = {N[{-a, 0,-c/2}],N[{-a-b, 0, 0}],N[{-b, a, 0}],N[{0, a,-c/2}]};
    sideb4 = {N[{-a, 0,-c/2}],N[{-a-b, 0, 0}],N[{-b,-a, 0}],N[{0,-a,-c/2}]};  \
               
    side1 =  {N[{ 0, a, c/2}],N[{ b, a, 0}],N[{ 0, a,-c/2}],N[{-b, a, 0}]};
    side2 =  {N[{ 0,-a, c/2}],N[{ b,-a, 0}],N[{ 0,-a,-c/2}],N[{-b,-a, 0}]};
    whole = Join[{Polygon[top]}   ,{Polygon[bot]},
             {Polygon[sidet1]},{Polygon[sidet2]},
             {Polygon[sidet3]},{Polygon[sidet4]},
             {Polygon[sideb1]},{Polygon[sideb2]},
             {Polygon[sideb3]},{Polygon[sideb4]},
             {Polygon[side1]} ,{Polygon[side2]}];
    Show[Graphics3D[whole],ViewPoint\[Rule]{8,4,3},PlotLabel\[Rule]\"18.1.11\"\
,LabelStyle\[Rule]{Black,20}]
  ],
  {a,1,2, Appearance\[Rule]\"Labeled\"},
  {{b,0.4},0,1, Appearance\[Rule]\"Labeled\"},
  {c,1,3, Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False,
  TrackedSymbols\[Rule]{a,b,c}
]                                                                             \
                                                                      \
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604756388522084*^9, 3.604756482031014*^9}, {
   3.6047565252018623`*^9, 3.604756742156316*^9}, {3.611150880760264*^9, 
   3.611150883995804*^9}, {3.627828195182231*^9, 3.627828214709227*^9}, {
   3.627828398436412*^9, 3.62782840271119*^9}, 3.631024747097022*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`b$$ = 
    0.4, $CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`a$$], 1, 2}, {{
       Hold[$CellContext`b$$], 0.4}, 0, 1}, {
      Hold[$CellContext`c$$], 1, 3}}, Typeset`size$$ = {500., {176., 192.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`a$4932$$ = 0, $CellContext`b$4933$$ = 
    0, $CellContext`c$4934$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`b$$ = 
        0.4, $CellContext`c$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$4932$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$4933$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$4934$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`top$, $CellContext`bot$, $CellContext`sidet1$, \
$CellContext`sidet2$, $CellContext`sidet3$, $CellContext`sidet4$, \
$CellContext`sideb1$, $CellContext`sideb2$, $CellContext`sideb3$, \
$CellContext`sideb4$, $CellContext`side1$, $CellContext`side2$, \
$CellContext`whole$}, $CellContext`top$ = Table[
           
           N[{$CellContext`a$$ Cos[2 Pi $CellContext`n/4], $CellContext`a$$ 
             Sin[2 Pi $CellContext`n/4], $CellContext`c$$/
             2}], {$CellContext`n, 1, 4}]; $CellContext`bot$ = Table[
           
           N[{$CellContext`a$$ Cos[2 Pi $CellContext`n/4], $CellContext`a$$ 
             Sin[2 Pi $CellContext`n/4], -$CellContext`c$$/
             2}], {$CellContext`n, 1, 4}]; $CellContext`sidet1$ = {
           N[{$CellContext`a$$, 0, $CellContext`c$$/2}], 
           N[{$CellContext`a$$ + $CellContext`b$$, 0, 0}], 
           N[{$CellContext`b$$, $CellContext`a$$, 0}], 
           
           N[{0, $CellContext`a$$, $CellContext`c$$/
             2}]}; $CellContext`sidet2$ = {
           N[{$CellContext`a$$, 0, $CellContext`c$$/2}], 
           N[{$CellContext`a$$ + $CellContext`b$$, 0, 0}], 
           N[{$CellContext`b$$, -$CellContext`a$$, 0}], 
           
           N[{0, -$CellContext`a$$, $CellContext`c$$/
             2}]}; $CellContext`sidet3$ = {
           N[{-$CellContext`a$$, 0, $CellContext`c$$/2}], 
           N[{-$CellContext`a$$ - $CellContext`b$$, 0, 0}], 
           N[{-$CellContext`b$$, $CellContext`a$$, 0}], 
           
           N[{0, $CellContext`a$$, $CellContext`c$$/
             2}]}; $CellContext`sidet4$ = {
           N[{-$CellContext`a$$, 0, $CellContext`c$$/2}], 
           N[{-$CellContext`a$$ - $CellContext`b$$, 0, 0}], 
           N[{-$CellContext`b$$, -$CellContext`a$$, 0}], 
           
           N[{0, -$CellContext`a$$, $CellContext`c$$/
             2}]}; $CellContext`sideb1$ = {
           N[{$CellContext`a$$, 0, -$CellContext`c$$/2}], 
           N[{$CellContext`a$$ + $CellContext`b$$, 0, 0}], 
           N[{$CellContext`b$$, $CellContext`a$$, 0}], 
           
           N[{0, $CellContext`a$$, -$CellContext`c$$/
             2}]}; $CellContext`sideb2$ = {
           N[{$CellContext`a$$, 0, -$CellContext`c$$/2}], 
           N[{$CellContext`a$$ + $CellContext`b$$, 0, 0}], 
           N[{$CellContext`b$$, -$CellContext`a$$, 0}], 
           
           N[{0, -$CellContext`a$$, -$CellContext`c$$/
             2}]}; $CellContext`sideb3$ = {
           N[{-$CellContext`a$$, 0, -$CellContext`c$$/2}], 
           N[{-$CellContext`a$$ - $CellContext`b$$, 0, 0}], 
           N[{-$CellContext`b$$, $CellContext`a$$, 0}], 
           
           N[{0, $CellContext`a$$, -$CellContext`c$$/
             2}]}; $CellContext`sideb4$ = {
           N[{-$CellContext`a$$, 0, -$CellContext`c$$/2}], 
           N[{-$CellContext`a$$ - $CellContext`b$$, 0, 0}], 
           N[{-$CellContext`b$$, -$CellContext`a$$, 0}], 
           
           N[{0, -$CellContext`a$$, -$CellContext`c$$/
             2}]}; $CellContext`side1$ = {
           N[{0, $CellContext`a$$, $CellContext`c$$/2}], 
           N[{$CellContext`b$$, $CellContext`a$$, 0}], 
           N[{0, $CellContext`a$$, -$CellContext`c$$/2}], 
           N[{-$CellContext`b$$, $CellContext`a$$, 0}]}; $CellContext`side2$ = {
           N[{0, -$CellContext`a$$, $CellContext`c$$/2}], 
           N[{$CellContext`b$$, -$CellContext`a$$, 0}], 
           N[{0, -$CellContext`a$$, -$CellContext`c$$/2}], 
           N[{-$CellContext`b$$, -$CellContext`a$$, 0}]}; $CellContext`whole$ = 
         Join[{
            Polygon[$CellContext`top$]}, {
            Polygon[$CellContext`bot$]}, {
            Polygon[$CellContext`sidet1$]}, {
            Polygon[$CellContext`sidet2$]}, {
            Polygon[$CellContext`sidet3$]}, {
            Polygon[$CellContext`sidet4$]}, {
            Polygon[$CellContext`sideb1$]}, {
            Polygon[$CellContext`sideb2$]}, {
            Polygon[$CellContext`sideb3$]}, {
            Polygon[$CellContext`sideb4$]}, {
            Polygon[$CellContext`side1$]}, {
            Polygon[$CellContext`side2$]}]; Show[
          Graphics3D[$CellContext`whole$], ViewPoint -> {8, 4, 3}, PlotLabel -> 
          "18.1.11", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{$CellContext`a$$, 1, 2, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.4}, 0, 1, Appearance -> 
         "Labeled"}, {$CellContext`c$$, 1, 3, Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {282., 289.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.604756698497572*^9, {3.604756755338097*^9, 3.604756778471013*^9}, 
   3.613814904227048*^9, 3.627828219123522*^9, 3.631024671757128*^9, {
   3.631024720434121*^9, 3.631024747846198*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.2  Miscellaneous Closed Surfaces with Edges", "Subsection",
 CellChangeTimes->{3.606250009700391*^9}],

Cell[CellGroupData[{

Cell["18.2.1  Cylinder", "Subsubsection"],

Cell[TextData[{
 "A cylinder is displayed here as a dense set of ",
 StyleBox["m",
  FontSlant->"Italic"],
 " rectangles for the side surface and ",
 StyleBox["m",
  FontSlant->"Italic"],
 "-sided polygons for the ends.  The number ",
 StyleBox["m",
  FontSlant->"Italic"],
 " should be chosen somewhat large to approach a smooth surface.  The axial \
length of the cylinder is given by ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", and the radius is given by ",
 StyleBox["a",
  FontSlant->"Italic"],
 ".  An oblique cylinder is displayed for ",
 StyleBox["c",
  FontSlant->"Italic"],
 " > 0, where ",
 StyleBox["c",
  FontSlant->"Italic"],
 " is the relative offset of the top and bottom.  The figure is also known as \
a disk when ",
 StyleBox["a",
  FontSlant->"Italic"],
 " >> ",
 StyleBox["b",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.604757425164336*^9, 3.6047574368164787`*^9}, {
  3.604757476370945*^9, 3.604757480184923*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "m", ",", "top", ",", "bot", ",", "topa", ",", "bota", ",", "t", ",", 
        "sides", ",", "whole"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", "100"}], ";", "\[IndentingNewLine]", 
       RowBox[{"top", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"N", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{"n", "/", "m"}]}], "]"}]}], "+", 
              RowBox[{"c", "/", "2"}]}], ",", 
             RowBox[{"a", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"2", "\[Pi]", " ", 
                RowBox[{"n", "/", "m"}]}], "]"}]}], ",", 
             RowBox[{"b", "/", "2"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"bot", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"N", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", "\[Pi]", " ", 
                 RowBox[{"n", "/", "m"}]}], "]"}]}], "-", 
              RowBox[{"c", "/", "2"}]}], ",", 
             RowBox[{"a", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"2", "\[Pi]", " ", 
                RowBox[{"n", "/", "m"}]}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"-", "b"}], "/", "2"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";", "\n", 
       "     ", 
       RowBox[{"topa", "=", 
        RowBox[{"Append", "[", 
         RowBox[{"top", ",", 
          RowBox[{"top", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", "\n", "     ", 
       RowBox[{"bota", "=", 
        RowBox[{"Append", "[", 
         RowBox[{"bot", ",", 
          RowBox[{"bot", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
       RowBox[{"t", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"N", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", "\[Pi]", " ", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}], "/", "m"}]}], "]"}]}], 
                "+", 
                RowBox[{"c", "/", "2"}]}], ",", 
               RowBox[{"a", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", "\[Pi]", " ", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}], "/", "m"}]}], "]"}]}], 
               ",", 
               RowBox[{"b", "/", "2"}]}], "}"}], "]"}], ",", 
            RowBox[{"N", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", "\[Pi]", " ", 
                   RowBox[{"n", "/", "m"}]}], "]"}]}], "+", 
                RowBox[{"c", "/", "2"}]}], ",", 
               RowBox[{"a", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", "\[Pi]", " ", 
                  RowBox[{"n", "/", "m"}]}], "]"}]}], ",", 
               RowBox[{"b", "/", "2"}]}], "}"}], "]"}], ",", 
            RowBox[{"N", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", "\[Pi]", " ", 
                   RowBox[{"n", "/", "m"}]}], "]"}]}], "-", 
                RowBox[{"c", "/", "2"}]}], ",", 
               RowBox[{"a", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", "\[Pi]", " ", 
                  RowBox[{"n", "/", "m"}]}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"-", "b"}], "/", "2"}]}], "}"}], "]"}], ",", 
            RowBox[{"N", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", "\[Pi]", " ", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}], "/", "m"}]}], "]"}]}], 
                "-", 
                RowBox[{"c", "/", "2"}]}], ",", 
               RowBox[{"a", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", "\[Pi]", " ", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}], "/", "m"}]}], "]"}]}], 
               ",", 
               RowBox[{
                RowBox[{"-", "b"}], "/", "2"}]}], "}"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";", "\n", 
       "     ", 
       RowBox[{"sides", "=", 
        RowBox[{"Map", "[", 
         RowBox[{"Polygon", ",", "t"}], "]"}]}], ";", "\n", "     ", 
       RowBox[{"whole", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"sides", ",", 
          RowBox[{"{", 
           RowBox[{"Polygon", "[", "top", "]"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Polygon", "[", "bot", "]"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Line", "[", "topa", "]"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Line", "[", "bota", "]"}], "}"}]}], "]"}]}], ";", "\n", 
       "     ", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Graphics3D", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"EdgeForm", "[", "]"}], ",", "whole"}], "}"}], "]"}], ",", 
         RowBox[{"ViewPoint", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"6", ",", 
            RowBox[{"-", "8"}], ",", "3"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<18.2.1\>\""}], ",", " ", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Black", ",", "20"}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "0.5"}], "}"}], ",", "0.2", ",", "1", ",", " ", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"b", ",", "2"}], "}"}], ",", "1", ",", "3", ",", " ", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "1"}], "}"}], ",", "0", ",", "2", ",", " ", 
      RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"TrackedSymbols", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]}], "\n", "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.6047570073296328`*^9, 3.604757258846384*^9}, {
  3.604757304005886*^9, 3.604757318312492*^9}, {3.6047573640909367`*^9, 
  3.6047573651124687`*^9}, {3.611150899554576*^9, 3.611150903455097*^9}, {
  3.627828439986108*^9, 3.6278284927595263`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    2, $CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.2, 1}, {{
       Hold[$CellContext`b$$], 2}, 1, 3}, {{
       Hold[$CellContext`c$$], 1}, 0, 2}}, Typeset`size$$ = {
    500., {289., 305.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$5425$$ = 
    0, $CellContext`b$5426$$ = 0, $CellContext`c$5427$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        2, $CellContext`c$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$5425$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$5426$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$5427$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`m$, $CellContext`top$, $CellContext`bot$, \
$CellContext`topa$, $CellContext`bota$, $CellContext`t$, $CellContext`sides$, \
$CellContext`whole$}, $CellContext`m$ = 100; $CellContext`top$ = Table[
           
           N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n/$CellContext`m$)] + $CellContext`c$$/
              2, $CellContext`a$$ 
             Sin[2 Pi ($CellContext`n/$CellContext`m$)], $CellContext`b$$/
             2}], {$CellContext`n, 1, $CellContext`m$}]; $CellContext`bot$ = 
         Table[
           
           N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n/$CellContext`m$)] - $CellContext`c$$/
             2, $CellContext`a$$ 
             Sin[2 Pi ($CellContext`n/$CellContext`m$)], (-$CellContext`b$$)/
             2}], {$CellContext`n, 1, $CellContext`m$}]; $CellContext`topa$ = 
         Append[$CellContext`top$, 
           Part[$CellContext`top$, 1]]; $CellContext`bota$ = 
         Append[$CellContext`bot$, 
           Part[$CellContext`bot$, 1]]; $CellContext`t$ = Table[{
            
            N[{$CellContext`a$$ 
               Cos[2 Pi (($CellContext`n - 
                   1)/$CellContext`m$)] + $CellContext`c$$/
               2, $CellContext`a$$ 
              Sin[2 Pi (($CellContext`n - 
                  1)/$CellContext`m$)], $CellContext`b$$/2}], 
            
            N[{$CellContext`a$$ 
               Cos[2 Pi ($CellContext`n/$CellContext`m$)] + $CellContext`c$$/
               2, $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n/$CellContext`m$)], $CellContext`b$$/
              2}], 
            
            N[{$CellContext`a$$ 
               Cos[2 Pi ($CellContext`n/$CellContext`m$)] - $CellContext`c$$/
              2, $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n/$CellContext`m$)], (-$CellContext`b$$)/
              2}], 
            
            N[{$CellContext`a$$ 
               Cos[2 Pi (($CellContext`n - 
                   1)/$CellContext`m$)] - $CellContext`c$$/
              2, $CellContext`a$$ 
              Sin[2 Pi (($CellContext`n - 
                  1)/$CellContext`m$)], (-$CellContext`b$$)/
              2}]}, {$CellContext`n, 
            1, $CellContext`m$}]; $CellContext`sides$ = 
         Map[Polygon, $CellContext`t$]; $CellContext`whole$ = 
         Join[$CellContext`sides$, {
            Polygon[$CellContext`top$]}, {
            Polygon[$CellContext`bot$]}, {
            Line[$CellContext`topa$]}, {
            Line[$CellContext`bota$]}]; Show[
          Graphics3D[{
            EdgeForm[], $CellContext`whole$}], ViewPoint -> {6, -8, 3}, 
          PlotLabel -> "18.2.1", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.2, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 2}, 1, 3, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 1}, 0, 2, Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {395., 402.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6047572890851307`*^9, {3.60475732071434*^9, 3.604757375816486*^9}, 
   3.613815005662274*^9, 3.62782845729338*^9, 3.62782849452617*^9, 
   3.6278287741070137`*^9, 3.631024952132112*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.2.2  Cone", "Subsubsection"],

Cell[TextData[{
 "A cone is displayed here as a dense set of ",
 StyleBox["m",
  FontSlant->"Italic"],
 " triangles for the side surface and an ",
 StyleBox["m",
  FontSlant->"Italic"],
 "-sided polygon for the base.  The number ",
 StyleBox["m",
  FontSlant->"Italic"],
 " should be chosen somewhat large to approach a smooth surface.  The height \
of the cone is ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", and the radius of the circular base is given by ",
 StyleBox["a",
  FontSlant->"Italic"],
 ".  An oblique cone is displayed for ",
 StyleBox["c",
  FontSlant->"Italic"],
 " > 0, where ",
 StyleBox["c",
  FontSlant->"Italic"],
 " is the displacement of the apex from the axis normal to the center of the \
base.  "
}], "Text",
 CellChangeTimes->{{3.604757575439377*^9, 3.6047575774636908`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{base,basea,t,sides,whole},
    m = 100; (*number of sections to represent main body of cone*)
    base = Table[N[{a Cos[2\[Pi] n/m],a Sin[2\[Pi] n/m], 0}],{n,1,m}];
    basea = Append[base, base[[1]]];
    t = Table[{N[{a Cos[2\[Pi](n-1)/m],a Sin[2\[Pi](n-1)/m], 0}],
           N[{a Cos[2\[Pi] n/m],a Sin[2\[Pi] n/m], 0}],
           N[{c,0,b}]},
           {n,1,m}];
    sides = Map[Polygon,t];
    whole = Join[sides,{Polygon[base]},{Line[basea]}];
    Show[Graphics3D[{EdgeForm[],whole}],ViewPoint\[Rule]{8,-10,4},PlotLabel\
\[Rule]\"18.2.2\", LabelStyle\[Rule]{Black,20}]
  ],
  {{a,0.5},0.2,1, Appearance\[Rule]\"Labeled\"},
  {{b,2},1,3, Appearance\[Rule]\"Labeled\"},
  {{c,1},0,2, Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False,
  TrackedSymbols\[Rule]{a,b,c}
]

\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604757590389779*^9, 3.604757680805813*^9}, {
   3.604757715016734*^9, 3.604757722824565*^9}, {3.6111509128840437`*^9, 
   3.611150920519598*^9}, 3.611152891592976*^9, {3.627828521510744*^9, 
   3.627828534917756*^9}, {3.6278287015352793`*^9, 3.627828704832412*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0.5, $CellContext`b$$ = 
    2, $CellContext`c$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 0.5}, 0.2, 1}, {{
       Hold[$CellContext`b$$], 2}, 1, 3}, {{
       Hold[$CellContext`c$$], 1}, 0, 2}}, Typeset`size$$ = {
    500., {343., 358.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$5671$$ = 
    0, $CellContext`b$5672$$ = 0, $CellContext`c$5673$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.5, $CellContext`b$$ = 
        2, $CellContext`c$$ = 1}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$5671$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$5672$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$5673$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`base$, $CellContext`basea$, $CellContext`t$, \
$CellContext`sides$, $CellContext`whole$}, $CellContext`m = 
         100; $CellContext`base$ = Table[
           
           N[{$CellContext`a$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m], $CellContext`a$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m], 0}], {$CellContext`n, 
            1, $CellContext`m}]; $CellContext`basea$ = 
         Append[$CellContext`base$, 
           Part[$CellContext`base$, 1]]; $CellContext`t$ = Table[{
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 1)/$CellContext`m], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m], 0}], 
            N[{$CellContext`c$$, 0, $CellContext`b$$}]}, {$CellContext`n, 
            1, $CellContext`m}]; $CellContext`sides$ = 
         Map[Polygon, $CellContext`t$]; $CellContext`whole$ = 
         Join[$CellContext`sides$, {
            Polygon[$CellContext`base$]}, {
            Line[$CellContext`basea$]}]; Show[
          Graphics3D[{
            EdgeForm[], $CellContext`whole$}], ViewPoint -> {8, -10, 4}, 
          PlotLabel -> "18.2.2", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a$$, 0.5}, 0.2, 1, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 2}, 1, 3, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 1}, 0, 2, Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {449., 456.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.6047577496354628`*^9, 3.6047577702726297`*^9}, 
   3.613815035806684*^9, 3.627828539976557*^9, 3.627828767858724*^9, 
   3.631024992761345*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.2.3  Frustrum of a Cone", "Subsubsection"],

Cell[TextData[{
 "A frustrum is displayed here as a dense set of ",
 StyleBox["m",
  FontSlant->"Italic"],
 " triangles for the side surface and ",
 StyleBox["m",
  FontSlant->"Italic"],
 "-sided polygon for the base and the top.  The number ",
 StyleBox["m",
  FontSlant->"Italic"],
 " should be chosen somewhat large to approach a smooth surface.  The height \
of the frustrum is ",
 StyleBox["b;",
  FontSlant->"Italic"],
 " the radius of the base is given by",
 StyleBox[" a;",
  FontSlant->"Italic"],
 " and the radius of the top is given by",
 StyleBox[" c",
  FontSlant->"Italic"],
 ".  The figure degenerates to a cone for ",
 StyleBox["c",
  FontSlant->"Italic"],
 " = 0."
}], "Text",
 CellChangeTimes->{{3.604757965429937*^9, 3.6047579703344*^9}, {
  3.6047580952229633`*^9, 3.604758110243496*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{top,base,topa,basea,sides,whole},
    m = 100; (*number of sections to represent main body of cone*)
    top  = Table[N[{c Cos[2\[Pi] n/m],c Sin[2\[Pi] n/m], b}],{n,1,m}];
    base = Table[N[{a Cos[2\[Pi] n/m],a Sin[2\[Pi] n/m], 0}],{n,1,m}];
    topa = Append[top, top[[1]]];
    basea = Append[base, base[[1]]];
    t = Table[{N[{a Cos[2\[Pi] (n-1)/m],a Sin[2\[Pi] (n-1)/m], 0}],
           N[{a Cos[2\[Pi]     n/m],a Sin[2\[Pi]     n/m], 0}],
           N[{c Cos[2\[Pi]     n/m],c Sin[2\[Pi]     n/m], b}],
           N[{c Cos[2\[Pi] (n-1)/m],c Sin[2\[Pi] (n-1)/m], b}]},
           {n,1,m}];
    sides = Map[Polygon,t];
    whole = \
Join[sides,{Polygon[base]},{Polygon[top]},{Line[topa]},{Line[basea]}];
    Show[Graphics3D[{EdgeForm[],whole}],ViewPoint\[Rule]{8,-10,3},PlotLabel\
\[Rule]\"18.2.3\", LabelStyle\[Rule]{Black,20}]
  ],
  {{a,1},0.5,2, Appearance\[Rule]\"Labeled\"},
  {{b,2},0.5,3, Appearance\[Rule]\"Labeled\"},
  {{c,a/2.},0,a, Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False,
  TrackedSymbols\[Rule]{a,b,c}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.604757833727903*^9, 3.604757945336878*^9}, {
   3.6047579894825583`*^9, 3.604758055833941*^9}, {3.611150927559794*^9, 
   3.6111509331323013`*^9}, 3.61115289167302*^9, {3.613815212610825*^9, 
   3.6138152131588383`*^9}, {3.6278285623577757`*^9, 3.627828591479877*^9}, {
   3.6278287116835833`*^9, 3.627828714134305*^9}, 3.631025035673367*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`b$$ = 
    2, $CellContext`c$$ = 0.5 $CellContext`a$$, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 1}, 0.5, 2}, {{
       Hold[$CellContext`b$$], 2}, 0.5, 3}, {{
       Hold[$CellContext`c$$], 0.5 $CellContext`a$$}, 0, 
      Dynamic[$CellContext`a$$]}}, Typeset`size$$ = {500., {238., 254.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`a$6318$$ = 0, $CellContext`b$6319$$ = 
    0, $CellContext`c$6320$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`b$$ = 
        2, $CellContext`c$$ = 0.5 $CellContext`a$$}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$6318$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$6319$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$6320$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`top$, $CellContext`base$, $CellContext`topa$, \
$CellContext`basea$, $CellContext`sides$, $CellContext`whole$}, \
$CellContext`m = 100; $CellContext`top$ = Table[
           
           N[{$CellContext`c$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m], $CellContext`c$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m], $CellContext`b$$}], \
{$CellContext`n, 1, $CellContext`m}]; $CellContext`base$ = Table[
           
           N[{$CellContext`a$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m], $CellContext`a$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m], 0}], {$CellContext`n, 
            1, $CellContext`m}]; $CellContext`topa$ = 
         Append[$CellContext`top$, 
           Part[$CellContext`top$, 1]]; $CellContext`basea$ = 
         Append[$CellContext`base$, 
           Part[$CellContext`base$, 1]]; $CellContext`t = Table[{
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 1)/$CellContext`m], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m], 0}], 
            
            N[{$CellContext`c$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m], $CellContext`c$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m], $CellContext`b$$}], 
            
            N[{$CellContext`c$$ 
              Cos[2 Pi ($CellContext`n - 1)/$CellContext`m], $CellContext`c$$ 
              Sin[2 Pi ($CellContext`n - 
                 1)/$CellContext`m], $CellContext`b$$}]}, {$CellContext`n, 
            1, $CellContext`m}]; $CellContext`sides$ = 
         Map[Polygon, $CellContext`t]; $CellContext`whole$ = 
         Join[$CellContext`sides$, {
            Polygon[$CellContext`base$]}, {
            Polygon[$CellContext`top$]}, {
            Line[$CellContext`topa$]}, {
            Line[$CellContext`basea$]}]; Show[
          Graphics3D[{
            EdgeForm[], $CellContext`whole$}], ViewPoint -> {8, -10, 3}, 
          PlotLabel -> "18.2.3", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a$$, 1}, 0.5, 2, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 2}, 0.5, 3, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.5 $CellContext`a$$}, 0, 
         Dynamic[$CellContext`a$$], Appearance -> "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {344., 351.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604758058652169*^9, 3.604758083704668*^9}, {
   3.613815050076263*^9, 3.613815147573854*^9}, {3.613815214955652*^9, 
   3.613815249524048*^9}, 3.62782859495889*^9, 3.6278287629413013`*^9, {
   3.631025010186597*^9, 3.631025042638041*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.2.4  Hemisphere", "Subsubsection"],

Cell[TextData[{
 "The hemisphere can be generalized to a hemi-ellipsoid with separate \
parameters (",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["c",
  FontSlant->"Italic"],
 ") for the radius of the base and the height of the apex from the base.  \
Using ",
 StyleBox["a",
  FontSlant->"Italic"],
 " = ",
 StyleBox["c",
  FontSlant->"Italic"],
 " gives the hemisphere.  The figure is constructed with a dense set of \
quadrilaterals at small increments of the azimuthal and polar angles given by \
2\[Pi]/",
 StyleBox["m",
  FontSlant->"Italic"],
 " and 2\[Pi]/",
 StyleBox["l",
  FontSlant->"Italic"],
 ", respectively."
}], "Text",
 CellChangeTimes->{{3.6047581502565603`*^9, 3.6047581568479*^9}, {
  3.60477084332447*^9, 3.6047709322442017`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
  Module[{m,l,bot,bota,t,r1,r2,z1,z2,s,hemi,whole},
    m = 100;
    l = 50;
    bot = Table[N[{a Cos[2\[Pi] n/m], a Sin[2\[Pi] n/m],0}],{n,1,m}];
    bota = Append[bot,bot[[1]]];
    t = {};
    Do[r1 = N[a Cos[(j-1)\[Pi]/(2l)]];
       r2 = N[a Cos[j \[Pi]/(2l)]];
       z1 = N[c Sin[(j-1)\[Pi]/(2l)]];
       z2 = N[c Sin[j \[Pi]/(2l)]];
       s = Table[{N[{r1 Cos[2\[Pi] (n-1)/m], r1 Sin[2\[Pi] (n-1)/m],z1}],
                  N[{r1 Cos[2\[Pi]     n/m], r1 Sin[2\[Pi]     n/m],z1}],
                  N[{r2 Cos[2\[Pi]     n/m], r2 Sin[2\[Pi]     n/m],z2}],
                  N[{r2 Cos[2\[Pi] (n-1)/m], r2 Sin[2\[Pi] (n-1)/m],z2}]},
                  {n,1,m}];
    t=Join[t,s],{j,1,l}];
    hemi = Map[Polygon,t];
    whole = Join[hemi,{Polygon[bot]},{Line[bota]}];
    Show[Graphics3D[{EdgeForm[],whole}],ViewPoint\[Rule]{6,-8,-2},PlotLabel\
\[Rule]\"18.2.4\", LabelStyle\[Rule]{Black,20}]
  ],
  {{a,1},0.2,1, Appearance\[Rule]\"Labeled\"},
  {{c,1},0.2,1, Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False,
  TrackedSymbols\[Rule]{a,c}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.6047581893040543`*^9, 3.6047582082822*^9}, {
   3.6047583516290083`*^9, 3.6047584321228848`*^9}, {3.604770290777587*^9, 
   3.604770406598238*^9}, {3.60477046667527*^9, 3.6047704677306747`*^9}, {
   3.6047705124530773`*^9, 3.604770522124271*^9}, {3.60477075498886*^9, 
   3.60477075668757*^9}, {3.604770799810812*^9, 3.60477081514291*^9}, {
   3.604770960852648*^9, 3.604770980461*^9}, {3.611150939609375*^9, 
   3.61115094431964*^9}, 3.611152891771418*^9, {3.627828614508029*^9, 
   3.627828626955349*^9}, {3.627828721734016*^9, 3.627828724209363*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`c$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 1}, 0.2, 1}, {{
       Hold[$CellContext`c$$], 1}, 0.2, 1}}, Typeset`size$$ = {
    500., {146., 162.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$6562$$ = 
    0, $CellContext`c$6563$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`c$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$6562$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$6563$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`m$, $CellContext`l$, $CellContext`bot$, \
$CellContext`bota$, $CellContext`t$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`z1$, $CellContext`z2$, $CellContext`s$, $CellContext`hemi$, \
$CellContext`whole$}, $CellContext`m$ = 100; $CellContext`l$ = 
         50; $CellContext`bot$ = Table[
           
           N[{$CellContext`a$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`a$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m$], 0}], {$CellContext`n, 
            1, $CellContext`m$}]; $CellContext`bota$ = 
         Append[$CellContext`bot$, 
           Part[$CellContext`bot$, 1]]; $CellContext`t$ = {}; 
        Do[$CellContext`r1$ = 
           N[$CellContext`a$$ 
             Cos[($CellContext`j - 1) Pi/(
               2 $CellContext`l$)]]; $CellContext`r2$ = 
           N[$CellContext`a$$ 
             Cos[$CellContext`j Pi/(2 $CellContext`l$)]]; $CellContext`z1$ = 
           N[$CellContext`c$$ 
             Sin[($CellContext`j - 1) Pi/(
               2 $CellContext`l$)]]; $CellContext`z2$ = 
           N[$CellContext`c$$ 
             Sin[$CellContext`j Pi/(2 $CellContext`l$)]]; $CellContext`s$ = 
           Table[{
              
              N[{$CellContext`r1$ 
                Cos[2 Pi ($CellContext`n - 
                   1)/$CellContext`m$], $CellContext`r1$ 
                Sin[2 Pi ($CellContext`n - 
                   1)/$CellContext`m$], $CellContext`z1$}], 
              
              N[{$CellContext`r1$ 
                Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`r1$ 
                Sin[2 Pi $CellContext`n/$CellContext`m$], $CellContext`z1$}], 
              
              N[{$CellContext`r2$ 
                Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`r2$ 
                Sin[2 Pi $CellContext`n/$CellContext`m$], $CellContext`z2$}], 
              
              N[{$CellContext`r2$ 
                Cos[2 Pi ($CellContext`n - 
                   1)/$CellContext`m$], $CellContext`r2$ 
                Sin[2 Pi ($CellContext`n - 
                   1)/$CellContext`m$], $CellContext`z2$}]}, {$CellContext`n, 
              1, $CellContext`m$}]; $CellContext`t$ = 
           Join[$CellContext`t$, $CellContext`s$], {$CellContext`j, 
           1, $CellContext`l$}]; $CellContext`hemi$ = 
         Map[Polygon, $CellContext`t$]; $CellContext`whole$ = 
         Join[$CellContext`hemi$, {
            Polygon[$CellContext`bot$]}, {
            Line[$CellContext`bota$]}]; Show[
          Graphics3D[{
            EdgeForm[], $CellContext`whole$}], ViewPoint -> {6, -8, -2}, 
          PlotLabel -> "18.2.4", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a$$, 1}, 0.2, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 1}, 0.2, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`c$$}}, 
      "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {230., 237.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604770455961267*^9, 3.6047704895078583`*^9}, 
   3.604770760451878*^9, 3.604770982856639*^9, 3.61381526772898*^9, 
   3.6278286339112053`*^9, 3.6278287544227743`*^9, 3.6310250638253736`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["18.2.5  Rectangular Torus", "Subsubsection"],

Cell[TextData[{
 "This figure is a torus whose cross-section is rectangular.  The display is \
built by using a dense set of ",
 StyleBox["m",
  FontSlant->"Italic"],
 " rectangles to form the sides, top, and bottom of the figure.  The number ",
 StyleBox["m",
  FontSlant->"Italic"],
 " should be chosen somewhat large to approach a smooth surface.  The outside \
radius is given by ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", and the inside radius is given by ",
 StyleBox["b",
  FontSlant->"Italic"],
 " (",
 StyleBox["b",
  FontSlant->"Italic"],
 " < ",
 StyleBox["a",
  FontSlant->"Italic"],
 ").  The height of a vertical cross-section is given by ",
 StyleBox["c, ",
  FontSlant->"Italic"],
 "thus giving a profile with height ",
 StyleBox["c",
  FontSlant->"Italic"],
 " and width ",
 StyleBox["a",
  FontSlant->"Italic"],
 " - ",
 StyleBox["b",
  FontSlant->"Italic"],
 ".  For ",
 StyleBox["c",
  FontSlant->"Italic"],
 " << ",
 StyleBox["a",
  FontSlant->"Italic"],
 " - ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", the figure is commonly called a \[OpenCurlyDoubleQuote]washer\
\[CloseCurlyDoubleQuote].  For ",
 StyleBox["b",
  FontSlant->"Italic"],
 " = 0, the figure degenerates to a cylinder."
}], "Text",
 CellChangeTimes->{{3.60475854308101*^9, 3.604758637187099*^9}, {
  3.60477150114834*^9, 3.604771523184724*^9}, {3.613815313686859*^9, 
  3.613815316910019*^9}}],

Cell[CellGroupData[{

Cell["\<\
Manipulate[
Module[{m,t1,t2,t3,t4,boto,botoa,boti,botia,opo,topoa,topi,topia,sides1,\
sides2,top,bot,whole},
    m = 100; (*number of rectangles used to represent figure*)
    t1 = Table[{N[{a Cos[2\[Pi] (n-1)/m], a Sin[2\[Pi] (n-1)/m], c}],
            N[{a Cos[2\[Pi]     n/m], a Sin[2\[Pi]     n/m], c}],
            N[{a Cos[2\[Pi]     n/m], a Sin[2\[Pi]     n/m], 0}],
            N[{a Cos[2\[Pi] (n-1)/m], a Sin[2\[Pi] (n-1)/m], 0}]},
            {n,1,m}];
    t2 = Table[{N[{b Cos[2\[Pi] (n-1)/m], b Sin[2\[Pi] (n-1)/m], c}],
            N[{b Cos[2\[Pi]     n/m], b Sin[2\[Pi]     n/m], c}],
            N[{b Cos[2\[Pi]     n/m], b Sin[2\[Pi]     n/m], 0}],
            N[{b Cos[2\[Pi] (n-1)/m], b Sin[2\[Pi] (n-1)/m], 0}]},
            {n,1,m}];
    t3 = Table[{N[{a Cos[2\[Pi] (n-1)/m], a Sin[2\[Pi] (n-1)/m], c}],
            N[{a Cos[2\[Pi]     n/m], a Sin[2\[Pi]     n/m], c}],
            N[{b Cos[2\[Pi]     n/m], b Sin[2\[Pi]     n/m], c}],
            N[{b Cos[2\[Pi] (n-1)/m], b Sin[2\[Pi] (n-1)/m], c}]},
            {n,1,m}];
    t4 = Table[{N[{a Cos[2\[Pi] (n-1)/m], a Sin[2\[Pi] (n-1)/m], 0}],
            N[{a Cos[2\[Pi]     n/m], a Sin[2\[Pi]     n/m], 0}],
            N[{b Cos[2\[Pi]     n/m], b Sin[2\[Pi]     n/m], 0}],
            N[{b Cos[2\[Pi] (n-1)/m], b Sin[2\[Pi] (n-1)/m], 0}]},
            {n,1,m}];
    boto = Table[N[{a Cos[2\[Pi] n/m], a Sin[2\[Pi] n/m],0}],{n,1,m}];
    botoa = Append[boto,boto[[1]]];
    boti = Table[N[{b Cos[2\[Pi] n/m], b Sin[2\[Pi] n/m],0}],{n,1,m}];
    botia = Append[boti,boti[[1]]];
    topo = Table[N[{a Cos[2\[Pi] n/m], a Sin[2\[Pi] n/m],c}],{n,1,m}];
    topoa = Append[topo,topo[[1]]];
    topi = Table[N[{b Cos[2\[Pi] n/m], b Sin[2\[Pi] n/m],c}],{n,1,m}];
    topia = Append[topi,topi[[1]]];
    sides1 = Map[Polygon,t1];
    sides2 = Map[Polygon,t2];
    top = Map[Polygon,t3];
    bot = Map[Polygon,t4];
    whole = \
Join[sides1,sides2,top,bot,{Line[botoa]},{Line[botia]},{Line[topoa]},{Line[\
topia]}];
    Show[Graphics3D[{EdgeForm[],whole}],ViewPoint\[Rule]{6,6,7},PlotLabel\
\[Rule]\"18.2.5\", LabelStyle\[Rule]{Black,20}]
  ],
  {{a,1},1,2, Appearance\[Rule]\"Labeled\"},
  {{b,0.5},0,a, Appearance\[Rule]\"Labeled\"},
  {{c,0.5},0,1, Appearance\[Rule]\"Labeled\"},
  ContinuousAction\[Rule]False,
  TrackedSymbols\[Rule]{a,b,c}
]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.6047710505728807`*^9, 3.6047713624550257`*^9}, {
   3.604771415276561*^9, 3.604771415869817*^9}, {3.611150955723406*^9, 
   3.611150961744711*^9}, 3.61115289186992*^9, {3.621726035961747*^9, 
   3.6217260376862793`*^9}, {3.62782865003364*^9, 3.627828668280746*^9}, {
   3.6278287323215837`*^9, 3.627828735360137*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 1, $CellContext`b$$ = 
    0.5, $CellContext`c$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a$$], 1}, 1, 2}, {{
       Hold[$CellContext`b$$], 0.5}, 0, 
      Dynamic[$CellContext`a$$]}, {{
       Hold[$CellContext`c$$], 0.5}, 0, 1}}, Typeset`size$$ = {
    500., {202., 217.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`a$6796$$ = 
    0, $CellContext`b$6797$$ = 0, $CellContext`c$6798$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 1, $CellContext`b$$ = 
        0.5, $CellContext`c$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`a$$, $CellContext`a$6796$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$6797$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$6798$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`m$, $CellContext`t1$, $CellContext`t2$, \
$CellContext`t3$, $CellContext`t4$, $CellContext`boto$, $CellContext`botoa$, \
$CellContext`boti$, $CellContext`botia$, $CellContext`opo$, \
$CellContext`topoa$, $CellContext`topi$, $CellContext`topia$, \
$CellContext`sides1$, $CellContext`sides2$, $CellContext`top$, \
$CellContext`bot$, $CellContext`whole$}, $CellContext`m$ = 
         100; $CellContext`t1$ = Table[{
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`c$$}], 
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$], $CellContext`c$$}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m$], 
              0}]}, {$CellContext`n, 1, $CellContext`m$}]; $CellContext`t2$ = 
         Table[{
            
            N[{$CellContext`b$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`b$$ 
              Sin[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`c$$}], 
            
            N[{$CellContext`b$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`b$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$], $CellContext`c$$}], 
            
            N[{$CellContext`b$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`b$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$], 0}], 
            
            N[{$CellContext`b$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`b$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m$], 
              0}]}, {$CellContext`n, 1, $CellContext`m$}]; $CellContext`t3$ = 
         Table[{
            
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`c$$}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$], $CellContext`c$$}], 
            
            N[{$CellContext`b$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`b$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$], $CellContext`c$$}], 
            
            N[{$CellContext`b$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`b$$ 
              Sin[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`c$$}]}, {$CellContext`n, 
            1, $CellContext`m$}]; $CellContext`t4$ = Table[{
            N[{$CellContext`a$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`a$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m$], 0}], 
            
            N[{$CellContext`a$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`a$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$], 0}], 
            
            N[{$CellContext`b$$ 
              Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`b$$ 
              Sin[2 Pi $CellContext`n/$CellContext`m$], 0}], 
            
            N[{$CellContext`b$$ 
              Cos[2 Pi ($CellContext`n - 
                 1)/$CellContext`m$], $CellContext`b$$ 
              Sin[2 Pi ($CellContext`n - 1)/$CellContext`m$], 
              0}]}, {$CellContext`n, 1, $CellContext`m$}]; $CellContext`boto$ = 
         Table[
           
           N[{$CellContext`a$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`a$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m$], 0}], {$CellContext`n, 
            1, $CellContext`m$}]; $CellContext`botoa$ = 
         Append[$CellContext`boto$, 
           Part[$CellContext`boto$, 1]]; $CellContext`boti$ = Table[
           
           N[{$CellContext`b$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`b$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m$], 0}], {$CellContext`n, 
            1, $CellContext`m$}]; $CellContext`botia$ = 
         Append[$CellContext`boti$, 
           Part[$CellContext`boti$, 1]]; $CellContext`topo = Table[
           
           N[{$CellContext`a$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`a$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m$], $CellContext`c$$}], \
{$CellContext`n, 1, $CellContext`m$}]; $CellContext`topoa$ = 
         Append[$CellContext`topo, 
           Part[$CellContext`topo, 1]]; $CellContext`topi$ = Table[
           
           N[{$CellContext`b$$ 
             Cos[2 Pi $CellContext`n/$CellContext`m$], $CellContext`b$$ 
             Sin[2 Pi $CellContext`n/$CellContext`m$], $CellContext`c$$}], \
{$CellContext`n, 1, $CellContext`m$}]; $CellContext`topia$ = 
         Append[$CellContext`topi$, 
           Part[$CellContext`topi$, 1]]; $CellContext`sides1$ = 
         Map[Polygon, $CellContext`t1$]; $CellContext`sides2$ = 
         Map[Polygon, $CellContext`t2$]; $CellContext`top$ = 
         Map[Polygon, $CellContext`t3$]; $CellContext`bot$ = 
         Map[Polygon, $CellContext`t4$]; $CellContext`whole$ = 
         Join[$CellContext`sides1$, $CellContext`sides2$, $CellContext`top$, \
$CellContext`bot$, {
            Line[$CellContext`botoa$]}, {
            Line[$CellContext`botia$]}, {
            Line[$CellContext`topoa$]}, {
            Line[$CellContext`topia$]}]; Show[
          Graphics3D[{
            EdgeForm[], $CellContext`whole$}], ViewPoint -> {6, 6, 7}, 
          PlotLabel -> "18.2.5", LabelStyle -> {Black, 20}]], 
      "Specifications" :> {{{$CellContext`a$$, 1}, 1, 2, Appearance -> 
         "Labeled"}, {{$CellContext`b$$, 0.5}, 0, 
         Dynamic[$CellContext`a$$], Appearance -> 
         "Labeled"}, {{$CellContext`c$$, 0.5}, 0, 1, Appearance -> 
         "Labeled"}}, 
      "Options" :> {
       ContinuousAction -> False, 
        TrackedSymbols -> {$CellContext`a$$, $CellContext`b$$, \
$CellContext`c$$}}, "DefaultOptions" :> {LabelStyle -> {
          GrayLevel[0], 20}}],
     ImageSizeCache->{555., {308., 315.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.604771376193119*^9, 3.604771477078298*^9}, 
   3.613815290606073*^9, 3.6217260162615337`*^9, 3.627828676006154*^9, 
   3.62782874835907*^9, 3.631025090833692*^9}]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
WindowSize->{955, 888},
WindowMargins->{{-17, Automatic}, {Automatic, 0}},
Magnification:>1.25 Inherited,
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 25, \
2016)",
StyleDefinitions->"myStyles.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 125, 2, 37, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1614, 39, 913, 18, 246, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[2564, 62, 58, 0, 51, "Section"],
Cell[2625, 64, 558, 8, 109, "Text"],
Cell[CellGroupData[{
Cell[3208, 76, 65, 0, 57, "Subsection"],
Cell[3276, 78, 567, 9, 408, "Text"],
Cell[3846, 89, 21, 0, 408, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3904, 94, 47, 0, 46, "Subsection"],
Cell[CellGroupData[{
Cell[3976, 98, 38, 0, 43, "Subsubsection"],
Cell[4017, 100, 729, 15, 212, "Text"],
Cell[CellGroupData[{
Cell[4771, 119, 6149, 159, 803, "Input"],
Cell[10923, 280, 4454, 91, 1516, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[15426, 377, 43, 0, 32, "Subsubsection"],
Cell[15472, 379, 854, 22, 257, "Text"],
Cell[CellGroupData[{
Cell[16351, 405, 18192, 453, 2007, "Input"],
Cell[34546, 860, 7809, 161, 1696, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[42404, 1027, 42, 0, 32, "Subsubsection"],
Cell[42449, 1029, 1050, 31, 165, "Text"],
Cell[CellGroupData[{
Cell[43524, 1064, 1379, 29, 578, "Input"],
Cell[44906, 1095, 4942, 100, 931, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[49897, 1201, 41, 0, 32, "Subsubsection"],
Cell[49941, 1203, 594, 16, 170, "Text"],
Cell[CellGroupData[{
Cell[50560, 1223, 1228, 26, 658, "Input"],
Cell[51791, 1251, 4594, 92, 1338, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[56434, 1349, 43, 0, 32, "Subsubsection"],
Cell[56480, 1351, 1427, 44, 281, "Text"],
Cell[CellGroupData[{
Cell[57932, 1399, 1693, 37, 881, "Input"],
Cell[59628, 1438, 5917, 119, 1370, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[65594, 1563, 47, 0, 32, "Subsubsection"],
Cell[65644, 1565, 842, 25, 206, "Text"],
Cell[CellGroupData[{
Cell[66511, 1594, 1619, 34, 850, "Input"],
Cell[68133, 1630, 5310, 94, 1132, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[73492, 1730, 40, 0, 32, "Subsubsection"],
Cell[73535, 1732, 848, 22, 206, "Text"],
Cell[CellGroupData[{
Cell[74408, 1758, 996, 24, 596, "Input"],
Cell[75407, 1784, 3484, 70, 1088, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[78940, 1860, 42, 0, 32, "Subsubsection"],
Cell[78985, 1862, 628, 15, 170, "Text"],
Cell[CellGroupData[{
Cell[79638, 1881, 1147, 28, 722, "Input"],
Cell[80788, 1911, 3959, 80, 1647, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[84796, 1997, 46, 0, 32, "Subsubsection"],
Cell[84845, 1999, 1105, 24, 281, "Text"],
Cell[CellGroupData[{
Cell[85975, 2027, 1369, 32, 850, "Input"],
Cell[87347, 2061, 4679, 93, 1572, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[92075, 2160, 41, 0, 32, "Subsubsection"],
Cell[92119, 2162, 574, 19, 132, "Text"],
Cell[CellGroupData[{
Cell[92718, 2185, 1270, 27, 690, "Input"],
Cell[93991, 2214, 5111, 90, 1163, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[99151, 2310, 56, 0, 32, "Subsubsection"],
Cell[99210, 2312, 819, 22, 206, "Text"],
Cell[CellGroupData[{
Cell[100054, 2338, 2134, 38, 1070, "Input"],
Cell[102191, 2378, 6637, 132, 922, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[108889, 2517, 110, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[109024, 2522, 41, 0, 53, "Subsubsection"],
Cell[109068, 2524, 957, 33, 170, "Text"],
Cell[CellGroupData[{
Cell[110050, 2561, 7695, 198, 850, "Input"],
Cell[117748, 2761, 5083, 105, 1276, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[122880, 2872, 37, 0, 40, "Subsubsection"],
Cell[122920, 2874, 804, 26, 170, "Text"],
Cell[CellGroupData[{
Cell[123749, 2904, 1147, 28, 722, "Input"],
Cell[124899, 2934, 3741, 74, 1445, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[128689, 3014, 51, 0, 40, "Subsubsection"],
Cell[128743, 3016, 808, 26, 170, "Text"],
Cell[CellGroupData[{
Cell[129576, 3046, 1482, 31, 785, "Input"],
Cell[131061, 3079, 4787, 94, 1116, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[135897, 3179, 43, 0, 40, "Subsubsection"],
Cell[135943, 3181, 764, 26, 132, "Text"],
Cell[CellGroupData[{
Cell[136732, 3211, 1696, 37, 881, "Input"],
Cell[138431, 3250, 4820, 98, 760, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[143300, 3354, 50, 0, 40, "Subsubsection"],
Cell[143353, 3356, 1386, 50, 206, "Text"],
Cell[CellGroupData[{
Cell[144764, 3410, 2700, 55, 1545, "Input"],
Cell[147467, 3467, 8683, 179, 1057, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature yx0CnMLPhXjNCAKEezEs1@0W *)
